(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    162492,       3726]*)
(*NotebookOutlinePosition[    163204,       3750]*)
(*  CellTagsIndexPosition[    163160,       3746]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The Transition to CLR", "Title"],

Cell["\<\
Computes transition from NCLR to CLR induced by rising wage premium (rising \
alpha)\
\>", "Subtitle"],

Cell[BoxData[{
    \(<< Graphics`MultipleListPlot`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\), "\[IndentingNewLine]", 
    \(Off[General::spell]\), "\[IndentingNewLine]", 
    \(Off[General::spell1]\)}], "Input"],

Cell["\<\
This version does have perfect foresight. It also allows the skilled to have \
large families. This one starts in the steady state where everyone has large \
families\
\>", "Text"],

Cell[CellGroupData[{

Cell["Setting parameters and functions of parameters", "Section"],

Cell["The preset parameter values", "Text"],

Cell[BoxData[{
    \(\(betaset =  .8;\)\), "\[IndentingNewLine]", 
    \(\(sigmaset =  .5;\)\), "\[IndentingNewLine]", 
    \(\(zset = 1;\)\), "\[IndentingNewLine]", 
    \(\(lamset =  .15;\)\), "\[IndentingNewLine]", 
    \(\(pi0set =  .05;\)\), "\[IndentingNewLine]", 
    \(\(pi1set =  .4;\)\), "\[IndentingNewLine]", 
    \(\(Pset = 1;\)\), "\[IndentingNewLine]", 
    \(\(Gset = 3;\)\), "\[IndentingNewLine]", 
    \(\(pset =  .013;\)\), "\[IndentingNewLine]", 
    \(\(lset =  .1;\)\), "\[IndentingNewLine]", 
    \(\(alphset =  .6;\)\), "\[IndentingNewLine]", 
    \(\(\(kappaset =  .5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(capshare = 0.3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(KAP = 1;\)\)}], "Input"],

Cell["\<\
Range for alpha. Alpha is constant until tstart, then increases by alphstep, \
until alphhi is reached.\
\>", "Text"],

Cell[BoxData[{
    \(\(alphlo =  .33;\)\), "\[IndentingNewLine]", 
    \(\(alphhi =  .65;\)\), "\[IndentingNewLine]", 
    \(\(alphstep =  .05;\)\), "\[IndentingNewLine]", 
    \(\(tstart = 3;\)\)}], "Input"],

Cell[BoxData[
    \(\(alfafun[time_] := 
        Min[alphhi, 
          alphlo + Max[time - tstart + 1, 0]\ alphstep];\)\)], "Input"],

Cell["\<\
Technical parameters. Periods is the number of periods over which utility is \
evaluated when computing the outcome path under CLR. iter is iterations over \
utility in the computation in the non-CLR path for a given eta path. The \
eta-path is adjusted etater times. Each time, eta is adjusted by etastep.  \
There are iter times etater iterations in total.\
\>", "Text"],

Cell[BoxData[{
    \(\(periods = 30;\)\), "\[IndentingNewLine]", 
    \(\(iter = 10;\)\), "\[IndentingNewLine]", 
    \(\(etater = 30;\)\), "\[IndentingNewLine]", 
    \(\(etastep =  .05;\)\)}], "Input"],

Cell[BoxData[
    \(\(SetOptions[ListPlot, PlotRange \[Rule] All, 
        PlotJoined \[Rule] True];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Frequently used routines", "Section"],

Cell["The utility function", "Text"],

Cell[BoxData[
    \(\(U[c_] := If[c \[LessEqual] 0, \(-10000\), c^ .5];\)\)], "Input"],

Cell["\<\
The ratio below is the ratio of skilled to unskilled labor supply\
\>", "Text"],

Cell[BoxData[{
    \(\(ws[labs_, labu_] := 
        If[\((labs < 0)\) || \((labu < 0)\), 0, 
          KAP^capshare\ \[Alpha]\ labs^\((\[Kappa] - 
                  1)\) \((\[Alpha]\ labs^\[Kappa] + \((1 - \[Alpha])\) 
                    labu^\[Kappa])\)^\((\((1 - 
                      capshare - \[Kappa])\)/\[Kappa])\)];\)\), "\
\[IndentingNewLine]", 
    \(\(wu[labs_, labu_] := 
        If[\((labs < 0)\) || \((labu < 0)\), 0, 
          KAP^capshare\ \((1 - \[Alpha])\)\ labu^\((\[Kappa] - 
                  1)\) \((\[Alpha]\ labs^\[Kappa] + \((1 - \[Alpha])\) 
                    labu^\[Kappa])\)^\((\((1 - 
                      capshare - \[Kappa])\)/\[Kappa])\)];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the outcome for a given switching time", "Section"],

Cell["\<\
This function computes the time path for utilities assuming a given switching \
time to CLR.\
\>", "Text"],

Cell[BoxData[
    \(\(outpath[xps0_, xgs0_, xpu0_, xgu0_, tzero_, tsw_] := 
        Module[{par, t, j, k, labs, 
            labu}, \[IndentingNewLine]\[IndentingNewLine]par = {\ \[Beta] \
\[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[1], \[Kappa] \[Rule] 
                kappaset}; \[IndentingNewLine]\[IndentingNewLine]Vgu = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]Vpu = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]Vgs = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]Vps = 
            Table[0, {i, 
                tsw - tzero + 
                  1}]; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]Vs = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]Vu = 
            Table[0, {i, 
                tsw - tzero + 
                  1}]; \[IndentingNewLine]\[IndentingNewLine]xgu = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]xpu = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]xgs = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]xps = 
            Table[0, {i, 
                tsw - tzero + 
                  1}]; \[IndentingNewLine]\[IndentingNewLine]pop = 
            Table[0, {i, 
                tsw - tzero + 
                  1}]; \[IndentingNewLine]\[IndentingNewLine]wui = 
            Table[0, {i, tsw - tzero}]; \[IndentingNewLine]wsi = 
            Table[0, {i, 
                tsw - tzero}]; \[IndentingNewLine]\[IndentingNewLine]eta = 
            Table[0.5, {i, tsw - tzero}]; \[IndentingNewLine]etaS = 
            Table[0.5, {i, 
                tsw - tzero}]; \[IndentingNewLine]\[IndentingNewLine]k = 
            1; \[IndentingNewLine]While[
            k \[LessEqual] etater, \[IndentingNewLine]\[IndentingNewLine]j = 
              1; \[IndentingNewLine]While[
              j \[LessEqual] 
                iter, \[IndentingNewLine]\[IndentingNewLine]xgs[\([1]\)] = 
                xgs0; \[IndentingNewLine]xps[\([1]\)] = 
                xps0; \[IndentingNewLine]xgu[\([1]\)] = 
                xgu0; \[IndentingNewLine]xpu[\([1]\)] = 
                xpu0; \[IndentingNewLine]\[IndentingNewLine]t = 
                1; \[IndentingNewLine]While[
                t \[LessEqual] 
                  tsw - tzero, \[IndentingNewLine]par = {\ \[Beta] \[Rule] 
                      betaset, 
                    z \[Rule] zset, \[Lambda] \[Rule] 
                      lamset, \[Pi]\_0 \[Rule] pi0set, \ \[Pi]\_1 \[Rule] 
                      pi1set, P \[Rule] Pset, G \[Rule] Gset, p \[Rule] pset, 
                    l \[Rule] lset, \[Alpha] \[Rule] 
                      alfafun[t + tzero - 1], \[Kappa] \[Rule] 
                      kappaset}; \[IndentingNewLine]\[IndentingNewLine]labs = 
                  xgs[\([t]\)] + xps[\([t]\)] /. 
                    par; \[IndentingNewLine]labu = \((\((1 + 
                              G\ l)\)\ xgu[\([t]\)] + xpu[\([t]\)] + 
                        G\ l\ xgs[\([t]\)])\) /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]wsi[\([t]\)] = 
                  ws[labs, labu] /. par; \[IndentingNewLine]wui[\([t]\)] = 
                  wu[labs, labu] /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]Vgu[\([t]\)] = 
                  U[wui[\([t]\)]\ \((1 + 
                              G\ l)\)] + \[Beta]\ \[Lambda]\ z \
\((\(\[Pi]\_0\) Vs[\([t + 1]\)] + \((1 - \[Pi]\_0)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vgu[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]Vpu[\([t]\)] = 
                  U[wui[\([t]\)]\  - 
                          P\ p] + \[Beta]\ \[Lambda]\ z \((\(\[Pi]\_1\) 
                              Vs[\([t + 1]\)] + \((1 - \[Pi]\_1)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vpu[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]Vgs[\([t]\)] = 
                  U[wsi[\([t]\)]\  + 
                          G\ l\ wui[\([t]\)]] + \[Beta]\ \[Lambda]\ z \((\(\
\[Pi]\_0\) Vs[\([t + 1]\)] + \((1 - \[Pi]\_0)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vgs[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]Vps[\([t]\)] = 
                  U[wsi[\([t]\)]\  - 
                          P\ p] + \[Beta]\ \[Lambda]\ z \((\(\[Pi]\_1\) 
                              Vs[\([t + 1]\)] + \((1 - \[Pi]\_1)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vps[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]Vs[\([t]\)] = 
                  Max[Vgs[\([t]\)], 
                    Vps[\([t]\)]]; \[IndentingNewLine]Vu[\([t]\)] = 
                  Max[Vgu[\([t]\)], 
                    Vpu[\([t]\)]]; \[IndentingNewLine]\[IndentingNewLine]xgu[\
\([t + 1]\)] = \((1 - \[Lambda])\) 
                        xgu[\([t]\)] + \[Lambda]\ \((1 - 
                            eta[\([t]\)])\) \((\((1 - \[Pi]\_1)\) 
                              P\ \((xpu[\([t]\)] + 
                                  xps[\([t]\)])\) + \((1 - \[Pi]\_0)\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]xpu[\([t + 
                        1]\)] = \((1 - \[Lambda])\) 
                        xpu[\([t]\)] + \[Lambda]\ eta[\([t]\)] \((\((1 - \
\[Pi]\_1)\) P\ \((xpu[\([t]\)] + xps[\([t]\)])\) + \((1 - \[Pi]\_0)\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]xgs[\([t + 
                        1]\)] = \((1 - \[Lambda])\) 
                        xgs[\([t]\)] + \[Lambda]\ \((1 - 
                            etaS[\([t]\)])\) \((\(\[Pi]\_1\) 
                              P\ \((xpu[\([t]\)] + 
                                  xps[\([t]\)])\) + \(\[Pi]\_0\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]xps[\([t + 
                        1]\)] = \((1 - \[Lambda])\) 
                        xps[\([t]\)] + \[Lambda]\ etaS[\([t]\)] \((\(\[Pi]\_1\
\) P\ \((xpu[\([t]\)] + xps[\([t]\)])\) + \(\[Pi]\_0\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]pop[\([t + 
                        1]\)] = 
                  100*\((\(\((1 + P)\) \((xps[\([t + 1]\)] + xpu[\([t + \
1]\)])\) + \((1 + G)\) \((xgs[\([t + 1]\)] + xgu[\([t + 1]\)])\)\)\/\(\((1 + \
P)\) \((xps[\([t]\)] + xpu[\([t]\)])\) + \((1 + G)\) \((xgs[\([t]\)] + \
xgu[\([t]\)])\)\) - 1)\) /. par; \[IndentingNewLine]\[IndentingNewLine]t = 
                  t + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]pop[\([1]\)] = 
                pop[\([2]\)] /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]{Vps[\([t]\)], 
                  Vgs[\([t]\)], \ Vpu[\([t]\)], \ Vgu[\([t]\)]} = \ 
                clrutil[xps[\([t]\)], xgs[\([t]\)], xpu[\([t]\)], 
                  xgu[\([t]\)], tsw]; \[IndentingNewLine]Vs[\([t]\)] = 
                Max[Vps[\([t]\)], 
                  Vgs[\([t]\)]]; \[IndentingNewLine]Vu[\([t]\)] = 
                Max[Vpu[\([t]\)], 
                  Vgu[\([t]\)]]; \[IndentingNewLine]\[IndentingNewLine]j = 
                j + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]t = 1; \[IndentingNewLine]While[
              t \[LessEqual] tsw - tzero, \[IndentingNewLine]If[
                Vgu[\([t + 1]\)] > Vpu[\([t + 1]\)], 
                eta[\([t]\)] = Max[0, eta[\([t]\)] - etastep], 
                eta[\([t]\)] = 
                  Min[1, eta[\([t]\)] + etastep]]; \[IndentingNewLine]t = 
                t + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]t = 1; \[IndentingNewLine]While[
              t \[LessEqual] tsw - tzero, \[IndentingNewLine]If[
                Vgs[\([t + 1]\)] > Vps[\([t + 1]\)], 
                etaS[\([t]\)] = Max[0, etaS[\([t]\)] - etastep], 
                etaS[\([t]\)] = 
                  Min[1, etaS[\([t]\)] + etastep]]; \[IndentingNewLine]t = 
                t + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]k = 
              k + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]{Vgu, \ eta, \ xps, \ xpu, \ 
            xgu}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(outpath2[xps0_, xgs0_, xpu0_, xgu0_, tzero_, tsw_] := 
        Module[{par, t, j, k, labs, 
            labu}, \[IndentingNewLine]\[IndentingNewLine]par = {\ \[Beta] \
\[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] 
                alfafun[tzero], \[Kappa] \[Rule] 
                kappaset}; \[IndentingNewLine]\[IndentingNewLine]Vgu = 
            Table[0, {i, tsw + 1}]; \[IndentingNewLine]Vpu = 
            Table[0, {i, tsw + 1}]; \[IndentingNewLine]Vgs = 
            Table[0, {i, tsw + 1}]; \[IndentingNewLine]Vps = 
            Table[0, {i, 
                tsw + 1}]; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]Vs = Table[0, {i, tsw + 1}]; \[IndentingNewLine]Vu = 
            Table[0, {i, 
                tsw + 1}]; \[IndentingNewLine]\[IndentingNewLine]xgu = 
            Table[0, {i, tsw + 1}]; \[IndentingNewLine]xpu = 
            Table[0, {i, tsw + 1}]; \[IndentingNewLine]xgs = 
            Table[0, {i, tsw + 1}]; \[IndentingNewLine]xps = 
            Table[0, {i, 
                tsw + 1}]; \[IndentingNewLine]\[IndentingNewLine]pop = 
            Table[0, {i, 
                tsw + 1}]; \[IndentingNewLine]\[IndentingNewLine]wui = 
            Table[0, {i, tsw}]; \[IndentingNewLine]wsi = 
            Table[0, {i, tsw}]; \[IndentingNewLine]\[IndentingNewLine]eta = 
            Table[0.5, {i, tsw}]; \[IndentingNewLine]etaS = 
            Table[0.5, {i, tsw}]; \[IndentingNewLine]\[IndentingNewLine]k = 
            1; \[IndentingNewLine]While[
            k \[LessEqual] etater, \[IndentingNewLine]\[IndentingNewLine]j = 
              1; \[IndentingNewLine]While[
              j \[LessEqual] 
                iter, \[IndentingNewLine]\[IndentingNewLine]xgs[\([tzero]\)] \
= xgs0; \[IndentingNewLine]xps[\([tzero]\)] = 
                xps0; \[IndentingNewLine]xgu[\([tzero]\)] = 
                xgu0; \[IndentingNewLine]xpu[\([tzero]\)] = 
                xpu0; \[IndentingNewLine]\[IndentingNewLine]t = 
                tzero; \[IndentingNewLine]While[
                t \[LessEqual] 
                  tsw, \[IndentingNewLine]par = {\ \[Beta] \[Rule] betaset, 
                    z \[Rule] zset, \[Lambda] \[Rule] 
                      lamset, \[Pi]\_0 \[Rule] pi0set, \ \[Pi]\_1 \[Rule] 
                      pi1set, P \[Rule] Pset, G \[Rule] Gset, p \[Rule] pset, 
                    l \[Rule] lset, \[Alpha] \[Rule] 
                      alfafun[t], \[Kappa] \[Rule] 
                      kappaset}; \[IndentingNewLine]\[IndentingNewLine]labs = 
                  xgs[\([t]\)] + xps[\([t]\)] /. 
                    par; \[IndentingNewLine]labu = \((\((1 + 
                              G\ l)\)\ xgu[\([t]\)] + xpu[\([t]\)] + 
                        G\ l\ xgs[\([t]\)])\) /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]wsi[\([t]\)] = 
                  ws[labs, labu] /. par; \[IndentingNewLine]wui[\([t]\)] = 
                  wu[labs, labu] /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]Vgu[\([t]\)] = 
                  U[wui[\([t]\)]\ \((1 + 
                              G\ l)\)] + \[Beta]\ \[Lambda]\ z \
\((\(\[Pi]\_0\) Vs[\([t + 1]\)] + \((1 - \[Pi]\_0)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vgu[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]Vpu[\([t]\)] = 
                  U[wui[\([t]\)]\  - 
                          P\ p] + \[Beta]\ \[Lambda]\ z \((\(\[Pi]\_1\) 
                              Vs[\([t + 1]\)] + \((1 - \[Pi]\_1)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vpu[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]Vgs[\([t]\)] = 
                  U[wsi[\([t]\)]\  + 
                          G\ l\ wui[\([t]\)]] + \[Beta]\ \[Lambda]\ z \((\(\
\[Pi]\_0\) Vs[\([t + 1]\)] + \((1 - \[Pi]\_0)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vgs[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]Vps[\([t]\)] = 
                  U[wsi[\([t]\)]\  - 
                          P\ p] + \[Beta]\ \[Lambda]\ z \((\(\[Pi]\_1\) 
                              Vs[\([t + 1]\)] + \((1 - \[Pi]\_1)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vps[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]Vs[\([t]\)] = 
                  Max[Vgs[\([t]\)], 
                    Vps[\([t]\)]]; \[IndentingNewLine]Vu[\([t]\)] = 
                  Max[Vgu[\([t]\)], 
                    Vpu[\([t]\)]]; \[IndentingNewLine]\[IndentingNewLine]xgu[\
\([t + 1]\)] = \((1 - \[Lambda])\) 
                        xgu[\([t]\)] + \[Lambda]\ \((1 - 
                            eta[\([t]\)])\) \((\((1 - \[Pi]\_1)\) 
                              P\ \((xpu[\([t]\)] + 
                                  xps[\([t]\)])\) + \((1 - \[Pi]\_0)\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]xpu[\([t + 
                        1]\)] = \((1 - \[Lambda])\) 
                        xpu[\([t]\)] + \[Lambda]\ eta[\([t]\)] \((\((1 - \
\[Pi]\_1)\) P\ \((xpu[\([t]\)] + xps[\([t]\)])\) + \((1 - \[Pi]\_0)\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]xgs[\([t + 
                        1]\)] = \((1 - \[Lambda])\) 
                        xgs[\([t]\)] + \[Lambda]\ \((1 - 
                            etaS[\([t]\)])\) \((\(\[Pi]\_1\) 
                              P\ \((xpu[\([t]\)] + 
                                  xps[\([t]\)])\) + \(\[Pi]\_0\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]xps[\([t + 
                        1]\)] = \((1 - \[Lambda])\) 
                        xps[\([t]\)] + \[Lambda]\ etaS[\([t]\)] \((\(\[Pi]\_1\
\) P\ \((xpu[\([t]\)] + xps[\([t]\)])\) + \(\[Pi]\_0\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]pop[\([t + 
                        1]\)] = 
                  100*\((\(\((1 + P)\) \((xps[\([t + 1]\)] + xpu[\([t + \
1]\)])\) + \((1 + G)\) \((xgs[\([t + 1]\)] + xgu[\([t + 1]\)])\)\)\/\(\((1 + \
P)\) \((xps[\([t]\)] + xpu[\([t]\)])\) + \((1 + G)\) \((xgs[\([t]\)] + \
xgu[\([t]\)])\)\) - 1)\) /. par; \[IndentingNewLine]\[IndentingNewLine]t = 
                  t + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]pop[\([1]\)] = 
                pop[\([2]\)] /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]{Vps[\([t]\)], 
                  Vgs[\([t]\)], \ Vpu[\([t]\)], \ Vgu[\([t]\)]} = \ 
                clrutil[xps[\([t]\)], xgs[\([t]\)], xpu[\([t]\)], 
                  xgu[\([t]\)], tsw]; \[IndentingNewLine]Vs[\([t]\)] = 
                Max[Vps[\([t]\)], 
                  Vgs[\([t]\)]]; \[IndentingNewLine]Vu[\([t]\)] = 
                Max[Vpu[\([t]\)], 
                  Vgu[\([t]\)]]; \[IndentingNewLine]\[IndentingNewLine]j = 
                j + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]t = tzero; \[IndentingNewLine]While[
              t \[LessEqual] tsw - 1, \[IndentingNewLine]If[
                Vgu[\([t + 1]\)] > Vpu[\([t + 1]\)], 
                eta[\([t]\)] = Max[0, eta[\([t]\)] - etastep], 
                eta[\([t]\)] = 
                  Min[1, eta[\([t]\)] + etastep]]; \[IndentingNewLine]t = 
                t + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]t = tzero; \[IndentingNewLine]While[
              t \[LessEqual] tsw - 1, \[IndentingNewLine]If[
                Vgs[\([t + 1]\)] > Vps[\([t + 1]\)], 
                etaS[\([t]\)] = Max[0, etaS[\([t]\)] - etastep], 
                etaS[\([t]\)] = 
                  Min[1, etaS[\([t]\)] + etastep]]; \[IndentingNewLine]t = 
                t + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]k = 
              k + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]{Vgu, \ eta, \ xps, \ xpu, \ 
            xgu}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing utilities once switch to CLR occurs", "Section"],

Cell["\<\
This function computes the utility of all types once CLR are in place. This \
function is called in the routine that computes the outcome path depending on \
which equilibrium is being tested.\
\>", "Text"],

Cell[BoxData[
    \(\(clrutil[xpssw_, xgssw_, xpusw_, xgusw_, tsw_] := 
        Module[{par, t, labs, 
            labu}, \[IndentingNewLine]\[IndentingNewLine]xsp = 
            xpssw; \[IndentingNewLine]xsg = xgssw; \[IndentingNewLine]xug = 
            xgusw; \[IndentingNewLine]xup = 
            xpusw; \[IndentingNewLine]\[IndentingNewLine]psps = 
            1; \[IndentingNewLine]pupps = 
            0; \[IndentingNewLine]\[IndentingNewLine]psgs = 
            0; \[IndentingNewLine]psggs = 1; \[IndentingNewLine]pupgs = 
            0; \[IndentingNewLine]\[IndentingNewLine]pspu = 
            0; \[IndentingNewLine]puppu = 
            1; \[IndentingNewLine]\[IndentingNewLine]psgu = 
            0; \[IndentingNewLine]pupgu = 0; \[IndentingNewLine]puggu = 
            1; \[IndentingNewLine]\[IndentingNewLine]VPSCLR = 
            0; \[IndentingNewLine]VGSCLR = 0; \[IndentingNewLine]VPUCLR = 
            0; \[IndentingNewLine]VGUCLR = 
            0; \[IndentingNewLine]\[IndentingNewLine]t = 
            tsw; \[IndentingNewLine]While[
            t \[LessEqual] 
              periods + 
                tsw, \[IndentingNewLine]par = {\ \[Beta] \[Rule] betaset, 
                z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                  pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
                G \[Rule] Gset, p \[Rule] pset, 
                l \[Rule] lset, \[Alpha] \[Rule] alfafun[t], \[Kappa] \[Rule] 
                  kappaset}; \[IndentingNewLine]\[IndentingNewLine]labs = 
              xsg + xsp; \[IndentingNewLine]labu = 
              xug + xup; \[IndentingNewLine]\[IndentingNewLine]wssw = 
              ws[labs, labu] /. par; \[IndentingNewLine]wusw = 
              wu[labs, labu] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]VPSCLR = 
              VPSCLR + psps\ U[wssw - p\ P] + pupps\ U[wusw - p\ P] /. 
                par; \[IndentingNewLine]VGSCLR = 
              VGSCLR + psggs\ U[wssw - p\ G] + psgs\ U[wssw - p\ P] + 
                  pupgs\ U[wusw - p\ P] /. par; \[IndentingNewLine]VPUCLR = 
              VPUCLR + pspu\ U[wssw - p\ P] + puppu\ U[wusw - p\ P] /. 
                par; \[IndentingNewLine]VGUCLR = 
              VGUCLR + puggu\ U[wusw - p\ G] + psgu\ U[wssw - p\ P] + 
                  pupgu\ U[wusw - p\ P] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]xugnew = \((1 - \
\[Lambda])\) xug /. par; \[IndentingNewLine]xsgnew = \((1 - \[Lambda])\) xsg /. 
                par; \[IndentingNewLine]xupnew = \((1 - \[Lambda])\) 
                    xup + \[Lambda] \((1 - \[Pi]\_1)\) \((P\ \((xup + 
                              xsp)\) + G\ \((xsg + xug)\))\) /. 
                par; \[IndentingNewLine]xspnew = \((1 - \[Lambda])\) 
                    xsp + \[Lambda]\ \(\[Pi]\_1\) \((P\ \((xup + xsp)\) + 
                        G\ \((xsg + xug)\))\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]pspsnew = \
\[Lambda]\ \[Beta]\ z\ \[Pi]\_1\ \((psps + 
                        pupps)\) + \((1 - \[Lambda])\)\ \[Beta]\ psps\  /. 
                par; \[IndentingNewLine]puppsnew = \[Lambda]\ \[Beta]\ z\ \
\((1 - \[Pi]\_1)\)\ \((psps + pupps)\) + \((1 - \[Lambda])\)\ \[Beta]\ pupps /. 
                par; \[IndentingNewLine]\[IndentingNewLine]psggsnew = \((1 - \
\[Lambda])\)\ \[Beta]\ psggs /. 
                par; \[IndentingNewLine]psgsnew = \[Lambda]\ \[Beta]\ z\ \
\[Pi]\_1\ \((psgs + pupgs + psggs)\) + \((1 - \[Lambda])\)\ \[Beta]\ psgs\  /. 
                par; \[IndentingNewLine]pupgsnew = \[Lambda]\ \[Beta]\ z\ \
\((1 - \[Pi]\_1)\)\ \((psgs + pupgs + 
                        psggs)\) + \((1 - \[Lambda])\)\ \[Beta]\ pupgs /. 
                par; \[IndentingNewLine]\t\[IndentingNewLine]pspunew = \
\[Lambda]\ \[Beta]\ z\ \[Pi]\_1\ \((pspu + 
                        puppu)\) + \((1 - \[Lambda])\)\ \[Beta]\ pspu\  /. 
                par; \[IndentingNewLine]puppunew = \[Lambda]\ \[Beta]\ z\ \
\((1 - \[Pi]\_1)\)\ \((pspu + puppu)\) + \((1 - \[Lambda])\)\ \[Beta]\ puppu /. 
                par; \[IndentingNewLine]\[IndentingNewLine]psgunew = \
\[Lambda]\ \[Beta]\ z\ \[Pi]\_1\ \((psgu + pupgu + 
                        puggu)\) + \((1 - \[Lambda])\)\ \[Beta]\ psgu\  /. 
                par; \[IndentingNewLine]pupgunew = \[Lambda]\ \[Beta]\ z\ \
\((1 - \[Pi]\_1)\)\ \((psgu + pupgu + 
                        puggu)\) + \((1 - \[Lambda])\)\ \[Beta]\ pupgu /. 
                par; \[IndentingNewLine]puggunew = \((1 - \[Lambda])\)\ \
\[Beta]\ puggu /. par; \[IndentingNewLine]\[IndentingNewLine]xug = 
              xugnew; \[IndentingNewLine]xup = 
              xupnew; \[IndentingNewLine]xsp = 
              xspnew; \[IndentingNewLine]xsg = 
              xsgnew; \[IndentingNewLine]\[IndentingNewLine]psps = 
              pspsnew; \[IndentingNewLine]pupps = 
              puppsnew; \[IndentingNewLine]\[IndentingNewLine]pspu = 
              pspunew; \[IndentingNewLine]puppu = 
              puppunew; \[IndentingNewLine]\[IndentingNewLine]psgu = 
              psgunew; \[IndentingNewLine]pupgu = 
              pupgunew; \[IndentingNewLine]puggu = 
              puggunew; \[IndentingNewLine]\[IndentingNewLine]psgs = 
              psgsnew; \[IndentingNewLine]pupgs = 
              pupgsnew; \[IndentingNewLine]psggs = 
              psggsnew; \[IndentingNewLine]\[IndentingNewLine]t = 
              t + 1;\[IndentingNewLine]]; \[IndentingNewLine]{\ VPSCLR, 
            VGSCLR, \ VPUCLR, \ VGUCLR}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check whether a given switching time is an equilibrium", "Section"],

Cell[TextData[{
  "The routine first computes the output path assuming that people assume \
that the switch occurs at time. For time to be an equilibrium, there has to \
be a majority in favor of CLR at time. In addition, there must be NO majority \
in favor at time-1.\n\nBelow I am storing the old steady state ratio\n",
  Cell[BoxData[
      \(\(\(\[IndentingNewLine]\)\(rhoss2 = \(-\(\(G\ \((\(-1\) + \[Pi]\_0)\) \
+ P\ \[Pi]\_1 + \@\(\(-4\)\ G\ P\ \[Pi]\_0\ \((\(-1\) + \[Pi]\_1)\) + \((G\ \
\((\(-1\) + \[Pi]\_0)\) + P\ \[Pi]\_1)\)\^2\)\)\/\(2\ P\ \((\(-1\) + \
\[Pi]\_1)\)\)\)\) /. par;\)\)\)]]
}], "Text"],

Cell[BoxData[
    \(\(checkswitch[time_] := 
        Module[{par, t, labs, 
            labu}, \[IndentingNewLine]\[IndentingNewLine]par = {\ \[Beta] \
\[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[1], \[Kappa] \[Rule] 
                kappaset}; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]outpath[0, \[Pi]\_0 /. par, 0, 1 - \[Pi]\_0 /. par, 1, 
            time]; \[IndentingNewLine]\[IndentingNewLine]vguifclr = 
            Vgu[\([time]\)]; \[IndentingNewLine]vgubefore = 
            Vgu[\([time - 
                  1]\)]; \[IndentingNewLine]\[IndentingNewLine]xpstemp = 
            xps[\([time]\)]; \[IndentingNewLine]xgstemp = 
            xgs[\([time]\)]; \[IndentingNewLine]xputemp = 
            xpu[\([time]\)]; \[IndentingNewLine]xgutemp = 
            xgu[\([time]\)]; \
\[IndentingNewLine]\[IndentingNewLine]xpstempbefore = 
            xps[\([time - 1]\)]; \[IndentingNewLine]xgstempbefore = 
            xgs[\([time - 1]\)]; \[IndentingNewLine]xputempbefore = 
            xpu[\([time - 1]\)]; \[IndentingNewLine]xgutempbefore = 
            xgu[\([time - 
                  1]\)]; \[IndentingNewLine]\[IndentingNewLine]outpath[
            xpstemp, xgstemp, \ xputemp, xgutemp, time, 
            time + 1]; \[IndentingNewLine]vgunoclr = 
            Vgu[\([1]\)]; \
\[IndentingNewLine]\[IndentingNewLine]{vpsifclrbefore, vgsifclrbefore, \ 
              vpuifclrbefore, \ vguifclrbefore} = \ 
            clrutil[xpstempbefore, xgstempbefore, xputempbefore, 
              xgutempbefore, 
              time - 1]; \[IndentingNewLine]\[IndentingNewLine]If[
            vguifclr \[GreaterEqual] vgunoclr || 
              xputemp/\((xpstemp + xgstemp + xgutemp)\) > 1, out = 1, 
            out = 0]; \[IndentingNewLine]\[IndentingNewLine]If[
            vguifclrbefore \[GreaterEqual] vgubefore || 
              xputempbefore/\((xpstempbefore + xgstempbefore + 
                      xgutempbefore)\) > 1, out2 = 1, 
            out2 = 0]; \[IndentingNewLine]\[IndentingNewLine]{out, out2, 
            vguifclr - vgunoclr, 
            xputemp/\((xpstemp + xgstemp + 
                  xgutemp)\)}\[IndentingNewLine]\[IndentingNewLine]];\)\)], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the transition path", "Section"],

Cell[BoxData[
    \(\(transition[switchtime_, horizon_] := 
        Module[{par, t, labs, 
            labu}, \[IndentingNewLine]\[IndentingNewLine]xguout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xgsout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xpuout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xpsout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]wuout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]wsout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]etaout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]etaSout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]giniout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]clout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]popout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]par = {\ \
\[Beta] \[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[1], \[Kappa] \[Rule] 
                kappaset}; \[IndentingNewLine]\[IndentingNewLine]outpath[
            0, \[Pi]\_0 /. par, 0, 1 - \[Pi]\_0 /. par, 1, 
            switchtime]; \[IndentingNewLine]\[IndentingNewLine]t = 
            1; \[IndentingNewLine]While[
            t \[LessEqual] 
              horizon, \[IndentingNewLine]par = {\ \[Beta] \[Rule] betaset, 
                z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                  pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
                G \[Rule] Gset, p \[Rule] pset, 
                l \[Rule] lset, \[Alpha] \[Rule] alfafun[t], \[Kappa] \[Rule] 
                  kappaset}; \[IndentingNewLine]\[IndentingNewLine]If[
              t < switchtime, \
\[IndentingNewLine]\[IndentingNewLine]xpsout[\([t]\)] = 
                xps[\([t]\)]; \[IndentingNewLine]xgsout[\([t]\)] = 
                xgs[\([t]\)]; \[IndentingNewLine]xguout[\([t]\)] = 
                xgu[\([t]\)]; \[IndentingNewLine]xpuout[\([t]\)] = 
                xpu[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]wuout[\([t]\)] = 
                wui[\([t]\)]; \[IndentingNewLine]wsout[\([t]\)] = 
                wsi[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]etaout[\([t]\)] = 
                eta[\([t]\)]; \[IndentingNewLine]etaSout[\([t]\)] = 
                etaS[\([t]\)]; \[IndentingNewLine]\[IndentingNewLine]giniout[\
\([t]\)] = \((wsi[\([t]\)] - \((1 + G\ l)\)\ wui[\([t]\)])\) 
                    xps[\([t]\)]/\((wsi[\([t]\)] 
                            xps[\([t]\)] + \((1 + G\ l)\) 
                            wui[\([t]\)] \((xgu[\([t]\)] + 
                                xpu[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]clout[\([t]\)] = 
                G\ \((xgsout[\([t]\)] + 
                          xguout[\([t]\)])\)/\((G\ \((xgsout[\([t]\)] + 
                                xguout[\([t]\)])\) + 
                          P \((xpsout[\([t]\)] + xpuout[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]popout[\([t]\)] \
= pop[\([t]\)]; \[IndentingNewLine]\[IndentingNewLine]If[t \[Equal] 1, 
                tx = popout[\([1]\)]];\[IndentingNewLine]\[IndentingNewLine]];\
 \[IndentingNewLine]\[IndentingNewLine]If[
              t \[GreaterEqual] 
                switchtime, \[IndentingNewLine]\[IndentingNewLine]If[
                t \[Equal] switchtime, \[IndentingNewLine]xpsout[\([t]\)] = 
                  xps[\([t]\)]; \[IndentingNewLine]xgsout[\([t]\)] = 
                  xgs[\([t]\)]; \[IndentingNewLine]xguout[\([t]\)] = 
                  xgu[\([t]\)]; \[IndentingNewLine]xpuout[\([t]\)] = 
                  xpu[\([t]\)];\[IndentingNewLine], \
\[IndentingNewLine]xpsout[\([t]\)] = \((1 - \[Lambda])\) 
                        xpsout[\([t - 
                              1]\)] + \[Lambda]\ \(\[Pi]\_1\) \((P\ \
\((xpuout[\([t - 1]\)] + xpsout[\([t - 1]\)])\) + 
                            G\ \ \((xgsout[\([t - 1]\)] + 
                                  xguout[\([t - 1]\)])\))\) /. 
                    par; \[IndentingNewLine]xgsout[\([t]\)] = \((1 - \
\[Lambda])\)\ xgsout[\([t - 1]\)] /. 
                    par; \[IndentingNewLine]xguout[\([t]\)] = \((1 - \
\[Lambda])\)\ xguout[\([t - 1]\)] /. 
                    par; \[IndentingNewLine]xpuout[\([t]\)] = \((1 - \
\[Lambda])\) xpuout[\([t - 
                              1]\)] + \[Lambda] \((1 - \[Pi]\_1)\) \((P\ \
\((xpuout[\([t - 1]\)] + xpsout[\([t - 1]\)])\) + 
                            G\ \ \((xgsout[\([t - 1]\)] + 
                                  xguout[\([t - 1]\)])\))\) /. 
                    par;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]labs = 
                xpsout[\([t]\)] + xgsout[\([t]\)]; \[IndentingNewLine]labu = 
                xpuout[\([t]\)] + 
                  xguout[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]wsout[\([t]\)] = 
                ws[labs, labu] /. par; \[IndentingNewLine]wuout[\([t]\)] = 
                wu[labs, labu] /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]etaout[\([t]\)] \
= 1; \[IndentingNewLine]etaSout[\([t]\)] = 
                1; \[IndentingNewLine]\[IndentingNewLine]giniout[\([t]\)] = \
\((wsout[\([t]\)] - \ wuout[\([t]\)])\) 
                    xpsout[\([t]\)]/\((wsout[\([t]\)] xpsout[\([t]\)] + 
                          wuout[\([t]\)] \((xguout[\([t]\)] + 
                                xpuout[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]clout[\([t]\)] = 
                0; \[IndentingNewLine]\[IndentingNewLine]popout[\([t]\)] = 
                100*\((\(\((1 + P)\) \((xpsout[\([t]\)] + xpuout[\([t]\)])\) \
+ \((1 + G)\) \((xgsout[\([t]\)] + xguout[\([t]\)])\)\)\/\(\((1 + P)\) \
\((xpsout[\([t - 1]\)] + xpuout[\([t - 1]\)])\) + \((1 + G)\) \((xgsout[\([t \
- 1]\)] + xguout[\([t - 1]\)])\)\) - 1)\) /. 
                  par;\[IndentingNewLine]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]t = 
              t + 1;\[IndentingNewLine]];\[IndentingNewLine]\
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(transition2[switchtime_, horizon_] := 
        Module[{par, t, labs, 
            labu}, \[IndentingNewLine]\[IndentingNewLine]xguout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xgsout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xpuout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xpsout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]wuout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]wsout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]etaout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]etaSout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]giniout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]clout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]popout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]par = {\ \
\[Beta] \[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[1], \[Kappa] \[Rule] 
                kappaset}; \[IndentingNewLine]\[IndentingNewLine]outpath[
            0, \[Pi]\_0 /. par, 0, 1 - \[Pi]\_0 /. par, 1, 
            switchtime]; \[IndentingNewLine]\[IndentingNewLine]t = 
            1; \[IndentingNewLine]While[
            t \[LessEqual] 
              horizon, \[IndentingNewLine]par = {\ \[Beta] \[Rule] betaset, 
                z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                  pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
                G \[Rule] Gset, p \[Rule] pset, 
                l \[Rule] lset, \[Alpha] \[Rule] alfafun[t], \[Kappa] \[Rule] 
                  kappaset}; \[IndentingNewLine]\[IndentingNewLine]If[
              t < switchtime, \
\[IndentingNewLine]\[IndentingNewLine]xpsout[\([t]\)] = 
                xps[\([t]\)]; \[IndentingNewLine]xgsout[\([t]\)] = 
                xgs[\([t]\)]; \[IndentingNewLine]xguout[\([t]\)] = 
                xgu[\([t]\)]; \[IndentingNewLine]xpuout[\([t]\)] = 
                xpu[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]wuout[\([t]\)] = 
                wui[\([t]\)]; \[IndentingNewLine]wsout[\([t]\)] = 
                wsi[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]etaout[\([t]\)] = 
                eta[\([t]\)]; \[IndentingNewLine]etaSout[\([t]\)] = 
                etaS[\([t]\)]; \[IndentingNewLine]\[IndentingNewLine]giniout[\
\([t]\)] = \((wsi[\([t]\)] - \((1 + G\ l)\)\ wui[\([t]\)])\) 
                    xps[\([t]\)]/\((wsi[\([t]\)] 
                            xps[\([t]\)] + \((1 + G\ l)\) 
                            wui[\([t]\)] \((xgu[\([t]\)] + 
                                xpu[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]clout[\([t]\)] = 
                G\ \((xgsout[\([t]\)] + 
                          xguout[\([t]\)])\)/\((G\ \((xgsout[\([t]\)] + 
                                xguout[\([t]\)])\) + 
                          P \((xpsout[\([t]\)] + xpuout[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]popout[\([t]\)] \
= pop[\([t]\)]; \[IndentingNewLine]\[IndentingNewLine]If[t \[Equal] 1, 
                tx = popout[\([1]\)]];\[IndentingNewLine]\[IndentingNewLine]];\
 \[IndentingNewLine]\[IndentingNewLine]If[
              t \[GreaterEqual] 
                switchtime, \[IndentingNewLine]\[IndentingNewLine]If[
                t \[Equal] switchtime, \[IndentingNewLine]xpsout[\([t]\)] = 
                  xps[\([t]\)]; \[IndentingNewLine]xgsout[\([t]\)] = 
                  xgs[\([t]\)]; \[IndentingNewLine]xguout[\([t]\)] = 
                  xgu[\([t]\)]; \[IndentingNewLine]xpuout[\([t]\)] = 
                  xpu[\([t]\)];\[IndentingNewLine], \
\[IndentingNewLine]xpsout[\([t]\)] = \((1 - \[Lambda])\) 
                        xpsout[\([t - 
                              1]\)] + \[Lambda] \((\ \ \[Pi]\_1\ P\ \
\((xpuout[\([t - 1]\)] + xpsout[\([t - 
                                        1]\)])\) + \ \[Pi]\_0\ \
G\ \ \((xgsout[\([t - 1]\)] + xguout[\([t - 1]\)])\))\) /. 
                    par; \[IndentingNewLine]xgsout[\([t]\)] = \((1 - \
\[Lambda])\)\ xgsout[\([t - 1]\)] /. 
                    par; \[IndentingNewLine]xguout[\([t]\)] = \((1 - \
\[Lambda])\)\ xguout[\([t - 1]\)] /. 
                    par; \[IndentingNewLine]xpuout[\([t]\)] = \((1 - \
\[Lambda])\) xpuout[\([t - 
                              1]\)] + \[Lambda] \((\((1 - \[Pi]\_1)\)\ P\ \
\((xpuout[\([t - 1]\)] + xpsout[\([t - 
                                        1]\)])\) + \((1 - \[Pi]\_0)\)\ \
G\ \ \((xgsout[\([t - 1]\)] + xguout[\([t - 1]\)])\))\) /. 
                    par;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]labs = 
                xpsout[\([t]\)] + xgsout[\([t]\)]; \[IndentingNewLine]labu = 
                xpuout[\([t]\)] + 
                  xguout[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]wsout[\([t]\)] = 
                ws[labs, labu] /. par; \[IndentingNewLine]wuout[\([t]\)] = 
                wu[labs, labu] /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]etaout[\([t]\)] \
= 1; \[IndentingNewLine]etaSout[\([t]\)] = 
                1; \[IndentingNewLine]\[IndentingNewLine]giniout[\([t]\)] = \
\((wsout[\([t]\)] - \ wuout[\([t]\)])\) 
                    xpsout[\([t]\)]/\((wsout[\([t]\)] xpsout[\([t]\)] + 
                          wuout[\([t]\)] \((xguout[\([t]\)] + 
                                xpuout[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]clout[\([t]\)] = 
                0; \[IndentingNewLine]\[IndentingNewLine]popout[\([t]\)] = 
                100*\((\(\((1 + P)\) \((xpsout[\([t]\)] + xpuout[\([t]\)])\) \
+ \((1 + G)\) \((xgsout[\([t]\)] + xguout[\([t]\)])\)\)\/\(\((1 + P)\) \
\((xpsout[\([t - 1]\)] + xpuout[\([t - 1]\)])\) + \((1 + G)\) \((xgsout[\([t \
- 1]\)] + xguout[\([t - 1]\)])\)\) - 1)\) /. 
                  par;\[IndentingNewLine]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]t = 
              t + 1;\[IndentingNewLine]];\[IndentingNewLine]\
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(transition3[switchtime_, horizon_] := 
        Module[{par, t, labs, 
            labu}, \[IndentingNewLine]\[IndentingNewLine]xguout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xgsout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xpuout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xpsout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]wuout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]wsout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]etaout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]etaSout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]giniout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]clout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]popout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]par = {\ \
\[Beta] \[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[1], \[Kappa] \[Rule] 
                kappaset}; \[IndentingNewLine]\[IndentingNewLine]outpath[
            0, \[Pi]\_0 /. par, 0, 1 - \[Pi]\_0 /. par, 1, 
            switchtime]; \[IndentingNewLine]\[IndentingNewLine]t = 
            1; \[IndentingNewLine]While[
            t \[LessEqual] 
              horizon, \[IndentingNewLine]par = {\ \[Beta] \[Rule] betaset, 
                z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                  pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
                G \[Rule] Gset, p \[Rule] pset, 
                l \[Rule] lset, \[Alpha] \[Rule] alfafun[t], \[Kappa] \[Rule] 
                  kappaset}; \[IndentingNewLine]\[IndentingNewLine]If[
              t < switchtime, \
\[IndentingNewLine]\[IndentingNewLine]xpsout[\([t]\)] = 
                xps[\([t]\)]; \[IndentingNewLine]xgsout[\([t]\)] = 
                xgs[\([t]\)]; \[IndentingNewLine]xguout[\([t]\)] = 
                xgu[\([t]\)]; \[IndentingNewLine]xpuout[\([t]\)] = 
                xpu[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]wuout[\([t]\)] = 
                wui[\([t]\)]; \[IndentingNewLine]wsout[\([t]\)] = 
                wsi[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]etaout[\([t]\)] = 
                eta[\([t]\)]; \[IndentingNewLine]etaSout[\([t]\)] = 
                etaS[\([t]\)]; \[IndentingNewLine]\[IndentingNewLine]giniout[\
\([t]\)] = \((wsi[\([t]\)] - \((1 + G\ l)\)\ wui[\([t]\)])\) 
                    xps[\([t]\)]/\((wsi[\([t]\)] 
                            xps[\([t]\)] + \((1 + G\ l)\) 
                            wui[\([t]\)] \((xgu[\([t]\)] + 
                                xpu[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]clout[\([t]\)] = 
                G\ \((xgsout[\([t]\)] + 
                          xguout[\([t]\)])\)/\((G\ \((xgsout[\([t]\)] + 
                                xguout[\([t]\)])\) + 
                          P \((xpsout[\([t]\)] + xpuout[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]popout[\([t]\)] \
= pop[\([t]\)]; \[IndentingNewLine]\[IndentingNewLine]If[t \[Equal] 1, 
                tx = popout[\([1]\)]];\[IndentingNewLine]\[IndentingNewLine]];\
 \[IndentingNewLine]\[IndentingNewLine]If[
              t \[GreaterEqual] 
                switchtime, \[IndentingNewLine]\[IndentingNewLine]If[
                t \[Equal] switchtime, \[IndentingNewLine]xpsout[\([t]\)] = 
                  xps[\([t]\)]; \[IndentingNewLine]xgsout[\([t]\)] = 
                  xgs[\([t]\)]; \[IndentingNewLine]xguout[\([t]\)] = 
                  xgu[\([t]\)]; \[IndentingNewLine]xpuout[\([t]\)] = 
                  xpu[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]outpath2[xps[\([t]\)], xgs[\([t]\)], 
                  xpu[\([t]\)], xgu[\([t]\)], t, 
                  45];\[IndentingNewLine], \[IndentingNewLine]xpsout[\([t]\)] \
= xps[\([t]\)]; \[IndentingNewLine]xgsout[\([t]\)] = 
                  xgs[\([t]\)]; \[IndentingNewLine]xguout[\([t]\)] = 
                  xgu[\([t]\)]; \[IndentingNewLine]xpuout[\([t]\)] = 
                  xpu[\([t]\)];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]wuout[\([t]\)] = 
                wui[\([t]\)]; \[IndentingNewLine]wsout[\([t]\)] = 
                wsi[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]etaout[\([t]\)] = 
                eta[\([t]\)]; \[IndentingNewLine]etaSout[\([t]\)] = 
                etaS[\([t]\)]; \[IndentingNewLine]\[IndentingNewLine]giniout[\
\([t]\)] = \((wsi[\([t]\)] - \((1 + G\ l)\)\ wui[\([t]\)])\) 
                    xps[\([t]\)]/\((wsi[\([t]\)] 
                            xps[\([t]\)] + \((1 + G\ l)\) 
                            wui[\([t]\)] \((xgu[\([t]\)] + 
                                xpu[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]clout[\([t]\)] = 
                G\ \((xgsout[\([t]\)] + 
                          xguout[\([t]\)])\)/\((G\ \((xgsout[\([t]\)] + 
                                xguout[\([t]\)])\) + 
                          P \((xpsout[\([t]\)] + xpuout[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine]popout[\([t]\)] = 
                100*\((\(\((1 + P)\) \((xpsout[\([t]\)] + xpuout[\([t]\)])\) \
+ \((1 + G)\) \((xgsout[\([t]\)] + xguout[\([t]\)])\)\)\/\(\((1 + P)\) \
\((xpsout[\([t - 1]\)] + xpuout[\([t - 1]\)])\) + \((1 + G)\) \((xgsout[\([t \
- 1]\)] + xguout[\([t - 1]\)])\)\) - 1)\) /. 
                  par;\[IndentingNewLine]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]t = 
              t + 1;\[IndentingNewLine]];\[IndentingNewLine]\
\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Carrying out the computations and graphing the results", "Section"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(zaehler = 2;\)\), "\[IndentingNewLine]", 
    \(\(While[
        zaehler < 10, \[IndentingNewLine]{res1, res2, res3, res4} = 
          checkswitch[zaehler]; \[IndentingNewLine]If[res1 == 1, 
          reform = zaehler; zaehler = 10, 
          zaehler = 
            zaehler + 1];\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(reform\), "\[IndentingNewLine]", 
    \(checkswitch[reform - 1]\), "\[IndentingNewLine]", 
    \(checkswitch[reform]\), "\[IndentingNewLine]", 
    \(checkswitch[reform + 1]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(checkswitch[6]\), "\[IndentingNewLine]", 
    \(checkswitch[7]\)}], "Input"],

Cell[BoxData[
    \({0, 0, \(-0.02783803820043751`\), 0.9500640327850305`}\)], "Output"],

Cell[BoxData[
    \({0, 0, \(-0.01946566341102951`\), 0.9433052268655725`}\)], "Output"],

Cell[BoxData[
    \({1, 0, \(-0.01918756072180683`\), 1.3646461298553514`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(checkswitch[6]\), "\[IndentingNewLine]", 
    \(checkswitch[8]\)}], "Input"],

Cell[BoxData[
    \({0, 0, \(-0.014645496690713689`\), 0.9433052268655725`}\)], "Output"],

Cell[BoxData[
    \({1, 1, \(-0.024133549879373994`\), 1.4909338849398215`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison Graphs", "Section"],

Cell[BoxData[
    \(transition[7, 40]\)], "Input"],

Cell[BoxData[
    \(\(output = 
        Table[\((\[Alpha]\ \((xpsout[\([i]\)] + 
                          xgsout[\([i]\)])\)^\[Kappa] + \((1 - \[Alpha])\)\ \
\((xpuout[\([i]\)] + xguout[\([i]\)] + 
                          l\ clout[\([i]\)] \((G\ \((xgsout[\([i]\)] + 
                                      xguout[\([i]\)])\) + 
                                P \((xpsout[\([i]\)] + 
                                      xpuout[\([i]\)])\))\))\)^\[Kappa])\)^\((\
1/\[Kappa])\) /. {\ \[Beta] \[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[i], \[Kappa] \[Rule] 
                kappaset}, {i, 40}];\)\)], "Input"],

Cell[BoxData[
    \(transition2[7, 40]\)], "Input"],

Cell[BoxData[
    \(\(outputalt = 
        Table[\((\[Alpha]\ \((xpsout[\([i]\)] + 
                          xgsout[\([i]\)])\)^\[Kappa] + \((1 - \[Alpha])\)\ \
\((xpuout[\([i]\)] + xguout[\([i]\)] + 
                          l\ G\ \((xgsout[\([i]\)] + 
                                xguout[\([i]\)])\))\)^\[Kappa])\)^\((1/\
\[Kappa])\) /. {\ \[Beta] \[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[i], \[Kappa] \[Rule] 
                kappaset}, {i, 40}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MultipleListPlot[output, outputalt, PlotJoined \[Rule] True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 -0.181538 0.289835 [
[.2619 .0958 -6 -9 ]
[.2619 .0958 6 0 ]
[.5 .0958 -6 -9 ]
[.5 .0958 6 0 ]
[.7381 .0958 -6 -9 ]
[.7381 .0958 6 0 ]
[.97619 .0958 -6 -9 ]
[.97619 .0958 6 0 ]
[.01131 .25321 -18 -4.5 ]
[.01131 .25321 0 4.5 ]
[.01131 .39813 -6 -4.5 ]
[.01131 .39813 0 4.5 ]
[.01131 .54305 -18 -4.5 ]
[.01131 .54305 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .1083 m
.2619 .11455 L
s
[(10)] .2619 .0958 0 1 Mshowa
.5 .1083 m
.5 .11455 L
s
[(20)] .5 .0958 0 1 Mshowa
.7381 .1083 m
.7381 .11455 L
s
[(30)] .7381 .0958 0 1 Mshowa
.97619 .1083 m
.97619 .11455 L
s
[(40)] .97619 .0958 0 1 Mshowa
.125 Mabswid
.07143 .1083 m
.07143 .11205 L
s
.11905 .1083 m
.11905 .11205 L
s
.16667 .1083 m
.16667 .11205 L
s
.21429 .1083 m
.21429 .11205 L
s
.30952 .1083 m
.30952 .11205 L
s
.35714 .1083 m
.35714 .11205 L
s
.40476 .1083 m
.40476 .11205 L
s
.45238 .1083 m
.45238 .11205 L
s
.54762 .1083 m
.54762 .11205 L
s
.59524 .1083 m
.59524 .11205 L
s
.64286 .1083 m
.64286 .11205 L
s
.69048 .1083 m
.69048 .11205 L
s
.78571 .1083 m
.78571 .11205 L
s
.83333 .1083 m
.83333 .11205 L
s
.88095 .1083 m
.88095 .11205 L
s
.92857 .1083 m
.92857 .11205 L
s
.25 Mabswid
0 .1083 m
1 .1083 L
s
.02381 .25321 m
.03006 .25321 L
s
[(1.5)] .01131 .25321 1 0 Mshowa
.02381 .39813 m
.03006 .39813 L
s
[(2)] .01131 .39813 1 0 Mshowa
.02381 .54305 m
.03006 .54305 L
s
[(2.5)] .01131 .54305 1 0 Mshowa
.125 Mabswid
.02381 .13728 m
.02756 .13728 L
s
.02381 .16626 m
.02756 .16626 L
s
.02381 .19525 m
.02756 .19525 L
s
.02381 .22423 m
.02756 .22423 L
s
.02381 .2822 m
.02756 .2822 L
s
.02381 .31118 m
.02756 .31118 L
s
.02381 .34016 m
.02756 .34016 L
s
.02381 .36915 m
.02756 .36915 L
s
.02381 .42712 m
.02756 .42712 L
s
.02381 .4561 m
.02756 .4561 L
s
.02381 .48508 m
.02756 .48508 L
s
.02381 .51407 m
.02756 .51407 L
s
.02381 .07931 m
.02756 .07931 L
s
.02381 .05033 m
.02756 .05033 L
s
.02381 .02135 m
.02756 .02135 L
s
.02381 .57203 m
.02756 .57203 L
s
.02381 .60102 m
.02756 .60102 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.04762 .01472 m
.07143 .07263 L
.09524 .11233 L
.11905 .15573 L
.14286 .17724 L
.16667 .19465 L
.19048 .17979 L
.21429 .24097 L
.2381 .28254 L
.2619 .31375 L
.28571 .33794 L
.30952 .35678 L
.33333 .38603 L
.35714 .41948 L
.38095 .44777 L
.40476 .47172 L
.42857 .49201 L
.45238 .50922 L
.47619 .52381 L
.5 .53619 L
.52381 .5467 L
.54762 .55562 L
.57143 .5632 L
.59524 .56963 L
.61905 .5751 L
.64286 .57974 L
.66667 .58369 L
.69048 .58704 L
.71429 .58989 L
.7381 .59231 L
.7619 .59437 L
.78571 .59612 L
.80952 .5976 L
.83333 .59886 L
.85714 .59994 L
.88095 .60085 L
.90476 .60162 L
.92857 .60228 L
.95238 .60284 L
.97619 .60332 L
s
.0001 w
.04762 .01472 -1.875 0 Mabsadd m
.04762 .01472 0 2.5 Mabsadd L
.04762 .01472 1.875 0 Mabsadd L
.04762 .01472 0 -2.5 Mabsadd L
.04762 .01472 -1.875 0 Mabsadd L closepath F
.07143 .07263 -1.875 0 Mabsadd m
.07143 .07263 0 2.5 Mabsadd L
.07143 .07263 1.875 0 Mabsadd L
.07143 .07263 0 -2.5 Mabsadd L
.07143 .07263 -1.875 0 Mabsadd L closepath F
.09524 .11233 -1.875 0 Mabsadd m
.09524 .11233 0 2.5 Mabsadd L
.09524 .11233 1.875 0 Mabsadd L
.09524 .11233 0 -2.5 Mabsadd L
.09524 .11233 -1.875 0 Mabsadd L closepath F
.11905 .15573 -1.875 0 Mabsadd m
.11905 .15573 0 2.5 Mabsadd L
.11905 .15573 1.875 0 Mabsadd L
.11905 .15573 0 -2.5 Mabsadd L
.11905 .15573 -1.875 0 Mabsadd L closepath F
.14286 .17724 -1.875 0 Mabsadd m
.14286 .17724 0 2.5 Mabsadd L
.14286 .17724 1.875 0 Mabsadd L
.14286 .17724 0 -2.5 Mabsadd L
.14286 .17724 -1.875 0 Mabsadd L closepath F
.16667 .19465 -1.875 0 Mabsadd m
.16667 .19465 0 2.5 Mabsadd L
.16667 .19465 1.875 0 Mabsadd L
.16667 .19465 0 -2.5 Mabsadd L
.16667 .19465 -1.875 0 Mabsadd L closepath F
.19048 .17979 -1.875 0 Mabsadd m
.19048 .17979 0 2.5 Mabsadd L
.19048 .17979 1.875 0 Mabsadd L
.19048 .17979 0 -2.5 Mabsadd L
.19048 .17979 -1.875 0 Mabsadd L closepath F
.21429 .24097 -1.875 0 Mabsadd m
.21429 .24097 0 2.5 Mabsadd L
.21429 .24097 1.875 0 Mabsadd L
.21429 .24097 0 -2.5 Mabsadd L
.21429 .24097 -1.875 0 Mabsadd L closepath F
.2381 .28254 -1.875 0 Mabsadd m
.2381 .28254 0 2.5 Mabsadd L
.2381 .28254 1.875 0 Mabsadd L
.2381 .28254 0 -2.5 Mabsadd L
.2381 .28254 -1.875 0 Mabsadd L closepath F
.2619 .31375 -1.875 0 Mabsadd m
.2619 .31375 0 2.5 Mabsadd L
.2619 .31375 1.875 0 Mabsadd L
.2619 .31375 0 -2.5 Mabsadd L
.2619 .31375 -1.875 0 Mabsadd L closepath F
.28571 .33794 -1.875 0 Mabsadd m
.28571 .33794 0 2.5 Mabsadd L
.28571 .33794 1.875 0 Mabsadd L
.28571 .33794 0 -2.5 Mabsadd L
.28571 .33794 -1.875 0 Mabsadd L closepath F
.30952 .35678 -1.875 0 Mabsadd m
.30952 .35678 0 2.5 Mabsadd L
.30952 .35678 1.875 0 Mabsadd L
.30952 .35678 0 -2.5 Mabsadd L
.30952 .35678 -1.875 0 Mabsadd L closepath F
.33333 .38603 -1.875 0 Mabsadd m
.33333 .38603 0 2.5 Mabsadd L
.33333 .38603 1.875 0 Mabsadd L
.33333 .38603 0 -2.5 Mabsadd L
.33333 .38603 -1.875 0 Mabsadd L closepath F
.35714 .41948 -1.875 0 Mabsadd m
.35714 .41948 0 2.5 Mabsadd L
.35714 .41948 1.875 0 Mabsadd L
.35714 .41948 0 -2.5 Mabsadd L
.35714 .41948 -1.875 0 Mabsadd L closepath F
.38095 .44777 -1.875 0 Mabsadd m
.38095 .44777 0 2.5 Mabsadd L
.38095 .44777 1.875 0 Mabsadd L
.38095 .44777 0 -2.5 Mabsadd L
.38095 .44777 -1.875 0 Mabsadd L closepath F
.40476 .47172 -1.875 0 Mabsadd m
.40476 .47172 0 2.5 Mabsadd L
.40476 .47172 1.875 0 Mabsadd L
.40476 .47172 0 -2.5 Mabsadd L
.40476 .47172 -1.875 0 Mabsadd L closepath F
.42857 .49201 -1.875 0 Mabsadd m
.42857 .49201 0 2.5 Mabsadd L
.42857 .49201 1.875 0 Mabsadd L
.42857 .49201 0 -2.5 Mabsadd L
.42857 .49201 -1.875 0 Mabsadd L closepath F
.45238 .50922 -1.875 0 Mabsadd m
.45238 .50922 0 2.5 Mabsadd L
.45238 .50922 1.875 0 Mabsadd L
.45238 .50922 0 -2.5 Mabsadd L
.45238 .50922 -1.875 0 Mabsadd L closepath F
.47619 .52381 -1.875 0 Mabsadd m
.47619 .52381 0 2.5 Mabsadd L
.47619 .52381 1.875 0 Mabsadd L
.47619 .52381 0 -2.5 Mabsadd L
.47619 .52381 -1.875 0 Mabsadd L closepath F
.5 .53619 -1.875 0 Mabsadd m
.5 .53619 0 2.5 Mabsadd L
.5 .53619 1.875 0 Mabsadd L
.5 .53619 0 -2.5 Mabsadd L
.5 .53619 -1.875 0 Mabsadd L closepath F
.52381 .5467 -1.875 0 Mabsadd m
.52381 .5467 0 2.5 Mabsadd L
.52381 .5467 1.875 0 Mabsadd L
.52381 .5467 0 -2.5 Mabsadd L
.52381 .5467 -1.875 0 Mabsadd L closepath F
.54762 .55562 -1.875 0 Mabsadd m
.54762 .55562 0 2.5 Mabsadd L
.54762 .55562 1.875 0 Mabsadd L
.54762 .55562 0 -2.5 Mabsadd L
.54762 .55562 -1.875 0 Mabsadd L closepath F
.57143 .5632 -1.875 0 Mabsadd m
.57143 .5632 0 2.5 Mabsadd L
.57143 .5632 1.875 0 Mabsadd L
.57143 .5632 0 -2.5 Mabsadd L
.57143 .5632 -1.875 0 Mabsadd L closepath F
.59524 .56963 -1.875 0 Mabsadd m
.59524 .56963 0 2.5 Mabsadd L
.59524 .56963 1.875 0 Mabsadd L
.59524 .56963 0 -2.5 Mabsadd L
.59524 .56963 -1.875 0 Mabsadd L closepath F
.61905 .5751 -1.875 0 Mabsadd m
.61905 .5751 0 2.5 Mabsadd L
.61905 .5751 1.875 0 Mabsadd L
.61905 .5751 0 -2.5 Mabsadd L
.61905 .5751 -1.875 0 Mabsadd L closepath F
.64286 .57974 -1.875 0 Mabsadd m
.64286 .57974 0 2.5 Mabsadd L
.64286 .57974 1.875 0 Mabsadd L
.64286 .57974 0 -2.5 Mabsadd L
.64286 .57974 -1.875 0 Mabsadd L closepath F
.66667 .58369 -1.875 0 Mabsadd m
.66667 .58369 0 2.5 Mabsadd L
.66667 .58369 1.875 0 Mabsadd L
.66667 .58369 0 -2.5 Mabsadd L
.66667 .58369 -1.875 0 Mabsadd L closepath F
.69048 .58704 -1.875 0 Mabsadd m
.69048 .58704 0 2.5 Mabsadd L
.69048 .58704 1.875 0 Mabsadd L
.69048 .58704 0 -2.5 Mabsadd L
.69048 .58704 -1.875 0 Mabsadd L closepath F
.71429 .58989 -1.875 0 Mabsadd m
.71429 .58989 0 2.5 Mabsadd L
.71429 .58989 1.875 0 Mabsadd L
.71429 .58989 0 -2.5 Mabsadd L
.71429 .58989 -1.875 0 Mabsadd L closepath F
.7381 .59231 -1.875 0 Mabsadd m
.7381 .59231 0 2.5 Mabsadd L
.7381 .59231 1.875 0 Mabsadd L
.7381 .59231 0 -2.5 Mabsadd L
.7381 .59231 -1.875 0 Mabsadd L closepath F
.7619 .59437 -1.875 0 Mabsadd m
.7619 .59437 0 2.5 Mabsadd L
.7619 .59437 1.875 0 Mabsadd L
.7619 .59437 0 -2.5 Mabsadd L
.7619 .59437 -1.875 0 Mabsadd L closepath F
.78571 .59612 -1.875 0 Mabsadd m
.78571 .59612 0 2.5 Mabsadd L
.78571 .59612 1.875 0 Mabsadd L
.78571 .59612 0 -2.5 Mabsadd L
.78571 .59612 -1.875 0 Mabsadd L closepath F
.80952 .5976 -1.875 0 Mabsadd m
.80952 .5976 0 2.5 Mabsadd L
.80952 .5976 1.875 0 Mabsadd L
.80952 .5976 0 -2.5 Mabsadd L
.80952 .5976 -1.875 0 Mabsadd L closepath F
.83333 .59886 -1.875 0 Mabsadd m
.83333 .59886 0 2.5 Mabsadd L
.83333 .59886 1.875 0 Mabsadd L
.83333 .59886 0 -2.5 Mabsadd L
.83333 .59886 -1.875 0 Mabsadd L closepath F
.85714 .59994 -1.875 0 Mabsadd m
.85714 .59994 0 2.5 Mabsadd L
.85714 .59994 1.875 0 Mabsadd L
.85714 .59994 0 -2.5 Mabsadd L
.85714 .59994 -1.875 0 Mabsadd L closepath F
.88095 .60085 -1.875 0 Mabsadd m
.88095 .60085 0 2.5 Mabsadd L
.88095 .60085 1.875 0 Mabsadd L
.88095 .60085 0 -2.5 Mabsadd L
.88095 .60085 -1.875 0 Mabsadd L closepath F
.90476 .60162 -1.875 0 Mabsadd m
.90476 .60162 0 2.5 Mabsadd L
.90476 .60162 1.875 0 Mabsadd L
.90476 .60162 0 -2.5 Mabsadd L
.90476 .60162 -1.875 0 Mabsadd L closepath F
.92857 .60228 -1.875 0 Mabsadd m
.92857 .60228 0 2.5 Mabsadd L
.92857 .60228 1.875 0 Mabsadd L
.92857 .60228 0 -2.5 Mabsadd L
.92857 .60228 -1.875 0 Mabsadd L closepath F
.95238 .60284 -1.875 0 Mabsadd m
.95238 .60284 0 2.5 Mabsadd L
.95238 .60284 1.875 0 Mabsadd L
.95238 .60284 0 -2.5 Mabsadd L
.95238 .60284 -1.875 0 Mabsadd L closepath F
.97619 .60332 -1.875 0 Mabsadd m
.97619 .60332 0 2.5 Mabsadd L
.97619 .60332 1.875 0 Mabsadd L
.97619 .60332 0 -2.5 Mabsadd L
.97619 .60332 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.04762 .01472 m
.07143 .07263 L
.09524 .11233 L
.11905 .15573 L
.14286 .17724 L
.16667 .19465 L
.19048 .20776 L
.21429 .21713 L
.2381 .22376 L
.2619 .22857 L
.28571 .23228 L
.30952 .23535 L
.33333 .25941 L
.35714 .29532 L
.38095 .32831 L
.40476 .35842 L
.42857 .38577 L
.45238 .41049 L
.47619 .43276 L
.5 .45274 L
.52381 .47062 L
.54762 .48659 L
.57143 .5008 L
.59524 .51343 L
.61905 .52464 L
.64286 .53456 L
.66667 .54333 L
.69048 .55108 L
.71429 .55791 L
.7381 .56392 L
.7619 .56921 L
.78571 .57386 L
.80952 .57794 L
.83333 .58152 L
.85714 .58466 L
.88095 .5874 L
.90476 .5898 L
.92857 .5919 L
.95238 .59374 L
.97619 .59534 L
s
.0001 w
[ ] 0 setdash
.04762 .01472 0 2.5 Mabsadd m
.04762 .01472 -0.56518 .7779 Mabsadd L
.04762 .01472 -2.37764 .77254 Mabsadd L
.04762 .01472 -0.91448 -0.29713 Mabsadd L
.04762 .01472 -1.46946 -2.02254 Mabsadd L
.04762 .01472 0 -0.96154 Mabsadd L
.04762 .01472 1.46946 -2.02254 Mabsadd L
.04762 .01472 .91448 -0.29713 Mabsadd L
.04762 .01472 2.37764 .77254 Mabsadd L
.04762 .01472 .56518 .7779 Mabsadd L
.04762 .01472 0 2.5 Mabsadd L closepath F
.07143 .07263 0 2.5 Mabsadd m
.07143 .07263 -0.56518 .7779 Mabsadd L
.07143 .07263 -2.37764 .77254 Mabsadd L
.07143 .07263 -0.91448 -0.29713 Mabsadd L
.07143 .07263 -1.46946 -2.02254 Mabsadd L
.07143 .07263 0 -0.96154 Mabsadd L
.07143 .07263 1.46946 -2.02254 Mabsadd L
.07143 .07263 .91448 -0.29713 Mabsadd L
.07143 .07263 2.37764 .77254 Mabsadd L
.07143 .07263 .56518 .7779 Mabsadd L
.07143 .07263 0 2.5 Mabsadd L closepath F
.09524 .11233 0 2.5 Mabsadd m
.09524 .11233 -0.56518 .7779 Mabsadd L
.09524 .11233 -2.37764 .77254 Mabsadd L
.09524 .11233 -0.91448 -0.29713 Mabsadd L
.09524 .11233 -1.46946 -2.02254 Mabsadd L
.09524 .11233 0 -0.96154 Mabsadd L
.09524 .11233 1.46946 -2.02254 Mabsadd L
.09524 .11233 .91448 -0.29713 Mabsadd L
.09524 .11233 2.37764 .77254 Mabsadd L
.09524 .11233 .56518 .7779 Mabsadd L
.09524 .11233 0 2.5 Mabsadd L closepath F
.11905 .15573 0 2.5 Mabsadd m
.11905 .15573 -0.56518 .7779 Mabsadd L
.11905 .15573 -2.37764 .77254 Mabsadd L
.11905 .15573 -0.91448 -0.29713 Mabsadd L
.11905 .15573 -1.46946 -2.02254 Mabsadd L
.11905 .15573 0 -0.96154 Mabsadd L
.11905 .15573 1.46946 -2.02254 Mabsadd L
.11905 .15573 .91448 -0.29713 Mabsadd L
.11905 .15573 2.37764 .77254 Mabsadd L
.11905 .15573 .56518 .7779 Mabsadd L
.11905 .15573 0 2.5 Mabsadd L closepath F
.14286 .17724 0 2.5 Mabsadd m
.14286 .17724 -0.56518 .7779 Mabsadd L
.14286 .17724 -2.37764 .77254 Mabsadd L
.14286 .17724 -0.91448 -0.29713 Mabsadd L
.14286 .17724 -1.46946 -2.02254 Mabsadd L
.14286 .17724 0 -0.96154 Mabsadd L
.14286 .17724 1.46946 -2.02254 Mabsadd L
.14286 .17724 .91448 -0.29713 Mabsadd L
.14286 .17724 2.37764 .77254 Mabsadd L
.14286 .17724 .56518 .7779 Mabsadd L
.14286 .17724 0 2.5 Mabsadd L closepath F
.16667 .19465 0 2.5 Mabsadd m
.16667 .19465 -0.56518 .7779 Mabsadd L
.16667 .19465 -2.37764 .77254 Mabsadd L
.16667 .19465 -0.91448 -0.29713 Mabsadd L
.16667 .19465 -1.46946 -2.02254 Mabsadd L
.16667 .19465 0 -0.96154 Mabsadd L
.16667 .19465 1.46946 -2.02254 Mabsadd L
.16667 .19465 .91448 -0.29713 Mabsadd L
.16667 .19465 2.37764 .77254 Mabsadd L
.16667 .19465 .56518 .7779 Mabsadd L
.16667 .19465 0 2.5 Mabsadd L closepath F
.19048 .20776 0 2.5 Mabsadd m
.19048 .20776 -0.56518 .7779 Mabsadd L
.19048 .20776 -2.37764 .77254 Mabsadd L
.19048 .20776 -0.91448 -0.29713 Mabsadd L
.19048 .20776 -1.46946 -2.02254 Mabsadd L
.19048 .20776 0 -0.96154 Mabsadd L
.19048 .20776 1.46946 -2.02254 Mabsadd L
.19048 .20776 .91448 -0.29713 Mabsadd L
.19048 .20776 2.37764 .77254 Mabsadd L
.19048 .20776 .56518 .7779 Mabsadd L
.19048 .20776 0 2.5 Mabsadd L closepath F
.21429 .21713 0 2.5 Mabsadd m
.21429 .21713 -0.56518 .7779 Mabsadd L
.21429 .21713 -2.37764 .77254 Mabsadd L
.21429 .21713 -0.91448 -0.29713 Mabsadd L
.21429 .21713 -1.46946 -2.02254 Mabsadd L
.21429 .21713 0 -0.96154 Mabsadd L
.21429 .21713 1.46946 -2.02254 Mabsadd L
.21429 .21713 .91448 -0.29713 Mabsadd L
.21429 .21713 2.37764 .77254 Mabsadd L
.21429 .21713 .56518 .7779 Mabsadd L
.21429 .21713 0 2.5 Mabsadd L closepath F
.2381 .22376 0 2.5 Mabsadd m
.2381 .22376 -0.56518 .7779 Mabsadd L
.2381 .22376 -2.37764 .77254 Mabsadd L
.2381 .22376 -0.91448 -0.29713 Mabsadd L
.2381 .22376 -1.46946 -2.02254 Mabsadd L
.2381 .22376 0 -0.96154 Mabsadd L
.2381 .22376 1.46946 -2.02254 Mabsadd L
.2381 .22376 .91448 -0.29713 Mabsadd L
.2381 .22376 2.37764 .77254 Mabsadd L
.2381 .22376 .56518 .7779 Mabsadd L
.2381 .22376 0 2.5 Mabsadd L closepath F
.2619 .22857 0 2.5 Mabsadd m
.2619 .22857 -0.56518 .7779 Mabsadd L
.2619 .22857 -2.37764 .77254 Mabsadd L
.2619 .22857 -0.91448 -0.29713 Mabsadd L
.2619 .22857 -1.46946 -2.02254 Mabsadd L
.2619 .22857 0 -0.96154 Mabsadd L
.2619 .22857 1.46946 -2.02254 Mabsadd L
.2619 .22857 .91448 -0.29713 Mabsadd L
.2619 .22857 2.37764 .77254 Mabsadd L
.2619 .22857 .56518 .7779 Mabsadd L
.2619 .22857 0 2.5 Mabsadd L closepath F
.28571 .23228 0 2.5 Mabsadd m
.28571 .23228 -0.56518 .7779 Mabsadd L
.28571 .23228 -2.37764 .77254 Mabsadd L
.28571 .23228 -0.91448 -0.29713 Mabsadd L
.28571 .23228 -1.46946 -2.02254 Mabsadd L
.28571 .23228 0 -0.96154 Mabsadd L
.28571 .23228 1.46946 -2.02254 Mabsadd L
.28571 .23228 .91448 -0.29713 Mabsadd L
.28571 .23228 2.37764 .77254 Mabsadd L
.28571 .23228 .56518 .7779 Mabsadd L
.28571 .23228 0 2.5 Mabsadd L closepath F
.30952 .23535 0 2.5 Mabsadd m
.30952 .23535 -0.56518 .7779 Mabsadd L
.30952 .23535 -2.37764 .77254 Mabsadd L
.30952 .23535 -0.91448 -0.29713 Mabsadd L
.30952 .23535 -1.46946 -2.02254 Mabsadd L
.30952 .23535 0 -0.96154 Mabsadd L
.30952 .23535 1.46946 -2.02254 Mabsadd L
.30952 .23535 .91448 -0.29713 Mabsadd L
.30952 .23535 2.37764 .77254 Mabsadd L
.30952 .23535 .56518 .7779 Mabsadd L
.30952 .23535 0 2.5 Mabsadd L closepath F
.33333 .25941 0 2.5 Mabsadd m
.33333 .25941 -0.56518 .7779 Mabsadd L
.33333 .25941 -2.37764 .77254 Mabsadd L
.33333 .25941 -0.91448 -0.29713 Mabsadd L
.33333 .25941 -1.46946 -2.02254 Mabsadd L
.33333 .25941 0 -0.96154 Mabsadd L
.33333 .25941 1.46946 -2.02254 Mabsadd L
.33333 .25941 .91448 -0.29713 Mabsadd L
.33333 .25941 2.37764 .77254 Mabsadd L
.33333 .25941 .56518 .7779 Mabsadd L
.33333 .25941 0 2.5 Mabsadd L closepath F
.35714 .29532 0 2.5 Mabsadd m
.35714 .29532 -0.56518 .7779 Mabsadd L
.35714 .29532 -2.37764 .77254 Mabsadd L
.35714 .29532 -0.91448 -0.29713 Mabsadd L
.35714 .29532 -1.46946 -2.02254 Mabsadd L
.35714 .29532 0 -0.96154 Mabsadd L
.35714 .29532 1.46946 -2.02254 Mabsadd L
.35714 .29532 .91448 -0.29713 Mabsadd L
.35714 .29532 2.37764 .77254 Mabsadd L
.35714 .29532 .56518 .7779 Mabsadd L
.35714 .29532 0 2.5 Mabsadd L closepath F
.38095 .32831 0 2.5 Mabsadd m
.38095 .32831 -0.56518 .7779 Mabsadd L
.38095 .32831 -2.37764 .77254 Mabsadd L
.38095 .32831 -0.91448 -0.29713 Mabsadd L
.38095 .32831 -1.46946 -2.02254 Mabsadd L
.38095 .32831 0 -0.96154 Mabsadd L
.38095 .32831 1.46946 -2.02254 Mabsadd L
.38095 .32831 .91448 -0.29713 Mabsadd L
.38095 .32831 2.37764 .77254 Mabsadd L
.38095 .32831 .56518 .7779 Mabsadd L
.38095 .32831 0 2.5 Mabsadd L closepath F
.40476 .35842 0 2.5 Mabsadd m
.40476 .35842 -0.56518 .7779 Mabsadd L
.40476 .35842 -2.37764 .77254 Mabsadd L
.40476 .35842 -0.91448 -0.29713 Mabsadd L
.40476 .35842 -1.46946 -2.02254 Mabsadd L
.40476 .35842 0 -0.96154 Mabsadd L
.40476 .35842 1.46946 -2.02254 Mabsadd L
.40476 .35842 .91448 -0.29713 Mabsadd L
.40476 .35842 2.37764 .77254 Mabsadd L
.40476 .35842 .56518 .7779 Mabsadd L
.40476 .35842 0 2.5 Mabsadd L closepath F
.42857 .38577 0 2.5 Mabsadd m
.42857 .38577 -0.56518 .7779 Mabsadd L
.42857 .38577 -2.37764 .77254 Mabsadd L
.42857 .38577 -0.91448 -0.29713 Mabsadd L
.42857 .38577 -1.46946 -2.02254 Mabsadd L
.42857 .38577 0 -0.96154 Mabsadd L
.42857 .38577 1.46946 -2.02254 Mabsadd L
.42857 .38577 .91448 -0.29713 Mabsadd L
.42857 .38577 2.37764 .77254 Mabsadd L
.42857 .38577 .56518 .7779 Mabsadd L
.42857 .38577 0 2.5 Mabsadd L closepath F
.45238 .41049 0 2.5 Mabsadd m
.45238 .41049 -0.56518 .7779 Mabsadd L
.45238 .41049 -2.37764 .77254 Mabsadd L
.45238 .41049 -0.91448 -0.29713 Mabsadd L
.45238 .41049 -1.46946 -2.02254 Mabsadd L
.45238 .41049 0 -0.96154 Mabsadd L
.45238 .41049 1.46946 -2.02254 Mabsadd L
.45238 .41049 .91448 -0.29713 Mabsadd L
.45238 .41049 2.37764 .77254 Mabsadd L
.45238 .41049 .56518 .7779 Mabsadd L
.45238 .41049 0 2.5 Mabsadd L closepath F
.47619 .43276 0 2.5 Mabsadd m
.47619 .43276 -0.56518 .7779 Mabsadd L
.47619 .43276 -2.37764 .77254 Mabsadd L
.47619 .43276 -0.91448 -0.29713 Mabsadd L
.47619 .43276 -1.46946 -2.02254 Mabsadd L
.47619 .43276 0 -0.96154 Mabsadd L
.47619 .43276 1.46946 -2.02254 Mabsadd L
.47619 .43276 .91448 -0.29713 Mabsadd L
.47619 .43276 2.37764 .77254 Mabsadd L
.47619 .43276 .56518 .7779 Mabsadd L
.47619 .43276 0 2.5 Mabsadd L closepath F
.5 .45274 0 2.5 Mabsadd m
.5 .45274 -0.56518 .7779 Mabsadd L
.5 .45274 -2.37764 .77254 Mabsadd L
.5 .45274 -0.91448 -0.29713 Mabsadd L
.5 .45274 -1.46946 -2.02254 Mabsadd L
.5 .45274 0 -0.96154 Mabsadd L
.5 .45274 1.46946 -2.02254 Mabsadd L
.5 .45274 .91448 -0.29713 Mabsadd L
.5 .45274 2.37764 .77254 Mabsadd L
.5 .45274 .56518 .7779 Mabsadd L
.5 .45274 0 2.5 Mabsadd L closepath F
.52381 .47062 0 2.5 Mabsadd m
.52381 .47062 -0.56518 .7779 Mabsadd L
.52381 .47062 -2.37764 .77254 Mabsadd L
.52381 .47062 -0.91448 -0.29713 Mabsadd L
.52381 .47062 -1.46946 -2.02254 Mabsadd L
.52381 .47062 0 -0.96154 Mabsadd L
.52381 .47062 1.46946 -2.02254 Mabsadd L
.52381 .47062 .91448 -0.29713 Mabsadd L
.52381 .47062 2.37764 .77254 Mabsadd L
.52381 .47062 .56518 .7779 Mabsadd L
.52381 .47062 0 2.5 Mabsadd L closepath F
.54762 .48659 0 2.5 Mabsadd m
.54762 .48659 -0.56518 .7779 Mabsadd L
.54762 .48659 -2.37764 .77254 Mabsadd L
.54762 .48659 -0.91448 -0.29713 Mabsadd L
.54762 .48659 -1.46946 -2.02254 Mabsadd L
.54762 .48659 0 -0.96154 Mabsadd L
.54762 .48659 1.46946 -2.02254 Mabsadd L
.54762 .48659 .91448 -0.29713 Mabsadd L
.54762 .48659 2.37764 .77254 Mabsadd L
.54762 .48659 .56518 .7779 Mabsadd L
.54762 .48659 0 2.5 Mabsadd L closepath F
.57143 .5008 0 2.5 Mabsadd m
.57143 .5008 -0.56518 .7779 Mabsadd L
.57143 .5008 -2.37764 .77254 Mabsadd L
.57143 .5008 -0.91448 -0.29713 Mabsadd L
.57143 .5008 -1.46946 -2.02254 Mabsadd L
.57143 .5008 0 -0.96154 Mabsadd L
.57143 .5008 1.46946 -2.02254 Mabsadd L
.57143 .5008 .91448 -0.29713 Mabsadd L
.57143 .5008 2.37764 .77254 Mabsadd L
.57143 .5008 .56518 .7779 Mabsadd L
.57143 .5008 0 2.5 Mabsadd L closepath F
.59524 .51343 0 2.5 Mabsadd m
.59524 .51343 -0.56518 .7779 Mabsadd L
.59524 .51343 -2.37764 .77254 Mabsadd L
.59524 .51343 -0.91448 -0.29713 Mabsadd L
.59524 .51343 -1.46946 -2.02254 Mabsadd L
.59524 .51343 0 -0.96154 Mabsadd L
.59524 .51343 1.46946 -2.02254 Mabsadd L
.59524 .51343 .91448 -0.29713 Mabsadd L
.59524 .51343 2.37764 .77254 Mabsadd L
.59524 .51343 .56518 .7779 Mabsadd L
.59524 .51343 0 2.5 Mabsadd L closepath F
.61905 .52464 0 2.5 Mabsadd m
.61905 .52464 -0.56518 .7779 Mabsadd L
.61905 .52464 -2.37764 .77254 Mabsadd L
.61905 .52464 -0.91448 -0.29713 Mabsadd L
.61905 .52464 -1.46946 -2.02254 Mabsadd L
.61905 .52464 0 -0.96154 Mabsadd L
.61905 .52464 1.46946 -2.02254 Mabsadd L
.61905 .52464 .91448 -0.29713 Mabsadd L
.61905 .52464 2.37764 .77254 Mabsadd L
.61905 .52464 .56518 .7779 Mabsadd L
.61905 .52464 0 2.5 Mabsadd L closepath F
.64286 .53456 0 2.5 Mabsadd m
.64286 .53456 -0.56518 .7779 Mabsadd L
.64286 .53456 -2.37764 .77254 Mabsadd L
.64286 .53456 -0.91448 -0.29713 Mabsadd L
.64286 .53456 -1.46946 -2.02254 Mabsadd L
.64286 .53456 0 -0.96154 Mabsadd L
.64286 .53456 1.46946 -2.02254 Mabsadd L
.64286 .53456 .91448 -0.29713 Mabsadd L
.64286 .53456 2.37764 .77254 Mabsadd L
.64286 .53456 .56518 .7779 Mabsadd L
.64286 .53456 0 2.5 Mabsadd L closepath F
.66667 .54333 0 2.5 Mabsadd m
.66667 .54333 -0.56518 .7779 Mabsadd L
.66667 .54333 -2.37764 .77254 Mabsadd L
.66667 .54333 -0.91448 -0.29713 Mabsadd L
.66667 .54333 -1.46946 -2.02254 Mabsadd L
.66667 .54333 0 -0.96154 Mabsadd L
.66667 .54333 1.46946 -2.02254 Mabsadd L
.66667 .54333 .91448 -0.29713 Mabsadd L
.66667 .54333 2.37764 .77254 Mabsadd L
.66667 .54333 .56518 .7779 Mabsadd L
.66667 .54333 0 2.5 Mabsadd L closepath F
.69048 .55108 0 2.5 Mabsadd m
.69048 .55108 -0.56518 .7779 Mabsadd L
.69048 .55108 -2.37764 .77254 Mabsadd L
.69048 .55108 -0.91448 -0.29713 Mabsadd L
.69048 .55108 -1.46946 -2.02254 Mabsadd L
.69048 .55108 0 -0.96154 Mabsadd L
.69048 .55108 1.46946 -2.02254 Mabsadd L
.69048 .55108 .91448 -0.29713 Mabsadd L
.69048 .55108 2.37764 .77254 Mabsadd L
.69048 .55108 .56518 .7779 Mabsadd L
.69048 .55108 0 2.5 Mabsadd L closepath F
.71429 .55791 0 2.5 Mabsadd m
.71429 .55791 -0.56518 .7779 Mabsadd L
.71429 .55791 -2.37764 .77254 Mabsadd L
.71429 .55791 -0.91448 -0.29713 Mabsadd L
.71429 .55791 -1.46946 -2.02254 Mabsadd L
.71429 .55791 0 -0.96154 Mabsadd L
.71429 .55791 1.46946 -2.02254 Mabsadd L
.71429 .55791 .91448 -0.29713 Mabsadd L
.71429 .55791 2.37764 .77254 Mabsadd L
.71429 .55791 .56518 .7779 Mabsadd L
.71429 .55791 0 2.5 Mabsadd L closepath F
.7381 .56392 0 2.5 Mabsadd m
.7381 .56392 -0.56518 .7779 Mabsadd L
.7381 .56392 -2.37764 .77254 Mabsadd L
.7381 .56392 -0.91448 -0.29713 Mabsadd L
.7381 .56392 -1.46946 -2.02254 Mabsadd L
.7381 .56392 0 -0.96154 Mabsadd L
.7381 .56392 1.46946 -2.02254 Mabsadd L
.7381 .56392 .91448 -0.29713 Mabsadd L
.7381 .56392 2.37764 .77254 Mabsadd L
.7381 .56392 .56518 .7779 Mabsadd L
.7381 .56392 0 2.5 Mabsadd L closepath F
.7619 .56921 0 2.5 Mabsadd m
.7619 .56921 -0.56518 .7779 Mabsadd L
.7619 .56921 -2.37764 .77254 Mabsadd L
.7619 .56921 -0.91448 -0.29713 Mabsadd L
.7619 .56921 -1.46946 -2.02254 Mabsadd L
.7619 .56921 0 -0.96154 Mabsadd L
.7619 .56921 1.46946 -2.02254 Mabsadd L
.7619 .56921 .91448 -0.29713 Mabsadd L
.7619 .56921 2.37764 .77254 Mabsadd L
.7619 .56921 .56518 .7779 Mabsadd L
.7619 .56921 0 2.5 Mabsadd L closepath F
.78571 .57386 0 2.5 Mabsadd m
.78571 .57386 -0.56518 .7779 Mabsadd L
.78571 .57386 -2.37764 .77254 Mabsadd L
.78571 .57386 -0.91448 -0.29713 Mabsadd L
.78571 .57386 -1.46946 -2.02254 Mabsadd L
.78571 .57386 0 -0.96154 Mabsadd L
.78571 .57386 1.46946 -2.02254 Mabsadd L
.78571 .57386 .91448 -0.29713 Mabsadd L
.78571 .57386 2.37764 .77254 Mabsadd L
.78571 .57386 .56518 .7779 Mabsadd L
.78571 .57386 0 2.5 Mabsadd L closepath F
.80952 .57794 0 2.5 Mabsadd m
.80952 .57794 -0.56518 .7779 Mabsadd L
.80952 .57794 -2.37764 .77254 Mabsadd L
.80952 .57794 -0.91448 -0.29713 Mabsadd L
.80952 .57794 -1.46946 -2.02254 Mabsadd L
.80952 .57794 0 -0.96154 Mabsadd L
.80952 .57794 1.46946 -2.02254 Mabsadd L
.80952 .57794 .91448 -0.29713 Mabsadd L
.80952 .57794 2.37764 .77254 Mabsadd L
.80952 .57794 .56518 .7779 Mabsadd L
.80952 .57794 0 2.5 Mabsadd L closepath F
.83333 .58152 0 2.5 Mabsadd m
.83333 .58152 -0.56518 .7779 Mabsadd L
.83333 .58152 -2.37764 .77254 Mabsadd L
.83333 .58152 -0.91448 -0.29713 Mabsadd L
.83333 .58152 -1.46946 -2.02254 Mabsadd L
.83333 .58152 0 -0.96154 Mabsadd L
.83333 .58152 1.46946 -2.02254 Mabsadd L
.83333 .58152 .91448 -0.29713 Mabsadd L
.83333 .58152 2.37764 .77254 Mabsadd L
.83333 .58152 .56518 .7779 Mabsadd L
.83333 .58152 0 2.5 Mabsadd L closepath F
.85714 .58466 0 2.5 Mabsadd m
.85714 .58466 -0.56518 .7779 Mabsadd L
.85714 .58466 -2.37764 .77254 Mabsadd L
.85714 .58466 -0.91448 -0.29713 Mabsadd L
.85714 .58466 -1.46946 -2.02254 Mabsadd L
.85714 .58466 0 -0.96154 Mabsadd L
.85714 .58466 1.46946 -2.02254 Mabsadd L
.85714 .58466 .91448 -0.29713 Mabsadd L
.85714 .58466 2.37764 .77254 Mabsadd L
.85714 .58466 .56518 .7779 Mabsadd L
.85714 .58466 0 2.5 Mabsadd L closepath F
.88095 .5874 0 2.5 Mabsadd m
.88095 .5874 -0.56518 .7779 Mabsadd L
.88095 .5874 -2.37764 .77254 Mabsadd L
.88095 .5874 -0.91448 -0.29713 Mabsadd L
.88095 .5874 -1.46946 -2.02254 Mabsadd L
.88095 .5874 0 -0.96154 Mabsadd L
.88095 .5874 1.46946 -2.02254 Mabsadd L
.88095 .5874 .91448 -0.29713 Mabsadd L
.88095 .5874 2.37764 .77254 Mabsadd L
.88095 .5874 .56518 .7779 Mabsadd L
.88095 .5874 0 2.5 Mabsadd L closepath F
.90476 .5898 0 2.5 Mabsadd m
.90476 .5898 -0.56518 .7779 Mabsadd L
.90476 .5898 -2.37764 .77254 Mabsadd L
.90476 .5898 -0.91448 -0.29713 Mabsadd L
.90476 .5898 -1.46946 -2.02254 Mabsadd L
.90476 .5898 0 -0.96154 Mabsadd L
.90476 .5898 1.46946 -2.02254 Mabsadd L
.90476 .5898 .91448 -0.29713 Mabsadd L
.90476 .5898 2.37764 .77254 Mabsadd L
.90476 .5898 .56518 .7779 Mabsadd L
.90476 .5898 0 2.5 Mabsadd L closepath F
.92857 .5919 0 2.5 Mabsadd m
.92857 .5919 -0.56518 .7779 Mabsadd L
.92857 .5919 -2.37764 .77254 Mabsadd L
.92857 .5919 -0.91448 -0.29713 Mabsadd L
.92857 .5919 -1.46946 -2.02254 Mabsadd L
.92857 .5919 0 -0.96154 Mabsadd L
.92857 .5919 1.46946 -2.02254 Mabsadd L
.92857 .5919 .91448 -0.29713 Mabsadd L
.92857 .5919 2.37764 .77254 Mabsadd L
.92857 .5919 .56518 .7779 Mabsadd L
.92857 .5919 0 2.5 Mabsadd L closepath F
.95238 .59374 0 2.5 Mabsadd m
.95238 .59374 -0.56518 .7779 Mabsadd L
.95238 .59374 -2.37764 .77254 Mabsadd L
.95238 .59374 -0.91448 -0.29713 Mabsadd L
.95238 .59374 -1.46946 -2.02254 Mabsadd L
.95238 .59374 0 -0.96154 Mabsadd L
.95238 .59374 1.46946 -2.02254 Mabsadd L
.95238 .59374 .91448 -0.29713 Mabsadd L
.95238 .59374 2.37764 .77254 Mabsadd L
.95238 .59374 .56518 .7779 Mabsadd L
.95238 .59374 0 2.5 Mabsadd L closepath F
.97619 .59534 0 2.5 Mabsadd m
.97619 .59534 -0.56518 .7779 Mabsadd L
.97619 .59534 -2.37764 .77254 Mabsadd L
.97619 .59534 -0.91448 -0.29713 Mabsadd L
.97619 .59534 -1.46946 -2.02254 Mabsadd L
.97619 .59534 0 -0.96154 Mabsadd L
.97619 .59534 1.46946 -2.02254 Mabsadd L
.97619 .59534 .91448 -0.29713 Mabsadd L
.97619 .59534 2.37764 .77254 Mabsadd L
.97619 .59534 .56518 .7779 Mabsadd L
.97619 .59534 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{725.125, 448.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;E0001`2000`400?l00000o`00003oo`3ooooo
0?ooomL0oooo003o0?ooool0ooooe`3oool00?l0ooooo`3ooooG0?ooo`006P3oool00`000000oooo
0?ooo`3o0?ooool0oooo^P3oool001X0oooo00<000000?ooo`3oool0o`3ooooo0?oookX0oooo000J
0?ooo`030000003oool0oooo0?l0ooooo`3ooonj0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
ool0oooo^P3oool001X0oooo00<000000?ooo`3oool0o`3ooooo0?oookX0oooo000J0?ooo`030000
003oool0oooo0?l0ooooo`3ooonj0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooool0oooo^P3o
ool001X0oooo00<000000?ooo`3oool0o`3ooooo0?oookX0oooo000J0?ooo`030000003oool0oooo
0?l0ooooo`3ooonj0?ooo`006P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0
ooooo`3ooonY0?ooo`006P3oool00`000000oooo0?ooo`0>0?ooo`800000o`3ooooo0?ooojX0oooo
000J0?ooo`030000003oool0oooo00`0oooo1@00003o0?ooool0ooooZ@3oool001X0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooool0ooooZ@3oool001X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooZ03oool001X0oooo00<000000?ooo`3o
ool03`3oool200000?l0ooooo`3ooonY0?ooo`006P3oool4000000l0oooo00<000000?ooo`3oool0
o`3ooooo0?ooojL0oooo000J0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3o
oooo0?ooojL0oooo000J0?ooo`030000003oool0oooo0100oooo0P00003o0?ooool0ooooZ03oool0
01X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooool0ooooYP3oool001X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooool0ooooYP3oool001X0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooool0ooooY@3oool001X0oooo00<0
00000?ooo`3oool04P3oool200000?l0ooooo`3ooonV0?ooo`006P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0?l0ooooo`3ooonT0?ooo`006P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0?l0ooooo`3ooonT0?ooo`006P3oool00`000000oooo0?ooo`0C0?ooo`80
0000o`3ooooo0?ooojD0oooo000J0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
o`3ooooo0?oooj<0oooo000J0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3o
oooo0?oooj<0oooo000J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooooo
0?oooj80oooo000J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oj80oooo000J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooooo0?oooj80
oooo000J0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooooo0?oooj40oooo
000J0?ooo`030000003oool0oooo01H0oooo0P00003o0?ooool0ooooXP3oool001X0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooool0ooooX03oool001X0oooo00<000000?oo
o`3oool05`3oool200000?l0ooooo`3ooonQ0?ooo`006P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonO0?ooo`006P3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0?l0ooooo`3ooonO0?ooo`006P3oool4000001L0oooo00<000000?ooo`3oool0o`3o
oooo0?oooil0oooo000J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooooo
0?oooih0oooo000J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oih0oooo000J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3ooooo0?oooid0
oooo000J0?ooo`030000003oool0oooo01X0oooo0P00003o0?ooool0ooooWP3oool001X0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?ooool0ooooW@3oool001X0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooool0ooooW03oool001X0oooo00<000000?oo
o`3oool06`3oool200000?l0ooooo`3ooonM0?ooo`006P3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonK0?ooo`006P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0?l0ooooo`3ooonK0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0?l0ooooo`3ooonJ0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0?l0ooooo`3ooonJ0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0?l0ooooo`3ooonJ0?ooo`006P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0
ooooo`3ooonI0?ooo`006P3oool00`000000oooo0?ooo`0N0?ooo`800000o`3ooooo0?oooiX0oooo
000J0?ooo`030000003oool0oooo01l0oooo0P00003o0?ooool0ooooV@3oool001X0oooo00<00000
0?ooo`3oool07P3oool300000?l0ooooo`3ooonI0?ooo`006P3oool00`000000oooo0?ooo`0M0?oo
o`D00000o`3ooooo0?oooiP0oooo000J0?ooo`030000003oool0oooo01l0oooo0P00003o0?ooool0
ooooV@3oool001X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooool0oooo
UP3oool001X0oooo00<000000?ooo`3oool08@3oool200000?l0ooooo`3ooonG0?ooo`006P3oool4
00000240oooo00<000000?ooo`3oool0o`3ooooo0?oooiD0oooo000J0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0o`3ooooo0?oooi@0oooo000J0?ooo`030000003oool0oooo02<0
oooo0P00003o0?ooool0ooooU@3oool001X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`3o0?ooool0ooooT`3oool001X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`1k0?ooo`D000000P3oool200000:80oooo100000030?ooo`800000XP3oool2000000@0oooo0P00
002S0?ooo`<000000P3oool2000000h0oooo000J0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0O03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000:00oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00002S0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool02`3oool001X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1k0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000XP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0WP3oool5000000050?ooo`000000oooo0?ooo`0000003@3oool001X0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1k0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`2Q0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`2Q0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0WP3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000d0oooo000J0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0NP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0W`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0:00oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00002Q0?ooo`030000003o
ool000000080oooo00@000000?ooo`3oool000003@3oool001X0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`1h0?ooo`800000103oool200000:<0oooo0P0000040?ooo`800000XP3o
ool2000000@0oooo0P00002S0?ooo`8000000`3oool2000000h0oooo000J0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooohl0oooo000J0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0o`3ooooo0?ooohh0oooo000J0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0o`3ooooo0?ooohh0oooo000J0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0o`3ooooo0?ooohd0oooo000J0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooh`0oooo000J0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooh`0oooo000J0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0o`3ooooo0?oooh/0oooo000J0?ooo`030000003oool0oooo02`0oooo0P00003o0?ooool0
ooooS03oool001X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?ooool0oooo
RP3oool001X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?ooool0ooooR@3o
ool001X0oooo00<000000?ooo`3oool0;P3oool200000?l0ooooo`3ooon:0?ooo`002@3ooooo0000
0?l00000cP00000001X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0=0?ooo`<0
00003`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00d0oooo0`00000?0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003o
ool0oooo02h0oooo1@00001d0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0
oooo0300oooo0P00001e0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0Y`3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0o`3ooooo0?ooohD0oooo000J0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0o`3ooooo0?ooohD0oooo000J0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0o`3ooooo0?oooh@0oooo000J0?ooo`030000003oool0oooo03<0oooo0P00
003o0?ooool0ooooQ@3oool001X0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o
0?ooool0ooooP`3oool001X0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?oo
ool0ooooP`3oool001X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?ooool0
ooooPP3oool001X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?ooool0oooo
PP3oool001X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?ooool0ooooP@3o
ool001X0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?ooool0ooooP03oool0
01X0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?ooool0ooooP03oool001X0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooool0ooooO`3oool001X0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?ooool0ooooO`3oool001X0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?ooool0ooooOP3oool001X0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?ooool0ooooOP3oool001X0oooo1000000i0?oo
o`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`006P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomm0?ooo`006P3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0?l0ooooo`3oooml0?ooo`006P3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomk0?ooo`006P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo0?l0ooooo`3ooomk0?ooo`006P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0?l0ooooo`3ooomj0?ooo`006P3oool00`000000oooo0?ooo`0m0?ooo`800000o`3ooooo0?ooog/0
oooo000J0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooooo0?ooogT0oooo
000J0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooooo0?ooogT0oooo000J
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooooo0?ooogP0oooo000J0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooooo0?ooogP0oooo000J0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0o`3ooooo0?ooogL0oooo000J0?ooo`030000
003oool0oooo0400oooo0`00003o0?ooool0ooooM`3oool001X0oooo00<000000?ooo`3oool0@03o
ool300000?l0ooooo`3ooomg0?ooo`006P3oool00`000000oooo0?ooo`0o0?ooo`D00000o`3ooooo
0?ooogH0oooo000J0?ooo`030000003oool0oooo0440oooo00@000000?ooo`0000000000o`3ooooo
0?ooogD0oooo000J0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3ooooo0?oo
og<0oooo000J0?ooo`030000003oool0oooo04D0oooo0P00003o0?ooool0ooooL`3oool001X0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o0?ooool0ooooL@3oool001X0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?ooool0ooooL03oool001X0oooo00<00000
0?ooo`3oool0B03oool200000?l0ooooo`3ooom`0?ooo`006P3oool4000004P0oooo0P00003o0?oo
ool0ooooK`3oool001X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooool0
ooooK03oool001X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooool0oooo
J`3oool001X0oooo00<000000?ooo`3oool0C@3oool200000?l0ooooo`3ooom[0?ooo`006P3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`006P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo0?l0ooooo`3ooomX0?ooo`006P3oool00`000000
oooo0?ooo`1@0?ooo`<00000o`3ooooo0?ooofL0oooo000J0?ooo`030000003oool0oooo0540oooo
0`00003o0?ooool0ooooIP3oool001X0oooo00<000000?ooo`3oool0D@3oool300000200oooo00<0
00000?ooo`3oool0o`3ooooo0?oood<0oooo000J0?ooo`030000003oool0oooo0500oooo1@00000O
0?ooo`800000o`3ooooo0?oood@0oooo000J0?ooo`030000003oool0oooo05D0oooo0P00000L0?oo
o`<00000o`3ooooo0?oood@0oooo000J0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool06@3oool300000?l0ooooo`3ooom50?ooo`006P3oool00`000000oooo0?ooo`1G0?ooo`800000
5`3oool2000000<0oooo00<000000?ooo`3oool0o`3ooooo0?oood80oooo000J0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?l0ooooo`3ooom20?ooo`006P3oool00`000000oooo0?ooo`1J0?ooo`8000004@3oool2
000000L0oooo00<000000?ooo`3oool0o`3ooooo0?oood40oooo000J0?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool0303oool2000000T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
od40oooo000J0?ooo`030000003oool0oooo05d0oooo0P00000:0?ooo`8000002`3oool00`000000
oooo0?ooo`3o0?ooool0oooo@@3oool001X0oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooooo0?oood00oooo
000J0?ooo`030000003oool0oooo0600oooo0P0000040?ooo`8000003`3oool00`000000oooo0?oo
o`3o0?ooool0oooo@03oool001X0oooo00<000000?ooo`3oool0H@3oool500000180oooo00<00000
0?ooo`3oool0o`3ooooo0?ooocl0oooo000J0?ooo`030000003oool0oooo0680oooo0`00000C0?oo
o`030000003oool0oooo0?l0ooooo`3ooolo0?ooo`006P3oool400000600oooo1@00000B0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolo0?ooo`006P3oool00`000000oooo0?ooo`1S0?ooo`050000
003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`3o0?ooool0oooo?P3oool001X0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`3o0?ooool0oooo?P3oool001X0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3o
oolm0?ooo`006P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0?l0ooooo`3ooolm
0?ooo`006P3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0o`3ooooo0?ooocd0oooo000J0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`3o0?ooool0oooo?03oool001X0oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`3o0?ooool0oooo?03oool001X0oooo00<000000?ooo`3oool0L`3o
ool2000000L0oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo000J0?ooo`030000003oool0
oooo0780oooo1@0000050?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`006P3oool00`00
0000oooo0?ooo`1d0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3ooooo
0?oooc/0oooo000J0?ooo`030000003oool0oooo07X0oooo00@000000?ooo`3oool00000o`3ooooo
0?oooc`0oooo000J0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ocX0oooo000J0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool00P00003o0?ooool0
oooo>03oool001X0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`020?ooo`040000
003oool0000000000?l0ooooo`3ooolc0?ooo`006P3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo00<0oooo0P00003o0?ooool0oooo=03oool001X0oooo00<000000?ooo`3oool0O`3o
ool010000000oooo0?ooo`3oool500000?l0ooooo`3ooolb0?ooo`006P3oool00`000000oooo0?oo
o`1o0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?ooool0oooo;@3oool001X0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0;
0?ooo`8000000P3oool00`000000oooo0?ooo`3o0?ooool0oooo9P3oool001X0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0000003oool00P00003o
0?ooool0oooo8P3oool001X0oooo1000001o0?ooo`030000003oool0oooo0180oooo1000003o0?oo
ool0oooo8@3oool001X0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0@0?ooo`D0
00000P3oool00`000000oooo0?ooo`3o0?ooool0oooo703oool001X0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000
003oool0oooo0080oooo0P00003o0?ooool0oooo4@3oool001X0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`0Q0?ooo`<00000o`3ooooo0?oooa80oooo000J0?ooo`030000003oool0
oooo0880oooo00<000000?ooo`3oool0803oool500000080oooo0P00003o0?ooool0oooo303oool0
01X0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P0000030?ooo`800000o`3ooooo0?ooo`006P3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo0300oooo0`0000000`3oool000000?ooo`3o0?ooood0
oooo000J0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0<03oool500000080oooo
0P0000020?ooo`030000003oool0oooo00D0oooo0P00003o0?ooonh0oooo000J0?ooo`030000003o
ool0oooo08<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`090?ooo`8000000P3o
ool200000?l0ooook`3oool001X0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`10
0?ooo`D00000o`3oooo]0?ooo`006P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo
0480oooo00<000000?ooo`000000o`3oooo]0?ooo`006P3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo0?l0ooooo`3ooolb0?ooo`006P3oool00`000000oooo0?ooo`240?ooo`<00000
AP3oool200000?l0oooojP3oool001X0oooo00<000000?ooo`3oool0Q@3oool200000?l0ooooo`3o
oolc0?ooo`006P3oool00`000000oooo0?ooo`250?ooo`800000o`3ooooo0?oooc<0oooo000J0?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o0?oo
onH0oooo000J0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0o`3ooooo0?oooc00
oooo000J0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0A`3oool200000?l0oooo
i@3oool001X0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`3o0?ooool0oooo;`3o
ool000030?ooo`000000000000<000000P3oool2000000@0oooo0P00000:0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0o`3ooooo0?ooobh0oooo00030?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0o`3ooooQ0?ooo`000`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00L0oooo1P0000270?ooo`030000003oool0oooo0?l0ooooo`3oool]0?oo
o`000`3oool00`000000oooo0?ooo`080?ooo`8000002P3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0o`3ooooO0?ooo`000`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`3o0?ooool0oooo;03oool00080oooo0P00000:0?ooo`<000002@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0o`3ooooK0?ooo`006P3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooooL
0?ooo`006P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04P0oooo1@00003o0?oo
om`0oooo000J0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0000003o0?ooom`0oooo000J0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`3o0?ooomX0oooo000J0?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooobP0oooo000J0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooomP0oooo000J0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?ooomP0oooo000J0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0o`3ooooo0?ooobL0oooo000J0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooomH0oooo
000J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`3o0?ooomH0oooo000J0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0o`3ooooo
0?ooobD0oooo000J0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`3o0?ooomD0oooo000J0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`3o0?ooom@0oooo000J0?ooo`030000003oool0oooo09@0oooo
00<000000?ooo`3oool0o`3ooooo0?ooob<0oooo000J0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool0C03oool200000?l0ooooe03oool001X0oooo00<000000?ooo`3oool0U@3oool2
00000?l0ooooo`3ooolS0?ooo`006P3oool00`000000oooo0?ooo`2E0?ooo`<00000o`3ooooo0?oo
ob80oooo000J0?ooo`@00000U03oool3000004d0oooo0P00003o0?ooom80oooo000J0?ooo`030000
003oool0oooo09H0oooo0P00003o0?ooool0oooo8P3oool001X0oooo00<000000?ooo`3oool0V03o
ool00`000000oooo0?ooo`3o0?ooool0oooo7`3oool001X0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`1<0?ooo`800000o`3oooo@0?ooo`006P3oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo0?l0ooooo`3ooolN0?ooo`006P3oool00`000000oooo0?ooo`2J0?ooo`03
0000003oool0oooo0?l0ooooo`3ooolM0?ooo`006P3oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0o`3oooo=0?ooo`006P3oool00`000000oooo0?oo
o`2K0?ooo`030000003oool0oooo0?l0ooooo`3ooolL0?ooo`006P3oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo04`0oooo0P00003o0?oool`0oooo000J0?ooo`030000003oool0oooo
09d0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oool/0oooo000J0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0B03oool500000?l0oooob`3oool001X0oooo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo
b`3oool001X0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0?l0oooob@3oool001X0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`3o
0?ooool0oooo5`3oool001X0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo0?l0ooooa`3oool001X0oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0ooooaP3oool001X0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`3o0?ooool0oooo5@3oool001X0oooo00<000000?ooo`3oool0X`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0ooooa@3oool001X0oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0ooooa03oool0
01X0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`3o0?ooool0oooo4P3oool001X0
oooo1000002T0?ooo`030000003oool0oooo04/0oooo0P00003o0?oool@0oooo000J0?ooo`030000
003oool0oooo0:H0oooo0P00003o0?ooool0oooo4P3oool001X0oooo00<000000?ooo`3oool0YP3o
ool300000?l0ooooo`3ooolA0?ooo`006P3oool00`000000oooo0?ooo`2W0?ooo`800000C03oool2
00000?l0oooo`P3oool001X0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0000003o0?oo
ool0oooo403oool001X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`3o0?ooool0
oooo3@3oool001X0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`190?ooo`800000
o`3oooo00?ooo`006P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0?l0ooooo`3o
ool;0?ooo`006P3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0?l0ooooo`3oool:
0?ooo`006P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo04P0oooo0P00003o0?oo
okh0oooo000J0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`P0
oooo000J0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`3o0?oookX0oooo000J0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`3o0?oookX0oooo000J0?ooo`030000003oool0oooo0;40oooo00<00000
0?ooo`3oool0AP3oool500000?l0oooo^P3oool001X0oooo00<000000?ooo`3oool0/P3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo^03oool001X0oooo00<000000?ooo`3o
ool0/`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0oooo^03oool001X0oooo
00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`3o0?ooool0oooo0`3oool001X0oooo00<0
00000?ooo`3oool0]@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0oooo]P3o
ool001X0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0000003o0?ooool0oooo0@3oool0
01X0oooo00<000000?ooo`3oool0]`3oool300000?l0ooooo`3oool001X0oooo00<000000?ooo`3o
ool0]`3oool3000004P0oooo00<000000?ooo`3oool0o`3ooond0?ooo`006P3oool400000;L0oooo
0P00003o0?ooool0oooo000J0?ooo`030000003oool0oooo0;X0oooo0P0000180?ooo`030000003o
ool0oooo0?l0oooo/P3oool001X0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo0?l0oooo/P3oool001X0oooo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`3o0?ooooT0oooo000J0?ooo`030000003oool0oooo0;h0oooo0P0000160?ooo`03
0000003oool0oooo0?l0oooo/03oool001X0oooo00<000000?ooo`3oool0`03oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0?l0oooo[`3oool001X0oooo00<000000?ooo`3oool0`@3o
ool00`000000oooo0?ooo`3o0?ooooD0oooo000J0?ooo`030000003oool0oooo0<80oooo0P000014
0?ooo`800000o`3ooon_0?ooo`006P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo
0?l0oooolP3oool001X0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`3o0?oooo40
oooo000J0?ooo`030000003oool0oooo0<H0oooo0P0000130?ooo`030000003oool0oooo0?l0oooo
Z`3oool001X0oooo00<000000?ooo`3oool0b03oool200000?l0ooook`3oool001X0oooo00<00000
0?ooo`3oool0b03oool300000480oooo0P00003o0?ooojX0oooo000J0?ooo`030000003oool0oooo
0<T0oooo0P0000120?ooo`030000003oool0oooo0?l0ooooZ@3oool001X0oooo00<000000?ooo`3o
ool0b@3oool00`000000oooo0000000o0?ooo`D00000o`3ooonY0?ooo`006P3oool00`000000oooo
0?ooo`3;0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooonW0?ooo`006P3o
ool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo0?l0oooojP3oool001X0oooo00<00000
0?ooo`3oool0c@3oool00`000000oooo0?ooo`3o0?ooonT0oooo000J0?ooo`030000003oool0oooo
0<h0oooo00<000000?ooo`3oool0@03oool200000?l0ooooYP3oool001X0oooo00<000000?ooo`3o
ool0c`3oool00`000000oooo0?ooo`3o0?ooonL0oooo000J0?ooo`030000003oool0oooo0<l0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?oooj80oooo000J0?ooo`@00000c`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooXP3oool001X0oooo00<00000
0?ooo`3oool0d@3oool00`000000oooo0?ooo`3o0?ooonD0oooo000J0?ooo`030000003oool0oooo
0=80oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oooj00oooo000J0?ooo`03
0000003oool0oooo0=<0oooo00<000000?ooo`3oool0o`3ooooS0?ooo`006P3oool00`000000oooo
0?ooo`3D0?ooo`030000003oool0oooo0?l0oooohP3oool001X0oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`110?ooo`800000o`3ooonO0?ooo`006P3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0?l0ooooh@3oool001X0oooo00<000000?ooo`3oool0eP3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo0?l0ooooV`3oool001X0oooo00<000000?ooo`3o
ool0e`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooV`3oool001X0oooo
00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`3o0?ooomh0oooo000J0?ooo`030000003o
ool0oooo0=P0oooo00<000000?ooo`000000@P3oool00`000000oooo0?ooo`3o0?oooiT0oooo000J
0?ooo`030000003oool0oooo0=T0oooo0`0000120?ooo`030000003oool0oooo0?l0ooooV03oool0
01X0oooo00<000000?ooo`3oool0f@3oool300000400oooo1@00003o0?oooiP0oooo000J0?ooo`03
0000003oool0oooo0=X0oooo0P0000120?ooo`030000003oool000000?l0ooooV03oool001X0oooo
00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`3o0?ooom/0oooo000J0?ooo`030000003o
ool0oooo0=`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?oooi@0oooo000J
0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool0o`3ooooI0?ooo`006P3oool00`00
0000oooo0?ooo`3N0?ooo`030000003oool0oooo0?l0oooof03oool001X0oooo00<000000?ooo`3o
ool0gP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0?l0ooooTP3oool000d0oooo
100000090?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0o`3ooooG0?ooo`003@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0@`3o
ool200000?l0ooooT@3oool000h0oooo00<000000?ooo`3oool02@3oool600000=d0oooo00<00000
0?ooo`3oool0o`3ooooF0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0>40oooo00<000000?ooo`3oool0o`3ooooE0?ooo`003@3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0>80oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?oo
ohd0oooo000>0?ooo`8000002P3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo0?l0
ooood`3oool001X0oooo00<000000?ooo`3oool0h`3oool00`000000oooo0?ooo`150?ooo`800000
o`3ooon<0?ooo`006P3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo0?l0oooodP3o
ool001X0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`3o0?ooom40oooo000J0?oo
o`030000003oool0oooo0>D0oooo00<000000?ooo`3oool0AP3oool300000?l0ooooR03oool001X0
oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0?l0
ooooQ`3oool001X0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`130?ooo`D00000
o`3ooon70?ooo`006P3oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo0?l0ooooc`3o
ool001X0oooo00<000000?ooo`3oool0j03oool00`000000oooo0?ooo`3o0?ooolh0oooo000J0?oo
o`030000003oool0oooo0>T0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?oo
oh<0oooo000J0?ooo`030000003oool0oooo0>X0oooo0P00003o0?ooold0oooo000J0?ooo`030000
003oool0oooo0>X0oooo0`0000180?ooo`800000o`3ooon20?ooo`006P3oool00`000000oooo0?oo
o`3Z0?ooo`<00000o`3oooo<0?ooo`006P3oool00`000000oooo0?ooo`3[0?ooo`800000B`3oool0
0`000000oooo0?ooo`3o0?ooogh0oooo000J0?ooo`030000003oool0oooo0>d0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`3o0?ooogh0oooo000J0?ooo`030000003oool0oooo0>h0
oooo00<000000?ooo`3oool0o`3oooo80?ooo`006P3oool00`000000oooo0?ooo`3_0?ooo`030000
003oool0oooo04P0oooo0P00003o0?ooogd0oooo000J0?ooo`@00000k`3oool00`000000oooo0?oo
o`3o0?ooolH0oooo000J0?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`3o0?ooogT0oooo000J0?ooo`030000003oool0oooo0?40oooo00<000000?oo
o`3oool0o`3oooo50?ooo`006P3oool00`000000oooo0?ooo`3b0?ooo`030000003oool0oooo04/0
oooo0P00003o0?ooogL0oooo000J0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`3o0?ooogH0oooo000J0?ooo`030000003oool0oooo0?@0oooo00<0
00000?ooo`3oool0A`3oool500000?l0ooooMP3oool001X0oooo00<000000?ooo`3oool0m@3oool0
0`000000oooo0?ooo`1:0?ooo`800000o`3ooome0?ooo`006P3oool00`000000oooo0?ooo`3f0?oo
o`030000003oool0oooo0?l0oooo`03oool001X0oooo00<000000?ooo`3oool0m`3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0ooooL@3oool001X0oooo00<000000?ooo`3oool0
n03oool00`000000oooo0?ooo`3o0?oookh0oooo000J0?ooo`030000003oool0oooo0?T0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooofh0oooo000J0?ooo`030000003oool0
oooo0?T0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooofh0oooo000J0?oo
o`030000003oool0oooo0?X0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?oo
of`0oooo000J0?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`3o0?ooof/0oooo000J0?ooo`030000003oool0oooo0?`0oooo0P00003o0?oook/0oooo
000J0?ooo`030000003oool0oooo0?/0oooo0`00001?0?ooo`030000003oool0oooo0?l0ooooJ@3o
ool001X0oooo00<000000?ooo`3oool0o03oool300000?l0oooo^P3oool001X0oooo00<000000?oo
o`3oool0o@3oool00`000000oooo0000001@0?ooo`030000003oool0oooo0?l0ooooIP3oool001X0
oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0o`3ooomU0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0
B`3oool500000?l0ooooI@3oool001X0oooo00<000000?ooo`3oool0o`3oool30?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`006P3oool400000?l0oooo0`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0?l0ooooH@3oool001X0oooo00<000000?oo
o`3oool0o`3oool50?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0o`3ooomP0?oo
o`006P3oool00`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`3o0?oooeh0oooo000J0?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0?l0ooooGP3oool001X0oooo00<000000?ooo`3oool0o`3o
ool80?ooo`030000003oool0oooo0?l0oooo[`3oool001X0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0o`3ooomK0?ooo`006P3oool00`00
0000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0o`3ooon]0?ooo`006P3oool00`000000
oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?oooeP0
oooo000J0?ooo`030000003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`3o0?oooj/0oooo
000J0?ooo`030000003oool0oooo0?l0oooo3@3oool00`000000oooo0?ooo`1A0?ooo`@00000o`3o
oomE0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`h0oooo0P00001C0?ooo`030000003oool0
oooo0?l0ooooE03oool001X0oooo00<000000?ooo`3oool0o`3oool=0?ooo`<00000D@3oool50000
0?l0ooooE03oool001X0oooo00<000000?ooo`3oool0o`3oool>0?ooo`<00000o`3ooonY0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`000000E@3oool00`000000oooo
0?ooo`3o0?oooe00oooo000J0?ooo`030000003oool0oooo0?l0oooo4P3oool00`000000oooo0?oo
o`3o0?ooojD0oooo000J0?ooo`030000003oool0oooo0?l0oooo4`3oool2000005D0oooo00<00000
0?ooo`3oool0o`3ooom=0?ooo`006P3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<000000?oo
o`3oool0o`3ooonR0?ooo`006P3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`3o0?ooodX0oooo000J0?ooo`030000003oool0oooo0?l0oooo
5`3oool00`000000oooo0?ooo`3o0?oooj00oooo000J0?ooo`030000003oool0oooo0?l0oooo603o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0ooooA`3oool001X0oooo00<00000
0?ooo`3oool0o`3ooolI0?ooo`030000003oool0oooo0?l0ooooWP3oool001X0oooo1000003o0?oo
oaT0oooo00<000000?ooo`3oool0EP3oool200000?l0ooooA@3oool001X0oooo00<000000?ooo`3o
ool0o`3ooolK0?ooo`800000EP3oool400000?l0oooo@`3oool001X0oooo00<000000?ooo`3oool0
o`3ooolM0?ooo`030000003oool0oooo0580oooo1@00003o0?oood<0oooo000J0?ooo`030000003o
ool0oooo0?l0oooo7P3oool00`000000oooo0000001H0?ooo`030000003oool0oooo0?l0oooo?P3o
ool001X0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`800000o`3ooonI0?ooo`006P3oool00`00
0000oooo0?ooo`3o0?oooah0oooo0`00001K0?ooo`030000003oool0oooo0?l0oooo>`3oool001X0
oooo00<000000?ooo`3oool0o`3ooolO0?ooo`@00000o`3ooonG0?ooo`006P3oool00`000000oooo
0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?ooocP0oooo
000J0?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`3o0?oooi<0oooo000J
0?ooo`030000003oool0oooo0?l0oooo9@3oool2000005/0oooo00<000000?ooo`3oool0o`3ooole
0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?ooo`3oool0F`3oool20000
0?l0oooo<`3oool001X0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`800000F`3oool00`000000
oooo0?ooo`3o0?oooc80oooo000J0?ooo`030000003oool0oooo0?l0oooo:P3oool00`000000oooo
0?ooo`1F0?ooo`H00000o`3ooola0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooob/0oooo0P00
003o0?ooohd0oooo000J0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0?l0oooo;03oool001X0oooo00<000000?ooo`3oool0o`3oool^0?oo
o`040000003oool0oooo000005`0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`006P3oool00`00
0000oooo0?ooo`3o0?ooobl0oooo0`00001L0?ooo`030000003oool0oooo0?l0oooo:@3oool001X0
oooo00<000000?ooo`3oool0o`3oool_0?ooo`<00000G`3oool00`000000oooo0?ooo`3o0?ooobH0
oooo000J0?ooo`030000003oool0oooo0?l0oooo<03oool400000?l0ooooQP3oool001X0oooo00<0
00000?ooo`3oool0o`3ooold0?ooo`800000GP3oool400000?l0oooo8P3oool001X0oooo1000003o
0?ooocD0oooo00<000000?ooo`3oool0G@3oool300000?l0oooo8@3oool001X0oooo00<000000?oo
o`3oool0o`3ooolg0?ooo`800000F`3oool500000?l0oooo8@3oool001X0oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`800000G`3oool200000?l0oooo7P3oool001X0oooo00<000000?ooo`3oool0
o`3ooolk0?ooo`800000H@3oool00`000000oooo0?ooo`3o0?oooaT0oooo000J0?ooo`030000003o
ool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`3o0?ooogX0oooo000J0?ooo`030000003oool0
oooo0?l0oooo?P3oool200000640oooo00<000000?ooo`3oool0o`3ooolF0?ooo`006P3oool00`00
0000oooo0?ooo`3o0?oood00oooo0`00001Q0?ooo`030000003oool0oooo0?l0oooo4`3oool001X0
oooo00<000000?ooo`3oool0o`3ooom00?ooo`<00000I03oool200000?l0oooo4@3oool001X0oooo
00<000000?ooo`3oool0o`3ooom10?ooo`@00000HP3oool00`000000oooo0?ooo`3o0?oooa00oooo
000J0?ooo`030000003oool0oooo0?l0oooo@P3oool00`000000oooo0?ooo`02000005h0oooo1`00
003o0?ooo`h0oooo000J0?ooo`030000003oool0oooo0?l0ooooA`3oool2000006@0oooo00<00000
0?ooo`3oool0o`3oool:0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooodT0oooo0P00001S0?oo
o`030000003oool0oooo0?l0oooo2@3oool001X0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`80
0000I03oool00`000000oooo0?ooo`3o0?ooo`H0oooo000J0?ooo`030000003oool0oooo0?l0oooo
C@3oool2000006D0oooo00<000000?ooo`3oool0o`3oool30?ooo`006P3oool00`000000oooo0?oo
o`3o0?ooodl0oooo0P00001V0?ooo`<00000o`3oool001X0oooo00<000000?ooo`3oool0o`3ooomA
0?ooo`<00000I03oool00`000000oooo0?ooo`3n0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
oe40oooo1000001Q0?ooo`H00000o@3oool001X0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`80
000000<0oooo000000000000I`3oool00`000000oooo0?ooo`3h0?ooo`006P3oool00`000000oooo
0?ooo`3o0?oooe<0oooo00@000000?ooo`3oool0oooo0P00001X0?ooo`030000003oool0oooo0?D0
oooo00000`3oool0000000000002000000<0oooo0P0000040?ooo`8000002P3oool00`000000oooo
0?ooo`3o0?oooeT0oooo0P00001Y0?ooo`030000003oool0oooo0?80oooo00000`3oool000000?oo
o`0:0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`800000
J03oool010000000oooo0?ooo`3oool200000>h0oooo00020?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01`3oool600000?l0ooooFP3oool2000006T0oooo0P00003_0?ooo`000`3o
ool00`000000oooo0?ooo`080?ooo`8000002P3oool00`000000oooo0?ooo`3o0?oooel0oooo0P00
00030?ooo`030000003oool0oooo0600oooo1@00003]0?ooo`0000D0oooo0000003oool0oooo0000
00090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooomQ0?ooo`@00000J@3o
ool200000>T0oooo00020?ooo`8000002P3oool3000000T0oooo00<000000?ooo`3oool0o`3ooomR
0?ooo`@00000K03oool00`000000oooo0?ooo`3T0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
of<0oooo0P000000103oool0000000000000001/0?ooo`030000003oool0oooo0>40oooo000J0?oo
o`030000003oool0oooo0?l0ooooJ@3oool3000006`0oooo0`00003N0?ooo`006P3oool00`000000
oooo0?ooo`3o0?ooof`0oooo0P00001[0?ooo`@00000g03oool001X0oooo00<000000?ooo`3oool0
o`3ooom^0?ooo`<00000I`3oool500000080oooo00<000000?ooo`3oool0e`3oool001X0oooo00<0
00000?ooo`3oool0o`3oooma0?ooo`D00000K03oool200000=D0oooo000J0?ooo`030000003oool0
oooo0?l0ooooL`3oool4000006l0oooo00<000000?ooo`3oool0d03oool001X0oooo00<000000?oo
o`3oool0o`3ooomd0?ooo`80000000<0oooo0000000000000P00001^0?ooo`030000003oool00000
0<d0oooo000J0?ooo`030000003oool0oooo0?l0ooooM@3oool00`000000oooo0?ooo`030?ooo`<0
0000J`3oool500000</0oooo000J0?ooo`030000003oool0oooo0?l0ooooOP3oool3000006l0oooo
00<000000?ooo`3oool0aP3oool001X0oooo00<000000?ooo`3oool0o`3ooon10?ooo`H00000K03o
ool200000080oooo00<000000?ooo`3oool0_`3oool001X0oooo00<000000?ooo`3oool0o`3ooon4
0?ooo`@00000K`3oool01@000000oooo0?ooo`000000oooo00800000^`3oool001X0oooo00<00000
0?ooo`3oool0o`3ooon50?ooo`80000000<0oooo0000000000000P00001`0?ooo`<00000^P3oool0
01X0oooo00<000000?ooo`3oool0o`3ooon60?ooo`030000003oool0oooo00<0oooo0`00001[0?oo
o`D000000P3oool00`000000oooo0?ooo`2e0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooohl0
oooo0`00001b0?ooo`8000000P3oool00`000000oooo0?ooo`2^0?ooo`006P3oool00`000000oooo
0?ooo`3o0?oooi80oooo1P00001`0?ooo`060000003oool0oooo0000003oool00000Z`3oool001X0
oooo00<000000?ooo`3oool0o`3ooonE0?ooo`D00000LP3oool400000:T0oooo000J0?ooo`030000
003oool0oooo0?l0ooooUP3oool200000080oooo1000001]0?ooo`D000000P3oool00`000000oooo
0?ooo`0200000:80oooo000J0?ooo`@00000o`3ooonF0?ooo`030000003oool0oooo00@0oooo1000
00060?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool00P3oool2000009T0oooo000J
0?ooo`030000003oool0oooo0?l0ooooXP3oool4000000030?ooo`000000000007<0oooo0`000000
0`3oool000000?ooo`2G0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooojH0oooo1@00001a0?oo
o`D000000P3oool200000080oooo00<000000?ooo`3oool0S`3oool001X0oooo00<000000?ooo`3o
ool0o`3ooonW0?ooo`8000000P3oool6000007H0oooo00@000000?ooo`3oool00000103oool20000
08P0oooo000J0?ooo`030000003oool0oooo0?l0oooo/@3oool6000000030?ooo`000000000007<0
oooo0`0000000`3oool000000?ooo`260?ooo`006P3oool00`000000oooo0?ooo`3o0?oookL0oooo
1@00001a0?ooo`D000000P3oool200000080oooo00<000000?ooo`3oool0OP3oool001X0oooo00<0
00000?ooo`3oool0o`3ooonh0?ooo`8000000P3oool6000007T0oooo0P0000020?ooo`<00000M`3o
ool001X0oooo00<000000?ooo`3oool0o`3oooni0?ooo`030000003oool0oooo00H0oooo1P000000
0`3oool000000000001c0?ooo`H000000P3oool00`000000oooo0?ooo`1`0?ooo`006P3oool00`00
0000oooo0?ooo`3o0?ooolP0oooo1`00001j0?ooo`8000000P3oool010000000oooo0?ooo`3oool2
000006H0oooo000J0?ooo`030000003oool0oooo0?l0oooob@3oool2000000@0oooo200000030?oo
o`800000M03oool500000080oooo00<000000?ooo`3oool0G`3oool001X0oooo00<000000?ooo`3o
ool0o`3oooo:0?ooo`030000003oool0oooo00X0oooo1`00001a0?ooo`D000001P3oool200000080
oooo00@000000?ooo`3oool0oooo0P00001E0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooomX0
oooo0P0000020?ooo`H00000203oool00`000000oooo0?ooo`1a0?ooo`H000000P3oool2000000T0
oooo0P0000140?ooo`006P3oool00`000000oooo0?ooo`3o0?ooom/0oooo00<000000?ooo`3oool0
1P3oool6000000030?ooo`000000000007D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0200000080oooo0P0000140?ooo`006P3oool00`000000oooo0?ooo`3o0?ooonX0oooo2`00
00070?ooo`800000L`3oool700000080oooo00<000000?ooo`3oool00P0000050?ooo`800000<`3o
ool001X0oooo00<000000?ooo`3oool0o`3oooo[0?ooo`800000203oool=000000`0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool02P3oool2
00000280oooo000J0?ooo`030000003oool0oooo0?l0ooooo03oool2000000@0oooo200000030?oo
o`800000403oool00`000000oooo0?ooo`1P0?ooo`D00000103oool200000080oooo00<000000?oo
o`3oool00P0000000`3oool000000000000?0?ooo`8000004@3oool001X0oooo00<000000?ooo`3o
ool0o`3oooom0?ooo`030000003oool0oooo00X0oooo3@0000070?ooo`800000L`3oool500000003
0?ooo`00000000000080oooo00<000000?ooo`3oool00P0000020?ooo`040000003oool000000000
0140oooo000J0?ooo`030000003oool0oooo0?l0ooooo`3oool>0?ooo`800000203ooolA000000L0
oooo0P00000@0?ooo`030000003oool0oooo0600oooo1@00000@0?ooo`006P3oool00`000000oooo
0?ooo`3o0?ooool0oooo7`3oool2000000P0oooo4@0000070?ooo`800000403oool00`000000oooo
0?ooo`1T0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooool0oooo<03oool2000000P0oooo4@00
00070?ooo`8000003`3oool200000100oooo00<000000?ooo`3oool0@P3oool001X0oooo1000003o
0?ooool0oooo<03oool00`000000oooo0?ooo`0=0?ooo`800000203ooolR000000L0oooo0P00000?
0?ooo`800000403oool00`000000oooo0?ooo`0P0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
ool0ooooDP3oool2000000l0oooo0P0000080?ooob8000001`3oool2000000l0oooo0P00000A0?oo
o`006P3oool00`000000oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0=0?ooo`80
00003`3oool2000000P0oooo6P00000A0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooool0oooo
QP3oool00`000000oooo0?ooo`0=0?ooo`8000003`3oool200000140oooo000J0?ooo`030000003o
ool0oooo0?l0ooooo`3ooonX0?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0
oooo0?l0ooooo`3ooonj0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooool0oooo^P3oool001X0
oooo00<000000?ooo`3oool0o`3ooooo0?oookX0oooo000J0?ooo`030000003oool0oooo0?l0oooo
o`3ooonj0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooool0oooo^P3oool001X0oooo00<00000
0?ooo`3oool0o`3ooooo0?oookX0oooo000J0?ooo`030000003oool0oooo0?l0ooooo`3ooonj0?oo
o`006P3oool00`000000oooo0?ooo`3o0?ooool0oooo^P3oool001X0oooo00<000000?ooo`3oool0
o`3ooooo0?oookX0oooo003o0?ooool0ooooe`3oool00?l0ooooo`3ooooG0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 724.125}, {447.188, 0}} -> {-1.58372, 0.612356, \
0.0588075, 0.00483094}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(transition[7, 35]\)], "Input"],

Cell[BoxData[
    \(\(output = 
        Table[\((\[Alpha]\ \((xpsout[\([i]\)] + 
                          xgsout[\([i]\)])\)^\[Kappa] + \((1 - \[Alpha])\)\ \
\((xpuout[\([i]\)] + xguout[\([i]\)] + 
                          l\ clout[\([i]\)] \((G\ \((xgsout[\([i]\)] + 
                                      xguout[\([i]\)])\) + 
                                P \((xpsout[\([i]\)] + 
                                      xpuout[\([i]\)])\))\))\)^\[Kappa])\)^\((\
1/\[Kappa])\) /. {\ \[Beta] \[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[i], \[Kappa] \[Rule] 
                kappaset}, {i, 35}];\)\)], "Input"],

Cell[BoxData[
    \(transition3[7, 35]\)], "Input"],

Cell[BoxData[
    \(\(outputalt = 
        Table[\((\[Alpha]\ \((xpsout[\([i]\)] + 
                          xgsout[\([i]\)])\)^\[Kappa] + \((1 - \[Alpha])\)\ \
\((xpuout[\([i]\)] + xguout[\([i]\)] + 
                          l\ G\ \((xgsout[\([i]\)] + 
                                xguout[\([i]\)])\))\)^\[Kappa])\)^\((1/\
\[Kappa])\) /. {\ \[Beta] \[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[i], \[Kappa] \[Rule] 
                kappaset}, {i, 35}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plot1 = 
      MultipleListPlot[
        capshare*Table[output[\([i]\)], {i, 1, 12}]^\((1 - capshare)\), 
        capshare*Table[outputalt[\([i]\)], {i, 1, 12}]^\((1 - capshare)\), 
        PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {Thickness[ .01], {Thickness[ .01], 
              Dashing[{ .02}]}}, Frame \[Rule] True, 
        FrameTicks \[Rule] {Automatic, Automatic}, Axes -> {False, False}, 
        SymbolShape -> PlotSymbol[Star, 0], 
        FrameLabel \[Rule] {"\<Time\>", "\<Capital Income\>"}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0793651 -0.351645 1.60443 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .04946 -24 -4.5 ]
[-0.0125 .04946 0 4.5 ]
[-0.0125 .12968 -18 -4.5 ]
[-0.0125 .12968 0 4.5 ]
[-0.0125 .20991 -24 -4.5 ]
[-0.0125 .20991 0 4.5 ]
[-0.0125 .29013 -18 -4.5 ]
[-0.0125 .29013 0 4.5 ]
[-0.0125 .37035 -24 -4.5 ]
[-0.0125 .37035 0 4.5 ]
[-0.0125 .45057 -18 -4.5 ]
[-0.0125 .45057 0 4.5 ]
[-0.0125 .53079 -24 -4.5 ]
[-0.0125 .53079 0 4.5 ]
[-0.0125 .61101 -18 -4.5 ]
[-0.0125 .61101 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -44 ]
[-0.01875 .30902 -24 44 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(2)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(4)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(8)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(12)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.06349 0 m
.06349 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30159 0 m
.30159 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.46032 0 m
.46032 .00375 L
s
.53968 0 m
.53968 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.69841 0 m
.69841 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.93651 0 m
.93651 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04946 m
.00625 .04946 L
s
[(0.25)] -0.0125 .04946 1 0 Mshowa
0 .12968 m
.00625 .12968 L
s
[(0.3)] -0.0125 .12968 1 0 Mshowa
0 .20991 m
.00625 .20991 L
s
[(0.35)] -0.0125 .20991 1 0 Mshowa
0 .29013 m
.00625 .29013 L
s
[(0.4)] -0.0125 .29013 1 0 Mshowa
0 .37035 m
.00625 .37035 L
s
[(0.45)] -0.0125 .37035 1 0 Mshowa
0 .45057 m
.00625 .45057 L
s
[(0.5)] -0.0125 .45057 1 0 Mshowa
0 .53079 m
.00625 .53079 L
s
[(0.55)] -0.0125 .53079 1 0 Mshowa
0 .61101 m
.00625 .61101 L
s
[(0.6)] -0.0125 .61101 1 0 Mshowa
.125 Mabswid
0 .06551 m
.00375 .06551 L
s
0 .08155 m
.00375 .08155 L
s
0 .0976 m
.00375 .0976 L
s
0 .11364 m
.00375 .11364 L
s
0 .14573 m
.00375 .14573 L
s
0 .16177 m
.00375 .16177 L
s
0 .17782 m
.00375 .17782 L
s
0 .19386 m
.00375 .19386 L
s
0 .22595 m
.00375 .22595 L
s
0 .24199 m
.00375 .24199 L
s
0 .25804 m
.00375 .25804 L
s
0 .27408 m
.00375 .27408 L
s
0 .30617 m
.00375 .30617 L
s
0 .32222 m
.00375 .32222 L
s
0 .33826 m
.00375 .33826 L
s
0 .3543 m
.00375 .3543 L
s
0 .38639 m
.00375 .38639 L
s
0 .40244 m
.00375 .40244 L
s
0 .41848 m
.00375 .41848 L
s
0 .43453 m
.00375 .43453 L
s
0 .46661 m
.00375 .46661 L
s
0 .48266 m
.00375 .48266 L
s
0 .4987 m
.00375 .4987 L
s
0 .51475 m
.00375 .51475 L
s
0 .54684 m
.00375 .54684 L
s
0 .56288 m
.00375 .56288 L
s
0 .57893 m
.00375 .57893 L
s
0 .59497 m
.00375 .59497 L
s
0 .03342 m
.00375 .03342 L
s
0 .01737 m
.00375 .01737 L
s
0 .00133 m
.00375 .00133 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Capital) show
111.000 12.813 moveto
(Income) show
147.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.06349 .61428 m
.06349 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.22222 .61428 m
.22222 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30159 .61428 m
.30159 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.42063 .61428 m
.42063 .61803 L
s
.46032 .61428 m
.46032 .61803 L
s
.53968 .61428 m
.53968 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.69841 .61428 m
.69841 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.93651 .61428 m
.93651 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04946 m
1 .04946 L
s
.99375 .12968 m
1 .12968 L
s
.99375 .20991 m
1 .20991 L
s
.99375 .29013 m
1 .29013 L
s
.99375 .37035 m
1 .37035 L
s
.99375 .45057 m
1 .45057 L
s
.99375 .53079 m
1 .53079 L
s
.99375 .61101 m
1 .61101 L
s
.125 Mabswid
.99625 .06551 m
1 .06551 L
s
.99625 .08155 m
1 .08155 L
s
.99625 .0976 m
1 .0976 L
s
.99625 .11364 m
1 .11364 L
s
.99625 .14573 m
1 .14573 L
s
.99625 .16177 m
1 .16177 L
s
.99625 .17782 m
1 .17782 L
s
.99625 .19386 m
1 .19386 L
s
.99625 .22595 m
1 .22595 L
s
.99625 .24199 m
1 .24199 L
s
.99625 .25804 m
1 .25804 L
s
.99625 .27408 m
1 .27408 L
s
.99625 .30617 m
1 .30617 L
s
.99625 .32222 m
1 .32222 L
s
.99625 .33826 m
1 .33826 L
s
.99625 .3543 m
1 .3543 L
s
.99625 .38639 m
1 .38639 L
s
.99625 .40244 m
1 .40244 L
s
.99625 .41848 m
1 .41848 L
s
.99625 .43453 m
1 .43453 L
s
.99625 .46661 m
1 .46661 L
s
.99625 .48266 m
1 .48266 L
s
.99625 .4987 m
1 .4987 L
s
.99625 .51475 m
1 .51475 L
s
.99625 .54684 m
1 .54684 L
s
.99625 .56288 m
1 .56288 L
s
.99625 .57893 m
1 .57893 L
s
.99625 .59497 m
1 .59497 L
s
.99625 .03342 m
1 .03342 L
s
.99625 .01737 m
1 .01737 L
s
.99625 .00133 m
1 .00133 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.10317 .01472 m
.18254 .08741 L
.2619 .13436 L
.34127 .18356 L
.42063 .21138 L
.5 .23112 L
.57937 .21426 L
.65873 .28474 L
.7381 .35137 L
.81746 .41407 L
.89683 .46373 L
.97619 .50388 L
s
.0001 w
.10317 .01472 m
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L closepath F
.18254 .08741 m
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L closepath F
.2619 .13436 m
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L closepath F
.34127 .18356 m
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L closepath F
.42063 .21138 m
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L closepath F
.5 .23112 m
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L closepath F
.57937 .21426 m
.57937 .21426 L
.57937 .21426 L
.57937 .21426 L
.57937 .21426 L
.57937 .21426 L
.57937 .21426 L
.57937 .21426 L
.57937 .21426 L
.57937 .21426 L
.57937 .21426 L closepath F
.65873 .28474 m
.65873 .28474 L
.65873 .28474 L
.65873 .28474 L
.65873 .28474 L
.65873 .28474 L
.65873 .28474 L
.65873 .28474 L
.65873 .28474 L
.65873 .28474 L
.65873 .28474 L closepath F
.7381 .35137 m
.7381 .35137 L
.7381 .35137 L
.7381 .35137 L
.7381 .35137 L
.7381 .35137 L
.7381 .35137 L
.7381 .35137 L
.7381 .35137 L
.7381 .35137 L
.7381 .35137 L closepath F
.81746 .41407 m
.81746 .41407 L
.81746 .41407 L
.81746 .41407 L
.81746 .41407 L
.81746 .41407 L
.81746 .41407 L
.81746 .41407 L
.81746 .41407 L
.81746 .41407 L
.81746 .41407 L closepath F
.89683 .46373 m
.89683 .46373 L
.89683 .46373 L
.89683 .46373 L
.89683 .46373 L
.89683 .46373 L
.89683 .46373 L
.89683 .46373 L
.89683 .46373 L
.89683 .46373 L
.89683 .46373 L closepath F
.97619 .50388 m
.97619 .50388 L
.97619 .50388 L
.97619 .50388 L
.97619 .50388 L
.97619 .50388 L
.97619 .50388 L
.97619 .50388 L
.97619 .50388 L
.97619 .50388 L
.97619 .50388 L closepath F
.01 w
[ .02 ] 0 setdash
.10317 .01472 m
.18254 .08741 L
.2619 .13436 L
.34127 .18356 L
.42063 .21138 L
.5 .23112 L
.57937 .2463 L
.65873 .27235 L
.7381 .32793 L
.81746 .41119 L
.89683 .50259 L
.97619 .60332 L
s
.0001 w
[ ] 0 setdash
.10317 .01472 m
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L
.10317 .01472 L closepath F
.18254 .08741 m
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L
.18254 .08741 L closepath F
.2619 .13436 m
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L
.2619 .13436 L closepath F
.34127 .18356 m
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L
.34127 .18356 L closepath F
.42063 .21138 m
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L
.42063 .21138 L closepath F
.5 .23112 m
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L
.5 .23112 L closepath F
.57937 .2463 m
.57937 .2463 L
.57937 .2463 L
.57937 .2463 L
.57937 .2463 L
.57937 .2463 L
.57937 .2463 L
.57937 .2463 L
.57937 .2463 L
.57937 .2463 L
.57937 .2463 L closepath F
.65873 .27235 m
.65873 .27235 L
.65873 .27235 L
.65873 .27235 L
.65873 .27235 L
.65873 .27235 L
.65873 .27235 L
.65873 .27235 L
.65873 .27235 L
.65873 .27235 L
.65873 .27235 L closepath F
.7381 .32793 m
.7381 .32793 L
.7381 .32793 L
.7381 .32793 L
.7381 .32793 L
.7381 .32793 L
.7381 .32793 L
.7381 .32793 L
.7381 .32793 L
.7381 .32793 L
.7381 .32793 L closepath F
.81746 .41119 m
.81746 .41119 L
.81746 .41119 L
.81746 .41119 L
.81746 .41119 L
.81746 .41119 L
.81746 .41119 L
.81746 .41119 L
.81746 .41119 L
.81746 .41119 L
.81746 .41119 L closepath F
.89683 .50259 m
.89683 .50259 L
.89683 .50259 L
.89683 .50259 L
.89683 .50259 L
.89683 .50259 L
.89683 .50259 L
.89683 .50259 L
.89683 .50259 L
.89683 .50259 L
.89683 .50259 L closepath F
.97619 .60332 m
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{392.375, 242.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000680000lR000`400?l00000o`00003oo`3ooon9
0?ooo`00o`3ooon90?ooo`00o`3ooon90?ooo`00o`3ooon90?ooo`00o`3ooon90?ooo`00cP3oool3
000000@0oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool300000:@0oooo
003?0?ooo`030000003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000002W0?ooo`00c`3oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`@00000Y03oool00<l0oooo00<000000?ooo`3oool0
0`3oool200000080oooo0`0000000`3oool000000?ooo`020?ooo`800000Y@3oool00<d0oooo00D0
00000?ooo`000000oooo0000002f0?ooo`00c@3oool5000000@0oooo00<000000?ooo`3oool0[`3o
ool00?l0ooooR@3oool00?l0ooooR@3oool00?l0ooooR@3oool003<0oooo0P00000d0?ooo`@00000
=@3oool300000380oooo0`00000d0?ooo`800000<@3oool500000080oooo0P00000^0?ooo`D00000
00<0oooo0000000000000P0000060?ooo`00<P3oool010000000oooo0?ooo`00000c0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0<@3oool010000000oooo0?ooo`00000b0?ooo`04
0000003oool0oooo00000380oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo02d0oooo00D000000?ooo`3oool0oooo000000090?ooo`00<P3oool010000000oooo0?ooo`00
000d0?ooo`030000003oool0oooo03<0oooo1@00000b0?ooo`040000003oool0oooo00000380oooo
00@000000?ooo`3oool00000<P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo000b0?ooo`04
0000003oool0oooo000003D0oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`00000c
0?ooo`<00000=03oool2000003<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`00<P3oool0
10000000oooo0?ooo`00000c0?ooo`040000003oool0oooo000003@0oooo00<000000?ooo`000000
=03oool00`000000oooo0?ooo`0b0?ooo`040000003oool0oooo00000380oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo02d0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00@0oooo000c0?ooo`800000=@3oool2000003H0oooo0P00000d0?oo
o`<00000<`3oool200000380oooo0P0000040?ooo`800000;`3oool2000000@0oooo0P0000070?oo
o`00o`3ooon90?ooo`00o`3ooon90?ooo`00o`3ooon90?ooo`00o`3ooon90?ooo`00o`3ooon90?oo
o`00o`3ooon90?ooo`00;03ooooo000005/000000P3oool002`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00;03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo000/0?ooo`030000003oool0oooo
0?l0ooooE`3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0803oool200000?l0
oooo=@3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool07`3oool500000?l0oooo
<`3oool100000040oooo0@3oool002`0oooo0P00000Q0?ooo`D00000o`3ooola0?ooo`8000000P3o
ool002`0oooo00<000000?ooo`3oool08@3oool500000?l0oooo<@3oool100000040oooo0@3oool0
02`0oooo00<000000?ooo`3oool08P3oool500000?l0oooo<03oool100000040oooo0@3oool002`0
oooo00<000000?ooo`3oool08`3oool500000?l0oooo;`3oool100000040oooo0@3oool002`0oooo
00<000000?ooo`3oool0903oool500000?l0oooo;P3oool100000040oooo0@3oool002`0oooo0P00
000V0?ooo`D00000o`3oool/0?ooo`8000000P3oool002`0oooo00<000000?ooo`3oool09P3oool5
00000?l0oooo;03oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0:03oool40000
0?l0oooo:`3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0:@3oool400000?l0
oooo:P3oool100000040oooo0@3oool00180oooo0P0000040?ooo`8000000`3oool4000000<0oooo
0P0000060?ooo`030000003oool0oooo02X0oooo1000003o0?ooobT0oooo0@0000010?ooo`40oooo
000A0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo02/0oooo1000003o0?ooobP0oooo0@0000010?ooo`40
oooo000A0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`<00000;03oool500000?l0oooo903oool300000080oooo000A0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`3o
ool0;@3oool500000?l0oooo9@3oool100000040oooo0@3oool00140oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0;P3oool500000?l0oooo903oool100000040oooo0@3oool00180oooo0P00000:0?ooo`80
0000103oool3000000D0oooo00<000000?ooo`3oool0;`3oool500000?l0oooo8`3oool100000040
oooo0@3oool002`0oooo00<000000?ooo`3oool0<03oool500000?l0oooo8P3oool100000040oooo
0@3oool002`0oooo00<000000?ooo`3oool0<P3oool400000?l0oooo8@3oool100000040oooo0@3o
ool002`0oooo0P00000d0?ooo`@00000o`3ooolO0?ooo`8000000P3oool002`0oooo00<000000?oo
o`3oool0<`3oool500000?l0oooo7`3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3o
ool0=03oool500000?l0oooo7P3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0
=P3oool400000?l0oooo7@3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0=`3o
ool500000?l0oooo6`3oool100000040oooo0@3oool002`0oooo0P00000i0?ooo`D00000o`3ooolI
0?ooo`8000000P3oool002`0oooo00<000000?ooo`3oool0>@3oool500000?l0oooo6@3oool10000
0040oooo0@3oool002`0oooo00<000000?ooo`3oool0>P3oool600000?l0oooo5`3oool100000040
oooo0@3oool002`0oooo00<000000?ooo`3oool0>`3oool700000?l0oooo5@3oool100000040oooo
0@3oool002`0oooo00<000000?ooo`3oool0?@3oool600000?l0oooo503oool100000040oooo0@3o
ool002`0oooo00<000000?ooo`3oool0?`3oool600000?l0oooo4P3oool100000040oooo0@3oool0
02`0oooo0P0000110?ooo`H00000o`3oool@0?ooo`8000000P3oool002`0oooo00<000000?ooo`3o
ool0@P3oool600000?l0oooo3`3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0
A03oool600000?l0oooo3@3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0A@3o
ool600000?l0oooo303oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0A`3oool6
00000?l0oooo2P3oool100000040oooo0@3oool002`0oooo0P00001:0?ooo`H00000o`3oool70?oo
o`8000000P3oool002`0oooo00<000000?ooo`3oool0BP3oool600000?l0oooo1`3oool100000040
oooo0@3oool002`0oooo00<000000?ooo`3oool0C03oool600000?l0oooo1@3oool100000040oooo
0@3oool002`0oooo00<000000?ooo`3oool0CP3oool600000?l0oooo0`3oool100000040oooo0@3o
ool001P0oooo0P0000040?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool0C`3oool6
00000?l0oooo0P3oool100000040oooo0@3oool001L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo0540oooo1P00003o0?ooo`4000000@3o
ool10?ooo`005`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo0`00
001C0?ooo`H00000n`3oool300000080oooo000G0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`1D0?ooo`H00000o03oool100000040oooo0@3o
ool001L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo05H0oooo1P00003j0?ooo`4000000@3oool10?ooo`00603oool2000000X0oooo0P00
00060?ooo`030000003oool0oooo05P0oooo1P00003h0?ooo`4000000@3oool10?ooo`00;03oool0
0`000000oooo0?ooo`1I0?ooo`H00000m`3oool100000040oooo0@3oool002`0oooo0P00001L0?oo
o`H00000m03oool200000080oooo000/0?ooo`030000003oool0oooo05`0oooo1`00003c0?ooo`40
00000@3oool10?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`H00000lP3oool100000040oooo
0@3oool002`0oooo00<000000?ooo`3oool0H03oool600000?00oooo0@0000010?ooo`40oooo000/
0?ooo`030000003oool0oooo0680oooo1P00003^0?ooo`4000000@3oool10?ooo`00;03oool00`00
0000oooo0?ooo`1R0?ooo`L00000k@3oool100000040oooo0@3oool002`0oooo0P00001U0?ooo`L0
0000jP3oool200000080oooo000/0?ooo`030000003oool0oooo06H0oooo1`00003Y0?ooo`400000
0@3oool10?ooo`00;03oool00`000000oooo0?ooo`1X0?ooo`H00000j03oool100000040oooo0@3o
ool002`0oooo00<000000?ooo`3oool0JP3oool600000>H0oooo0@0000010?ooo`40oooo000/0?oo
o`030000003oool0oooo06`0oooo1P00003T0?ooo`4000000@3oool10?ooo`00;03oool2000006h0
oooo1P00003R0?ooo`8000000P3oool002`0oooo00<000000?ooo`3oool0KP3oool700000>40oooo
0@0000010?ooo`40oooo000/0?ooo`030000003oool0oooo0700oooo2000003N0?ooo`4000000@3o
ool10?ooo`00;03oool00`000000oooo0?ooo`1b0?ooo`T00000f`3oool100000040oooo0@3oool0
02`0oooo00<000000?ooo`3oool0M03oool:00000=P0oooo0@0000010?ooo`40oooo000/0?ooo`03
0000003oool0oooo07L0oooo2@00003F0?ooo`4000000@3oool10?ooo`001@3oool4000002<0oooo
0P00001k0?ooo`T00000dP3oool200000080oooo00040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1l0?ooo`X00000d03oool100000040oooo0@3o
ool000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo07l0oooo2@00003>0?ooo`4000000@3oool10?ooo`00103oool2000000<0oooo00<000000?oo
o`3oool01P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000H0oooo00<000000?oo
o`3oool0P@3oool:00000</0oooo0@0000010?ooo`40oooo000A0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo08D0oooo2@0000380?ooo`4000000@3oool10?ooo`004@3oool010000000oooo0?ooo`00
000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool3000008L0oooo2P00
00330?ooo`<000000P3oool000P0oooo0P0000070?ooo`040000003oool0oooo000000/0oooo00@0
00000?ooo`3oool0oooo0P0000060?ooo`030000003oool0oooo08X0oooo2P00000_0?ooo`<00000
T03oool100000040oooo0@3oool000H0oooo00@000000?ooo`00000000001`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2=0?ooo`d000009@3oool9000008h0oooo0@0000010?ooo`40oooo00060?ooo`04
0000003oool00000000000P0oooo0P00000:0?ooo`800000103oool3000000D0oooo00<000000?oo
o`3oool0T03oool?000001/0oooo3`00002=0?ooo`4000000@3oool10?ooo`001P3oool400000280
oooo00<000000?ooo`3oool0U03oool<000001H0oooo3@0000030?ooo`@00000S03oool100000040
oooo0@3oool000T0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2H0?ooo`h00000
2`3oool>000000P0oooo1000002;0?ooo`4000000@3oool10?ooo`001P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01h0oooo0P00002M0?ooo`d00000103oool=000000h0oooo1000
00290?ooo`8000000P3oool000H0oooo1P00000P0?ooo`030000003oool0oooo0:00oooo5P00000C
0?ooo`@00000R@3oool100000040oooo0@3oool000H0oooo00H000000?ooo`3oool000000?ooo`00
000P0?ooo`030000003oool0oooo0:@0oooo4@00000E0?ooo`@00000R03oool100000040oooo0@3o
ool000H0oooo00@000000?ooo`3oool000008P3oool00`000000oooo0?ooo`2X0?ooo`D000000`3o
ool:00000140oooo100000270?ooo`4000000@3oool10?ooo`001`3oool2000002<0oooo00<00000
0?ooo`3oool0/03oool:00000180oooo1@0000250?ooo`4000000@3oool10?ooo`00;03oool20000
0;H0oooo1@0000030?ooo`D000002`3oool5000008<0oooo0P0000020?ooo`00;03oool00`000000
oooo0?ooo`2m0?ooo`X00000203oool4000008<0oooo0@0000010?ooo`40oooo000/0?ooo`030000
003oool0oooo0;d0oooo2P0000090?ooo`@00000PP3oool100000040oooo0@3oool000H0oooo00@0
00000?ooo`3oool000008P3oool00`000000oooo0?ooo`320?ooo`D00000103oool400000080oooo
100000210?ooo`4000000@3oool10?ooo`00103oool00`000000oooo0000000300000280oooo00<0
00000?ooo`3oool0b`3oool6000000030?ooo`000000000000800000P03oool100000040oooo0@3o
ool000T0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3;0?ooo``00000O`3oool1
00000040oooo0@3oool002`0oooo0P00003?0?ooo`X00000O@3oool200000080oooo00060?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0d03oool4000000030?ooo`000000000000@0
0000N`3oool100000040oooo0@3oool000D0oooo1000000S0?ooo`030000003oool0oooo0=H0oooo
1`00001i0?ooo`4000000@3oool10?ooo`001P3oool010000000oooo0?ooo`00000R0?ooo`030000
003oool0oooo0=P0oooo1`00001g0?ooo`4000000@3oool10?ooo`001P3oool010000000oooo0?oo
o`00000R0?ooo`030000003oool0oooo0=T0oooo2000001e0?ooo`4000000@3oool10?ooo`001P3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0=X0oooo1`00001e0?ooo`4000000@3o
ool10?ooo`00;03oool200000=`0oooo1P00001d0?ooo`8000000P3oool002`0oooo00<000000?oo
o`3oool0g03oool4000000@0oooo0`00001_0?ooo`4000000@3oool10?ooo`00203oool200000280
oooo00<000000?ooo`3oool0g@3oool4000000<0oooo1000001^0?ooo`4000000@3oool10?ooo`00
1P3oool010000000oooo00000000000>0?ooo`800000103oool2000000D0oooo0`0000040?ooo`03
0000003oool0oooo0=h0oooo1@0000000`3oool0000000000004000006`0oooo0@0000010?ooo`40
oooo00060?ooo`040000003oool00000000000d0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0=l0oooo1@0000020?ooo`D00000J`3oool10000
0040oooo0@3oool000H0oooo1000000=0?ooo`040000003oool0oooo000000P0oooo1@0000040?oo
o`<00000h@3oool400000080oooo1P00001W0?ooo`<000000P3oool000T0oooo00<000000?ooo`3o
ool02`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0hP3oool4000000<0oooo1000001Y0?ooo`4000000@3oool10?ooo`005`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0h`3oool5
00000080oooo0`00001Y0?ooo`4000000@3oool10?ooo`00103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00`0oooo0P00000;0?ooo`8000001@3oool00`000000oooo0?ooo`3T0?oo
o`D00000K@3oool100000040oooo0@3oool000@0oooo1P00000R0?ooo`030000003oool0oooo0>H0
oooo100000050?ooo`<00000I03oool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`3W0?ooo`@00000103oool4000006<0oooo0@0000010?ooo`40oooo
000/0?ooo`800000j@3oool4000000<0oooo1P00001P0?ooo`8000000P3oool002`0oooo00<00000
0?ooo`3oool0j@3oool5000000<0oooo1@00001P0?ooo`4000000@3oool10?ooo`00;03oool00`00
0000oooo0?ooo`3Z0?ooo`D000000`3oool6000005h0oooo0@0000010?ooo`40oooo000/0?ooo`03
0000003oool0oooo0>`0oooo100000040?ooo`@00000GP3oool100000040oooo0@3oool002`0oooo
00<000000?ooo`3oool0k@3oool4000000@0oooo0`00001N0?ooo`4000000@3oool10?ooo`00;03o
ool200000>l0oooo1@00001R0?ooo`8000000P3oool002`0oooo00<000000?ooo`3oool0k`3oool5
000000L0oooo0P00001I0?ooo`4000000@3oool10?ooo`00;03oool00`000000oooo0?ooo`3a0?oo
o`@000001@3oool4000005P0oooo0@0000010?ooo`40oooo000/0?ooo`030000003oool0oooo0?80
oooo100000050?ooo`@00000E`3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0
l`3oool4000000D0oooo1000001F0?ooo`4000000@3oool10?ooo`00103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0m03oool5000000@0oooo1000
001E0?ooo`4000000@3oool10?ooo`00103oool600000280oooo0P00003f0?ooo`D00000103oool4
000005<0oooo0P0000020?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0m`3oool4000000@0oooo1000001C0?ooo`4000000@3oool10?oo
o`00;03oool00`000000oooo0?ooo`3h0?ooo`@00000103oool3000005<0oooo0@0000010?ooo`40
oooo00060?ooo`040000003oool0oooo00000280oooo00<000000?ooo`3oool0n@3oool4000000@0
oooo00<000000?ooo`3oool0DP3oool100000040oooo0@3oool000H0oooo1000000R0?ooo`030000
003oool0oooo0?X0oooo1@00001G0?ooo`4000000@3oool10?ooo`001P3oool00`000000oooo0?oo
o`0S0?ooo`800000o03oool5000000@0oooo0P00001?0?ooo`8000000P3oool000H0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`3m0?ooo`@000000P3oool4000004l0oooo0@000001
0?ooo`40oooo00070?ooo`<000008P3oool00`000000oooo0?ooo`3n0?ooo`@000000P3oool40000
04h0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0o`3oool5000000030?ooo`000000000000800000C@3oool100000040oooo0@3oool00180oooo
0P0000040?ooo`8000001@3oool300000080oooo0P0000060?ooo`030000003oool0oooo0?l0oooo
0@3oool5000000030?ooo`000000000000800000C03oool100000040oooo0@3oool000L0oooo0P00
00080?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo0`3oool4000000030?ooo`00000000000080
0000B`3oool100000040oooo0@3oool000H0oooo00@000000?ooo`3oool000001`3oool010000000
oooo0?ooo`0000080?ooo`D00000103oool00`000000oooo0?ooo`030?ooo`<00000o`3oool40?oo
o`@0000000<0oooo0000000000000P0000180?ooo`<000000P3oool000H0oooo00@000000?ooo`3o
ool000001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P00
00060?ooo`030000003oool0oooo0?l0oooo1@3oool8000004X0oooo0@0000010?ooo`40oooo0006
0?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
000000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool60?ooo`H00000
B`3oool100000040oooo0@3oool00180oooo0P00000;0?ooo`8000000`3oool3000000D0oooo00<0
00000?ooo`3oool0o`3oool80?ooo`@00000B`3oool100000040oooo0@3oool002`0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`@000000P3oool2000004H0oooo0@0000010?ooo`40oooo00070?oo
o`8000008`3oool200000?l0oooo2`3oool8000004@0oooo0P0000020?ooo`001P3oool010000000
oooo0?ooo`00000R0?ooo`030000003oool0oooo0?l0oooo2`3oool8000004@0oooo0@0000010?oo
o`40oooo00060?ooo`040000003oool0oooo00000280oooo00<000000?ooo`3oool0o`3oool<0?oo
o`P00000@`3oool100000040oooo0@3oool000L0oooo0P00000S0?ooo`030000003oool0oooo0?l0
oooo3P3oool700000480oooo0@0000010?ooo`40oooo000/0?ooo`030000003oool0oooo0?l0oooo
3`3oool700000440oooo0@0000010?ooo`40oooo00060?ooo`040000003oool0oooo00000280oooo
00<000000?ooo`3oool0o`3oool@0?ooo`L00000@03oool100000040oooo0@3oool000H0oooo1000
000R0?ooo`800000o`3ooolB0?ooo`H00000?`3oool200000080oooo00060?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`@00000@03oool100000040oooo0@3oool0
00L0oooo0`00000R0?ooo`030000003oool0oooo0?l0oooo503oool4000003l0oooo0@0000010?oo
o`40oooo00060?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`D0
0000?@3oool100000040oooo0@3oool000L0oooo0`00000R0?ooo`030000003oool0oooo0?l0oooo
5P3oool5000003`0oooo0@0000010?ooo`40oooo000/0?ooo`800000o`3ooolH0?ooo`H00000>@3o
ool200000080oooo00070?ooo`8000008`3oool00`000000oooo0?ooo`3o0?oooaT0oooo1P00000h
0?ooo`4000000@3oool10?ooo`001P3oool2000000030?ooo`000000oooo0240oooo00<000000?oo
o`3oool0o`3ooolJ0?ooo`H00000=`3oool100000040oooo0@3oool000H0oooo0P0000000`3oool0
00000?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo6`3oool7000003D0oooo0@0000010?ooo`40
oooo00070?ooo`030000003oool000000280oooo00<000000?ooo`3oool0o`3ooolL0?ooo`P00000
<`3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`P00000<P3o
ool100000040oooo0@3oool002`0oooo0P00003o0?oooal0oooo00<000000?ooo`3oool01P00000_
0?ooo`8000000P3oool002`0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`H00000;P3oool10000
0040oooo0@3oool002`0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`H00000;@3oool100000040
oooo0@3oool002`0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`8000000`3oool6000002/0oooo
0@0000010?ooo`40oooo000H0?ooo`800000103oool2000000@0oooo0P0000060?ooo`030000003o
ool0oooo0?l0oooo803oool4000000@0oooo1P00000Y0?ooo`4000000@3oool10?ooo`005`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
o`3ooolQ0?ooo`@00000103oool6000002P0oooo0@0000010?ooo`40oooo000G0?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool00`3oool300000?l0oooo8P3oool4000000D0oooo
1P00000T0?ooo`<000000P3oool001L0oooo00@000000?ooo`3oool000002@3oool2000000H0oooo
00<000000?ooo`3oool0o`3ooolS0?ooo`@000001P3oool6000002@0oooo0@0000010?ooo`40oooo
000G0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3o0?ooob@0oooo100000060?ooo`H000008`3oool100000040oooo0@3oool001P0oooo0P00
000:0?ooo`<000001@3oool00`000000oooo0?ooo`3o0?ooobD0oooo100000070?ooo`H000008@3o
ool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`<000002@3oool6
000001l0oooo0@0000010?ooo`40oooo000/0?ooo`800000o`3ooolX0?ooo`030000003oool0oooo
00T0oooo1`00000L0?ooo`8000000P3oool002`0oooo00<000000?ooo`3oool0o`3ooole0?ooo`L0
00006`3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`800000
2`3oool7000001T0oooo0@0000010?ooo`40oooo000/0?ooo`030000003oool0oooo0?l0oooo:@3o
ool4000000`0oooo1`00000G0?ooo`4000000@3oool10?ooo`00;03oool00`000000oooo0?ooo`3o
0?ooobX0oooo1000000=0?ooo`L000005@3oool100000040oooo0@3oool002`0oooo00<000000?oo
o`3oool0o`3oool[0?ooo`@000003P3oool6000001@0oooo0@0000010?ooo`40oooo000/0?ooo`80
0000o`3oool]0?ooo`@000003`3oool600000140oooo0P0000020?ooo`00;03oool00`000000oooo
0?ooo`3o0?ooobd0oooo1000000@0?ooo`H00000403oool100000040oooo0@3oool002`0oooo00<0
00000?ooo`3oool0o`3oool^0?ooo`@00000403oool7000000h0oooo0@0000010?ooo`40oooo000/
0?ooo`030000003oool0oooo0?l0oooo;`3oool300000180oooo1`00000<0?ooo`4000000@3oool1
0?ooo`00;03oool00`000000oooo0?ooo`3o0?oooc00oooo00<000000?ooo`3oool04`3oool70000
00X0oooo0@0000010?ooo`40oooo000/0?ooo`800000o`3ooom90?ooo`L000001`3oool200000080
oooo000/0?ooo`030000003oool0oooo0?l0oooo=@3oool00`000000oooo0?ooo`0B0?ooo`L00000
1P3oool100000040oooo0@3oool002`0oooo00<000000?ooo`3oool0o`3ooold0?ooo`<000005@3o
ool5000000H0oooo0@0000010?ooo`40oooo000/0?ooo`030000003oool0oooo0?l0oooo=03oool3
000001L0oooo0`0000060?ooo`4000000@3oool10?ooo`00;03oool00`000000oooo0?ooo`3o0?oo
ocD0oooo0`00000O0?ooo`4000000@3oool10?ooo`00;03oool00`000000oooo0?ooo`3o0?ooocD0
oooo1000000N0?ooo`4000000@3oool10?ooo`00;03oool200000?l0oooo=`3oool4000001`0oooo
0P0000020?ooo`00;03oool00`000000oooo0?ooo`3o0?ooocL0oooo0`00000M0?ooo`4000000@3o
ool10?ooo`00;03oool00`000000oooo0?ooo`3o0?ooocP0oooo0`00000L0?ooo`4000000@3oool1
0?ooo`004P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000H0oooo00<000000?oo
o`3oool0o`3ooolh0?ooo`<00000703oool100000040oooo0@3oool00140oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0o`3oooli0?ooo`030000003oool0oooo01/0oooo0@0000010?ooo`40oooo000A
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`<00000o`3ooomE0?ooo`<000000P3oool00140oooo00@000000?ooo`3oool000002@3o
ool2000000@0oooo0P0000060?ooo`030000003oool0oooo0?l0oooo?03oool3000001P0oooo0@00
00010?ooo`40oooo000A0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo?03oool3000001P0oooo0@00
00010?ooo`40oooo000B0?ooo`8000002P3oool3000000<0oooo0`0000050?ooo`030000003oool0
oooo0?l0oooo?03oool4000001L0oooo0@0000010?ooo`40oooo000/0?ooo`030000003oool0oooo
0?l0oooo?@3oool4000001H0oooo0@0000010?ooo`40oooo000/0?ooo`030000003oool0oooo0?l0
oooo?P3oool3000001H0oooo0@0000010?ooo`40oooo000/0?ooo`800000o`3ooolo0?ooo`@00000
503oool200000080oooo000/0?ooo`030000003oool0oooo0?l0oooo?`3oool4000001@0oooo0@00
00010?ooo`40oooo000/0?ooo`030000003oool0oooo0?l0oooo@03oool3000001@0oooo0@000001
0?ooo`40oooo000/0?ooo`030000003oool0oooo0?l0oooo@03oool3000001@0oooo0@0000010?oo
o`40oooo000/0?ooo`030000003oool0oooo0?l0ooooE`3oool100000040oooo0@3oool002`0oooo
0P00003o0?oooeL0oooo0P0000020?ooo`00;03oool00`000000oooo0?ooo`3o0?ooodD0oooo0`00
000?0?ooo`4000000@3oool10?ooo`00;03oool00`000000oooo0?ooo`3o0?ooodD0oooo0`00000?
0?ooo`4000000@3oool10?ooo`00;03oool00`000000oooo0?ooo`3o0?ooodD0oooo1000000>0?oo
o`4000000@3oool10?ooo`00;03oool00`000000oooo0?ooo`3o0?ooodH0oooo1000000=0?ooo`40
00000@3oool10?ooo`00;03oool00`000000oooo0?ooo`3o0?ooodL0oooo0`00000=0?ooo`400000
0@3oool10?ooo`00;03oool200000?l0ooooB03oool4000000/0oooo0P0000020?ooo`00;03oool0
0`000000oooo0?ooo`3o0?ooodP0oooo1000000;0?ooo`4000000@3oool10?ooo`00;03oool00`00
0000oooo0?ooo`3o0?ooodT0oooo0`00000;0?ooo`4000000@3oool10?ooo`00;03oool00`000000
oooo0?ooo`3o0?ooodT0oooo0`00000;0?ooo`4000000@3oool10?ooo`00;03oool00`000000oooo
0?ooo`3o0?oooeL0oooo0@0000010?ooo`40oooo000/0?ooo`800000o`3ooomG0?ooo`8000000P3o
ool002`0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`800000203oool100000040oooo0@3oool0
02`0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`@000001`3oool100000040oooo0@3oool002`0
oooo00<000000?ooo`3oool0o`3ooom=0?ooo`@000001P3oool100000040oooo0@3oool001P0oooo
0P0000040?ooo`8000000`3oool3000000H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`<00000
1P3oool100000040oooo0@3oool001L0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo0?l0ooooC`3oool00`000000oooo0?ooo`050?ooo`40
00000@3oool10?ooo`005`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00D0oooo0`0000050?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`005`3oool010000000
oooo0?ooo`0000080?ooo`<000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`40oooo000G0?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool01@3ooooo000005/000000P3oool001P0oooo0P00000:0?ooo`<00000o`3ooomR0?ooo`00
o`3ooon90?ooo`00\
\>"],
  ImageRangeCache->{{{0, 391.375}, {241.5, 0}} -> {-1.91859, 0.172482, \
0.0364667, 0.00180387}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetDirectory["\<C:\Documents and Settings\doepke\My \
Documents\sync\mathematica\>"]\), "\[IndentingNewLine]", 
    \(\(Export["\<plotcap1.eps\>", plot1, "\<EPS\>"];\)\)}], "Input"],

Cell[BoxData[
    \("C:\\Documents and Settings\\doepke\\My \
Documents\\sync\\mathematica"\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowSize->{980, 644},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 38, 0, 95, "Title"],
Cell[1817, 55, 112, 3, 80, "Subtitle"],
Cell[1932, 60, 226, 4, 90, "Input"],
Cell[2161, 66, 190, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[2376, 74, 65, 0, 73, "Section"],
Cell[2444, 76, 43, 0, 33, "Text"],
Cell[2490, 78, 770, 16, 330, "Input"],
Cell[3263, 96, 127, 3, 33, "Text"],
Cell[3393, 101, 208, 4, 90, "Input"],
Cell[3604, 107, 133, 3, 30, "Input"],
Cell[3740, 112, 382, 6, 52, "Text"],
Cell[4125, 120, 203, 4, 90, "Input"],
Cell[4331, 126, 115, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4483, 133, 43, 0, 73, "Section"],
Cell[4529, 135, 36, 0, 33, "Text"],
Cell[4568, 137, 86, 1, 30, "Input"],
Cell[4657, 140, 89, 2, 33, "Text"],
Cell[4749, 144, 693, 13, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5479, 162, 67, 0, 73, "Section"],
Cell[5549, 164, 116, 3, 33, "Text"],
Cell[5668, 169, 8847, 153, 1894, "Input"],
Cell[14518, 324, 8588, 146, 1894, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23143, 475, 64, 0, 73, "Section"],
Cell[23210, 477, 216, 4, 52, "Text"],
Cell[23429, 483, 5515, 88, 1690, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28981, 576, 73, 0, 73, "Section"],
Cell[29057, 578, 613, 10, 142, "Text"],
Cell[29673, 590, 2406, 43, 690, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32116, 638, 48, 0, 73, "Section"],
Cell[32167, 640, 6477, 110, 1832, "Input"],
Cell[38647, 752, 6469, 110, 1832, "Input"],
Cell[45119, 864, 6092, 102, 1792, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51248, 971, 73, 0, 73, "Section"],
Cell[51324, 973, 567, 11, 210, "Input"],

Cell[CellGroupData[{
Cell[51916, 988, 97, 2, 50, "Input"],
Cell[52016, 992, 88, 1, 29, "Output"],
Cell[52107, 995, 88, 1, 29, "Output"],
Cell[52198, 998, 88, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52323, 1004, 97, 2, 50, "Input"],
Cell[52423, 1008, 89, 1, 29, "Output"],
Cell[52515, 1011, 89, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52653, 1018, 36, 0, 73, "Section"],
Cell[52692, 1020, 50, 1, 30, "Input"],
Cell[52745, 1023, 830, 14, 130, "Input"],
Cell[53578, 1039, 51, 1, 30, "Input"],
Cell[53632, 1042, 690, 12, 90, "Input"],

Cell[CellGroupData[{
Cell[54347, 1058, 93, 1, 30, "Input"],
Cell[54443, 1061, 68199, 1423, 457, 27623, 918, "GraphicsData", "PostScript", \
"Graphics"],
Cell[122645, 2486, 130, 3, 29, "Output"]
}, Open  ]],
Cell[122790, 2492, 50, 1, 30, "Input"],
Cell[122843, 2495, 830, 14, 130, "Input"],
Cell[123676, 2511, 51, 1, 30, "Input"],
Cell[123730, 2514, 690, 12, 90, "Input"],

Cell[CellGroupData[{
Cell[124445, 2530, 549, 10, 90, "Input"],
Cell[124997, 2542, 36975, 1162, 251, 12331, 853, "GraphicsData", \
"PostScript", "Graphics"],
Cell[161975, 3706, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[162142, 3714, 202, 3, 50, "Input"],
Cell[162347, 3719, 105, 2, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

