(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    358782,      10503]*)
(*NotebookOutlinePosition[    359494,      10527]*)
(*  CellTagsIndexPosition[    359450,      10523]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The Transition to CLR", "Title"],

Cell["\<\
Computes transition from NCLR to CLR induced by rising wage premium (rising \
alpha)\
\>", "Subtitle"],

Cell[BoxData[{
    \(<< Graphics`MultipleListPlot`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\)}], "Input"],

Cell[CellGroupData[{

Cell["Setting parameters and functions of parameters", "Section"],

Cell["The preset parameter values", "Text"],

Cell[BoxData[{
    \(\(betaset =  .8;\)\), "\[IndentingNewLine]", 
    \(\(sigmaset =  .5;\)\), "\[IndentingNewLine]", 
    \(\(zset = 1;\)\), "\[IndentingNewLine]", 
    \(\(lamset =  .15;\)\), "\[IndentingNewLine]", 
    \(\(pi0set =  .05;\)\), "\[IndentingNewLine]", 
    \(\(pi1set =  .4;\)\), "\[IndentingNewLine]", 
    \(\(Pset = 1;\)\), "\[IndentingNewLine]", 
    \(\(Gset = 3;\)\), "\[IndentingNewLine]", 
    \(\(pset =  .013;\)\), "\[IndentingNewLine]", 
    \(\(lset =  .1;\)\), "\[IndentingNewLine]", 
    \(\(alphset =  .6;\)\), "\[IndentingNewLine]", 
    \(\(kappaset =  .5;\)\)}], "Input"],

Cell["\<\
Range for alpha. Alpha is constant until tstart, then increases by alphstep, \
until alphhi is reached.\
\>", "Text"],

Cell[BoxData[{
    \(\(alphlo =  .33;\)\), "\[IndentingNewLine]", 
    \(\(alphhi =  .65;\)\), "\[IndentingNewLine]", 
    \(\(alphstep =  .05;\)\), "\[IndentingNewLine]", 
    \(\(tstart = 3;\)\)}], "Input"],

Cell[BoxData[
    \(\(alfafun[time_] := 
        Min[alphhi, 
          alphlo + Max[time - tstart + 1, 0]\ alphstep];\)\)], "Input"],

Cell["\<\
Technical parameters. Periods is the number of periods over which utility is \
evaluated when computing the outcome path under CLR. iter is iterations over \
utility in the computation in the non-CLR path for a given eta path. The \
eta-path is adjusted etater times. Each time, eta is adjusted by etastep.  \
There are iter times etater iterations in total.\
\>", "Text"],

Cell[BoxData[{
    \(\(periods = 30;\)\), "\[IndentingNewLine]", 
    \(\(iter = 10;\)\), "\[IndentingNewLine]", 
    \(\(etater = 30;\)\), "\[IndentingNewLine]", 
    \(\(etastep =  .05;\)\)}], "Input"],

Cell[BoxData[{
    \(\(SetOptions[ListPlot, PlotRange \[Rule] All, 
        PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[MultipleListPlot, PlotRange \[Rule] All, 
        PlotJoined \[Rule] True];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Frequently used routines", "Section"],

Cell["The utility function", "Text"],

Cell[BoxData[
    \(\(U[c_] := If[c \[LessEqual] 0, \(-10000\), c^ .5];\)\)], "Input"],

Cell["\<\
The ratio below is the ratio of skilled to unskilled labor supply\
\>", "Text"],

Cell[BoxData[{
    \(\(ws[ratio_] := 
        If[ratio < 0, 
          0, \[Alpha]\ ratio^\((\[Kappa] - 1)\) \((\[Alpha]\ ratio^\[Kappa] + 
                  1 - \[Alpha])\)^\((\((1 - \[Kappa])\)/\[Kappa])\)];\)\), "\
\[IndentingNewLine]", 
    \(\(wu[ratio_] := 
        If[ratio < 0, 
          0, \((1 - \[Alpha])\) \((\[Alpha]\ ratio^\[Kappa] + 
                  1 - \[Alpha])\)^\((\((1 - \[Kappa])\)/\[Kappa])\)];\)\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the outcome for a given switching time", "Section"],

Cell["\<\
This function computes the time path for utilities assuming a given switching \
time to CLR.\
\>", "Text"],

Cell[BoxData[
    \(\(outpath[xps0_, xgs0_, xpu0_, xgu0_, tzero_, tsw_] := 
        Module[{par, t, j, k, 
            ratio}, \[IndentingNewLine]\[IndentingNewLine]par = {\ \[Beta] \
\[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[1], \[Kappa] \[Rule] 
                kappaset}; \[IndentingNewLine]\[IndentingNewLine]Vgu = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]Vpu = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]Vgs = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]Vps = 
            Table[0, {i, 
                tsw - tzero + 
                  1}]; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]Vs = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]Vu = 
            Table[0, {i, 
                tsw - tzero + 
                  1}]; \[IndentingNewLine]\[IndentingNewLine]xgu = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]xpu = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]xgs = 
            Table[0, {i, tsw - tzero + 1}]; \[IndentingNewLine]xps = 
            Table[0, {i, 
                tsw - tzero + 
                  1}]; \[IndentingNewLine]\[IndentingNewLine]pop = 
            Table[0, {i, 
                tsw - tzero + 
                  1}]; \[IndentingNewLine]\[IndentingNewLine]wui = 
            Table[0, {i, tsw - tzero}]; \[IndentingNewLine]wsi = 
            Table[0, {i, 
                tsw - tzero}]; \[IndentingNewLine]\[IndentingNewLine]eta = 
            Table[0.5, {i, tsw - tzero}]; \[IndentingNewLine]etaS = 
            Table[0.5, {i, 
                tsw - tzero}]; \[IndentingNewLine]\[IndentingNewLine]k = 
            1; \[IndentingNewLine]While[
            k \[LessEqual] etater, \[IndentingNewLine]\[IndentingNewLine]j = 
              1; \[IndentingNewLine]While[
              j \[LessEqual] 
                iter, \[IndentingNewLine]\[IndentingNewLine]xgs[\([1]\)] = 
                xgs0; \[IndentingNewLine]xps[\([1]\)] = 
                xps0; \[IndentingNewLine]xgu[\([1]\)] = 
                xgu0; \[IndentingNewLine]xpu[\([1]\)] = 
                xpu0; \[IndentingNewLine]\[IndentingNewLine]t = 
                1; \[IndentingNewLine]While[
                t \[LessEqual] 
                  tsw - tzero, \[IndentingNewLine]par = {\ \[Beta] \[Rule] 
                      betaset, 
                    z \[Rule] zset, \[Lambda] \[Rule] 
                      lamset, \[Pi]\_0 \[Rule] pi0set, \ \[Pi]\_1 \[Rule] 
                      pi1set, P \[Rule] Pset, G \[Rule] Gset, p \[Rule] pset, 
                    l \[Rule] lset, \[Alpha] \[Rule] 
                      alfafun[t + tzero - 1], \[Kappa] \[Rule] 
                      kappaset}; \[IndentingNewLine]\[IndentingNewLine]ratio \
= \((xgs[\([t]\)] + xps[\([t]\)])\)/\((\((1 + G\ l)\)\ xgu[\([t]\)] + 
                          xpu[\([t]\)] + G\ l\ xgs[\([t]\)])\) /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]wsi[\([t]\)] = 
                  ws[ratio] /. par; \[IndentingNewLine]wui[\([t]\)] = 
                  wu[ratio] /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]Vgu[\([t]\)] = 
                  U[wui[\([t]\)]\ \((1 + 
                              G\ l)\)] + \[Beta]\ \[Lambda]\ z \
\((\(\[Pi]\_0\) Vs[\([t + 1]\)] + \((1 - \[Pi]\_0)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vgu[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]Vpu[\([t]\)] = 
                  U[wui[\([t]\)]\  - 
                          P\ p] + \[Beta]\ \[Lambda]\ z \((\(\[Pi]\_1\) 
                              Vs[\([t + 1]\)] + \((1 - \[Pi]\_1)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vpu[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]Vgs[\([t]\)] = 
                  U[wsi[\([t]\)]\  + 
                          G\ l\ wui[\([t]\)]] + \[Beta]\ \[Lambda]\ z \((\(\
\[Pi]\_0\) Vs[\([t + 1]\)] + \((1 - \[Pi]\_0)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vgs[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]Vps[\([t]\)] = 
                  U[wsi[\([t]\)]\  - 
                          P\ p] + \[Beta]\ \[Lambda]\ z \((\(\[Pi]\_1\) 
                              Vs[\([t + 1]\)] + \((1 - \[Pi]\_1)\) 
                              Vu[\([t + 
                                    1]\)])\) + \[Beta]\ \((1 - \[Lambda])\) 
                        Vps[\([t + 1]\)] /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]Vs[\([t]\)] = 
                  Max[Vgs[\([t]\)], 
                    Vps[\([t]\)]]; \[IndentingNewLine]Vu[\([t]\)] = 
                  Max[Vgu[\([t]\)], 
                    Vpu[\([t]\)]]; \[IndentingNewLine]\[IndentingNewLine]xgu[\
\([t + 1]\)] = \((1 - \[Lambda])\) 
                        xgu[\([t]\)] + \[Lambda]\ \((1 - 
                            eta[\([t]\)])\) \((\((1 - \[Pi]\_1)\) 
                              P\ \((xpu[\([t]\)] + 
                                  xps[\([t]\)])\) + \((1 - \[Pi]\_0)\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]xpu[\([t + 
                        1]\)] = \((1 - \[Lambda])\) 
                        
                        xpu[\([t]\)] + \[Lambda]\ eta[\([t]\)] \((\((1 - \
\[Pi]\_1)\) P\ \((xpu[\([t]\)] + xps[\([t]\)])\) + \((1 - \[Pi]\_0)\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]xgs[\([t + 
                        1]\)] = \((1 - \[Lambda])\) 
                        xgs[\([t]\)] + \[Lambda]\ \((1 - 
                            etaS[\([t]\)])\) \((\(\[Pi]\_1\) 
                              P\ \((xpu[\([t]\)] + 
                                  xps[\([t]\)])\) + \(\[Pi]\_0\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]xps[\([t + 
                        1]\)] = \((1 - \[Lambda])\) 
                        xps[\([t]\)] + \[Lambda]\ etaS[\([t]\)] \((\(\[Pi]\_1\
\) P\ \((xpu[\([t]\)] + xps[\([t]\)])\) + \(\[Pi]\_0\) 
                              G\ \((xgs[\([t]\)] + xgu[\([t]\)])\))\) /. 
                    par; \[IndentingNewLine]\[IndentingNewLine]pop[\([t + 
                        1]\)] = 
                  100*\((\(\((1 + P)\) \((xps[\([t + 1]\)] + xpu[\([t + \
1]\)])\) + \((1 + G)\) \((xgs[\([t + 1]\)] + xgu[\([t + 1]\)])\)\)\/\(\((1 + \
P)\) \((xps[\([t]\)] + xpu[\([t]\)])\) + \((1 + G)\) \((xgs[\([t]\)] + \
xgu[\([t]\)])\)\) - 1)\) /. par; \[IndentingNewLine]\[IndentingNewLine]t = 
                  t + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]pop[\([1]\)] = 
                pop[\([2]\)] /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]{Vps[\([t]\)], 
                  Vgs[\([t]\)], \ Vpu[\([t]\)], \ Vgu[\([t]\)]} = \ 
                clrutil[xps[\([t]\)], xgs[\([t]\)], xpu[\([t]\)], 
                  xgu[\([t]\)], tsw]; \[IndentingNewLine]Vs[\([t]\)] = 
                Max[Vps[\([t]\)], 
                  Vgs[\([t]\)]]; \[IndentingNewLine]Vu[\([t]\)] = 
                Max[Vpu[\([t]\)], 
                  Vgu[\([t]\)]]; \[IndentingNewLine]\[IndentingNewLine]j = 
                j + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]t = 1; \[IndentingNewLine]While[
              t \[LessEqual] tsw - tzero, \[IndentingNewLine]If[
                Vgu[\([t + 1]\)] > Vpu[\([t + 1]\)], 
                eta[\([t]\)] = Max[0, eta[\([t]\)] - etastep], 
                eta[\([t]\)] = 
                  Min[1, eta[\([t]\)] + etastep]]; \[IndentingNewLine]t = 
                t + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]t = 1; \[IndentingNewLine]While[
              t \[LessEqual] tsw - tzero, \[IndentingNewLine]If[
                Vgs[\([t + 1]\)] > Vps[\([t + 1]\)], 
                etaS[\([t]\)] = Max[0, etaS[\([t]\)] - etastep], 
                etaS[\([t]\)] = 
                  Min[1, etaS[\([t]\)] + etastep]]; \[IndentingNewLine]t = 
                t + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]k = 
              k + 1;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]{Vgu, \ eta, \ xps, \ xpu, \ 
            xgu}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing utilities once switch to CLR occurs", "Section"],

Cell["\<\
This function computes the utility of all types once CLR are in place. This \
function is called in the routine that computes the outcome path depending on \
which equilibrium is being tested.\
\>", "Text"],

Cell[BoxData[
    \(\(clrutil[xpssw_, xgssw_, xpusw_, xgusw_, tsw_] := 
        Module[{par, t, ratio}, \[IndentingNewLine]\[IndentingNewLine]xsp = 
            xpssw; \[IndentingNewLine]xsg = xgssw; \[IndentingNewLine]xug = 
            xgusw; \[IndentingNewLine]xup = 
            xpusw; \[IndentingNewLine]\[IndentingNewLine]psps = 
            1; \[IndentingNewLine]pupps = 
            0; \[IndentingNewLine]\[IndentingNewLine]psgs = 
            0; \[IndentingNewLine]psggs = 1; \[IndentingNewLine]pupgs = 
            0; \[IndentingNewLine]\[IndentingNewLine]pspu = 
            0; \[IndentingNewLine]puppu = 
            1; \[IndentingNewLine]\[IndentingNewLine]psgu = 
            0; \[IndentingNewLine]pupgu = 0; \[IndentingNewLine]puggu = 
            1; \[IndentingNewLine]\[IndentingNewLine]VPSCLR = 
            0; \[IndentingNewLine]VGSCLR = 0; \[IndentingNewLine]VPUCLR = 
            0; \[IndentingNewLine]VGUCLR = 
            0; \[IndentingNewLine]\[IndentingNewLine]t = 
            tsw; \[IndentingNewLine]While[
            t \[LessEqual] 
              periods + 
                tsw, \[IndentingNewLine]par = {\ \[Beta] \[Rule] betaset, 
                z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                  pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
                G \[Rule] Gset, p \[Rule] pset, 
                l \[Rule] lset, \[Alpha] \[Rule] alfafun[t], \[Kappa] \[Rule] 
                  kappaset}; \[IndentingNewLine]\[IndentingNewLine]ratio = \
\((xsg + xsp)\)/\((xug + xup)\); \[IndentingNewLine]\[IndentingNewLine]wssw = 
              ws[ratio] /. par; \[IndentingNewLine]wusw = 
              wu[ratio] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]VPSCLR = 
              VPSCLR + psps\ U[wssw - p\ P] + pupps\ U[wusw - p\ P] /. 
                par; \[IndentingNewLine]VGSCLR = 
              VGSCLR + psggs\ U[wssw - p\ G] + psgs\ U[wssw - p\ P] + 
                  pupgs\ U[wusw - p\ P] /. par; \[IndentingNewLine]VPUCLR = 
              VPUCLR + pspu\ U[wssw - p\ P] + puppu\ U[wusw - p\ P] /. 
                par; \[IndentingNewLine]VGUCLR = 
              VGUCLR + puggu\ U[wusw - p\ G] + psgu\ U[wssw - p\ P] + 
                  pupgu\ U[wusw - p\ P] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]xugnew = \((1 - \
\[Lambda])\) xug /. par; \[IndentingNewLine]xsgnew = \((1 - \[Lambda])\) xsg /. 
                par; \[IndentingNewLine]xupnew = \((1 - \[Lambda])\) 
                    xup + \[Lambda] \((1 - \[Pi]\_1)\) \((P\ \((xup + 
                              xsp)\) + G\ \((xsg + xug)\))\) /. 
                par; \[IndentingNewLine]xspnew = \((1 - \[Lambda])\) 
                    xsp + \[Lambda]\ \(\[Pi]\_1\) \((P\ \((xup + xsp)\) + 
                        G\ \((xsg + xug)\))\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]pspsnew = \
\[Lambda]\ \[Beta]\ z\ \[Pi]\_1\ \((psps + 
                        pupps)\) + \((1 - \[Lambda])\)\ \[Beta]\ psps\  /. 
                par; \[IndentingNewLine]puppsnew = \[Lambda]\ \[Beta]\ z\ \
\((1 - \[Pi]\_1)\)\ \((psps + pupps)\) + \((1 - \[Lambda])\)\ \[Beta]\ pupps /. 
                par; \[IndentingNewLine]\[IndentingNewLine]psggsnew = \((1 - \
\[Lambda])\)\ \[Beta]\ psggs /. 
                par; \[IndentingNewLine]psgsnew = \[Lambda]\ \[Beta]\ z\ \
\[Pi]\_1\ \((psgs + pupgs + psggs)\) + \((1 - \[Lambda])\)\ \[Beta]\ psgs\  /. 
                par; \[IndentingNewLine]pupgsnew = \[Lambda]\ \[Beta]\ z\ \
\((1 - \[Pi]\_1)\)\ \((psgs + pupgs + 
                        psggs)\) + \((1 - \[Lambda])\)\ \[Beta]\ pupgs /. 
                par; \[IndentingNewLine]\t\[IndentingNewLine]pspunew = \
\[Lambda]\ \[Beta]\ z\ \[Pi]\_1\ \((pspu + 
                        puppu)\) + \((1 - \[Lambda])\)\ \[Beta]\ pspu\  /. 
                par; \[IndentingNewLine]puppunew = \[Lambda]\ \[Beta]\ z\ \
\((1 - \[Pi]\_1)\)\ \((pspu + puppu)\) + \((1 - \[Lambda])\)\ \[Beta]\ puppu /. 
                par; \[IndentingNewLine]\[IndentingNewLine]psgunew = \
\[Lambda]\ \[Beta]\ z\ \[Pi]\_1\ \((psgu + pupgu + 
                        puggu)\) + \((1 - \[Lambda])\)\ \[Beta]\ psgu\  /. 
                par; \[IndentingNewLine]pupgunew = \[Lambda]\ \[Beta]\ z\ \
\((1 - \[Pi]\_1)\)\ \((psgu + pupgu + 
                        puggu)\) + \((1 - \[Lambda])\)\ \[Beta]\ pupgu /. 
                par; \[IndentingNewLine]puggunew = \((1 - \[Lambda])\)\ \
\[Beta]\ puggu /. par; \[IndentingNewLine]\[IndentingNewLine]xug = 
              xugnew; \[IndentingNewLine]xup = 
              xupnew; \[IndentingNewLine]xsp = 
              xspnew; \[IndentingNewLine]xsg = 
              xsgnew; \[IndentingNewLine]\[IndentingNewLine]psps = 
              pspsnew; \[IndentingNewLine]pupps = 
              puppsnew; \[IndentingNewLine]\[IndentingNewLine]pspu = 
              pspunew; \[IndentingNewLine]puppu = 
              puppunew; \[IndentingNewLine]\[IndentingNewLine]psgu = 
              psgunew; \[IndentingNewLine]pupgu = 
              pupgunew; \[IndentingNewLine]puggu = 
              puggunew; \[IndentingNewLine]\[IndentingNewLine]psgs = 
              psgsnew; \[IndentingNewLine]pupgs = 
              pupgsnew; \[IndentingNewLine]psggs = 
              psggsnew; \[IndentingNewLine]\[IndentingNewLine]t = 
              t + 1;\[IndentingNewLine]]; \[IndentingNewLine]{\ VPSCLR, 
            VGSCLR, \ VPUCLR, \ VGUCLR}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check whether a given switching time is an equilibrium", "Section"],

Cell[TextData[{
  "The routine first computes the output path assuming that people assume \
that the switch occurs at time. For time to be an equilibrium, there has to \
be a majority in favor of CLR at time. In addition, there must be NO majority \
in favor at time-1.\n\nBelow I am storing the old steady state ratio\n",
  Cell[BoxData[
      \(\(\(\[IndentingNewLine]\)\(rhoss2 = \(-\(\(G\ \((\(-1\) + \[Pi]\_0)\) \
+ P\ \[Pi]\_1 + \@\(\(-4\)\ G\ P\ \[Pi]\_0\ \((\(-1\) + \[Pi]\_1)\) + \((G\ \
\((\(-1\) + \[Pi]\_0)\) + P\ \[Pi]\_1)\)\^2\)\)\/\(2\ P\ \((\(-1\) + \
\[Pi]\_1)\)\)\)\) /. par;\)\)\)]]
}], "Text"],

Cell[BoxData[
    \(\(checkswitch[time_] := 
        Module[{par, t, 
            ratio}, \[IndentingNewLine]\[IndentingNewLine]par = {\ \[Beta] \
\[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[1], \[Kappa] \[Rule] 
                kappaset}; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]outpath[0, \[Pi]\_0 /. par, 0, 1 - \[Pi]\_0 /. par, 1, 
            time]; \[IndentingNewLine]\[IndentingNewLine]vguifclr = 
            Vgu[\([time]\)]; \[IndentingNewLine]vgubefore = 
            Vgu[\([time - 
                  1]\)]; \[IndentingNewLine]\[IndentingNewLine]xpstemp = 
            xps[\([time]\)]; \[IndentingNewLine]xgstemp = 
            xgs[\([time]\)]; \[IndentingNewLine]xputemp = 
            xpu[\([time]\)]; \[IndentingNewLine]xgutemp = 
            xgu[\([time]\)]; \
\[IndentingNewLine]\[IndentingNewLine]xpstempbefore = 
            xps[\([time - 1]\)]; \[IndentingNewLine]xgstempbefore = 
            xgs[\([time - 1]\)]; \[IndentingNewLine]xputempbefore = 
            xpu[\([time - 1]\)]; \[IndentingNewLine]xgutempbefore = 
            xgu[\([time - 
                  1]\)]; \[IndentingNewLine]\[IndentingNewLine]outpath[
            xpstemp, xgstemp, \ xputemp, xgutemp, time, 
            time + 1]; \[IndentingNewLine]vgunoclr = 
            Vgu[\([1]\)]; \
\[IndentingNewLine]\[IndentingNewLine]{vpsifclrbefore, vgsifclrbefore, \ 
              vpuifclrbefore, \ vguifclrbefore} = \ 
            clrutil[xpstempbefore, xgstempbefore, xputempbefore, 
              xgutempbefore, 
              time - 1]; \[IndentingNewLine]\[IndentingNewLine]If[
            vguifclr \[GreaterEqual] vgunoclr || 
              xputemp/\((xpstemp + xgstemp + xgutemp)\) > 1, out = 1, 
            out = 0]; \[IndentingNewLine]\[IndentingNewLine]If[
            vguifclrbefore \[GreaterEqual] vgubefore || 
              xputempbefore/\((xpstempbefore + xgstempbefore + 
                      xgutempbefore)\) > 1, out2 = 1, 
            out2 = 0]; \[IndentingNewLine]\[IndentingNewLine]{out, out2, 
            vguifclr - vgunoclr, 
            xputemp/\((xpstemp + xgstemp + 
                  xgutemp)\)}\[IndentingNewLine]\[IndentingNewLine]];\)\)], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the transition path", "Section"],

Cell[BoxData[
    \(\(transition[switchtime_, horizon_] := 
        Module[{par, t, 
            ratio}, \[IndentingNewLine]\[IndentingNewLine]xguout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xgsout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xpuout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]xpsout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]wuout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]wsout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]etaout = 
            Table[0, {i, horizon}]; \[IndentingNewLine]etaSout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]giniout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]clout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]popout = 
            Table[0, {i, 
                horizon}]; \[IndentingNewLine]\[IndentingNewLine]par = {\ \
\[Beta] \[Rule] betaset, 
              z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
              G \[Rule] Gset, p \[Rule] pset, 
              l \[Rule] lset, \[Alpha] \[Rule] alfafun[1], \[Kappa] \[Rule] 
                kappaset}; \[IndentingNewLine]\[IndentingNewLine]outpath[
            0, \[Pi]\_0 /. par, 0, 1 - \[Pi]\_0 /. par, 1, 
            switchtime]; \[IndentingNewLine]\[IndentingNewLine]t = 
            1; \[IndentingNewLine]While[
            t \[LessEqual] 
              horizon, \[IndentingNewLine]par = {\ \[Beta] \[Rule] betaset, 
                z \[Rule] zset, \[Lambda] \[Rule] lamset, \[Pi]\_0 \[Rule] 
                  pi0set, \ \[Pi]\_1 \[Rule] pi1set, P \[Rule] Pset, 
                G \[Rule] Gset, p \[Rule] pset, 
                l \[Rule] lset, \[Alpha] \[Rule] alfafun[t], \[Kappa] \[Rule] 
                  kappaset}; \[IndentingNewLine]\[IndentingNewLine]If[
              t < switchtime, \
\[IndentingNewLine]\[IndentingNewLine]xpsout[\([t]\)] = 
                xps[\([t]\)]; \[IndentingNewLine]xgsout[\([t]\)] = 
                xgs[\([t]\)]; \[IndentingNewLine]xguout[\([t]\)] = 
                xgu[\([t]\)]; \[IndentingNewLine]xpuout[\([t]\)] = 
                xpu[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]wuout[\([t]\)] = 
                wui[\([t]\)]; \[IndentingNewLine]wsout[\([t]\)] = 
                
                wsi[\([t]\)]; \
\[IndentingNewLine]\[IndentingNewLine]etaout[\([t]\)] = 
                eta[\([t]\)]; \[IndentingNewLine]etaSout[\([t]\)] = 
                etaS[\([t]\)]; \[IndentingNewLine]\[IndentingNewLine]giniout[\
\([t]\)] = \((wsi[\([t]\)] - \((1 + G\ l)\)\ wui[\([t]\)])\) 
                    xps[\([t]\)]/\((wsi[\([t]\)] 
                            xps[\([t]\)] + \((1 + G\ l)\) 
                            wui[\([t]\)] \((xgu[\([t]\)] + 
                                xpu[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]clout[\([t]\)] = 
                G\ \((xgsout[\([t]\)] + 
                          xguout[\([t]\)])\)/\((G\ \((xgsout[\([t]\)] + 
                                xguout[\([t]\)])\) + 
                          P \((xpsout[\([t]\)] + xpuout[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]popout[\([t]\)] \
= pop[\([t]\)]; \[IndentingNewLine]\[IndentingNewLine]If[t \[Equal] 1, 
                tx = popout[\([1]\)]];\[IndentingNewLine]\[IndentingNewLine]];\
 \[IndentingNewLine]\[IndentingNewLine]If[
              t \[GreaterEqual] 
                switchtime, \[IndentingNewLine]\[IndentingNewLine]If[
                t \[Equal] switchtime, \[IndentingNewLine]xpsout[\([t]\)] = 
                  xps[\([t]\)]; \[IndentingNewLine]xgsout[\([t]\)] = 
                  xgs[\([t]\)]; \[IndentingNewLine]xguout[\([t]\)] = 
                  xgu[\([t]\)]; \[IndentingNewLine]xpuout[\([t]\)] = 
                  xpu[\([t]\)];\[IndentingNewLine], \
\[IndentingNewLine]xpsout[\([t]\)] = \((1 - \[Lambda])\) 
                        xpsout[\([t - 
                              1]\)] + \[Lambda]\ \(\[Pi]\_1\) \((P\ \
\((xpuout[\([t - 1]\)] + xpsout[\([t - 1]\)])\) + 
                            G\ \ \((xgsout[\([t - 1]\)] + 
                                  xguout[\([t - 1]\)])\))\) /. 
                    par; \[IndentingNewLine]xgsout[\([t]\)] = \((1 - \
\[Lambda])\)\ xgsout[\([t - 1]\)] /. 
                    par; \[IndentingNewLine]xguout[\([t]\)] = \((1 - \
\[Lambda])\)\ xguout[\([t - 1]\)] /. 
                    par; \[IndentingNewLine]xpuout[\([t]\)] = \((1 - \
\[Lambda])\) xpuout[\([t - 
                              1]\)] + \[Lambda] \((1 - \[Pi]\_1)\) \((P\ \
\((xpuout[\([t - 1]\)] + xpsout[\([t - 1]\)])\) + 
                            G\ \ \((xgsout[\([t - 1]\)] + 
                                  xguout[\([t - 1]\)])\))\) /. 
                    par;\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]ratio = \((xpsout[\([t]\)] + 
                      xgsout[\([t]\)])\)/\((xpuout[\([t]\)] + 
                      xguout[\([t]\)])\); \[IndentingNewLine]\
\[IndentingNewLine]wsout[\([t]\)] = 
                ws[ratio] /. par; \[IndentingNewLine]wuout[\([t]\)] = 
                wu[ratio] /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]etaout[\([t]\)] \
= 1; \[IndentingNewLine]etaSout[\([t]\)] = 
                1; \[IndentingNewLine]\[IndentingNewLine]giniout[\([t]\)] = \
\((wsout[\([t]\)] - \ wuout[\([t]\)])\) 
                    xpsout[\([t]\)]/\((wsout[\([t]\)] xpsout[\([t]\)] + 
                          wuout[\([t]\)] \((xguout[\([t]\)] + 
                                xpuout[\([t]\)])\))\) /. 
                  par; \[IndentingNewLine]\[IndentingNewLine]clout[\([t]\)] = 
                0; \[IndentingNewLine]\[IndentingNewLine]popout[\([t]\)] = 
                100*\((\(\((1 + P)\) \((xpsout[\([t]\)] + xpuout[\([t]\)])\) \
+ \((1 + G)\) \((xgsout[\([t]\)] + xguout[\([t]\)])\)\)\/\(\((1 + P)\) \
\((xpsout[\([t - 1]\)] + xpuout[\([t - 1]\)])\) + \((1 + G)\) \((xgsout[\([t \
- 1]\)] + xguout[\([t - 1]\)])\)\) - 1)\) /. 
                  par;\[IndentingNewLine]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]t = 
              t + 1;\[IndentingNewLine]];\[IndentingNewLine]\
\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Carrying out the computations and graphing the results", "Section"],

Cell[BoxData[{
    \(\(zaehler = 2;\)\), "\[IndentingNewLine]", 
    \(\(While[
        zaehler < 10, \[IndentingNewLine]{res1, res2, res3, res4} = 
          checkswitch[zaehler]; \[IndentingNewLine]If[res1 == 1, 
          reform = zaehler; zaehler = 10, 
          zaehler = 
            zaehler + 1];\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(reform\), "\[IndentingNewLine]", 
    \(checkswitch[reform - 1]\), "\[IndentingNewLine]", 
    \(checkswitch[reform]\), "\[IndentingNewLine]", 
    \(checkswitch[reform + 1]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(checkswitch[7]\)], "Input"],

Cell[BoxData[
    \({1, 0, \(-0.013920365945329749`\), 1.2303502213390245`}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(transition[7, 11]\)], "Input"],

Cell["Now save what we will need later for the graph", "Text"],

Cell[BoxData[{
    \(\(wsreform = wsout/wuout;\)\), "\[IndentingNewLine]", 
    \(\(popoutreform = popout;\)\), "\[IndentingNewLine]", 
    \(\(cloutreform = clout;\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plot1 = 
        ListPlot[wsout/wuout, PlotRange \[Rule] {{0, 12}, {1.5, 5}}, 
          PlotStyle \[Rule] Thickness[0.01], AxesOrigin \[Rule] {0, 0}, 
          Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time\>", "\<Wage Ratio\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(plot2 = 
        ListPlot[popout, PlotRange \[Rule] {{0, 12}, {0, 30}}, 
          PlotStyle \[Rule] Thickness[0.01], AxesOrigin \[Rule] {0, 0}, 
          Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time\>", "\<Population Growth\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(plot3 = 
        ListPlot[clout, PlotRange \[Rule] {{0, 12}, {\(- .1\), 1}}, 
          PlotStyle \[Rule] Thickness[0.01], AxesOrigin \[Rule] {0, 0}, 
          Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time\>", "\<Working Children\>"}];\)\)}], \
"Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.264872 0.176581 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .08829 -6 -4.5 ]
[-0.0125 .08829 0 4.5 ]
[-0.0125 .17658 -18 -4.5 ]
[-0.0125 .17658 0 4.5 ]
[-0.0125 .26487 -6 -4.5 ]
[-0.0125 .26487 0 4.5 ]
[-0.0125 .35316 -18 -4.5 ]
[-0.0125 .35316 0 4.5 ]
[-0.0125 .44145 -6 -4.5 ]
[-0.0125 .44145 0 4.5 ]
[-0.0125 .52974 -18 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -32 ]
[-0.01875 .30902 -18 32 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08829 m
.00625 .08829 L
s
[(2)] -0.0125 .08829 1 0 Mshowa
0 .17658 m
.00625 .17658 L
s
[(2.5)] -0.0125 .17658 1 0 Mshowa
0 .26487 m
.00625 .26487 L
s
[(3)] -0.0125 .26487 1 0 Mshowa
0 .35316 m
.00625 .35316 L
s
[(3.5)] -0.0125 .35316 1 0 Mshowa
0 .44145 m
.00625 .44145 L
s
[(4)] -0.0125 .44145 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(4.5)] -0.0125 .52974 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01766 m
.00375 .01766 L
s
0 .03532 m
.00375 .03532 L
s
0 .05297 m
.00375 .05297 L
s
0 .07063 m
.00375 .07063 L
s
0 .10595 m
.00375 .10595 L
s
0 .12361 m
.00375 .12361 L
s
0 .14126 m
.00375 .14126 L
s
0 .15892 m
.00375 .15892 L
s
0 .19424 m
.00375 .19424 L
s
0 .2119 m
.00375 .2119 L
s
0 .22956 m
.00375 .22956 L
s
0 .24721 m
.00375 .24721 L
s
0 .28253 m
.00375 .28253 L
s
0 .30019 m
.00375 .30019 L
s
0 .31785 m
.00375 .31785 L
s
0 .3355 m
.00375 .3355 L
s
0 .37082 m
.00375 .37082 L
s
0 .38848 m
.00375 .38848 L
s
0 .40614 m
.00375 .40614 L
s
0 .42379 m
.00375 .42379 L
s
0 .45911 m
.00375 .45911 L
s
0 .47677 m
.00375 .47677 L
s
0 .49443 m
.00375 .49443 L
s
0 .51209 m
.00375 .51209 L
s
0 .5474 m
.00375 .5474 L
s
0 .56506 m
.00375 .56506 L
s
0 .58272 m
.00375 .58272 L
s
0 .60038 m
.00375 .60038 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -117.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 10.2813 translate
90 rotate
-93 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Wage) show
93.000 12.813 moveto
(Ratio) show
123.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .08829 m
1 .08829 L
s
.99375 .17658 m
1 .17658 L
s
.99375 .26487 m
1 .26487 L
s
.99375 .35316 m
1 .35316 L
s
.99375 .44145 m
1 .44145 L
s
.99375 .52974 m
1 .52974 L
s
.125 Mabswid
.99625 .01766 m
1 .01766 L
s
.99625 .03532 m
1 .03532 L
s
.99625 .05297 m
1 .05297 L
s
.99625 .07063 m
1 .07063 L
s
.99625 .10595 m
1 .10595 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14126 m
1 .14126 L
s
.99625 .15892 m
1 .15892 L
s
.99625 .19424 m
1 .19424 L
s
.99625 .2119 m
1 .2119 L
s
.99625 .22956 m
1 .22956 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .28253 m
1 .28253 L
s
.99625 .30019 m
1 .30019 L
s
.99625 .31785 m
1 .31785 L
s
.99625 .3355 m
1 .3355 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .38848 m
1 .38848 L
s
.99625 .40614 m
1 .40614 L
s
.99625 .42379 m
1 .42379 L
s
.99625 .45911 m
1 .45911 L
s
.99625 .47677 m
1 .47677 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .51209 m
1 .51209 L
s
.99625 .5474 m
1 .5474 L
s
.99625 .56506 m
1 .56506 L
s
.99625 .58272 m
1 .58272 L
s
.99625 .60038 m
1 .60038 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .16999 m
.16667 .16909 L
.25 .27047 L
.33333 .38706 L
.41667 .5011 L
.5 .55451 L
.58333 .54435 L
.66667 .43011 L
.75 .37094 L
.83333 .30514 L
.91667 .26381 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{272.625, 168.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004@0000Z2000`400?l00000o`00003oo`3ooolA
0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00R`3oool3
000000@0oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool3000006l0oooo
002<0?ooo`030000003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000001b0?ooo`00S03oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`@00000K`3oool008`0oooo00<000000?ooo`3oool0
0`3oool200000080oooo0`0000000`3oool000000?ooo`020?ooo`800000L03oool008X0oooo00D0
00000?ooo`000000oooo000000210?ooo`00RP3oool5000000@0oooo00<000000?ooo`3oool0NP3o
ool00?l0oooo4@3oool00?l0oooo4@3oool00?l0oooo4@3oool004T0oooo1000000S0?ooo`<00000
8@3oool3000002<0oooo0P00000O0?ooo`D000000P3oool2000001d0oooo1@0000000`3oool00000
00000002000000D0oooo00190?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0803o
ool010000000oooo0?ooo`00000Q0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`00BP3oool00`000000oooo0?ooo`0Q0?ooo`D000008@3oool010000000oooo0?ooo`00000Q
0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`00B`3o
ool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo00000280oooo0`00000S0?ooo`800000
8@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00190?ooo`040000003oool0oooo00000280
oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo0000
0200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo001:0?ooo`800000903oool2
000002<0oooo0`00000R0?ooo`800000803oool2000000@0oooo0P00000N0?ooo`800000103oool2
000000H0oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo000V
0?ooon4000002@3oool002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`009P3o
ool00`000000oooo0?ooo`3L0?ooo`8000002@3oool002H0oooo00<000000?ooo`3oool0g@3oool0
0`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo
00L0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3oool002H0oooo
00<000000?ooo`3oool0g03oool2000000T0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<0
00000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`07
0?ooo`009P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`03
0000003oool0oooo0=`0oooo0P0000090?ooo`009P3oool00`000000oooo0?ooo`3M0?ooo`030000
003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3o
ool002H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`009P3oool00`00
0000oooo0?ooo`3L0?ooo`8000002@3oool002H0oooo00<000000?ooo`3oool0g@3oool00`000000
oooo0?ooo`070?ooo`007P3oool4000000@0oooo00<000000?ooo`3oool0g@3oool00`000000oooo
0?ooo`070?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=d0oooo00<0
00000?ooo`3oool01`3oool001l0oooo00<000000?ooo`3oool0103oool200000=`0oooo0`000009
0?ooo`00803oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0=d0oooo00<000000?oo
o`3oool01`3oool001h0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3M0?oo
o`030000003oool0oooo00L0oooo000O0?ooo`8000001@3oool00`000000oooo0?ooo`3M0?ooo`03
0000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=`0oooo0P0000090?ooo`009P3o
ool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0
oooo0=d0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`00
0000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`3L0?ooo`8000002@3oool002H0oooo
00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?oo
o`3M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<00000
0?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0g03oool2000000T0oooo000V0?ooo`03
0000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0
g@3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`3M0?ooo`030000003o
ool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=`0oooo0P0000090?ooo`009P3oool00`00
0000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000B0?ooo`@000000`3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo0100oooo5000002i0?ooo`030000003oool0oooo00L0
oooo000B0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`0>0?oooaL00000^03oool00`000000oooo0?ooo`070?ooo`004`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`8000004`3oool200000;H0oooo
0`0000090?ooo`001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo0P00
00050?ooo`030000003oool0oooo02@0oooo0P00002g0?ooo`030000003oool0oooo00L0oooo0006
0?ooo`D000001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0903oool300000;H0oooo00<000000?ooo`3oool01`3oool000H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`8000002P3oool3000000@0oooo00<00000
0?ooo`3oool09@3oool300000;D0oooo00<000000?ooo`3oool01`3oool000P0oooo0`00000K0?oo
o`030000003oool0oooo02H0oooo0`00002c0?ooo`8000002@3oool000H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02L0oooo0`00002c0?ooo`03
0000003oool0oooo00L0oooo00060?ooo`D000006`3oool00`000000oooo0?ooo`0X0?ooo`800000
/`3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`0Y0?ooo`800000/P3o
ool00`000000oooo0?ooo`070?ooo`002P3oool2000001X0oooo00<000000?ooo`3oool0:@3oool3
00000;00oooo0P0000090?ooo`00203oool010000000oooo00000000000J0?ooo`030000003oool0
oooo02X0oooo0`00002`0?ooo`030000003oool0oooo00L0oooo00080?ooo`040000003oool00000
000001X0oooo00<000000?ooo`3oool0:`3oool300000:l0oooo00<000000?ooo`3oool01`3oool0
00P0oooo1000000J0?ooo`030000003oool0oooo02`0oooo0`00002^0?ooo`030000003oool0oooo
00L0oooo000;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0;@3oool200000:d0
oooo0P0000090?ooo`009P3oool00`000000oooo0?ooo`0^0?ooo`800000[@3oool00`000000oooo
0?ooo`070?ooo`002@3oool200000080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0^0?ooo`<00000[03oool00`000000oooo0?ooo`070?ooo`00203oool01P000000oooo0?ooo`00
0000oooo000001P0oooo00<000000?ooo`3oool0;`3oool300000:/0oooo00<000000?ooo`3oool0
1`3oool000P0oooo00H000000?ooo`3oool000000?ooo`00000H0?ooo`030000003oool0oooo0300
oooo0`00002Y0?ooo`8000002@3oool000P0oooo1@00000I0?ooo`030000003oool0oooo0340oooo
0`00002Y0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo01@0oooo0P00
00050?ooo`030000003oool0oooo0380oooo0P00002Y0?ooo`030000003oool0oooo00L0oooo000N
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0<`3oool2000009D0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`002@3oool2000001D0oooo00<00000
0?ooo`3oool00`3oool2000003@0oooo0`00002B0?ooo`@000003`3oool3000000T0oooo00080?oo
o`80000000<0oooo0000003oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03@0oooo0P00002@0?ooo`D000004P3oool00`000000oooo0?ooo`070?ooo`00203oool200000003
0?ooo`000000oooo0140oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0e0?oo
o`800000S@3oool5000001@0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`00
00004`3oool2000000D0oooo00<000000?ooo`3oool0=P3oool2000008X0oooo1@00000F0?ooo`03
0000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
Q@3oool6000001L0oooo0P0000090?ooo`009P3oool00`000000oooo0?ooo`0g0?ooo`800000Q03o
ool6000001X0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0>03oool2
00000840oooo1@00000M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0O@3oool5000001l0oooo00<000000?ooo`3oool01`3oool002H0
oooo00<000000?ooo`3oool0>@3oool2000007`0oooo1@00000P0?ooo`8000002@3oool002H0oooo
00<000000?ooo`3oool0>P3oool2000007X0oooo1000000S0?ooo`030000003oool0oooo00L0oooo
000V0?ooo`030000003oool0oooo03/0oooo0P00001h0?ooo`<000009@3oool00`000000oooo0?oo
o`070?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`1d0?ooo`@000009P3oool00`000000oooo0?ooo`07
0?ooo`001P3oool6000001X0oooo00<000000?ooo`3oool0?03oool2000007@0oooo1000000V0?oo
o`8000002@3oool000H0oooo00H000000?ooo`3oool000000?ooo`00000J0?ooo`030000003oool0
oooo03d0oooo0P00001b0?ooo`<00000:@3oool00`000000oooo0?ooo`070?ooo`001P3oool01000
0000oooo0?ooo`00000L0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0K`3oool3
000002X0oooo00<000000?ooo`3oool01`3oool000L0oooo0P0000000`3oool000000?ooo`0J0?oo
o`030000003oool0oooo03h0oooo0P00001_0?ooo`<00000:`3oool00`000000oooo0?ooo`070?oo
o`002`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03l0oooo0P00001/0?ooo`@0
0000:`3oool2000000T0oooo000V0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
J@3oool4000002d0oooo00<000000?ooo`3oool01`3oool000X0oooo0P0000070?ooo`800000103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo0400oooo0P00001Y0?ooo`<00000;`3o
ool00`000000oooo0?ooo`070?ooo`00203oool010000000oooo0000000000060?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`110?ooo`80
0000I`3oool300000300oooo00<000000?ooo`3oool01`3oool000P0oooo00@000000?ooo`000000
0000203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo0P0000130?ooo`03
0000003oool0oooo06@0oooo0`00000_0?ooo`<000002@3oool000P0oooo100000090?ooo`030000
003oool0oooo00L0oooo0P0000050?ooo`030000003oool0oooo0480oooo0P00001S0?ooo`@00000
<P3oool00`000000oooo0?ooo`070?ooo`002`3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`130?ooo`800000
H@3oool4000003<0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0203o
ool2000000X0oooo0`0000040?ooo`030000003oool0oooo04@0oooo0P00001O0?ooo`<00000=@3o
ool00`000000oooo0?ooo`070?ooo`001`3oool4000001/0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`1L0?ooo`<00000=@3oool2000000T0oooo00080?ooo`040000003oool0oooo
000001X0oooo00<000000?ooo`3oool0A@3oool2000005/0oooo1000000g0?ooo`030000003oool0
oooo00L0oooo00080?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0AP3oool2
000005T0oooo1000000h0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1E0?ooo`@00000>P3oool00`00
0000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`170?ooo`800000E@3oool4000003X0
oooo0P0000090?ooo`009P3oool00`000000oooo0?ooo`180?ooo`800000DP3oool4000003d0oooo
00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0B@3oool200000500oooo1000
000n0?ooo`030000003oool0oooo00L0oooo00080?ooo`040000003oool0oooo000001X0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`1<0?ooo`@00000?`3oool2000000T0oooo0006
0?ooo`030000003oool0000000<000006P3oool00`000000oooo0?ooo`1:0?ooo`800000C03oool4
00000440oooo00<000000?ooo`3oool01`3oool000/0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`1;0?ooo`800000B@3oool4000004<0oooo00<000000?ooo`3oool01`3oool002H0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`160?ooo`@00000A03oool00`000000
oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`1<0?ooo`800000A@3oool4000004D0oooo
0P0000090?ooo`002@3oool2000001/0oooo00<000000?ooo`3oool0C@3oool2000004<0oooo1000
00170?ooo`030000003oool0oooo00L0oooo00080?ooo`040000003oool0oooo000001@0oooo0`00
00030?ooo`030000003oool0oooo04h0oooo0P0000120?ooo`800000B@3oool00`000000oooo0?oo
o`070?ooo`00203oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0o0?ooo`800000BP3oool00`000000oooo0?oo
o`070?ooo`002@3oool2000001<0oooo1@0000030?ooo`800000D03oool2000003l0oooo0P000019
0?ooo`<000002@3oool001h0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1@
0?ooo`800000?@3oool2000004`0oooo00<000000?ooo`3oool01`3oool001l0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`1A0?ooo`800000?03oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo00L0oooo000P0?ooo`800000103oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo03T0oooo0P00001=0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000
003oool0oooo0580oooo0P00000i0?ooo`800000C@3oool2000000T0oooo000V0?ooo`030000003o
ool0oooo05<0oooo0P00000g0?ooo`800000C`3oool00`000000oooo0?ooo`070?ooo`009P3oool0
0`000000oooo0?ooo`1D0?ooo`800000=P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo00L0oooo000V0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0<`3oool20000
0500oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0E@3oool2000003<0
oooo0P00001@0?ooo`8000002@3oool002H0oooo00<000000?ooo`3oool0EP3oool200000340oooo
0P00001B0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0;P3oool2000005<0oooo00<000000?ooo`3oool01`3oool002H0oooo00<00000
0?ooo`3oool0E`3oool2000002l0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`07
0?ooo`009P3oool00`000000oooo0?ooo`1H0?ooo`800000;@3oool2000005<0oooo0P0000090?oo
o`009P3oool00`000000oooo0?ooo`1I0?ooo`800000:`3oool2000005D0oooo00<000000?ooo`3o
ool01`3oool002H0oooo00<000000?ooo`3oool0FP3oool3000002P0oooo0P00001F0?ooo`030000
003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo05X0oooo1000000W0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0G03oool4
000002@0oooo0P00001F0?ooo`8000002@3oool002H0oooo00<000000?ooo`3oool0G@3oool40000
0280oooo0P00001H0?ooo`030000003oool0oooo00L0oooo000D0?ooo`<000000P3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo05l0oooo1000000O0?ooo`800000F@3oool00`000000
oooo0?ooo`070?ooo`005@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0H03oool4000001h0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`070?ooo`004P3oool5000000X0oooo00<000000?ooo`3oool00P3oool2000006<0oooo
1000000K0?ooo`800000F03oool3000000T0oooo000B0?ooo`040000003oool0oooo000000T0oooo
0P0000050?ooo`030000003oool0oooo06<0oooo1@00000H0?ooo`800000F`3oool00`000000oooo
0?ooo`070?ooo`004`3oool00`000000oooo000000090?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0I@3oool4000001H0oooo0P00001L0?ooo`030000003oool0oooo00L0oooo000D
0?ooo`8000002@3oool3000000@0oooo00<000000?ooo`3oool0I`3oool4000000h0oooo1`00001M
0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo06P0oooo100000070?oo
o`d00000G03oool2000000T0oooo000V0?ooo`030000003oool0oooo06X0oooo3`00001T0?ooo`03
0000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo06/0oooo2000001Z0?ooo`030000
003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3o
ool002H0oooo00<000000?ooo`3oool0g03oool2000000T0oooo000V0?ooo`030000003oool0oooo
0=d0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`000000
oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo
000V0?ooo`030000003oool0oooo0=`0oooo0P0000090?ooo`009P3oool00`000000oooo0?ooo`3M
0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<000000?oo
o`3oool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`00
9P3oool00`000000oooo0?ooo`3L0?ooo`8000002@3oool002H0oooo00<000000?ooo`3oool0g@3o
ool00`000000oooo0?ooo`070?ooo`007`3oool2000000D0oooo00<000000?ooo`3oool0g@3oool0
0`000000oooo0?ooo`070?ooo`007P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo000Q0?ooo`030000003oool0oooo0080ooooh@0000090?ooo`007`3oool200000>l0
oooo000O0?ooo`030000003oool0oooo0>h0oooo000O0?ooo`<00000kP3oool00?l0oooo4@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 271.625}, {167.438, 0}} -> {-2.03853, 0.884577, \
0.0535203, 0.0252577}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0 0.0206011 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .10301 -6 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -12 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5625 -53 ]
[-0.01875 .30902 -12 53 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(10)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(20)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(25)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(30)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -132.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
114 10.2813 translate
90 rotate
-114 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Population) show
129.000 12.813 moveto
(Growth) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .59486 m
.16667 .59486 L
.25 .59128 L
.33333 .58878 L
.41667 .26042 L
.5 .12886 L
.58333 .10308 L
.66667 .08345 L
.75 .06817 L
.83333 .05609 L
.91667 .04641 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{272.625, 168.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004@0000Z2000`400?l00000o`00003oo`3ooolA
0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00R03oool3
000000@0oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool300000780oooo
00290?ooo`030000003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000001e0?ooo`00R@3oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`@00000LP3oool008T0oooo00<000000?ooo`3oool0
0`3oool200000080oooo0`0000000`3oool000000?ooo`020?ooo`800000L`3oool008L0oooo00D0
00000?ooo`000000oooo000000240?ooo`00Q`3oool5000000@0oooo00<000000?ooo`3oool0O@3o
ool00?l0oooo4@3oool00?l0oooo4@3oool00?l0oooo4@3oool004H0oooo1000000S0?ooo`<00000
8@3oool3000002<0oooo0P00000O0?ooo`D000000P3oool2000001d0oooo1@0000000`3oool00000
00000002000000P0oooo00160?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0803o
ool010000000oooo0?ooo`00000Q0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`00A`3oool00`000000oooo0?ooo`0Q0?ooo`D000008@3oool010000000oooo0?ooo`00000Q
0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`00B03o
ool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo00000280oooo0`00000S0?ooo`800000
8@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00160?ooo`040000003oool0oooo00000280
oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo0000
0200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00170?ooo`800000903oool2
000002<0oooo0`00000R0?ooo`800000803oool2000000@0oooo0P00000N0?ooo`800000103oool2
000000T0oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo000S
0?ooon400000303oool002<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool02P3oool002<0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0:0?ooo`008`3o
ool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0
oooo0=`0oooo0P00000<0?ooo`008`3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo
00X0oooo000S0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool02P3oool002<0oooo
00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?oo
o`3M0?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool03`3oool2000000`0oooo000S0?ooo`030000003oool0oooo0<40oooo2P00000B0?oo
o`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0oooo0;L0oooo4`00000C0?ooo`03
0000003oool0oooo00X0oooo000S0?ooo`030000003oool0oooo0;40oooo4000000L0?ooo`030000
003oool0oooo00X0oooo000S0?ooo`030000003oool0oooo0:/0oooo3000000U0?ooo`800000303o
ool002<0oooo00<000000?ooo`3oool0Y@3oool<000002`0oooo00<000000?ooo`3oool02P3oool0
02<0oooo00<000000?ooo`3oool0W`3oool<00000380oooo00<000000?ooo`3oool02P3oool002<0
oooo00<000000?ooo`3oool0V@3oool<000003P0oooo00<000000?ooo`3oool02P3oool002<0oooo
00<000000?ooo`3oool0TP3oool=000003h0oooo00<000000?ooo`3oool02P3oool002<0oooo00<0
00000?ooo`3oool0S`3oool:000004<0oooo0P00000<0?ooo`002@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0R`3oool7000004/0oooo00<00000
0?ooo`3oool02P3oool000T0oooo1P00000D0?ooo`030000003oool0oooo08L0oooo2000001>0?oo
o`030000003oool0oooo00X0oooo00090?ooo`060000003oool0oooo0000003oool000003@3oool2
000000D0oooo00<000000?ooo`3oool0P`3oool800000580oooo00<000000?ooo`3oool02P3oool0
00T0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo07l0oooo2000001F0?ooo`030000003oool0oooo00X0oooo000:0?ooo`8000004P3oool0
0`000000oooo0?ooo`020?ooo`800000O@3oool7000005P0oooo0`00000<0?ooo`00703oool20000
00D0oooo00<000000?ooo`3oool0N03oool7000005h0oooo00<000000?ooo`3oool02P3oool001`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1e0?ooo`L00000H@3oool00`000000
oooo0?ooo`0:0?ooo`00303oool2000000h0oooo0`0000040?ooo`030000003oool0oooo0740oooo
1`00001U0?ooo`030000003oool0oooo00X0oooo000;0?ooo`040000003oool0oooo000001@0oooo
00<000000?ooo`3oool0K@3oool8000006L0oooo0P00000<0?ooo`002`3oool010000000oooo0?oo
o`00000D0?ooo`030000003oool0oooo06d0oooo1000001/0?ooo`030000003oool0oooo00X0oooo
000<0?ooo`8000005@3oool00`000000oooo0?ooo`1/0?ooo`800000K`3oool00`000000oooo0?oo
o`0:0?ooo`008`3oool00`000000oooo0?ooo`1[0?ooo`800000L03oool00`000000oooo0?ooo`0:
0?ooo`002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00X0oooo000;0?ooo`H0
00004P3oool00`000000oooo0?ooo`1Z0?ooo`800000L03oool2000000`0oooo000;0?ooo`060000
003oool0oooo0000003oool000004P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool02P3oool000/0oooo00@000000?ooo`3oool00000503oool00`00
0000oooo0?ooo`1Y0?ooo`800000LP3oool00`000000oooo0?ooo`0:0?ooo`00303oool2000001D0
oooo00<000000?ooo`3oool0J03oool2000007<0oooo00<000000?ooo`3oool02P3oool002<0oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1a0?ooo`800000303oool000/0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`1W0?ooo`800000M03oool00`000000oooo0?oo
o`0:0?ooo`002`3oool3000001D0oooo00<000000?ooo`3oool0IP3oool2000007D0oooo00<00000
0?ooo`3oool02P3oool000h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`00
00005@3oool00`000000oooo0?ooo`1U0?ooo`800000MP3oool00`000000oooo0?ooo`0:0?ooo`00
2`3oool4000001@0oooo00<000000?ooo`3oool0I03oool2000007H0oooo0P00000<0?ooo`003P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`1S0?ooo`800000N03oool0
0`000000oooo0?ooo`0:0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool02P3oool000T0oooo1P0000080?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0680oooo0P00001i0?oo
o`030000003oool0oooo00X0oooo000>0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0080oooo0P00001R0?ooo`800000N03oool30000
00`0oooo000G0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0:0?oo
o`005`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1P0?ooo`800000N`3oool00`000000oooo0?ooo`0:0?ooo`005P3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo05l0oooo0P00001l0?ooo`030000003oool0oooo00X0
oooo000=0?ooo`800000503oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo07X0oooo
0P00000<0?ooo`002`3oool010000000oooo00000000000D0?ooo`030000003oool0oooo05h0oooo
0P00001m0?ooo`030000003oool0oooo00X0oooo000;0?ooo`040000003oool00000000001@0oooo
00<000000?ooo`3oool0G@3oool2000007h0oooo00<000000?ooo`3oool02P3oool000/0oooo1000
000D0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?oo
o`0:0?ooo`003P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05`0oooo0P00001o
0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`1m0?ooo`800000303oool000X0oooo1000000E0?ooo`03
0000003oool0oooo05/0oooo0P0000200?ooo`030000003oool0oooo00X0oooo000;0?ooo`040000
003oool0oooo000001@0oooo00<000000?ooo`3oool0FP3oool200000840oooo00<000000?ooo`3o
ool02P3oool000/0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo0800oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`000000
5@3oool00`000000oooo0?ooo`1I0?ooo`800000P@3oool2000000`0oooo000S0?ooo`030000003o
ool0oooo05T0oooo0P0000220?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0
oooo05T0oooo0P0000220?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0oooo
05P0oooo0`0000220?ooo`030000003oool0oooo00X0oooo000;0?ooo`040000003oool0oooo0000
01@0oooo00<000000?ooo`3oool0F03oool2000008<0oooo00<000000?ooo`3oool02P3oool000T0
oooo00<000000?ooo`0000000`00000D0?ooo`030000003oool0oooo05P0oooo0P0000220?ooo`80
0000303oool000h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1H0?ooo`800000
P`3oool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`1G0?ooo`<00000P`3o
ool00`000000oooo0?ooo`0:0?ooo`005@3oool500000080oooo0P0000050?ooo`030000003oool0
oooo05L0oooo0P0000240?ooo`030000003oool0oooo00X0oooo000<0?ooo`8000002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G
0?ooo`800000Q03oool00`000000oooo0?ooo`0:0?ooo`002`3oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000005P0oooo0P000022
0?ooo`<00000303oool000/0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`02
0?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`<00000Q03oool00`000000oooo0?ooo`0:
0?ooo`00303oool2000000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo05H0oooo0P0000250?ooo`030000003oool0oooo00X0oooo000F0?ooo`80
0000103oool3000000@0oooo00<000000?ooo`3oool0EP3oool2000008D0oooo00<000000?ooo`3o
ool02P3oool000/0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`1E0?ooo`<0
0000Q03oool2000000`0oooo000;0?ooo`@00000503oool00`000000oooo0?ooo`1E0?ooo`800000
QP3oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo05D0oooo0P0000260?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0E@3oool2000008H0oooo00<000000?ooo`3oool02P3oool0
00`0oooo0`00000D0?ooo`030000003oool0oooo05@0oooo0`0000260?ooo`030000003oool0oooo
00X0oooo000>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0E03oool2000008H0
oooo0P00000<0?ooo`008`3oool00`000000oooo0?ooo`1D0?ooo`800000Q`3oool00`000000oooo
0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`1D0?ooo`800000Q`3oool00`000000oooo0?oo
o`0:0?ooo`008`3oool00`000000oooo0?ooo`1C0?ooo`<00000Q`3oool00`000000oooo0?ooo`0:
0?ooo`008`3oool00`000000oooo0?ooo`1C0?ooo`800000R03oool00`000000oooo0?ooo`0:0?oo
o`008`3oool00`000000oooo0?ooo`1C0?ooo`800000Q`3oool2000000`0oooo000S0?ooo`030000
003oool0oooo05<0oooo0P0000280?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003o
ool0oooo0580oooo0`0000280?ooo`030000003oool0oooo00X0oooo000:0?ooo`@000005@3oool0
0`000000oooo0?ooo`1B0?ooo`800000R@3oool00`000000oooo0?ooo`0:0?ooo`002@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0DP3oool20000
08P0oooo0P00000<0?ooo`002@3oool01P000000oooo0?ooo`000000oooo000001@0oooo00<00000
0?ooo`3oool0DP3oool2000008T0oooo00<000000?ooo`3oool02P3oool000T0oooo00<000000?oo
o`3oool00P00000E0?ooo`030000003oool0oooo0540oooo0`0000290?ooo`030000003oool0oooo
00X0oooo000<0?ooo`030000003oool0oooo00H0oooo100000030?ooo`8000001@3oool00`000000
oooo0?ooo`1A0?ooo`800000RP3oool00`000000oooo0?ooo`0:0?ooo`005@3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0D@3oool2000008X0
oooo00<000000?ooo`3oool02P3oool000/0oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P00001B0?ooo`800000R03oool30000
00`0oooo000;0?ooo`@00000203oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1@0?ooo`<00000RP3oool00`000000oooo0?ooo`0:0?oo
o`002`3oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1@0?ooo`800000R`3oool00`000000oooo0?oo
o`0:0?ooo`002`3oool010000000oooo0?ooo`0000070?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0D03oool2000008/0oooo00<000000?ooo`3oool02P3oool002<0oooo00<00000
0?ooo`3oool0C`3oool3000008X0oooo0P00000<0?ooo`008`3oool00`000000oooo0?ooo`1?0?oo
o`800000S03oool00`000000oooo0?ooo`0:0?ooo`00303oool2000001D0oooo00<000000?ooo`3o
ool0C`3oool2000008`0oooo00<000000?ooo`3oool02P3oool000/0oooo00@000000?ooo`3oool0
0000503oool00`000000oooo0?ooo`1?0?ooo`800000S03oool00`000000oooo0?ooo`0:0?ooo`00
2`3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo04h0oooo0`00002<0?ooo`03
0000003oool0oooo00X0oooo000<0?ooo`8000005@3oool00`000000oooo0?ooo`1>0?ooo`800000
S03oool2000000`0oooo000S0?ooo`030000003oool0oooo04h0oooo0P00002=0?ooo`030000003o
ool0oooo00X0oooo000;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0CP3oool2
000008d0oooo00<000000?ooo`3oool02P3oool000/0oooo0`00000E0?ooo`030000003oool0oooo
04d0oooo0`00002=0?ooo`030000003oool0oooo00X0oooo000;0?ooo`040000003oool0oooo0000
01@0oooo00<000000?ooo`3oool0C@3oool2000008h0oooo00<000000?ooo`3oool02P3oool000`0
oooo0P00000E0?ooo`030000003oool0oooo04d0oooo0P00002=0?ooo`800000303oool000/0oooo
00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`1=0?ooo`800000SP3oool00`000000
oooo0?ooo`0:0?ooo`002`3oool3000001D0oooo00<000000?ooo`3oool0C03oool3000008h0oooo
00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1<0?ooo`800000S`3oool00`000000oooo0?ooo`0:0?ooo`002P3oool4000001D0oooo00<00000
0?ooo`3oool0C03oool2000008h0oooo0P00000<0?ooo`002`3oool010000000oooo0?ooo`00000D
0?ooo`030000003oool0oooo04`0oooo0P00002?0?ooo`030000003oool0oooo00X0oooo000;0?oo
o`040000003oool0oooo000001@0oooo00<000000?ooo`3oool0B`3oool3000008l0oooo00<00000
0?ooo`3oool02P3oool000/0oooo00<000000?ooo`0000001`3oool4000000<0oooo0P0000050?oo
o`030000003oool0oooo04/0oooo0P00002@0?ooo`030000003oool0oooo00X0oooo000E0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1;0?oo
o`800000T03oool00`000000oooo0?ooo`0:0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`80
0000C03oool2000008h0oooo0`00000<0?ooo`002@3oool6000000P0oooo00<000000?ooo`3oool0
0P3oool2000000D0oooo00<000000?ooo`3oool0BP3oool300000900oooo00<000000?ooo`3oool0
2P3oool000/0oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0BP3oool200000940oooo00<000000?ooo`3o
ool02P3oool000/0oooo00<000000?ooo`3oool0203oool2000000@0oooo0`0000040?ooo`030000
003oool0oooo04X0oooo0P00002A0?ooo`030000003oool0oooo00X0oooo000<0?ooo`<00000503o
ool00`000000oooo0?ooo`190?ooo`<00000T@3oool00`000000oooo0?ooo`0:0?ooo`003P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04T0oooo0P00002A0?ooo`800000303oool0
02<0oooo00<000000?ooo`3oool0B@3oool200000980oooo00<000000?ooo`3oool02P3oool002<0
oooo00<000000?ooo`3oool0B@3oool200000980oooo00<000000?ooo`3oool02P3oool002<0oooo
00<000000?ooo`3oool0B03oool300000980oooo00<000000?ooo`3oool02P3oool002<0oooo00<0
00000?ooo`3oool0B03oool200000980oooo0P00000<0?ooo`008`3oool00`000000oooo0?ooo`18
0?ooo`800000T`3oool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`180?oo
o`800000T`3oool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`170?ooo`<0
0000T`3oool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`170?ooo`800000
U03oool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`170?ooo`800000T`3o
ool2000000`0oooo000S0?ooo`030000003oool0oooo04L0oooo0P00002D0?ooo`030000003oool0
oooo00X0oooo000S0?ooo`030000003oool0oooo03D0oooo5000002D0?ooo`030000003oool0oooo
00X0oooo000S0?ooo`030000003oool0oooo0280oooo9@00002F0?ooo`030000003oool0oooo00X0
oooo000S0?ooo`030000003oool0oooo00h0oooo9`00002W0?ooo`800000303oool002<0oooo00<0
00000?ooo`3oool03P3ooolD00000;/0oooo00<000000?ooo`3oool02P3oool002<0oooo00<00000
0?ooo`3oool0g@3oool00`000000oooo0?ooo`0:0?ooo`005P3oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo0=d0oooo00<000000?ooo`3oool02P3oool001D0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo000G0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooon400000303oool0
01P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`3_0?ooo`005@3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?40oooo000F0?ooo`800000103oool2
00000?80oooo003o0?oooa40oooo0000\
\>"],
  ImageRangeCache->{{{0, 271.625}, {167.438, 0}} -> {-1.87797, -5.27508, \
0.0535203, 0.216495}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0.0561849 0.561849 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .05618 -6 -4.5 ]
[-0.0125 .05618 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .28092 -18 -4.5 ]
[-0.0125 .28092 0 4.5 ]
[-0.0125 .39329 -18 -4.5 ]
[-0.0125 .39329 0 4.5 ]
[-0.0125 .50566 -18 -4.5 ]
[-0.0125 .50566 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -50 ]
[-0.01875 .30902 -18 50 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05618 m
.00625 .05618 L
s
[(0)] -0.0125 .05618 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.2)] -0.0125 .16855 1 0 Mshowa
0 .28092 m
.00625 .28092 L
s
[(0.4)] -0.0125 .28092 1 0 Mshowa
0 .39329 m
.00625 .39329 L
s
[(0.6)] -0.0125 .39329 1 0 Mshowa
0 .50566 m
.00625 .50566 L
s
[(0.8)] -0.0125 .50566 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .47757 m
.00375 .47757 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
0 .58994 m
.00375 .58994 L
s
0 .02809 m
.00375 .02809 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
111 10.2813 translate
90 rotate
-111 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Working) show
111.000 12.813 moveto
(Children) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05618 m
1 .05618 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .28092 m
1 .28092 L
s
.99375 .39329 m
1 .39329 L
s
.99375 .50566 m
1 .50566 L
s
.125 Mabswid
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.99625 .58994 m
1 .58994 L
s
.99625 .02809 m
1 .02809 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61475 L
.25 .61245 L
.33333 .61083 L
.41667 .55222 L
.5 .47781 L
.58333 .05618 L
.66667 .05618 L
.75 .05618 L
.83333 .05618 L
.91667 .05618 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{272.625, 168.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004@0000Z2000`400?l00000o`00003oo`3ooolA
0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00R`3oool3
000000@0oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool3000006l0oooo
002<0?ooo`030000003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000001b0?ooo`00S03oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`@00000K`3oool008`0oooo00<000000?ooo`3oool0
0`3oool200000080oooo0`0000000`3oool000000?ooo`020?ooo`800000L03oool008X0oooo00D0
00000?ooo`000000oooo000000210?ooo`00RP3oool5000000@0oooo00<000000?ooo`3oool0NP3o
ool00?l0oooo4@3oool00?l0oooo4@3oool00?l0oooo4@3oool004T0oooo1000000S0?ooo`<00000
8@3oool3000002<0oooo0P00000O0?ooo`D000000P3oool2000001d0oooo1@0000000`3oool00000
00000002000000D0oooo00190?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0803o
ool010000000oooo0?ooo`00000Q0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`00BP3oool00`000000oooo0?ooo`0Q0?ooo`D000008@3oool010000000oooo0?ooo`00000Q
0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`00B`3o
ool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo00000280oooo0`00000S0?ooo`800000
8@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00190?ooo`040000003oool0oooo00000280
oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo0000
0200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo001:0?ooo`800000903oool2
000002<0oooo0`00000R0?ooo`800000803oool2000000@0oooo0P00000N0?ooo`800000103oool2
000000H0oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo000V
0?ooon4000002@3oool002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`009P3o
ool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0
oooo0=d0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`00
0000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`3L0?ooo`8000002@3oool002H0oooo
00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?oo
o`3M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<00000
0?ooo`3oool01`3oool001l0oooo0P0000050?ooo`030000003oool0oooo0=d0oooo00<000000?oo
o`3oool01`3oool001h0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3M0?oo
o`030000003oool0oooo00L0oooo000N0?ooo`040000003oool0oooo000000@0oooo0P00001o0?oo
odd00000403oool3000000T0oooo000N0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0OP3ooom=00000180oooo00<000000?ooo`3oool01`3oool001h0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1n0?ooo`800000G@3oool00`000000oooo0?ooo`070?oo
o`007`3oool2000000D0oooo00<000000?ooo`3oool0OP3oool2000005d0oooo00<000000?ooo`3o
ool01`3oool002H0oooo00<000000?ooo`3oool0OP3oool2000005d0oooo00<000000?ooo`3oool0
1`3oool002H0oooo00<000000?ooo`3oool0OP3oool2000005d0oooo00<000000?ooo`3oool01`3o
ool002H0oooo00<000000?ooo`3oool0O@3oool2000005d0oooo0P0000090?ooo`009P3oool00`00
0000oooo0?ooo`1m0?ooo`800000GP3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000
oooo0?ooo`1m0?ooo`800000GP3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo
0?ooo`1m0?ooo`800000GP3oool00`000000oooo0?ooo`070?ooo`001P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo07d0oooo0P00001N0?ooo`030000003oool0oooo00L0oooo0006
0?ooo`D000006`3oool00`000000oooo0?ooo`1l0?ooo`800000G`3oool00`000000oooo0?ooo`07
0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0O03oool2000005l0oooo00<000000?ooo`3oool01`3oool000P0oooo0`00000K0?ooo`03
0000003oool0oooo07`0oooo0P00001N0?ooo`8000002@3oool000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo07`0oooo0P00001O0?ooo`030000
003oool0oooo00L0oooo00060?ooo`D000006`3oool00`000000oooo0?ooo`1l0?ooo`800000G`3o
ool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`1k0?ooo`800000H03oool0
0`000000oooo0?ooo`070?ooo`002@3oool2000001/0oooo00<000000?ooo`3oool0N`3oool20000
0600oooo00<000000?ooo`3oool01`3oool000P0oooo00@000000?ooo`3oool000006P3oool00`00
0000oooo0?ooo`1k0?ooo`800000H03oool00`000000oooo0?ooo`070?ooo`00203oool010000000
oooo0?ooo`00000J0?ooo`030000003oool0oooo07/0oooo0P00001O0?ooo`8000002@3oool000T0
oooo0P00000K0?ooo`030000003oool0oooo07/0oooo0P00001P0?ooo`030000003oool0oooo00L0
oooo000V0?ooo`030000003oool0oooo07/0oooo0P00001P0?ooo`030000003oool0oooo00L0oooo
000V0?ooo`030000003oool0oooo07X0oooo0P00001Q0?ooo`030000003oool0oooo00L0oooo0008
0?ooo`040000003oool0oooo000000L0oooo0P0000040?ooo`8000000`3oool4000000@0oooo00<0
00000?ooo`3oool0NP3oool200000640oooo00<000000?ooo`3oool01`3oool000P0oooo10000006
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1j0?ooo`800000H@3oool00`000000oooo0?ooo`070?ooo`00203oool010000000oooo0?ooo`00
00060?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool2000007/0oooo
0P00001O0?ooo`<000002@3oool000P0oooo00@000000?ooo`3oool000001P3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0NP3oool200000640
oooo00<000000?ooo`3oool01`3oool00180oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo07T0oooo0P00001R0?ooo`030000003oool0oooo
00L0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool2000000X0
oooo0P0000050?ooo`030000003oool0oooo07T0oooo0P00001R0?ooo`030000003oool0oooo00L0
oooo00060?ooo`H000006P3oool00`000000oooo0?ooo`1i0?ooo`800000HP3oool00`000000oooo
0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo07T0oooo0P00
001R0?ooo`030000003oool0oooo00L0oooo00080?ooo`@000006P3oool00`000000oooo0?ooo`1i
0?ooo`800000HP3oool00`000000oooo0?ooo`070?ooo`00203oool010000000oooo0?ooo`00000J
0?ooo`030000003oool0oooo07P0oooo0P00001R0?ooo`8000002@3oool002H0oooo00<000000?oo
o`3oool0N03oool2000006<0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3o
ool0N03oool2000006<0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0
N03oool2000006<0oooo00<000000?ooo`3oool01`3oool000P0oooo00@000000?ooo`3oool00000
6P3oool00`000000oooo0?ooo`1h0?ooo`800000H`3oool00`000000oooo0?ooo`070?ooo`001P3o
ool00`000000oooo00000003000001X0oooo00<000000?ooo`3oool0M`3oool2000006@0oooo00<0
00000?ooo`3oool01`3oool000/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1g
0?ooo`800000H`3oool2000000T0oooo000V0?ooo`030000003oool0oooo07L0oooo0P00001T0?oo
o`030000003oool0oooo00L0oooo00080?ooo`040000003oool0oooo000001X0oooo00<000000?oo
o`3oool0M`3oool2000006@0oooo00<000000?ooo`3oool01`3oool000P0oooo1000000J0?ooo`03
0000003oool0oooo07L0oooo0P00001T0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0M`3oool2000006@0oooo00<000000?ooo`3oool0
1`3oool000P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1f0?ooo`800000I@3o
ool00`000000oooo0?ooo`070?ooo`002@3oool3000001X0oooo00<000000?ooo`3oool0MP3oool2
000006@0oooo0P0000090?ooo`002`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
07H0oooo0P00001U0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo07H0
oooo0P00001U0?ooo`030000003oool0oooo00L0oooo00090?ooo`8000000P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo07H0oooo0P00001U0?ooo`030000003oool0oooo00L0oooo
00080?ooo`060000003oool0oooo0000003oool000001@3oool2000000@0oooo0P0000050?ooo`<0
00000`3oool00`000000oooo0?ooo`1e0?ooo`800000IP3oool00`000000oooo0?ooo`070?ooo`00
203oool01P000000oooo0?ooo`000000oooo000000@0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07D0oooo0P00001V0?ooo`030000003oool0
oooo00L0oooo00080?ooo`D000001@3oool010000000oooo0?ooo`0000080?ooo`D000000`3oool2
000007H0oooo0P00001T0?ooo`<000002@3oool000P0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0M@3o
ool2000006H0oooo00<000000?ooo`3oool01`3oool00180oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo000000040?ooo`030000003oool0oooo07D0oooo0P00001V0?ooo`030000003o
ool0oooo00L0oooo000C0?ooo`8000002`3oool2000000@0oooo00<000000?ooo`3oool0M03oool2
000006L0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0M03oool20000
06L0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0M03oool2000006L0
oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0M03oool2000006L0oooo
00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0M03oool2000006H0oooo0P00
00090?ooo`009P3oool00`000000oooo0?ooo`1d0?ooo`800000I`3oool00`000000oooo0?ooo`07
0?ooo`001`3oool4000001/0oooo00<000000?ooo`3oool0L`3oool2000006P0oooo00<000000?oo
o`3oool01`3oool000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo07<0oooo0P00001X0?ooo`030000003oool0oooo00L0oooo00060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1c0?ooo`800000
J03oool00`000000oooo0?ooo`070?ooo`001P3oool2000000<0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`1c0?ooo`800000J03oool00`000000oooo0?ooo`070?ooo`009P3oool0
0`000000oooo0?ooo`1c0?ooo`800000I`3oool2000000T0oooo00060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1b0?ooo`800000J@3oool00`00
0000oooo0?ooo`070?ooo`001P3oool6000001X0oooo00<000000?ooo`3oool0LP3oool2000006T0
oooo00<000000?ooo`3oool01`3oool000P0oooo00@000000?ooo`3oool000006P3oool00`000000
oooo0?ooo`1b0?ooo`800000J@3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0780oooo0P00001Y0?ooo`030000003oool0oooo00L0oooo
00090?ooo`<000006P3oool00`000000oooo0?ooo`1b0?ooo`800000J@3oool00`000000oooo0?oo
o`070?ooo`002`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0740oooo0P00001Y
0?ooo`8000002@3oool002H0oooo00<000000?ooo`3oool0L@3oool2000006X0oooo00<000000?oo
o`3oool01`3oool002H0oooo00<000000?ooo`3oool0L@3oool2000006X0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1a0?ooo`80
0000JP3oool00`000000oooo0?ooo`070?ooo`001P3oool00`000000oooo00000003000001X0oooo
00<000000?ooo`3oool0L@3oool2000006X0oooo00<000000?ooo`3oool01`3oool000/0oooo00<0
00000?ooo`3oool01@3oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?oo
o`1`0?ooo`800000J`3oool00`000000oooo0?ooo`070?ooo`004P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0L03oool2000006/0oooo
00<000000?ooo`3oool01`3oool00180oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000040?ooo`800000L@3oool2000006T0oooo0`0000090?ooo`001P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000203oool3000000D0
oooo00<000000?ooo`3oool0L03oool2000006/0oooo00<000000?ooo`3oool01`3oool000H0oooo
1P0000060?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1`0?ooo`800000J`3oool00`000000oooo0?ooo`070?ooo`002`3oool00`000000oooo
0?ooo`050?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0L03oool2000006/0oooo
00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0K`3oool2000006`0oooo00<0
00000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0K`3oool2000006`0oooo00<00000
0?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0K`3oool2000006/0oooo0P0000090?oo
o`002@3oool2000001/0oooo00<000000?ooo`3oool0K`3oool2000006`0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1_0?ooo`80
0000K03oool00`000000oooo0?ooo`070?ooo`001P3oool00`000000oooo000000020?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0KP3oool2000006d0oooo00<000000?ooo`3oool0
1`3oool000H0oooo1P00000J0?ooo`030000003oool0oooo06h0oooo0P00001]0?ooo`030000003o
ool0oooo00L0oooo000;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0KP3oool2
000006d0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0KP3oool20000
06`0oooo0P0000090?ooo`00203oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo
06h0oooo0P00001]0?ooo`030000003oool0oooo00L0oooo00080?ooo`@000006P3oool00`000000
oooo0?ooo`1]0?ooo`800000KP3oool00`000000oooo0?ooo`070?ooo`00203oool010000000oooo
0?ooo`00000J0?ooo`030000003oool0oooo06d0oooo0P00001^0?ooo`030000003oool0oooo00L0
oooo00080?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0K@3oool2000006h0
oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0K@3oool2000006h0oooo
00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0K@3oool2000006h0oooo00<0
00000?ooo`3oool01`3oool000T0oooo0P00000K0?ooo`030000003oool0oooo06`0oooo0P00001^
0?ooo`8000002@3oool000P0oooo0P0000000`3oool000000?ooo`0I0?ooo`030000003oool0oooo
06/0oooo0`00001_0?ooo`030000003oool0oooo00L0oooo00080?ooo`80000000<0oooo0000003o
ool06@3oool00`000000oooo0?ooo`1Y0?ooo`@00000L03oool00`000000oooo0?ooo`070?ooo`00
2@3oool00`000000oooo0000000J0?ooo`030000003oool0oooo06P0oooo1000001a0?ooo`030000
003oool0oooo00L0oooo000C0?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo06L0oooo0`00001c0?ooo`030000003oool0oooo00L0oooo00080?ooo`040000003oool0
oooo000000H0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo06H0oooo0`00001d0?ooo`030000003oool0oooo00L0oooo00080?ooo`@00000
1P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P00001V0?oo
o`<00000L`3oool3000000T0oooo00080?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool000002@3oool2000000D0oooo00<000000?ooo`3oool0H`3oool4000007H0oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0HP3oool4000007L0oooo00<00000
0?ooo`3oool01`3oool000T0oooo0`0000070?ooo`8000002P3oool2000000D0oooo00<000000?oo
o`3oool0H@3oool3000007T0oooo00<000000?ooo`3oool01`3oool000/0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`1P0?ooo`<00000NP3oool00`000000oooo0?ooo`070?ooo`00
9P3oool00`000000oooo0?ooo`1O0?ooo`<00000N`3oool00`000000oooo0?ooo`070?ooo`009P3o
ool00`000000oooo0?ooo`1N0?ooo`<00000N`3oool2000000T0oooo000V0?ooo`030000003oool0
oooo05`0oooo1000001m0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo
05/0oooo1000001n0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo05X0
oooo0`0000200?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo05T0oooo
0`0000210?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo05L0oooo1000
00220?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo05H0oooo10000022
0?ooo`8000002@3oool002H0oooo00<000000?ooo`3oool0E03oool4000008D0oooo00<000000?oo
o`3oool01`3oool002H0oooo00<000000?ooo`3oool0D`3oool4000008H0oooo00<000000?ooo`3o
ool01`3oool002H0oooo00<000000?ooo`3oool0D@3oool4000008P0oooo00<000000?ooo`3oool0
1`3oool002H0oooo00<000000?ooo`3oool0D03oool4000008T0oooo00<000000?ooo`3oool01`3o
ool002H0oooo00<000000?ooo`3oool0CP3oool4000008/0oooo00<000000?ooo`3oool01`3oool0
02H0oooo00<000000?ooo`3oool0C@3oool4000008`0oooo00<000000?ooo`3oool01`3oool002H0
oooo00<000000?ooo`3oool0B`3oool4000008d0oooo0P0000090?ooo`009P3oool00`000000oooo
0?ooo`1:0?ooo`@00000S`3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?oo
o`180?ooo`@00000T@3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`17
0?ooo`@00000TP3oool00`000000oooo0?ooo`070?ooo`007P3oool5000000<0oooo00<000000?oo
o`3oool0=@3ooolD000009@0oooo00<000000?ooo`3oool01`3oool00200oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo>@0000090?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo000P0?ooo`030000003oool0oooo00<0ooooh@0000090?ooo`00803o
ool00`000000oooo0?ooo`0D0?ooo`800000e`3oool00200oooo00<000000?ooo`3oool0k@3oool0
01l0oooo0P00003_0?ooo`00o`3ooolA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 271.625}, {167.438, 0}} -> {-2.03853, -0.293419, \
0.0535203, 0.00793812}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot4 = 
        Plot[alfafun[time], {time, 1, 11}, 
          PlotRange \[Rule] {{0, 12}, {0.2, 0.8}}, 
          PlotStyle \[Rule] Thickness[0.01], AxesOrigin \[Rule] {0, 0}, 
          Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time\>", "\<Alpha\>"}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.206011 1.03006 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -17 ]
[-0.01875 .30902 -18 17 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.3)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.4)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.6)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.7)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.8)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -102.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
78 10.2813 translate
90 rotate
-78 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Alpha) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .13391 m
.11714 .13391 L
.13473 .13391 L
.14405 .13391 L
.15401 .13391 L
.15883 .13391 L
.1612 .13391 L
.16339 .13391 L
.16538 .13391 L
.16638 .13391 L
.16749 .13442 L
.17193 .13716 L
.18863 .14748 L
.22388 .16927 L
.25781 .19024 L
.29388 .21253 L
.32863 .234 L
.36205 .25466 L
.39761 .27664 L
.43185 .2978 L
.46823 .32029 L
.50329 .34195 L
.53702 .3628 L
.5729 .38497 L
.60745 .40633 L
.64068 .42686 L
.65918 .4383 L
.67605 .44872 L
.68442 .4539 L
.69353 .45953 L
.6977 .46211 L
.69872 .46273 L
.69981 .46341 L
.70043 .46353 L
.70101 .46353 L
.70213 .46353 L
.71009 .46353 L
.74476 .46353 L
.77811 .46353 L
.8136 .46353 L
.84777 .46353 L
.88408 .46353 L
.91667 .46353 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00T`3oool3000000@0oooo0`00
00001`3oool000000000003oool000000?ooo`0000000P3oool3000007L0oooo002D0?ooo`030000
003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
001j0?ooo`00U03oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`@00000M`3oool009@0oooo00<000000?ooo`3oool00`3oool200000080
oooo0`0000000`3oool000000?ooo`020?ooo`800000N03oool00980oooo00D000000?ooo`000000
oooo000000290?ooo`00TP3oool5000000@0oooo00<000000?ooo`3oool0PP3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool004`0oooo1000000V0?ooo`<000008`3oool3000002D0
oooo0P00000R0?ooo`D000000P3oool2000001l0oooo1@0000000`3oool0000000000002000000H0
oooo001<0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool08P3oool010000000oooo
0?ooo`00000S0?ooo`040000003oool0oooo000002<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000090?ooo`00C@3oool0
0`000000oooo0?ooo`0T0?ooo`D000008`3oool010000000oooo0?ooo`00000S0?ooo`040000003o
ool0oooo000002<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`00CP3oool00`000000oooo
0?ooo`0S0?ooo`040000003oool0oooo000002@0oooo0`00000U0?ooo`800000903oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo001<0?ooo`040000003oool0oooo000002D0oooo00<000000?oo
o`0000009@3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000002<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00@0oooo001=0?ooo`8000009`3oool2000002D0oooo0`00
000T0?ooo`8000008`3oool2000000@0oooo0P00000P0?ooo`800000103oool2000000L0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000V
0?oooo0000002P3oool002H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0203oool002H0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`009P3o
ool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000V0?ooo`800000k03oool2
000000X0oooo000V0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0203oool002H0
oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo
0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo0>`0oooo00<0
00000?ooo`3oool0203oool002H0oooo0P00003/0?ooo`8000002P3oool002H0oooo00<000000?oo
o`3oool0k03oool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`3/0?ooo`03
0000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0
203oool002H0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`009P3oool2
00000>`0oooo0P00000:0?ooo`009P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo
00P0oooo000V0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0203oool002H0oooo
00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?oo
o`3/0?ooo`030000003oool0oooo00P0oooo000V0?ooo`800000k03oool2000000X0oooo000V0?oo
o`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3o
ool0k03oool00`000000oooo0?ooo`080?ooo`004`3oool2000000@0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000B0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3/0?ooo`03
0000003oool0oooo00P0oooo000B0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool200000>`0oooo0P00000:0?ooo`004P3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`00
4P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0k03oool00`000000oooo0?ooo`080?ooo`004`3oool2000000X0oooo0P0000050?ooo`03
0000003oool0oooo0>`0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0
k03oool00`000000oooo0?ooo`080?ooo`009P3oool200000>`0oooo0P00000:0?ooo`009P3oool0
0`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo
0100oooo5`0000350?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo0100
oooo6@0000330?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo02H0oooo
1@0000310?ooo`030000003oool0oooo00P0oooo000V0?ooo`800000:@3oool400000;l0oooo0P00
000:0?ooo`009P3oool00`000000oooo0?ooo`0Z0?ooo`@00000_P3oool00`000000oooo0?ooo`08
0?ooo`009P3oool00`000000oooo0?ooo`0[0?ooo`@00000_@3oool00`000000oooo0?ooo`080?oo
o`009P3oool00`000000oooo0?ooo`0]0?ooo`<00000_03oool00`000000oooo0?ooo`080?ooo`00
9P3oool00`000000oooo0?ooo`0^0?ooo`@00000^P3oool00`000000oooo0?ooo`080?ooo`009P3o
ool200000300oooo1000002h0?ooo`8000002P3oool002H0oooo00<000000?ooo`3oool0<@3oool4
00000;L0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0<P3oool50000
0;D0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0=03oool400000;@0
oooo00<000000?ooo`3oool0203oool002H0oooo0P00000g0?ooo`@00000/@3oool2000000X0oooo
000V0?ooo`030000003oool0oooo03L0oooo1@00002`0?ooo`030000003oool0oooo00P0oooo000V
0?ooo`030000003oool0oooo03T0oooo1@00002^0?ooo`030000003oool0oooo00P0oooo000C0?oo
o`800000103oool2000000D0oooo0`0000030?ooo`030000003oool0oooo03/0oooo1000002]0?oo
o`030000003oool0oooo00P0oooo000B0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`@00000Z`3oool00`000000oooo0?ooo`080?oo
o`004P3oool010000000oooo0?ooo`0000080?ooo`D000000`3oool2000003l0oooo1000002Y0?oo
o`8000002P3oool00180oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0400oooo1000002X0?ooo`030000003oool0oooo00P0oooo000B0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`11
0?ooo`D00000YP3oool00`000000oooo0?ooo`080?ooo`004`3oool2000000/0oooo0P0000040?oo
o`030000003oool0oooo04<0oooo1@00002T0?ooo`030000003oool0oooo00P0oooo000V0?ooo`03
0000003oool0oooo04D0oooo1000002S0?ooo`030000003oool0oooo00P0oooo000V0?ooo`800000
B03oool400000:00oooo0P00000:0?ooo`009P3oool00`000000oooo0?ooo`180?ooo`D00000W`3o
ool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`1:0?ooo`D00000W@3oool0
0`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`1<0?ooo`@00000W03oool00`00
0000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`1>0?ooo`@00000VP3oool00`000000
oooo0?ooo`080?ooo`009P3oool200000500oooo1000002H0?ooo`8000002P3oool002H0oooo00<0
00000?ooo`3oool0D@3oool4000009L0oooo00<000000?ooo`3oool0203oool000X0oooo0P00000J
0?ooo`030000003oool0oooo0580oooo1@00002E0?ooo`030000003oool0oooo00P0oooo00060?oo
o`060000003oool000000000003oool000006P3oool00`000000oooo0?ooo`1D0?ooo`@00000U03o
ool00`000000oooo0?ooo`080?ooo`001P3oool2000000030?ooo`000000oooo01/0oooo00<00000
0?ooo`3oool0EP3oool400000980oooo00<000000?ooo`3oool0203oool000P0oooo0P0000000`3o
ool000000?ooo`0I0?ooo`800000F03oool400000900oooo0P00000:0?ooo`002P3oool2000001X0
oooo00<000000?ooo`3oool0F@3oool4000008l0oooo00<000000?ooo`3oool0203oool002H0oooo
00<000000?ooo`3oool0FP3oool5000008d0oooo00<000000?ooo`3oool0203oool000H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05`0oooo1000
002<0?ooo`030000003oool0oooo00P0oooo00060?ooo`H000006P3oool00`000000oooo0?ooo`1N
0?ooo`@00000RP3oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`0H0?oo
o`800000H03oool4000008P0oooo0P00000:0?ooo`009P3oool00`000000oooo0?ooo`1Q0?ooo`@0
0000Q`3oool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`1R0?ooo`@00000
QP3oool00`000000oooo0?ooo`080?ooo`00203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0I03o
ool4000008@0oooo00<000000?ooo`3oool0203oool000P0oooo1P0000040?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1U0?ooo`@00000
P`3oool00`000000oooo0?ooo`080?ooo`00203oool01P000000oooo0?ooo`000000oooo000000@0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`800000J03oool40000
0800oooo0P00000:0?ooo`00203oool010000000oooo0?ooo`0000060?ooo`040000003oool0oooo
000000T0oooo0P0000050?ooo`030000003oool0oooo06P0oooo100000200?ooo`030000003oool0
oooo00P0oooo00090?ooo`8000001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0JP3oool4000007h0oooo00<000000?ooo`3oool0203oool0
01<0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`1[0?ooo`D00000O03oool00`00
0000oooo0?ooo`080?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0K@3oool4000007/0oooo00<000000?ooo`3oool0203oool000H0oooo
1P00000J0?ooo`800000L03oool4000007P0oooo0P00000:0?ooo`00203oool010000000oooo0?oo
o`00000J0?ooo`030000003oool0oooo0700oooo1000001h0?ooo`030000003oool0oooo00P0oooo
00080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0LP3oool4000007H0oooo00<0
00000?ooo`3oool0203oool000T0oooo0`00000J0?ooo`030000003oool0oooo07<0oooo1@00001d
0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0M@3oool4000007<0oooo00<000000?ooo`3oool0203oool002H0oooo0P00001h0?ooo`@0
0000L03oool2000000X0oooo000:0?ooo`8000006P3oool00`000000oooo0?ooo`1h0?ooo`@00000
L03oool00`000000oooo0?ooo`080?ooo`00203oool010000000oooo00000000000J0?ooo`030000
003oool0oooo07X0oooo1000001^0?ooo`030000003oool0oooo00P0oooo00080?ooo`040000003o
ool00000000001X0oooo00<000000?ooo`3oool0N`3oool5000006`0oooo00<000000?ooo`3oool0
203oool000P0oooo1000000J0?ooo`030000003oool0oooo07d0oooo1@00001Z0?ooo`030000003o
ool0oooo00P0oooo000;0?ooo`030000003oool0oooo01P0oooo0P0000200?ooo`@00000J03oool2
000000X0oooo000V0?ooo`030000003oool0oooo0840oooo1000001W0?ooo`030000003oool0oooo
00P0oooo000V0?ooo`030000003oool0oooo0880oooo1@00001U0?ooo`030000003oool0oooo00P0
oooo000V0?ooo`030000003oool0oooo08@0oooo1@00001S0?ooo`030000003oool0oooo00P0oooo
000V0?ooo`030000003oool0oooo08H0oooo1000001R0?ooo`030000003oool0oooo00P0oooo000V
0?ooo`800000R@3oool4000005l0oooo0P00000:0?ooo`009P3oool00`000000oooo0?ooo`290?oo
o`@00000G`3oool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`2;0?ooo`@0
0000G@3oool00`000000oooo0?ooo`080?ooo`004`3oool2000000@0oooo0P0000030?ooo`<00000
1@3oool00`000000oooo0?ooo`2<0?ooo`D00000F`3oool00`000000oooo0?ooo`080?ooo`004P3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0SP3oool4000005X0oooo00<000000?ooo`3oool0203oool00180oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`800000T@3oool4000005L0oooo0P00000:0?oo
o`004P3oool010000000oooo0?ooo`0000080?ooo`<000001@3oool00`000000oooo0?ooo`2A0?oo
o`@00000E`3oool00`000000oooo0?ooo`080?ooo`004P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0T`3oool4000005D0oooo00<000000?oo
o`3oool0203oool001<0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`2D0?ooo`D0
0000D`3oool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`2F0?ooo`@00000
DP3oool00`000000oooo0?ooo`080?ooo`009P3oool2000009T0oooo1000001?0?ooo`8000002P3o
ool002H0oooo00<000000?ooo`3oool0V@3oool5000004h0oooo00<000000?ooo`3oool0203oool0
02H0oooo00<000000?ooo`3oool0V`3oool5000004`0oooo00<000000?ooo`3oool0203oool002H0
oooo00<000000?ooo`3oool0W@3oool4000004/0oooo00<000000?ooo`3oool0203oool002H0oooo
00<000000?ooo`3oool0W`3oool3000004X0oooo00<000000?ooo`3oool0203oool002H0oooo0P00
002Q0?ooo`@00000A`3oool2000000X0oooo000V0?ooo`030000003oool0oooo0:40oooo10000017
0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo0:<0oooo=P00000C0?oo
o`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo0:@0oooo=@00000C0?ooo`03
0000003oool0oooo00P0oooo000V0?ooo`800000k03oool2000000X0oooo000V0?ooo`030000003o
ool0oooo0>`0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0k03oool0
0`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo
00P0oooo000V0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0203oool002H0oooo
0P00003/0?ooo`8000002P3oool002H0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?oo
o`080?ooo`009P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000C0?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3/0?oo
o`030000003oool0oooo00P0oooo000B0?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000B0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool200000>`0oooo0P00000:0?oo
o`004P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0k03oool00`000000oooo0?ooo`080?ooo`004P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`08
0?ooo`004`3oool2000000T0oooo100000040?ooo`030000003oool0oooo0>`0oooo00<000000?oo
o`3oool0203oool002H0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`00
9P3oool200000>`0oooo0P00000:0?ooo`009P3oool00`000000oooo0?ooo`3/0?ooo`030000003o
ool0oooo00P0oooo000V0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0203oool0
02H0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`009P3oool00`000000
oooo0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000V0?ooo`800000k03oool2000000X0oooo
000V0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0203oool002H0oooo00<00000
0?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`3/0?oo
o`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3o
ool0203oool002H0oooo0P00003/0?ooo`8000002P3oool002H0oooo00<000000?ooo`3oool0k03o
ool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0
oooo00P0oooo000V0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0203oool002H0
oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`009P3oool200000>`0oooo
0P00000:0?ooo`009P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000V
0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0203oool001<0oooo0P0000040?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?oo
o`004P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00180oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?oooo0000002P3oool00180oooo00@000000?ooo`3oool000002@3oool200000?l0oooo000B
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000oP3oool001<0oooo0P00
000:0?ooo`800000o`3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.92499, 0.100377, \
0.0501504, 0.00405724}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear[AxesLabel]\)], "Input"],

Cell[BoxData[
    \(Clear::"wrsym" \(\(:\)\(\ \)\) 
      "Symbol \!\(AxesLabel\) is Protected."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetDirectory["\<C:\Documents and Settings\doepke\My \
Documents\sync\mathematica\>"]\), "\[IndentingNewLine]", 
    \(\(Export["\<plot1dyn2.eps\>", 
        plot1, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<plot2dyn2.eps\>", 
        plot2, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<plot3dyn2.eps\>", 
        plot3, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<plot4dyn2.eps\>", plot4, "\<EPS\>"];\)\)}], "Input"],

Cell[BoxData[
    \("C:\\Documents and Settings\\doepke\\My \
Documents\\sync\\mathematica"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot5a = 
        ListPlot[etaout, PlotRange \[Rule] {{0, 12}, {0, 1}}, 
          PlotStyle \[Rule] Thickness[0.01], AxesOrigin \[Rule] {0, 0}, 
          AxesLabel \[Rule] "\<Time\>", Frame \[Rule] True];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 0 m
.16667 0 L
.25 0 L
.33333 .43262 L
.41667 .61803 L
.5 .61803 L
.58333 .61803 L
.66667 .61803 L
.75 .61803 L
.83333 .61803 L
.91667 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?P3oool4000002T0oooo0`00000W0?ooo`<00000:@3oool2000002D0oooo1@0000020?oo
o`8000008P3oool5000000030?ooo`0000000000008000000`3oool003h0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000002L0oooo00@000000?oo
o`3oool000009P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool08@3o
ool01@000000oooo0?ooo`3oool0000000H0oooo000o0?ooo`030000003oool0oooo02L0oooo1@00
000W0?ooo`040000003oool0oooo000002L0oooo00@000000?ooo`3oool000009P3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00100?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3o
ool00000:03oool3000002T0oooo0P00000W0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
03h0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0000000Y0?ooo`030000003oool0
oooo02L0oooo00@000000?ooo`3oool000009P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool08@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00@3oool003l0oooo0P00000Z0?ooo`800000:@3oool3000002P0oooo0P00000V0?ooo`800000
103oool2000002<0oooo0P0000040?ooo`800000103oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooooo`000005000000L0oooo000E
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool^000000T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo000E0?oo
o`030000003oool0oooo03h0oooo0P0000300?ooo`030000003oool0oooo00D0oooo000E0?ooo`03
0000003oool0oooo03h0oooo0P0000300?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo03h0oooo0P0000300?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo03h0oooo0P0000300?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo03l0oooo0P00002o0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
03l0oooo0P00002o0?ooo`030000003oool0oooo00D0oooo000E0?ooo`800000@03oool200000;h0
oooo0P0000070?ooo`005@3oool00`000000oooo0?ooo`0o0?ooo`800000_`3oool00`000000oooo
0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0o0?ooo`800000_`3oool00`000000oooo0?oo
o`050?ooo`005@3oool00`000000oooo0?ooo`100?ooo`800000_P3oool00`000000oooo0?ooo`05
0?ooo`005@3oool00`000000oooo0?ooo`100?ooo`800000_P3oool00`000000oooo0?ooo`050?oo
o`005@3oool00`000000oooo0?ooo`100?ooo`800000_P3oool00`000000oooo0?ooo`050?ooo`00
5@3oool00`000000oooo0?ooo`100?ooo`800000_P3oool00`000000oooo0?ooo`050?ooo`005@3o
ool00`000000oooo0?ooo`100?ooo`800000_P3oool00`000000oooo0?ooo`050?ooo`005@3oool2
00000440oooo0P00002m0?ooo`8000001`3oool001D0oooo00<000000?ooo`3oool0@@3oool20000
0;d0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0@@3oool200000;d0
oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0@@3oool200000;d0oooo
00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0@@3oool200000;d0oooo00<0
00000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0@@3oool200000;d0oooo00<00000
0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0@P3oool200000;`0oooo00<000000?oo
o`3oool01@3oool001D0oooo00<000000?ooo`3oool0@P3oool200000;`0oooo00<000000?ooo`3o
ool01@3oool001D0oooo0P0000130?ooo`800000^`3oool2000000L0oooo000E0?ooo`030000003o
ool0oooo0480oooo0P00002l0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo0480oooo0P00002l0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
04<0oooo0P00002k0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo04<0
oooo0P00002k0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo04<0oooo
0P00002k0?ooo`030000003oool0oooo00D0oooo00020?ooo`800000103oool2000000<0oooo1000
00040?ooo`030000003oool0oooo04<0oooo0P00002k0?ooo`030000003oool0oooo00D0oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`130?ooo`800000^`3oool00`000000oooo0?ooo`050?ooo`0000D0oooo0000003oool0oooo0000
00090?ooo`030000003oool0oooo00@0oooo0`0000130?ooo`800000^P3oool2000000L0oooo0000
1@3oool000000?ooo`3oool0000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`140?ooo`800000^P3oool00`000000oooo0?ooo`050?ooo`0000D0oooo0000003oool0oooo0000
00080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0A03oool200000;X0oooo
00<000000?ooo`3oool01@3oool00080oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?oo
o`140?ooo`800000^P3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`14
0?ooo`800000^P3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`140?oo
o`800000^P3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`150?ooo`80
0000^@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`150?ooo`800000
^@3oool00`000000oooo0?ooo`050?ooo`005@3oool2000004H0oooo0P00002h0?ooo`8000001`3o
ool001D0oooo00<000000?ooo`3oool0A@3oool200000;T0oooo00<000000?ooo`3oool01@3oool0
01D0oooo00<000000?ooo`3oool0A@3oool200000;T0oooo00<000000?ooo`3oool01@3oool001D0
oooo00<000000?ooo`3oool0AP3oool200000;P0oooo00<000000?ooo`3oool01@3oool001D0oooo
00<000000?ooo`3oool0AP3oool200000;P0oooo00<000000?ooo`3oool01@3oool001D0oooo00<0
00000?ooo`3oool0AP3oool200000;P0oooo00<000000?ooo`3oool01@3oool001D0oooo00<00000
0?ooo`3oool0AP3oool200000;P0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?oo
o`3oool0AP3oool200000;P0oooo00<000000?ooo`3oool01@3oool001D0oooo0P0000170?ooo`80
0000]`3oool2000000L0oooo000E0?ooo`030000003oool0oooo04L0oooo0P00002g0?ooo`030000
003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo04L0oooo0P00002g0?ooo`030000003o
ool0oooo00D0oooo000E0?ooo`030000003oool0oooo04L0oooo0P00002g0?ooo`030000003oool0
oooo00D0oooo000E0?ooo`030000003oool0oooo04L0oooo0P00002g0?ooo`030000003oool0oooo
00D0oooo000E0?ooo`030000003oool0oooo04L0oooo0P00002g0?ooo`030000003oool0oooo00D0
oooo000E0?ooo`030000003oool0oooo04P0oooo0P00002f0?ooo`030000003oool0oooo00D0oooo
000E0?ooo`030000003oool0oooo04P0oooo0P00002f0?ooo`030000003oool0oooo00D0oooo000E
0?ooo`800000B@3oool200000;D0oooo0P0000070?ooo`005@3oool00`000000oooo0?ooo`180?oo
o`800000]P3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`180?ooo`80
0000]P3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`190?ooo`800000
]@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`190?ooo`800000]@3o
ool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`190?ooo`800000]@3oool0
0`000000oooo0?ooo`050?ooo`000P3oool2000000@0oooo0P0000050?ooo`<000000`3oool00`00
0000oooo0?ooo`190?ooo`800000]@3oool00`000000oooo0?ooo`050?ooo`0000D0oooo0000003o
ool0oooo0000000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0B@3oool20000
0;D0oooo00<000000?ooo`3oool01@3oool000050?ooo`000000oooo0?ooo`000000203oool50000
00<0oooo0`0000190?ooo`800000]03oool2000000L0oooo00001@3oool000000?ooo`3oool00000
00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1:0?ooo`800000]03oool0
0`000000oooo0?ooo`050?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0
000000@0oooo00<000000?ooo`3oool0BP3oool200000;@0oooo00<000000?ooo`3oool01@3oool0
0080oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`1:0?ooo`800000]03oool00`00
0000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`1:0?ooo`800000]03oool00`000000
oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`1:0?ooo`800000]03oool00`000000oooo
0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`1;0?ooo`800000/`3oool00`000000oooo0?oo
o`050?ooo`005@3oool00`000000oooo0?ooo`1;0?ooo`800000/`3oool00`000000oooo0?ooo`05
0?ooo`005@3oool2000004`0oooo0P00002b0?ooo`8000001`3oool001D0oooo00<000000?ooo`3o
ool0B`3oool200000;<0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0
B`3oool200000;<0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0C03o
ool200000;80oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0C03oool2
00000;80oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0C03oool20000
0;80oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0C03oool200000;80
oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0C03oool200000;80oooo
00<000000?ooo`3oool01@3oool001D0oooo0P00001=0?ooo`800000/@3oool2000000L0oooo000E
0?ooo`030000003oool0oooo04d0oooo0P00002a0?ooo`030000003oool0oooo00D0oooo000E0?oo
o`030000003oool0oooo04d0oooo0P00002a0?ooo`030000003oool0oooo00D0oooo000E0?ooo`03
0000003oool0oooo04d0oooo0P00002a0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo04d0oooo0P00002a0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo04d0oooo0P00002a0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo04h0oooo0P00002`0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
04h0oooo0P00002`0?ooo`030000003oool0oooo00D0oooo000E0?ooo`800000C`3oool200000:l0
oooo0P0000070?ooo`005@3oool00`000000oooo0?ooo`1>0?ooo`800000/03oool00`000000oooo
0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`1>0?ooo`800000/03oool00`000000oooo0?oo
o`050?ooo`005@3oool00`000000oooo0?ooo`1?0?ooo`800000[`3oool00`000000oooo0?ooo`05
0?ooo`005@3oool00`000000oooo0?ooo`1?0?ooo`800000[`3oool00`000000oooo0?ooo`050?oo
o`005@3oool00`000000oooo0?ooo`1?0?ooo`800000[`3oool00`000000oooo0?ooo`050?ooo`00
0P3oool2000000@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`1?0?ooo`800000
[`3oool00`000000oooo0?ooo`050?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0C`3oool200000:l0oooo00<000000?ooo`3o
ool01@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?oo
o`<00000C`3oool200000:h0oooo0P0000070?ooo`0000D0oooo0000003oool0oooo000000080?oo
o`<000001@3oool00`000000oooo0?ooo`1@0?ooo`800000[P3oool00`000000oooo0?ooo`050?oo
o`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0D03oool200000:h0oooo00<000000?ooo`3oool01@3oool00080oooo0P00000:0?ooo`<0
0000103oool00`000000oooo0?ooo`1@0?ooo`800000[P3oool00`000000oooo0?ooo`050?ooo`00
5@3oool00`000000oooo0?ooo`1@0?ooo`800000[P3oool00`000000oooo0?ooo`050?ooo`005@3o
ool00`000000oooo0?ooo`1@0?ooo`800000[P3oool00`000000oooo0?ooo`050?ooo`005@3oool0
0`000000oooo0?ooo`1A0?ooo`800000[@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`00
0000oooo0?ooo`1A0?ooo`800000[@3oool00`000000oooo0?ooo`050?ooo`005@3oool200000580
oooo0P00002/0?ooo`8000001`3oool001D0oooo00<000000?ooo`3oool0D@3oool200000:d0oooo
00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0D@3oool200000:d0oooo00<0
00000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0DP3oool200000:`0oooo00<00000
0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0DP3oool200000:`0oooo00<000000?oo
o`3oool01@3oool001D0oooo00<000000?ooo`3oool0DP3oool200000:`0oooo00<000000?ooo`3o
ool01@3oool001D0oooo00<000000?ooo`3oool0DP3oool200000:`0oooo00<000000?ooo`3oool0
1@3oool001D0oooo00<000000?ooo`3oool0DP3oool200000:`0oooo00<000000?ooo`3oool01@3o
ool001D0oooo0P00001D0?ooo`030000003oool0oooo0:T0oooo0P0000070?ooo`005@3oool00`00
0000oooo0?ooo`1C0?ooo`800000Z`3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool01@3oool001D0oooo
00<000000?ooo`3oool0E03oool200000:X0oooo00<000000?ooo`3oool01@3oool001D0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo00D0oooo000E
0?ooo`030000003oool0oooo05D0oooo0P00002Y0?ooo`030000003oool0oooo00D0oooo000E0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`050?oo
o`005@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool01@3oool001D0oooo0P00001G0?ooo`800000Y`3oool2000000L0oooo000E0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`050?ooo`005@3oool0
0`000000oooo0?ooo`1G0?ooo`800000Y`3oool00`000000oooo0?ooo`050?ooo`005@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool01@3oool001D0
oooo00<000000?ooo`3oool0F03oool200000:H0oooo00<000000?ooo`3oool01@3oool001D0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00D0oooo
00020?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05T0oooo0P00
002U0?ooo`030000003oool0oooo00D0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0:<0oooo
00<000000?ooo`3oool01@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo
0?ooo`0000040?ooo`<00000FP3oool200000:<0oooo0P0000070?ooo`0000D0oooo0000003oool0
oooo000000090?ooo`8000001@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0:80
oooo00<000000?ooo`3oool01@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0XP3oool00`00
0000oooo0?ooo`050?ooo`000P3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo05/0
oooo0P00002S0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo05`0oooo
00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?oo
o`1L0?ooo`800000XP3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?oo
o`3oool0G@3oool200000:40oooo00<000000?ooo`3oool01@3oool001D0oooo0P00001O0?ooo`03
0000003oool0oooo09h0oooo0P0000070?ooo`005@3oool00`000000oooo0?ooo`1N0?ooo`800000
X03oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0G`3oool2
000009l0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`2M0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0600
oooo0P00002N0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool01@3oool001D0oooo0P00001R
0?ooo`800000W03oool2000000L0oooo000E0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`80
0000W03oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0H`3o
ool2000009/0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
06@0oooo0P00002J0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`050?ooo`005@3oool2000006H0oooo
0P00002H0?ooo`8000001`3oool001D0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`2G0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool0U`3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`1V0?oo
o`800000V03oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0
I`3oool2000009L0oooo00<000000?ooo`3oool01@3oool000d0oooo1@0000030?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool01@3oool000l0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`8000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo000?0?ooo`030000003oool0oooo00<0ooooo`000005000000L0oooo000?0?ooo`03
0000003oool0oooo06l0ooooP`00000L0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo
000>0?ooo`800000o`3ooolA0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.996191, -0.0764114, \
0.0462956, 0.00624232}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot5b = 
        ListPlot[etaSout, PlotRange \[Rule] {{0, 12}, {0, 1}}, 
          PlotStyle \[Rule] Thickness[0.01], AxesOrigin \[Rule] {0, 0}, 
          AxesLabel \[Rule] "\<Time\>", Frame \[Rule] True];\)\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(plot5b\)\" is similar \
to existing symbol \"\!\(plot5a\)\"."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61803 L
.25 .61803 L
.33333 .61803 L
.41667 .61803 L
.5 .61803 L
.58333 .61803 L
.66667 .61803 L
.75 .61803 L
.83333 .61803 L
.91667 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{365.938, 226.188},
  ImageMargins->{{213, 0}, {0, 30}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005]0000hR000`400?l00000o`00003oo`3ooom^
0?ooo`00C03oool4000003H0oooo0`00000c0?ooo`<00000=P3oool200000380oooo1@0000020?oo
o`800000;`3oool5000000030?ooo`0000000000008000000P3oool004`0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0b0?ooo`040000003oool0oooo000003@0oooo00@000000?oo
o`3oool00000<`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0;P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo001=0?ooo`030000003oool0oooo03@0oooo1@00
000c0?ooo`040000003oool0oooo000003@0oooo00@000000?ooo`3oool00000<`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo03<0oooo00@000000?ooo`3o
ool00000=03oool3000003H0oooo0P00000d0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool0
04`0oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0000000e0?ooo`030000003oool0
oooo03@0oooo00@000000?ooo`3oool00000<`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0;P3oool01@000000oooo0?ooo`3oool000000080oooo0@0000010?ooo`40
oooo001=0?ooo`800000=`3oool2000003D0oooo0`00000e0?ooo`800000<`3oool2000000@0oooo
0P00000`0?ooo`800000103oool2000000<0oooo003o0?ooofh0oooo003o0?ooofh0oooo003o0?oo
ofh0oooo003o0?ooofh0oooo003o0?ooofh0oooo003o0?ooofh0oooo003o0?ooofh0oooo000F0?oo
ool00000DP0000060?ooo`005P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103o
ool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?oo
o`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000
oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3o
ool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<00000
0?ooo`3oool0103oool001H0oooo0P00003o0?ooodh0oooo0P0000060?ooo`005P3oool00`000000
oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3o
ool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<00000
0?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo
00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`00
5P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<0
00000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0
oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool200000?l0ooooCP3oool20000
00H0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`00
5P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<0
00000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0
oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?oo
odh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`03
0000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo
0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103o
ool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?oo
o`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool200000?l0
ooooCP3oool2000000H0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo
0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103o
ool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?oo
o`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000
oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3o
ool00`000000oooo0?ooo`040?ooo`000P3oool2000000@0oooo0P0000030?ooo`@000001@3oool0
0`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool000050?ooo`000000oooo
0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooCP3oool0
0`000000oooo0?ooo`040?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0
oooo00D0oooo0`00003o0?oood`0oooo0`0000060?ooo`0000D0oooo0000003oool0oooo0000000:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0
oooo00@0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool00080oooo0P00000:
0?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool0
01H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3o
oom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool0
0`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?oo
o`3oool0103oool001H0oooo0P00003o0?ooodh0oooo0P0000060?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3o
oom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool0
0`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?oo
o`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<00000
0?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo00<000000?ooo`3oool0103oool001H0oooo0P00003o0?ooodh0oooo0P0000060?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<00000
0?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000
003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?oo
o`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool0
01H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool200000?l0oooo
CP3oool2000000H0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?oo
o`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool0
01H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3o
oom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool0
0`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?oo
o`3oool0103oool00080oooo0P0000040?ooo`8000001@3oool3000000@0oooo00<000000?ooo`3o
ool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo00001@3oool000000?ooo`3oool0000000/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3o
ool0103oool000050?ooo`000000oooo0?ooo`000000203oool5000000@0oooo0`00003o0?oood`0
oooo0`0000060?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo00001@3oool0
00000?ooo`3oool0000000T0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`3o0?oo
odh0oooo00<000000?ooo`3oool0103oool00080oooo0P00000;0?ooo`8000001@3oool00`000000
oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3o
ool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<00000
0?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo
00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`00
5P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo0P00
003o0?ooodh0oooo0P0000060?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<00000
0?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo
00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`00
5P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<0
00000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0
oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?oo
odh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`03
0000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo
0?ooo`040?ooo`005P3oool200000?l0ooooCP3oool2000000H0oooo000F0?ooo`030000003oool0
oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?oo
odh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`03
0000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo
0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103o
ool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?oo
o`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000
oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3o
ool00`000000oooo0?ooo`040?ooo`005P3oool200000?l0ooooCP3oool2000000H0oooo000F0?oo
o`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000
oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3o
ool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<00000
0?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo
00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`00
0P3oool2000000@0oooo0P0000030?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooodh0oooo
00<000000?ooo`3oool0103oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`00
00D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000D0oooo0`00003o0?oo
od`0oooo0`0000060?ooo`0000D0oooo0000003oool0oooo000000080?ooo`<000001P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool000050?ooo`000000oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooCP3oool00`00
0000oooo0?ooo`040?ooo`000P3oool2000000X0oooo0`0000050?ooo`030000003oool0oooo0?l0
ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo
00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003o
ool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`04
0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0
oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000
003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool200000?l0ooooCP3o
ool2000000H0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`04
0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0
oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000
003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?oo
o`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>
0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`00
0000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3o
ool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo
000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool2
00000?l0ooooCP3oool2000000H0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`00
0000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3o
ool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo
000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool0
0`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?oo
o`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0
ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo
00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003o
ool0oooo00@0oooo000F0?ooo`800000o`3ooom>0?ooo`8000001P3oool001H0oooo00<000000?oo
o`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0
ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo
00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003o
ool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`04
0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0
oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000
003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`000P3oool2000000@0oooo0P00
00040?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103o
ool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`040000003oool0oooo000000D0oooo0`00003o0?oood`0oooo0`0000060?ooo`00
00D0oooo0000003oool0oooo000000090?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo00<000000?ooo`3oool0103oool000050?ooo`000000oooo0?ooo`000000203oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?oo
o`000P3oool2000000X0oooo0P0000060?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000
oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0
103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3o
ool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool00`000000oooo0?ooo`040?ooo`005P3oool200000?l0ooooCP3oool2000000H0oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3o
ool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<0
00000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0
oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo
00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`800000o`3o
oom>0?ooo`8000001P3oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0
oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo
00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?oo
o`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000
oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0
103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F
0?ooo`800000o`3ooom>0?ooo`8000001P3oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?oo
o`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000
oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0
103oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3o
ool0o`3ooom>0?ooo`030000003oool0oooo00@0oooo000=0?ooo`D00000103oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`040?ooo`003`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02P3ooooo000001`00000303oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00@0oooo000?0?ooo`030000003oool0oooo00@0ooooo`00001B000000H0oooo000?0?oo
o`030000003oool0oooo01l0ooooo`00000L00000240oooo000?0?ooo`030000003oool0oooo0?l0
ooooG03oool000h0oooo0P00003o0?oooeh0oooo003o0?ooofh0oooo0000\
\>"],
  ImageRangeCache->{{{0, 364.938}, {225.188, 0}} -> {-0.811518, -0.0636061, \
0.0357434, 0.00481951}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Carrying out computations under the assumption that there is no reform\
\>", "Section"],

Cell[BoxData[
    \(transition[30, 11]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plot1 = 
        MultipleListPlot[wsreform, wsout/wuout, 
          PlotRange \[Rule] {{0, 12}, {2, 7}}, 
          PlotStyle \[Rule] {Thickness[ .01], {Thickness[ .01], 
                Dashing[{ .02}]}}, SymbolShape -> PlotSymbol[Star, 0], 
          AxesOrigin \[Rule] {0, 0}, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time\>", "\<Wage Ratio\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(plot2 = 
        MultipleListPlot[popoutreform, popout, 
          PlotRange \[Rule] {{0, 12}, {0, 30}}, 
          PlotStyle \[Rule] {Thickness[ .01], {Thickness[ .01], 
                Dashing[{ .02}]}}, SymbolShape -> PlotSymbol[Star, 0], 
          AxesOrigin \[Rule] {0, 0}, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time\>", "\<Population Growth\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(plot3 = 
        MultipleListPlot[cloutreform, clout, 
          PlotRange \[Rule] {{0, 12}, {\(- .1\), 1}}, 
          PlotStyle \[Rule] {Thickness[ .01], {Thickness[ .01], 
                Dashing[{ .02}]}}, SymbolShape -> PlotSymbol[Star, 0], 
          AxesOrigin \[Rule] {0, 0}, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time\>", "\<Working Children\>"}];\)\)}], \
"Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.247214 0.123607 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -18.5625 -32 ]
[-0.01875 .30902 -6 32 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(3)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(5)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(6)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(7)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -105.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 10.2813 translate
90 rotate
-93 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Wage) show
93.000 12.813 moveto
(Ratio) show
123.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .02472 m
1 .02472 L
s
.99625 .04944 m
1 .04944 L
s
.99625 .07416 m
1 .07416 L
s
.99625 .09889 m
1 .09889 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .17305 m
1 .17305 L
s
.99625 .19777 m
1 .19777 L
s
.99625 .22249 m
1 .22249 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .29666 m
1 .29666 L
s
.99625 .32138 m
1 .32138 L
s
.99625 .3461 m
1 .3461 L
s
.99625 .39554 m
1 .39554 L
s
.99625 .42026 m
1 .42026 L
s
.99625 .44498 m
1 .44498 L
s
.99625 .46971 m
1 .46971 L
s
.99625 .51915 m
1 .51915 L
s
.99625 .54387 m
1 .54387 L
s
.99625 .56859 m
1 .56859 L
s
.99625 .59331 m
1 .59331 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05719 m
.16667 .05656 L
.25 .12752 L
.33333 .20914 L
.41667 .28897 L
.5 .32635 L
.58333 .31924 L
.66667 .23928 L
.75 .19785 L
.83333 .1518 L
.91667 .12287 L
s
.0001 w
.08333 .05719 m
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L closepath F
.16667 .05656 m
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L closepath F
.25 .12752 m
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L closepath F
.33333 .20914 m
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L closepath F
.41667 .28897 m
.41667 .28897 L
.41667 .28897 L
.41667 .28897 L
.41667 .28897 L
.41667 .28897 L
.41667 .28897 L
.41667 .28897 L
.41667 .28897 L
.41667 .28897 L
.41667 .28897 L closepath F
.5 .32635 m
.5 .32635 L
.5 .32635 L
.5 .32635 L
.5 .32635 L
.5 .32635 L
.5 .32635 L
.5 .32635 L
.5 .32635 L
.5 .32635 L
.5 .32635 L closepath F
.58333 .31924 m
.58333 .31924 L
.58333 .31924 L
.58333 .31924 L
.58333 .31924 L
.58333 .31924 L
.58333 .31924 L
.58333 .31924 L
.58333 .31924 L
.58333 .31924 L
.58333 .31924 L closepath F
.66667 .23928 m
.66667 .23928 L
.66667 .23928 L
.66667 .23928 L
.66667 .23928 L
.66667 .23928 L
.66667 .23928 L
.66667 .23928 L
.66667 .23928 L
.66667 .23928 L
.66667 .23928 L closepath F
.75 .19785 m
.75 .19785 L
.75 .19785 L
.75 .19785 L
.75 .19785 L
.75 .19785 L
.75 .19785 L
.75 .19785 L
.75 .19785 L
.75 .19785 L
.75 .19785 L closepath F
.83333 .1518 m
.83333 .1518 L
.83333 .1518 L
.83333 .1518 L
.83333 .1518 L
.83333 .1518 L
.83333 .1518 L
.83333 .1518 L
.83333 .1518 L
.83333 .1518 L
.83333 .1518 L closepath F
.91667 .12287 m
.91667 .12287 L
.91667 .12287 L
.91667 .12287 L
.91667 .12287 L
.91667 .12287 L
.91667 .12287 L
.91667 .12287 L
.91667 .12287 L
.91667 .12287 L
.91667 .12287 L closepath F
.01 w
[ .02 ] 0 setdash
.08333 .05719 m
.16667 .05656 L
.25 .12752 L
.33333 .20914 L
.41667 .30543 L
.5 .40726 L
.58333 .47167 L
.66667 .51319 L
.75 .4814 L
.83333 .4252 L
.91667 .40151 L
s
.0001 w
[ ] 0 setdash
.08333 .05719 m
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L
.08333 .05719 L closepath F
.16667 .05656 m
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L
.16667 .05656 L closepath F
.25 .12752 m
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L
.25 .12752 L closepath F
.33333 .20914 m
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L
.33333 .20914 L closepath F
.41667 .30543 m
.41667 .30543 L
.41667 .30543 L
.41667 .30543 L
.41667 .30543 L
.41667 .30543 L
.41667 .30543 L
.41667 .30543 L
.41667 .30543 L
.41667 .30543 L
.41667 .30543 L closepath F
.5 .40726 m
.5 .40726 L
.5 .40726 L
.5 .40726 L
.5 .40726 L
.5 .40726 L
.5 .40726 L
.5 .40726 L
.5 .40726 L
.5 .40726 L
.5 .40726 L closepath F
.58333 .47167 m
.58333 .47167 L
.58333 .47167 L
.58333 .47167 L
.58333 .47167 L
.58333 .47167 L
.58333 .47167 L
.58333 .47167 L
.58333 .47167 L
.58333 .47167 L
.58333 .47167 L closepath F
.66667 .51319 m
.66667 .51319 L
.66667 .51319 L
.66667 .51319 L
.66667 .51319 L
.66667 .51319 L
.66667 .51319 L
.66667 .51319 L
.66667 .51319 L
.66667 .51319 L
.66667 .51319 L closepath F
.75 .4814 m
.75 .4814 L
.75 .4814 L
.75 .4814 L
.75 .4814 L
.75 .4814 L
.75 .4814 L
.75 .4814 L
.75 .4814 L
.75 .4814 L
.75 .4814 L closepath F
.83333 .4252 m
.83333 .4252 L
.83333 .4252 L
.83333 .4252 L
.83333 .4252 L
.83333 .4252 L
.83333 .4252 L
.83333 .4252 L
.83333 .4252 L
.83333 .4252 L
.83333 .4252 L closepath F
.91667 .40151 m
.91667 .40151 L
.91667 .40151 L
.91667 .40151 L
.91667 .40151 L
.91667 .40151 L
.91667 .40151 L
.91667 .40151 L
.91667 .40151 L
.91667 .40151 L
.91667 .40151 L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00S@3oool3000000@0oooo0`00
00001`3oool000000000003oool000000?ooo`0000000P3oool3000007d0oooo002>0?ooo`030000
003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
00200?ooo`00SP3oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`@00000O@3oool008h0oooo00<000000?ooo`3oool00`3oool200000080
oooo0`0000000`3oool000000?ooo`020?ooo`800000OP3oool008`0oooo00D000000?ooo`000000
oooo0000002?0?ooo`00S03oool5000000@0oooo00<000000?ooo`3oool0R03oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool004H0oooo1000000V0?ooo`<000008`3oool3000002D0
oooo0P00000R0?ooo`D000000P3oool2000001l0oooo1@0000000`3oool0000000000002000000`0
oooo00160?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool08P3oool010000000oooo
0?ooo`00000S0?ooo`040000003oool0oooo000002<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`00A`3oool0
0`000000oooo0?ooo`0T0?ooo`D000008`3oool010000000oooo0?ooo`00000S0?ooo`040000003o
ool0oooo000002<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`00B03oool00`000000oooo
0?ooo`0S0?ooo`040000003oool0oooo000002@0oooo0`00000U0?ooo`800000903oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo00160?ooo`040000003oool0oooo000002D0oooo00<000000?oo
o`0000009@3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000002<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00X0oooo00170?ooo`8000009`3oool2000002D0oooo0`00
000T0?ooo`8000008`3oool2000000@0oooo0P00000P0?ooo`800000103oool2000000d0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000P
0?oooo000000403oool00200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool03P3oool00200oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`0>0?ooo`00803o
ool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0
oooo0>`0oooo00<000000?ooo`3oool03P3oool00200oooo0P00003/0?ooo`800000403oool00200
oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo
0?ooo`3/0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0>`0oooo00<0
00000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`0>
0?ooo`00803oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00h0oooo000P0?ooo`80
0000k03oool200000100oooo000P0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`0@0?oooaL00000a@3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`0@0?oooaT00000``3oool0
0`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`0V0?ooo`@00000`P3oool00`00
0000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`0W0?ooo`@00000`@3oool00`000000
oooo0?ooo`0>0?ooo`00803oool2000002X0oooo0`00002o0?ooo`800000403oool00200oooo00<0
00000?ooo`3oool0:P3oool300000;l0oooo00<000000?ooo`3oool03P3oool00200oooo00<00000
0?ooo`3oool0:`3oool400000;d0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?oo
o`3oool0;03oool400000;`0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3o
ool0;@3oool400000;/0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
;P3oool400000;X0oooo00<000000?ooo`3oool03P3oool00200oooo0P00000a0?ooo`<00000^03o
ool200000100oooo000P0?ooo`030000003oool0oooo0340oooo0`00002h0?ooo`030000003oool0
oooo00h0oooo000P0?ooo`030000003oool0oooo0380oooo0`00002g0?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo03<0oooo0`00002f0?ooo`030000003oool0oooo00h0
oooo000I0?ooo`8000001@3oool00`000000oooo0?ooo`0d0?ooo`@00000]03oool00`000000oooo
0?ooo`0>0?ooo`00603oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03D0oooo
1000002O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool001X0oooo00<0
00000?ooo`3oool00`3oool2000003L0oooo1000002K0?ooo`@000004P3oool200000100oooo000K
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>03oool3000009L0oooo1P00000D
0?ooo`030000003oool0oooo00h0oooo000H0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0>@3oool300000980oooo1`00000G0?ooo`030000003oool0oooo00h0oooo000I0?oo
o`8000001@3oool00`000000oooo0?ooo`0j0?ooo`<00000SP3oool7000001X0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0>`3oool3000008X0oooo1P00000N0?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo03`0oooo0`0000250?ooo`L00000
8@3oool00`000000oooo0?ooo`0>0?ooo`00803oool2000003h0oooo0`0000220?ooo`H000008`3o
ool200000100oooo000P0?ooo`030000003oool0oooo03h0oooo0`00001o0?ooo`D000009`3oool0
0`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`0o0?ooo`<00000O@3oool40000
02T0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0@03oool3000007X0
oooo1000000[0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0440oooo
1000001f0?ooo`D00000;03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?oo
o`120?ooo`@00000L`3oool5000002h0oooo00<000000?ooo`3oool03P3oool00200oooo0P000014
0?ooo`@00000L03oool5000002l0oooo0P00000@0?ooo`00803oool00`000000oooo0?ooo`140?oo
o`@00000K@3oool500000380oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3o
ool0AP3oool3000006/0oooo1000000d0?ooo`030000003oool0oooo00h0oooo000<0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0A`3oool3000006P0oooo1000000f0?ooo`030000
003oool0oooo00h0oooo000<0?ooo`D000003`3oool00`000000oooo0?ooo`180?ooo`<00000I@3o
ool5000003L0oooo00<000000?ooo`3oool03P3oool000`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0<0?ooo`800000BP3oool300000680oooo1@00000h0?ooo`800000403oool0
00h0oooo0`00000?0?ooo`030000003oool0oooo04X0oooo0`00001O0?ooo`D00000>`3oool00`00
0000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0B`3oool3000005`0oooo1@00000m0?ooo`030000003oool0oooo00h0
oooo000<0?ooo`D000003`3oool00`000000oooo0?ooo`1;0?ooo`@00000F@3oool5000003l0oooo
00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0C@3oool3000005H0oooo1@00
00110?ooo`030000003oool0oooo00h0oooo000@0?ooo`8000003P3oool00`000000oooo0?ooo`1>
0?ooo`<00000D`3oool5000004<0oooo00<000000?ooo`3oool03P3oool000h0oooo00@000000?oo
o`00000000003P3oool2000004l0oooo1000001@0?ooo`D00000A03oool200000100oooo000>0?oo
o`040000003oool00000000000h0oooo00<000000?ooo`3oool0C`3oool4000004d0oooo1@000017
0?ooo`030000003oool0oooo00h0oooo000>0?ooo`@000003P3oool00`000000oooo0?ooo`1@0?oo
o`@00000BP3oool5000004T0oooo00<000000?ooo`3oool03P3oool00140oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1A0?ooo`@00000A`3oool5000004/0oooo00<000000?ooo`3o
ool03P3oool001X0oooo0`0000030?ooo`030000003oool0oooo0540oooo00<000000?ooo`000000
0P0000150?ooo`@00000C@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool200000080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05@0oooo0`00
00130?ooo`<00000C`3oool00`000000oooo0?ooo`0>0?ooo`003P3oool01P000000oooo0?ooo`00
0000oooo000000@0oooo1@0000030?ooo`800000EP3oool400000400oooo0`00001?0?ooo`800000
403oool000h0oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0E@3oool5000003h0oooo0`00001A0?ooo`030000003oool0oooo
00h0oooo000>0?ooo`D000001P3oool00`000000oooo000000040?ooo`030000003oool0oooo05H0
oooo1@00000l0?ooo`<00000DP3oool00`000000oooo0?ooo`0>0?ooo`003P3oool00`000000oooo
0?ooo`090?ooo`800000103oool00`000000oooo0?ooo`1G0?ooo`D00000>P3oool3000005<0oooo
00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0F03oool00`000000oooo0000
0002000003P0oooo0`00001D0?ooo`030000003oool0oooo00h0oooo000?0?ooo`8000003`3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<00000=P3oool3000005D0oooo00<00000
0?ooo`3oool03P3oool000h0oooo0P0000000`3oool000000?ooo`0=0?ooo`800000G@3oool30000
03@0oooo0`00001E0?ooo`800000403oool000h0oooo0P0000000`3oool000000?ooo`0=0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`0000000P00000b0?ooo`<00000E`3oool00`000000
oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0000000>0?ooo`030000003oool0oooo05X0oooo
0`000000103oool0000000000000000`0?ooo`<00000F03oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`1K0?ooo`<0000000@0oooo0000000000000000;P3oool3000005T0
oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0G03oool3000000030?oo
o`000000000000800000:`3oool3000005X0oooo00<000000?ooo`3oool03P3oool00200oooo00<0
00000?ooo`3oool0G@3oool3000000030?ooo`000000000000<00000:03oool3000005/0oooo00<0
00000?ooo`3oool03P3oool00200oooo0P00001O0?ooo`030000003oool0oooo0080oooo1P00000T
0?ooo`<00000F`3oool200000100oooo000P0?ooo`030000003oool0oooo06D0oooo1P00000Q0?oo
o`<00000G@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`1Q0?ooo`03
0000003oool0oooo00@0oooo1@00000N0?ooo`<00000GP3oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00H0oooo1@00000K0?ooo`<00000
G`3oool00`000000oooo0?ooo`0>0?ooo`00303oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0H@3oool2000000T0oooo1P00000G0?ooo`<00000H03o
ool00`000000oooo0?ooo`0>0?ooo`00303oool6000000h0oooo00<000000?ooo`3oool0HP3oool2
000000X0oooo1P00000D0?ooo`<00000H@3oool00`000000oooo0?ooo`0>0?ooo`00303oool01P00
0000oooo0?ooo`000000oooo000000h0oooo0P00001T0?ooo`800000303ooolI00000640oooo0P00
000@0?ooo`00303oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool0303ooolF000006<0oooo00<000000?ooo`3oool03P3oool000d0oooo0P000000
0`3oool000000?ooo`0>0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`0>0?ooo`004@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool03P3oool00100oooo
0P00000>0?ooo`030000003oool0oooo06L0oooo0P0000230?ooo`030000003oool0oooo00h0oooo
000>0?ooo`040000003oool00000000000h0oooo0P00001Y0?ooo`800000P@3oool200000100oooo
000>0?ooo`040000003oool00000000000h0oooo00<000000?ooo`3oool0J@3oool200000840oooo
00<000000?ooo`3oool03P3oool000h0oooo1000000>0?ooo`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`0>0?ooo`004@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0>
0?ooo`003P3oool00`000000oooo0?ooo`080?ooo`8000001@3oool00`000000oooo0?ooo`3/0?oo
o`030000003oool0oooo00h0oooo000=0?ooo`@000001`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0>0?oo
o`003P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo0P00001]0?oo
o`<00000O03oool200000100oooo000>0?ooo`040000003oool0oooo000000L0oooo0P0000050?oo
o`030000003oool0oooo06d0oooo0`00001l0?ooo`030000003oool0oooo00h0oooo000>0?ooo`03
0000003oool0000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1^0?ooo`<0
0000N`3oool00`000000oooo0?ooo`0>0?ooo`006@3oool3000000@0oooo00<000000?ooo`3oool0
K`3oool3000007X0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0
oooo0>`0oooo00<000000?ooo`3oool03P3oool000h0oooo00@000000?ooo`3oool000003P3oool2
000007@0oooo00<000000?ooo`3oool0M@3oool200000100oooo000<0?ooo`030000003oool00000
00<000003P3oool00`000000oooo0?ooo`1b0?ooo`<00000H`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00h0oooo000A0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0L`3oool3000007H0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
M03oool4000005H0oooo1P00000H0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003o
ool0oooo07D0oooo1000001A0?ooo`030000003oool0oooo00L00000603oool00`000000oooo0?oo
o`0>0?ooo`003`3oool2000000l0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1=
0?ooo`D0000000<0oooo0000003oool07@3oool00`000000oooo0?ooo`0>0?ooo`003P3oool01000
0000oooo0?ooo`00000>0?ooo`800000N`3oool00`000000oooo0?ooo`180?ooo`H00000803oool2
00000100oooo000>0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0N@3oool3
000004P0oooo1000000T0?ooo`030000003oool0oooo00h0oooo000?0?ooo`8000003`3oool00`00
0000oooo0?ooo`1j0?ooo`@00000@`3oool01@000000oooo0?ooo`3oool0000002H0oooo00<00000
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0N`3oool400000440oooo0`00000Y0?oo
o`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo07d0oooo0`00000n0?ooo`@0
0000:P3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo03`0oooo1000000[0?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000P`3o
ool00`000000oooo0?ooo`0g0?ooo`<00000;03oool200000100oooo000P0?ooo`030000003oool0
oooo0840oooo0`00000e0?ooo`050000003oool0oooo0?ooo`000000;P3oool00`000000oooo0?oo
o`0>0?ooo`00803oool00`000000oooo0?ooo`220?ooo`@00000<P3oool300000340oooo00<00000
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0P`3oool4000002l0oooo1000000b0?oo
o`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo08D0oooo0`00000]0?ooo`@0
0000<`3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo02/0oooo0`00000e0?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000R@3o
ool00`000000oooo0000000Z0?ooo`030000003oool0oooo03<0oooo0P00000@0?ooo`00803oool0
0`000000oooo0?ooo`290?ooo`@000008`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo00h0oooo000P0?ooo`030000003oool0oooo08X0oooo1@00000O0?ooo`@00000>P3oool00`00
0000oooo0?ooo`0>0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0S03oool4000001d0
oooo1@00000j0?ooo`030000003oool0oooo00h0oooo000H0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0SP3oool01@000000oooo0?ooo`3oool0000001D0oooo00@000000?oo
o`3oool0oooo0`00000m0?ooo`030000003oool0oooo00h0oooo000H0?ooo`040000003oool0oooo
000000@0oooo0P00002B0?ooo`@000004@3oool4000000<0oooo00<000000?ooo`3oool0>`3oool2
00000100oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2B0?ooo`H00000303oool50000
04<0oooo00<000000?ooo`3oool03P3oool001T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2D0?ooo`D000002P3oool4000004D0oooo00<000000?ooo`3oool03P3oool001T0oooo
0`0000040?ooo`030000003oool0oooo09L0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`2J0?ooo`L00000B`3oool00`000000oooo0?ooo`0>0?ooo`00803o
ool00`000000oooo0?ooo`2K0?ooo`D00000C03oool00`000000oooo0?ooo`0>0?ooo`00803oool2
000009d0oooo00<000000?ooo`3oool0C03oool200000100oooo000P0?ooo`030000003oool0oooo
0>`0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0k03oool00`000000
oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00h0oooo
000P0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool03P3oool00200oooo00<00000
0?ooo`3oool0k03oool00`000000oooo0?ooo`0>0?ooo`00803oool200000>`0oooo0P00000@0?oo
o`00803oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000
003oool0oooo0>`0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0k03o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`3/0?ooo`030000003oool0
oooo00h0oooo000P0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool03P3oool00200
oooo0P00003/0?ooo`800000403oool00200oooo00<000000?ooo`3oool0k03oool00`000000oooo
0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00h0oooo000P
0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?oo
o`3oool0k03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`3/0?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`800000k03oool200000100oooo000P0?ooo`030000003o
ool0oooo0>`0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0k03oool0
0`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo
00h0oooo000J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0k03oool00`000000
oooo0?ooo`0>0?ooo`006P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
000J0?ooo`030000003oool0oooo00<0ooool000000@0?ooo`006`3oool00`000000oooo0?ooo`3o
0?ooo`<0oooo000H0?ooo`040000003oool0oooo00000?l0oooo1@3oool001P0oooo1000003o0?oo
o`D0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.62408, 1.16981, \
0.0501504, 0.0338104}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0 0.0206011 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .10301 -6 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -12 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5625 -53 ]
[-0.01875 .30902 -12 53 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(10)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(20)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(25)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(30)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -132.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
114 10.2813 translate
90 rotate
-114 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Population) show
129.000 12.813 moveto
(Growth) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .59486 m
.16667 .59486 L
.25 .59128 L
.33333 .58878 L
.41667 .26042 L
.5 .12886 L
.58333 .10308 L
.66667 .08345 L
.75 .06817 L
.83333 .05609 L
.91667 .04641 L
s
.0001 w
.08333 .59486 m
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L closepath F
.16667 .59486 m
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L closepath F
.25 .59128 m
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L closepath F
.33333 .58878 m
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L closepath F
.41667 .26042 m
.41667 .26042 L
.41667 .26042 L
.41667 .26042 L
.41667 .26042 L
.41667 .26042 L
.41667 .26042 L
.41667 .26042 L
.41667 .26042 L
.41667 .26042 L
.41667 .26042 L closepath F
.5 .12886 m
.5 .12886 L
.5 .12886 L
.5 .12886 L
.5 .12886 L
.5 .12886 L
.5 .12886 L
.5 .12886 L
.5 .12886 L
.5 .12886 L
.5 .12886 L closepath F
.58333 .10308 m
.58333 .10308 L
.58333 .10308 L
.58333 .10308 L
.58333 .10308 L
.58333 .10308 L
.58333 .10308 L
.58333 .10308 L
.58333 .10308 L
.58333 .10308 L
.58333 .10308 L closepath F
.66667 .08345 m
.66667 .08345 L
.66667 .08345 L
.66667 .08345 L
.66667 .08345 L
.66667 .08345 L
.66667 .08345 L
.66667 .08345 L
.66667 .08345 L
.66667 .08345 L
.66667 .08345 L closepath F
.75 .06817 m
.75 .06817 L
.75 .06817 L
.75 .06817 L
.75 .06817 L
.75 .06817 L
.75 .06817 L
.75 .06817 L
.75 .06817 L
.75 .06817 L
.75 .06817 L closepath F
.83333 .05609 m
.83333 .05609 L
.83333 .05609 L
.83333 .05609 L
.83333 .05609 L
.83333 .05609 L
.83333 .05609 L
.83333 .05609 L
.83333 .05609 L
.83333 .05609 L
.83333 .05609 L closepath F
.91667 .04641 m
.91667 .04641 L
.91667 .04641 L
.91667 .04641 L
.91667 .04641 L
.91667 .04641 L
.91667 .04641 L
.91667 .04641 L
.91667 .04641 L
.91667 .04641 L
.91667 .04641 L closepath F
.01 w
[ .02 ] 0 setdash
.08333 .59486 m
.16667 .59486 L
.25 .59128 L
.33333 .58878 L
.41667 .58703 L
.5 .34671 L
.58333 .13504 L
.66667 .12588 L
.75 .20507 L
.83333 .32823 L
.91667 .3483 L
s
.0001 w
[ ] 0 setdash
.08333 .59486 m
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L
.08333 .59486 L closepath F
.16667 .59486 m
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L
.16667 .59486 L closepath F
.25 .59128 m
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L
.25 .59128 L closepath F
.33333 .58878 m
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L
.33333 .58878 L closepath F
.41667 .58703 m
.41667 .58703 L
.41667 .58703 L
.41667 .58703 L
.41667 .58703 L
.41667 .58703 L
.41667 .58703 L
.41667 .58703 L
.41667 .58703 L
.41667 .58703 L
.41667 .58703 L closepath F
.5 .34671 m
.5 .34671 L
.5 .34671 L
.5 .34671 L
.5 .34671 L
.5 .34671 L
.5 .34671 L
.5 .34671 L
.5 .34671 L
.5 .34671 L
.5 .34671 L closepath F
.58333 .13504 m
.58333 .13504 L
.58333 .13504 L
.58333 .13504 L
.58333 .13504 L
.58333 .13504 L
.58333 .13504 L
.58333 .13504 L
.58333 .13504 L
.58333 .13504 L
.58333 .13504 L closepath F
.66667 .12588 m
.66667 .12588 L
.66667 .12588 L
.66667 .12588 L
.66667 .12588 L
.66667 .12588 L
.66667 .12588 L
.66667 .12588 L
.66667 .12588 L
.66667 .12588 L
.66667 .12588 L closepath F
.75 .20507 m
.75 .20507 L
.75 .20507 L
.75 .20507 L
.75 .20507 L
.75 .20507 L
.75 .20507 L
.75 .20507 L
.75 .20507 L
.75 .20507 L
.75 .20507 L closepath F
.83333 .32823 m
.83333 .32823 L
.83333 .32823 L
.83333 .32823 L
.83333 .32823 L
.83333 .32823 L
.83333 .32823 L
.83333 .32823 L
.83333 .32823 L
.83333 .32823 L
.83333 .32823 L closepath F
.91667 .3483 m
.91667 .3483 L
.91667 .3483 L
.91667 .3483 L
.91667 .3483 L
.91667 .3483 L
.91667 .3483 L
.91667 .3483 L
.91667 .3483 L
.91667 .3483 L
.91667 .3483 L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00T03oool3000000@0oooo0`00
00001`3oool000000000003oool000000?ooo`0000000P3oool3000007X0oooo002A0?ooo`030000
003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
001m0?ooo`00T@3oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`@00000NP3oool00940oooo00<000000?ooo`3oool00`3oool200000080
oooo0`0000000`3oool000000?ooo`020?ooo`800000N`3oool008l0oooo00D000000?ooo`000000
oooo0000002<0?ooo`00S`3oool5000000@0oooo00<000000?ooo`3oool0Q@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool004T0oooo1000000V0?ooo`<000008`3oool3000002D0
oooo0P00000R0?ooo`D000000P3oool2000001l0oooo1@0000000`3oool0000000000002000000T0
oooo00190?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool08P3oool010000000oooo
0?ooo`00000S0?ooo`040000003oool0oooo000002<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`00BP3oool0
0`000000oooo0?ooo`0T0?ooo`D000008`3oool010000000oooo0?ooo`00000S0?ooo`040000003o
ool0oooo000002<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00B`3oool00`000000oooo
0?ooo`0S0?ooo`040000003oool0oooo000002@0oooo0`00000U0?ooo`800000903oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00P0oooo00190?ooo`040000003oool0oooo000002D0oooo00<000000?oo
o`0000009@3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000002<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo001:0?ooo`8000009`3oool2000002D0oooo0`00
000T0?ooo`8000008`3oool2000000@0oooo0P00000P0?ooo`800000103oool2000000X0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000S
0?oooo0000003@3oool002<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool002<0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool02`3oool002<0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`0;0?ooo`008`3o
ool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00/0oooo000S0?ooo`800000k03oool2
000000d0oooo000S0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool02`3oool002<0
oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`0;0?ooo`008`3oool00`000000oooo
0?ooo`3/0?ooo`030000003oool0oooo00/0oooo000S0?ooo`030000003oool0oooo0>`0oooo00<0
00000?ooo`3oool02`3oool002<0oooo0P00003/0?ooo`8000003@3oool002<0oooo00<000000?oo
o`3oool0dP3oool7000001<0oooo00<000000?ooo`3oool02`3oool002<0oooo00<000000?ooo`3o
ool0b`3oool>000001<0oooo00<000000?ooo`3oool02`3oool002<0oooo00<000000?ooo`3oool0
a03oool>000001X0oooo00<000000?ooo`3oool02`3oool002<0oooo00<000000?ooo`3oool0^P3o
oolA00000240oooo00<000000?ooo`3oool02`3oool002<0oooo0P00002a0?oooa@000009`3oool2
000000d0oooo000S0?ooo`030000003oool0oooo0:/0oooo3`00000b0?ooo`030000003oool0oooo
00/0oooo000S0?ooo`030000003oool0oooo0:H0oooo2P00000l0?ooo`030000003oool0oooo00/0
oooo000S0?ooo`030000003oool0oooo0:40oooo2P0000110?ooo`030000003oool0oooo00/0oooo
000S0?ooo`030000003oool0oooo09`0oooo2P0000160?ooo`030000003oool0oooo00/0oooo000S
0?ooo`800000V@3oool9000004X0oooo0P00000=0?ooo`008`3oool00`000000oooo0?ooo`2D0?oo
o`P00000D03oool00`000000oooo0?ooo`0;0?ooo`008`3oool00`000000oooo0?ooo`2@0?ooo`P0
0000E03oool00`000000oooo0?ooo`0;0?ooo`00703oool2000000D0oooo00<000000?ooo`3oool0
S03oool8000005P0oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
R03oool8000005`0oooo00<000000?ooo`3oool02`3oool000T0oooo1P00000?0?ooo`030000003o
ool0oooo0080oooo0P0000260?ooo`L00000G`3oool2000000d0oooo00090?ooo`060000003oool0
oooo0000003oool000003@3oool2000000D0oooo00<000000?ooo`3oool0PP3oool6000006@0oooo
00<000000?ooo`3oool02`3oool000T0oooo00@000000?ooo`3oool000003`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo07l0oooo1P00001W0?ooo`030000003oool0oooo00/0oooo
000:0?ooo`800000403oool3000000@0oooo00<000000?ooo`3oool0O03oool6000006X0oooo00<0
00000?ooo`3oool02`3oool002<0oooo00<000000?ooo`3oool0N@3oool6000001d0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`0;0?ooo`008`3oool2000007H0oooo1`00000L0?oo
o`H00000C@3oool2000000d0oooo000<0?ooo`8000005@3oool00`000000oooo0?ooo`1e0?ooo`@0
00003`3oool00`000000oooo0?ooo`030?ooo`H000000`3oool7000004h0oooo00<000000?ooo`3o
ool02`3oool000/0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`1d0?ooo`80
00004@3oool400000080oooo1`0000030?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool02`3oool000/0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`1c0?ooo`80
00004P3oool400000080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00/0oooo000<0?ooo`8000005@3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0140oooo0P00000F0?ooo`<00000BP3oool00`000000oooo0?ooo`0;0?ooo`008`3o
ool2000007<0oooo0P00000C0?ooo`8000005`3oool3000004P0oooo0P00000=0?ooo`002`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0L@3oool2
000001<0oooo0`00000H0?ooo`<00000B03oool00`000000oooo0?ooo`0;0?ooo`002`3oool60000
0180oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01P0oooo0`0000170?ooo`030000003oool0oooo00/0oooo000;0?ooo`060000003oool0oooo0000
003oool000004P3oool00`000000oooo0?ooo`1`0?ooo`800000<@3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00/0oooo000;0?ooo`040000003oool0oooo000001@0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool02`3oool000`0oooo0P00000E0?ooo`800000L03oool2000001<0oooo0P00000Q0?oo
o`030000003oool0oooo0440oooo0P00000=0?ooo`008`3oool00`000000oooo0?ooo`1^0?ooo`80
0000503oool200000240oooo0P0000130?ooo`030000003oool0oooo00/0oooo000;0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0C0?ooo`800000
8P3oool200000480oooo00<000000?ooo`3oool02`3oool000/0oooo0`00000E0?ooo`030000003o
ool0oooo06d0oooo0P00000E0?ooo`8000008`3oool200000440oooo00<000000?ooo`3oool02`3o
ool000h0oooo00<000000?ooo`3oool04P3oool2000006d0oooo0P00000F0?ooo`800000903oool0
0`000000oooo0?ooo`0n0?ooo`8000003@3oool000/0oooo00<000000?ooo`0000005@3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo01D0oooo0P00000T0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool02`3oool000/0oooo1000000D0?ooo`030000003oool0oooo06/0
oooo0P00000F0?ooo`800000:@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00/0
oooo000>0?ooo`030000003oool0oooo00@0oooo1@0000020?ooo`8000001@3oool00`000000oooo
0?ooo`1Z0?ooo`800000@@3oool3000003`0oooo00<000000?ooo`3oool02`3oool001L0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02T0oooo0`00000k0?ooo`030000
003oool0oooo00/0oooo00090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool2000006X0oooo
0P00000F0?ooo`<00000:`3oool3000003T0oooo0P00000=0?ooo`002@3oool6000000P0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
J03oool2000001L0oooo0P00000]0?ooo`<00000>@3oool00`000000oooo0?ooo`0;0?ooo`003P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool05@3oool3000002h0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0;0?ooo`005P3oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo06L0oooo0P00000G0?ooo`800000JP3oool00`000000oooo0?oo
o`0;0?ooo`008`3oool00`000000oooo0?ooo`1V0?ooo`800000603oool200000380oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`008`3oool2000006L0oooo00<000000?oo
o`3oool05P3oool300000380oooo00<000000?ooo`3oool0=03oool2000000d0oooo000=0?ooo`80
0000503oool00`000000oooo0?ooo`1U0?ooo`8000006@3oool00`000000oooo0?ooo`0a0?ooo`80
0000=P3oool00`000000oooo0?ooo`0;0?ooo`002`3oool010000000oooo00000000000D0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00/0oooo000;0?ooo`040000003oool00000000001@0oooo00<000000?ooo`3o
ool0I03oool2000004l0oooo0P00000e0?ooo`030000003oool0oooo00/0oooo000;0?ooo`@00000
503oool00`000000oooo0?ooo`1S0?ooo`800000603oool2000003L0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0;0?ooo`003P3oool00`000000oooo0?ooo`0B0?ooo`800000I03o
ool00`000000oooo0?ooo`0G0?ooo`800000=`3oool00`000000oooo0?ooo`0b0?ooo`8000003@3o
ool000/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1R0?ooo`8000006@3oool2
000006d0oooo00<000000?ooo`3oool02`3oool000X0oooo1000000E0?ooo`030000003oool0oooo
0640oooo0P00000J0?ooo`800000>P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00/0oooo000;0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool0H@3oool00`00
0000oooo0?ooo`0I0?ooo`800000>P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00/0oooo000;0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool0H03oool20000
01/0oooo0P00000j0?ooo`800000<@3oool00`000000oooo0?ooo`0;0?ooo`002`3oool00`000000
oooo0000000E0?ooo`800000H@3oool2000001X0oooo0P00000l0?ooo`800000;`3oool2000000d0
oooo000S0?ooo`030000003oool0oooo0600oooo0P00001I0?ooo`800000;`3oool00`000000oooo
0?ooo`0;0?ooo`008`3oool00`000000oooo0?ooo`1O0?ooo`<000006@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02`3oool002<0oooo00<00000
0?ooo`3oool0G`3oool2000001X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00/0oooo000;0?ooo`040000003oool0oooo000001@0oooo00<00000
0?ooo`3oool0G`3oool2000001T0oooo0P00001`0?ooo`030000003oool0oooo00/0oooo00090?oo
o`030000003oool0000000<00000503oool200000600oooo0P00000I0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0:P3oool2000000d0oooo000>0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0GP3oool3000001P0oooo0P0000130?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool02`3oool002<0oooo00<000000?ooo`3oool0GP3oool2000001T0oooo
00<000000?ooo`3oool0@P3oool2000002`0oooo00<000000?ooo`3oool02`3oool001D0oooo1@00
00020?ooo`8000001@3oool00`000000oooo0?ooo`1N0?ooo`8000006@3oool00`000000oooo0?oo
o`130?ooo`800000:`3oool00`000000oooo0?ooo`0;0?ooo`00303oool2000000T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0GP3o
ool200000600oooo0P00000Z0?ooo`030000003oool0oooo00/0oooo000;0?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`800000GP3o
ool300000640oooo00<000000?ooo`3oool09`3oool2000000d0oooo000;0?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0G@3o
ool2000001P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00/0oooo000<0?ooo`8000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0G@3oool2000001L0oooo0`00001c0?ooo`030000003oool0
oooo00/0oooo000F0?ooo`800000103oool3000000@0oooo00<000000?ooo`3oool0G@3oool20000
01L0oooo0P00001d0?ooo`030000003oool0oooo00/0oooo000;0?ooo`040000003oool0oooo0000
01@0oooo00<000000?ooo`3oool0G03oool3000001L0oooo0P00001;0?ooo`8000009`3oool00`00
0000oooo0?ooo`0;0?ooo`002`3oool4000001@0oooo0P00001M0?ooo`800000603oool2000004/0
oooo1@00000S0?ooo`8000003@3oool000/0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`1L0?ooo`8000005`3oool3000004/0oooo1P0000030?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool02`3oool000/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1L0?ooo`800000603oool00`000000oooo0?ooo`1?0?ooo`040000003oool0oooo0?ooo`L00000
6@3oool00`000000oooo0?ooo`0;0?ooo`00303oool3000001@0oooo00<000000?ooo`3oool0F`3o
ool3000006l0oooo1P00000I0?ooo`030000003oool0oooo00/0oooo000>0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0F`3oool2000001P0oooo00<000000?ooo`3oool0G@3oool4
000001<0oooo00<000000?ooo`3oool02`3oool002<0oooo0P00001L0?ooo`8000005`3oool00`00
0000oooo0?ooo`1N0?ooo`@000004P3oool2000000d0oooo000S0?ooo`030000003oool0oooo05/0
oooo0P00000G0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool02`3oool002<0oooo
00<000000?ooo`3oool0FP3oool3000001H0oooo0P00001g0?ooo`030000003oool0oooo00/0oooo
000S0?ooo`030000003oool0oooo05X0oooo0P00000G0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool02`3oool002<0oooo00<000000?ooo`3oool0FP3oool2000001H0oooo0P00001h
0?ooo`030000003oool0oooo00/0oooo000S0?ooo`800000F`3oool2000001H0oooo00<000000?oo
o`3oool0MP3oool2000000d0oooo000S0?ooo`030000003oool0oooo05T0oooo0`00000F0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool02`3oool000X0oooo1000000E0?ooo`030000
003oool0oooo05T0oooo0P00002A0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1I0?ooo`800000T@3o
ool00`000000oooo0?ooo`0;0?ooo`002@3oool01P000000oooo0?ooo`000000oooo000001@0oooo
00<000000?ooo`3oool0F@3oool2000001H0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`0;0?ooo`002@3oool00`000000oooo0?ooo`02000001D0oooo0P00001I0?ooo`<000005P3o
ool00`000000oooo0?ooo`1g0?ooo`8000003@3oool000`0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1H0?ooo`8000005P3oool2000007X0oooo00<000000?ooo`3oool02`3oool0
02<0oooo00<000000?ooo`3oool0F03oool2000001H0oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`0;0?ooo`002`3oool010000000oooo0?ooo`0000060?ooo`@000000`3oool20000
00D0oooo00<000000?ooo`3oool0F03oool2000001D0oooo0P00001k0?ooo`030000003oool0oooo
00/0oooo000;0?ooo`@000001P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0E`3oool3000001D0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0;0?ooo`002`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool2000005P0oooo0P00000F0?ooo`030000003oool0
oooo07T0oooo0P00000=0?ooo`002`3oool010000000oooo0?ooo`0000080?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo0P00
002C0?ooo`030000003oool0oooo00/0oooo000E0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1F0?ooo`<00000T`3oool00`000000oooo
0?ooo`0;0?ooo`005P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05H0oooo0P00
000F0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool02`3oool000`0oooo0P00000E
0?ooo`030000003oool0oooo05H0oooo0P00000F0?ooo`030000003oool0oooo07/0oooo00<00000
0?ooo`3oool02`3oool000/0oooo00@000000?ooo`3oool00000503oool2000005L0oooo0P00000E
0?ooo`800000O03oool2000000d0oooo000;0?ooo`040000003oool0oooo000001@0oooo00<00000
0?ooo`3oool0E@3oool3000001D0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0;
0?ooo`00303oool2000001D0oooo00<000000?ooo`3oool0E@3oool2000001D0oooo0P00001n0?oo
o`030000003oool0oooo00/0oooo000S0?ooo`030000003oool0oooo05D0oooo0P00000E0?ooo`03
0000003oool0oooo07d0oooo00<000000?ooo`3oool02`3oool000/0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`1E0?ooo`8000005@3oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo00/0oooo000;0?ooo`<000005@3oool2000005D0oooo0`00002D0?ooo`8000003@3o
ool000/0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`1D0?ooo`800000UP3o
ool00`000000oooo0?ooo`0;0?ooo`00303oool2000001D0oooo00<000000?ooo`3oool0E03oool2
000009H0oooo00<000000?ooo`3oool02`3oool000/0oooo00@000000?ooo`3oool00000503oool0
0`000000oooo0?ooo`1D0?ooo`8000004`3oool200000840oooo00<000000?ooo`3oool02`3oool0
00/0oooo0`00000E0?ooo`800000E03oool3000001<0oooo0P0000200?ooo`8000003@3oool000/0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1C0?ooo`800000503oool200000840
oooo00<000000?ooo`3oool02`3oool000X0oooo1000000E0?ooo`030000003oool0oooo05<0oooo
0P00000D0?ooo`800000P@3oool00`000000oooo0?ooo`0;0?ooo`002`3oool010000000oooo0?oo
o`00000D0?ooo`030000003oool0oooo05<0oooo0P00000D0?ooo`800000P@3oool00`000000oooo
0?ooo`0;0?ooo`002`3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo0580oooo
0`00000D0?ooo`800000P@3oool00`000000oooo0?ooo`0;0?ooo`002`3oool00`000000oooo0000
000E0?ooo`800000D`3oool2000001@0oooo0P0000210?ooo`8000003@3oool002<0oooo00<00000
0?ooo`3oool0DP3oool2000009P0oooo00<000000?ooo`3oool02`3oool000T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0580oooo0P00002H0?oo
o`030000003oool0oooo00/0oooo00090?ooo`H000001P3oool4000000<0oooo0P0000050?ooo`03
0000003oool0oooo0540oooo0`00000B0?ooo`800000Q03oool00`000000oooo0?ooo`0;0?ooo`00
2`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1A0?ooo`8000004`3oool2000008@0oooo00<000000?oo
o`3oool02`3oool000/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo0P00001B0?ooo`8000004`3oool2000008<0oooo0P00000=0?ooo`00
303oool3000000P0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0
D@3oool2000001<0oooo0P0000240?ooo`030000003oool0oooo00/0oooo000>0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0500oooo0`00000C0?ooo`800000Q03oool00`000000oooo0?ooo`0;0?ooo`005P3o
ool2000000@0oooo0`0000040?ooo`030000003oool0oooo0500oooo0P00000D0?ooo`800000Q03o
ool00`000000oooo0?ooo`0;0?ooo`008`3oool00`000000oooo0?ooo`1@0?ooo`8000004`3oool2
000008D0oooo00<000000?ooo`3oool02`3oool002<0oooo0P00001A0?ooo`800000V@3oool20000
00d0oooo000S0?ooo`030000003oool0oooo04l0oooo0`00002J0?ooo`030000003oool0oooo00/0
oooo000S0?ooo`030000003oool0oooo04l0oooo0P00000B0?ooo`800000Q`3oool00`000000oooo
0?ooo`0;0?ooo`008`3oool00`000000oooo0?ooo`1?0?ooo`8000004P3oool2000008L0oooo00<0
00000?ooo`3oool02`3oool002<0oooo00<000000?ooo`3oool0C`3oool200000180oooo0P000027
0?ooo`030000003oool0oooo00/0oooo000S0?ooo`800000C`3oool300000180oooo0P0000260?oo
o`8000003@3oool002<0oooo00<000000?ooo`3oool0CP3oool2000001<0oooo0P0000270?ooo`03
0000003oool0oooo00/0oooo000S0?ooo`030000003oool0oooo04h0oooo0P00000C0?ooo`800000
Q`3oool00`000000oooo0?ooo`0;0?ooo`008`3oool00`000000oooo0?ooo`1>0?ooo`8000004P3o
ool2000008P0oooo00<000000?ooo`3oool02`3oool002<0oooo00<000000?ooo`3oool0C@3oool3
000009`0oooo00<000000?ooo`3oool02`3oool002<0oooo0P00001>0?ooo`800000W03oool20000
00d0oooo000S0?ooo`030000003oool0oooo04d0oooo0P00000A0?ooo`800000RP3oool00`000000
oooo0?ooo`0;0?ooo`008`3oool00`000000oooo0?ooo`1=0?ooo`8000004@3oool2000008X0oooo
00<000000?ooo`3oool02`3oool002<0oooo00<000000?ooo`3oool0>@3ooolG000000<0oooo1`00
00020?ooo`H00000RP3oool00`000000oooo0?ooo`0;0?ooo`008`3oool00`000000oooo0?ooo`0@
0?oood0000000`3oool700000080oooo1P00002:0?ooo`030000003oool0oooo00/0oooo000S0?oo
o`8000004@3oool]00000:h0oooo0P00000=0?ooo`008`3oool00`000000oooo0?ooo`3/0?ooo`03
0000003oool0oooo00/0oooo000S0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0
2`3oool001H0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`3/0?ooo`030000003o
ool0oooo00/0oooo000E0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0;0?ooo`005`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oooo`000000d0oooo000H0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0o`3oool001D0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00003o0?ooo`80oooo000F0?ooo`800000103oool200000?l0oooo0`3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.77454, -4.98115, \
0.0501504, 0.202863}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0.0561849 0.561849 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .05618 -6 -4.5 ]
[-0.0125 .05618 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .28092 -18 -4.5 ]
[-0.0125 .28092 0 4.5 ]
[-0.0125 .39329 -18 -4.5 ]
[-0.0125 .39329 0 4.5 ]
[-0.0125 .50566 -18 -4.5 ]
[-0.0125 .50566 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -50 ]
[-0.01875 .30902 -18 50 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05618 m
.00625 .05618 L
s
[(0)] -0.0125 .05618 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.2)] -0.0125 .16855 1 0 Mshowa
0 .28092 m
.00625 .28092 L
s
[(0.4)] -0.0125 .28092 1 0 Mshowa
0 .39329 m
.00625 .39329 L
s
[(0.6)] -0.0125 .39329 1 0 Mshowa
0 .50566 m
.00625 .50566 L
s
[(0.8)] -0.0125 .50566 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .47757 m
.00375 .47757 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
0 .58994 m
.00375 .58994 L
s
0 .02809 m
.00375 .02809 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
111 10.2813 translate
90 rotate
-111 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Working) show
111.000 12.813 moveto
(Children) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05618 m
1 .05618 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .28092 m
1 .28092 L
s
.99375 .39329 m
1 .39329 L
s
.99375 .50566 m
1 .50566 L
s
.125 Mabswid
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.99625 .58994 m
1 .58994 L
s
.99625 .02809 m
1 .02809 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61475 L
.25 .61245 L
.33333 .61083 L
.41667 .55222 L
.5 .47781 L
.58333 .05618 L
.66667 .05618 L
.75 .05618 L
.83333 .05618 L
.91667 .05618 L
s
.0001 w
.08333 .61803 m
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L closepath F
.16667 .61475 m
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L closepath F
.25 .61245 m
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L closepath F
.33333 .61083 m
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L closepath F
.41667 .55222 m
.41667 .55222 L
.41667 .55222 L
.41667 .55222 L
.41667 .55222 L
.41667 .55222 L
.41667 .55222 L
.41667 .55222 L
.41667 .55222 L
.41667 .55222 L
.41667 .55222 L closepath F
.5 .47781 m
.5 .47781 L
.5 .47781 L
.5 .47781 L
.5 .47781 L
.5 .47781 L
.5 .47781 L
.5 .47781 L
.5 .47781 L
.5 .47781 L
.5 .47781 L closepath F
.58333 .05618 m
.58333 .05618 L
.58333 .05618 L
.58333 .05618 L
.58333 .05618 L
.58333 .05618 L
.58333 .05618 L
.58333 .05618 L
.58333 .05618 L
.58333 .05618 L
.58333 .05618 L closepath F
.66667 .05618 m
.66667 .05618 L
.66667 .05618 L
.66667 .05618 L
.66667 .05618 L
.66667 .05618 L
.66667 .05618 L
.66667 .05618 L
.66667 .05618 L
.66667 .05618 L
.66667 .05618 L closepath F
.75 .05618 m
.75 .05618 L
.75 .05618 L
.75 .05618 L
.75 .05618 L
.75 .05618 L
.75 .05618 L
.75 .05618 L
.75 .05618 L
.75 .05618 L
.75 .05618 L closepath F
.83333 .05618 m
.83333 .05618 L
.83333 .05618 L
.83333 .05618 L
.83333 .05618 L
.83333 .05618 L
.83333 .05618 L
.83333 .05618 L
.83333 .05618 L
.83333 .05618 L
.83333 .05618 L closepath F
.91667 .05618 m
.91667 .05618 L
.91667 .05618 L
.91667 .05618 L
.91667 .05618 L
.91667 .05618 L
.91667 .05618 L
.91667 .05618 L
.91667 .05618 L
.91667 .05618 L
.91667 .05618 L closepath F
.01 w
[ .02 ] 0 setdash
.08333 .61803 m
.16667 .61475 L
.25 .61245 L
.33333 .61083 L
.41667 .60968 L
.5 .56877 L
.58333 .49189 L
.66667 .43263 L
.75 .41828 L
.83333 .44777 L
.91667 .47041 L
s
.0001 w
[ ] 0 setdash
.08333 .61803 m
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L
.08333 .61803 L closepath F
.16667 .61475 m
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L
.16667 .61475 L closepath F
.25 .61245 m
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L
.25 .61245 L closepath F
.33333 .61083 m
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L
.33333 .61083 L closepath F
.41667 .60968 m
.41667 .60968 L
.41667 .60968 L
.41667 .60968 L
.41667 .60968 L
.41667 .60968 L
.41667 .60968 L
.41667 .60968 L
.41667 .60968 L
.41667 .60968 L
.41667 .60968 L closepath F
.5 .56877 m
.5 .56877 L
.5 .56877 L
.5 .56877 L
.5 .56877 L
.5 .56877 L
.5 .56877 L
.5 .56877 L
.5 .56877 L
.5 .56877 L
.5 .56877 L closepath F
.58333 .49189 m
.58333 .49189 L
.58333 .49189 L
.58333 .49189 L
.58333 .49189 L
.58333 .49189 L
.58333 .49189 L
.58333 .49189 L
.58333 .49189 L
.58333 .49189 L
.58333 .49189 L closepath F
.66667 .43263 m
.66667 .43263 L
.66667 .43263 L
.66667 .43263 L
.66667 .43263 L
.66667 .43263 L
.66667 .43263 L
.66667 .43263 L
.66667 .43263 L
.66667 .43263 L
.66667 .43263 L closepath F
.75 .41828 m
.75 .41828 L
.75 .41828 L
.75 .41828 L
.75 .41828 L
.75 .41828 L
.75 .41828 L
.75 .41828 L
.75 .41828 L
.75 .41828 L
.75 .41828 L closepath F
.83333 .44777 m
.83333 .44777 L
.83333 .44777 L
.83333 .44777 L
.83333 .44777 L
.83333 .44777 L
.83333 .44777 L
.83333 .44777 L
.83333 .44777 L
.83333 .44777 L
.83333 .44777 L closepath F
.91667 .47041 m
.91667 .47041 L
.91667 .47041 L
.91667 .47041 L
.91667 .47041 L
.91667 .47041 L
.91667 .47041 L
.91667 .47041 L
.91667 .47041 L
.91667 .47041 L
.91667 .47041 L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00T`3oool3000000@0oooo0`00
00001`3oool000000000003oool000000?ooo`0000000P3oool3000007L0oooo002D0?ooo`030000
003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
001j0?ooo`00U03oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo0?ooo`000000oooo
0000003oool000000?ooo`@00000M`3oool009@0oooo00<000000?ooo`3oool00`3oool200000080
oooo0`0000000`3oool000000?ooo`020?ooo`800000N03oool00980oooo00D000000?ooo`000000
oooo000000290?ooo`00TP3oool5000000@0oooo00<000000?ooo`3oool0PP3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool004`0oooo1000000V0?ooo`<000008`3oool3000002D0
oooo0P00000R0?ooo`D000000P3oool2000001l0oooo1@0000000`3oool0000000000002000000H0
oooo001<0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool08P3oool010000000oooo
0?ooo`00000S0?ooo`040000003oool0oooo000002<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo000000090?ooo`00C@3oool0
0`000000oooo0?ooo`0T0?ooo`D000008`3oool010000000oooo0?ooo`00000S0?ooo`040000003o
ool0oooo000002<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`00CP3oool00`000000oooo
0?ooo`0S0?ooo`040000003oool0oooo000002@0oooo0`00000U0?ooo`800000903oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo001<0?ooo`040000003oool0oooo000002D0oooo00<000000?oo
o`0000009@3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000002<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00@0oooo001=0?ooo`8000009`3oool2000002D0oooo0`00
000T0?ooo`8000008`3oool2000000@0oooo0P00000P0?ooo`800000103oool2000000L0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000V
0?oooo0000002P3oool002H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0203oool002H0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`009P3o
ool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0
oooo0>`0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0k03oool00`00
0000oooo0?ooo`080?ooo`009P3oool200000>`0oooo0P00000:0?ooo`009P3oool00`000000oooo
0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo0>`0oooo00<0
00000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`08
0?ooo`009P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000O0?ooo`80
00001@3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo00P0oooo000N0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`080?ooo`00
7P3oool010000000oooo0?ooo`0000040?ooo`800000R03ooomB00000180oooo0P00000:0?ooo`00
7P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo08L0ooooDP00000C0?ooo`03
0000003oool0oooo00P0oooo000N0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0Q`3oool2000006<0oooo00<000000?ooo`3oool0203oool001l0oooo0P0000050?ooo`030000
003oool0oooo08L0oooo0P00001S0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003o
ool0oooo08L0oooo0P00001S0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0
oooo08L0oooo0P00001S0?ooo`030000003oool0oooo00P0oooo000V0?ooo`800000Q`3oool20000
06<0oooo0P00000:0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`800000I03oool00`000000
oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`260?ooo`800000I03oool00`000000oooo
0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`260?ooo`800000I03oool00`000000oooo0?oo
o`080?ooo`009P3oool00`000000oooo0?ooo`260?ooo`800000I03oool00`000000oooo0?ooo`08
0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`800000I@3oool00`000000oooo0?ooo`080?oo
o`009P3oool00`000000oooo0?ooo`250?ooo`800000I@3oool00`000000oooo0?ooo`080?ooo`00
1P3oool00`000000oooo0?ooo`0M0?ooo`800000QP3oool2000006@0oooo0P00000:0?ooo`001P3o
ool5000001/0oooo00<000000?ooo`3oool0Q@3oool2000006D0oooo00<000000?ooo`3oool0203o
ool000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo08D0oooo0P00001U0?ooo`030000003oool0oooo00P0oooo00080?ooo`<000006`3oool00`00
0000oooo0?ooo`240?ooo`800000IP3oool00`000000oooo0?ooo`080?ooo`001P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0Q03oool2000006H0
oooo00<000000?ooo`3oool0203oool000H0oooo1@00000K0?ooo`030000003oool0oooo08@0oooo
0P00001V0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo08@0oooo0P00
001V0?ooo`030000003oool0oooo00P0oooo00090?ooo`8000006`3oool2000008D0oooo0P00001U
0?ooo`8000002P3oool000P0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`24
0?ooo`800000IP3oool00`000000oooo0?ooo`080?ooo`00203oool010000000oooo0?ooo`00000J
0?ooo`030000003oool0oooo08<0oooo0P00001W0?ooo`030000003oool0oooo00P0oooo00090?oo
o`8000006`3oool00`000000oooo0?ooo`230?ooo`800000I`3oool00`000000oooo0?ooo`080?oo
o`004`3oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`230?ooo`80
0000I`3oool00`000000oooo0?ooo`080?ooo`004P3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0P`3oool2000006L0oooo00<000000?ooo`3o
ool0203oool000P0oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00@0oooo0P0000240?ooo`800000IP3oool2000000X0oooo00080?ooo`@0
00001P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0PP3oool2000006P0oooo00<000000?ooo`3oool0203oool000P0oooo00@000000?ooo`3o
ool000001P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0PP3oool2000006P0oooo00<000000?ooo`3oool0203oool000P0oooo00@00000
0?ooo`3oool000001`3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0880oooo0P00
001X0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo0880oooo0P00001X
0?ooo`030000003oool0oooo00P0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`220?ooo`800000J03oool00`000000oooo0?ooo`080?oo
o`001P3oool6000001X0oooo00<000000?ooo`3oool0P@3oool2000006T0oooo00<000000?ooo`3o
ool0203oool000T0oooo00<000000?ooo`3oool06P3oool200000880oooo0P00001X0?ooo`800000
2P3oool000P0oooo1000000J0?ooo`030000003oool0oooo0840oooo0P00001Y0?ooo`030000003o
ool0oooo00P0oooo00080?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0P@3o
ool2000006T0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0P@3oool2
000006T0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0P03oool20000
06X0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0P03oool2000006X0
oooo00<000000?ooo`3oool0203oool000P0oooo00@000000?ooo`3oool000006P3oool00`000000
oooo0?ooo`200?ooo`800000JP3oool00`000000oooo0?ooo`080?ooo`001P3oool00`000000oooo
00000003000001X0oooo0P0000210?ooo`800000J@3oool2000000X0oooo000;0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0P03oool2000006X0oooo00<000000?ooo`3oool0203o
ool002H0oooo00<000000?ooo`3oool0P03oool2000006X0oooo00<000000?ooo`3oool0203oool0
00P0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1o0?ooo`800000J`3oool0
0`000000oooo0?ooo`080?ooo`00203oool4000001X0oooo00<000000?ooo`3oool0O`3oool20000
06/0oooo00<000000?ooo`3oool0203oool000P0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`1o0?ooo`800000J`3oool00`000000oooo0?ooo`080?ooo`00203oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo07l0oooo0P00001[0?ooo`030000003oool0oooo00P0oooo
00090?ooo`<000006P3oool200000800oooo0P00001Z0?ooo`8000002P3oool000/0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`1n0?ooo`800000K03oool00`000000oooo0?ooo`08
0?ooo`009P3oool00`000000oooo0?ooo`1n0?ooo`800000K03oool00`000000oooo0?ooo`080?oo
o`002@3oool200000080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1n0?ooo`80
0000K03oool00`000000oooo0?ooo`080?ooo`00203oool01P000000oooo0?ooo`000000oooo0000
00D0oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3oool0OP3oool20000
06`0oooo00<000000?ooo`3oool0203oool000P0oooo00H000000?ooo`3oool000000?ooo`000004
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1n0?ooo`800000K03oool00`000000oooo0?ooo`080?ooo`00203oool5000000D0oooo00@00000
0?ooo`3oool00000203oool5000000<0oooo0P00001n0?ooo`800000K03oool2000000X0oooo0008
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo07d0oooo0P00001]0?ooo`030000003oool0oooo00P0oooo
000B0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`1m0?ooo`800000K@3oool00`000000oooo0?ooo`080?ooo`004`3oool2000000/0oooo0P00
00040?ooo`030000003oool0oooo07d0oooo0P00001]0?ooo`030000003oool0oooo00P0oooo000V
0?ooo`030000003oool0oooo07d0oooo0P00001]0?ooo`030000003oool0oooo00P0oooo000V0?oo
o`030000003oool0oooo07`0oooo0P00001^0?ooo`030000003oool0oooo00P0oooo000V0?ooo`03
0000003oool0oooo07`0oooo0P00001^0?ooo`030000003oool0oooo00P0oooo000V0?ooo`800000
O@3oool2000006d0oooo0P00000:0?ooo`009P3oool00`000000oooo0?ooo`1l0?ooo`800000KP3o
ool00`000000oooo0?ooo`080?ooo`001`3oool4000001/0oooo00<000000?ooo`3oool0O03oool2
000006h0oooo00<000000?ooo`3oool0203oool000H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo07`0oooo0P00001^0?ooo`030000003oool0oooo
00P0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1k0?ooo`800000K`3oool00`000000oooo0?ooo`080?ooo`001P3oool2000000<0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1k0?ooo`800000K`3oool00`000000oooo
0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`1k0?ooo`800000K`3oool00`000000oooo0?oo
o`080?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo0P00001l
0?ooo`800000KP3oool2000000X0oooo00060?ooo`H000006P3oool00`000000oooo0?ooo`1k0?oo
o`800000K`3oool00`000000oooo0?ooo`080?ooo`00203oool010000000oooo0?ooo`00000J0?oo
o`030000003oool0oooo07X0oooo0P00001`0?ooo`030000003oool0oooo00P0oooo00080?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0NP3oool200000700oooo00<000000?ooo`3o
ool0203oool000T0oooo0`00000J0?ooo`030000003oool0oooo07X0oooo0P00001`0?ooo`030000
003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0NP3o
ool200000700oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0NP3oool2
00000700oooo00<000000?ooo`3oool0203oool002H0oooo0P00001j0?ooo`800000L03oool20000
00X0oooo00080?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0N@3oool20000
0740oooo00<000000?ooo`3oool0203oool000H0oooo00<000000?ooo`0000000`00000J0?ooo`03
0000003oool0oooo07T0oooo0P00001a0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0N@3oool200000740oooo00<000000?ooo`3oool0
203oool001<0oooo0P0000040?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0N@3o
ool200000740oooo00<000000?ooo`3oool0203oool00180oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07P0oooo0P00001b0?ooo`030000
003oool0oooo00P0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P00001i0?ooo`80
0000L@3oool2000000X0oooo00060?ooo`H000001P3oool010000000oooo0?ooo`0000080?ooo`<0
00001@3oool00`000000oooo0?ooo`1h0?ooo`800000LP3oool00`000000oooo0?ooo`080?ooo`00
2`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1h0?ooo`800000LP3oool00`000000oooo0?ooo`080?ooo`00
4`3oool2000000X0oooo0`0000040?ooo`030000003oool0oooo07P0oooo0P00001b0?ooo`030000
003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo07P0oooo0P00001b0?ooo`030000003o
ool0oooo00P0oooo000V0?ooo`030000003oool0oooo07L0oooo0P00000g0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0203oool000T0oooo0P00000K0?ooo`030000003oool0oooo
07L0oooo0P00000f0?ooo`D00000>03oool00`000000oooo0?ooo`080?ooo`00203oool010000000
oooo0?ooo`00000J0?ooo`800000N03oool2000002`0oooo1P0000030?ooo`L00000=P3oool20000
00X0oooo00060?ooo`030000003oool000000080oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1g0?ooo`800000:`3oool7000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0203oool000H0oooo1P00000J0?ooo`03
0000003oool0oooo07L0oooo0P00000S0?ooo`H000000P3oool00`000000oooo0?ooo`0@0?ooo`@0
0000<@3oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo07H0oooo0P00000S0?ooo`L000005P3oool5000002l0oooo00<000000?ooo`3oool0
203oool002H0oooo00<000000?ooo`3oool0MP3oool2000002<0oooo00<000000?ooo`3oool0703o
ool4000000<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`00203oool0
10000000oooo0?ooo`00000J0?ooo`030000003oool0oooo07H0oooo0P00000P0?ooo`030000003o
ool0oooo0240oooo00@000000?ooo`3oool0oooo1@00000W0?ooo`030000003oool0oooo00P0oooo
00080?ooo`@000006P3oool00`000000oooo0?ooo`1f0?ooo`8000007P3oool4000002L0oooo1@00
000V0?ooo`030000003oool0oooo00P0oooo00080?ooo`040000003oool0oooo000001X0oooo0P00
001g0?ooo`800000703oool5000002/0oooo0`0000020?ooo`030000003oool0oooo01l0oooo0P00
000:0?ooo`00203oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo07D0oooo0P00
000L0?ooo`@00000;P3oool010000000oooo0?ooo`3oool7000001`0oooo00<000000?ooo`3oool0
203oool002H0oooo00<000000?ooo`3oool0M@3oool2000001d0oooo00<000000?ooo`3oool0<`3o
ool6000000<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`009P3oool0
0`000000oooo0?ooo`1e0?ooo`8000006@3oool00`000000oooo0?ooo`0o0?ooo`@000005P3oool0
0`000000oooo0?ooo`080?ooo`002@3oool2000001/0oooo00<000000?ooo`3oool0M@3oool20000
01P0oooo0`0000110?ooo`H000004`3oool00`000000oooo0?ooo`080?ooo`00203oool200000003
0?ooo`000000oooo01T0oooo00<000000?ooo`3oool0M@3oool2000001H0oooo100000140?ooo`D0
00004P3oool00`000000oooo0?ooo`080?ooo`00203oool2000000030?ooo`000000oooo01T0oooo
0P00001e0?ooo`8000005P3oool4000004P0oooo00<000000?ooo`3oool0403oool2000000X0oooo
00090?ooo`030000003oool0000001X0oooo00<000000?ooo`3oool0L`3oool3000001D0oooo0`00
001N0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo0780oooo0`00000G
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0203oool000P0oooo00@000000?oo
o`3oool000006P3oool00`000000oooo0?ooo`1a0?ooo`<00000503oool00`000000oooo0?ooo`1Q
0?ooo`030000003oool0oooo00P0oooo00080?ooo`@000006P3oool00`000000oooo0?ooo`1_0?oo
o`@00000503oool300000680oooo00<000000?ooo`3oool0203oool000P0oooo00<000000?ooo`3o
ool0203oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1^0?ooo`@0
0000503oool400000680oooo00<000000?ooo`3oool0203oool000P0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0K@3oool3000001D0oooo0`00001T0?ooo`030000003oool0oooo00P0oooo00090?ooo`<0
00001P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P00001]
0?ooo`<000005@3oool3000006@0oooo0P00000:0?ooo`002`3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo06/0oooo0`00000G
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0203oool00180oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06X0oooo0`00
000D0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0203oool001<0oooo0P00000:
0?ooo`8000001@3oool00`000000oooo0?ooo`1Y0?ooo`<000005@3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo06P0oooo0`00000E0?oo
o`800000JP3oool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`1W0?ooo`<0
00005@3oool2000006/0oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0
I@3oool4000001D0oooo0P00001/0?ooo`030000003oool0oooo00P0oooo000V0?ooo`800000I@3o
ool4000001H0oooo00<000000?ooo`3oool0JP3oool2000000X0oooo000V0?ooo`030000003oool0
oooo06<0oooo0`00000H0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0203oool0
02H0oooo00<000000?ooo`3oool0HP3oool3000001D0oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`1Q0?ooo`<000005@3oool300000700
oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0H03oool3000001D0oooo
0`00001a0?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003oool0oooo05h0oooo1000
000E0?ooo`<00000LP3oool00`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`1M
0?ooo`@000005@3oool3000007<0oooo00<000000?ooo`3oool0203oool002H0oooo0P00001L0?oo
o`@00000603oool00`000000oooo0?ooo`1a0?ooo`8000002P3oool002H0oooo00<000000?ooo`3o
ool0FP3oool4000001D0oooo00<000000?ooo`000000MP3oool00`000000oooo0?ooo`080?ooo`00
9P3oool00`000000oooo0?ooo`1H0?ooo`@000005@3oool4000007L0oooo00<000000?ooo`3oool0
203oool002H0oooo00<000000?ooo`3oool0E`3oool4000001@0oooo1@00001h0?ooo`030000003o
ool0oooo00P0oooo000V0?ooo`030000003oool0oooo05H0oooo0`00000E0?ooo`@00000NP3oool0
0`000000oooo0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`1D0?ooo`@000004`3oool01@00
0000oooo0?ooo`3oool0000007`0oooo00<000000?ooo`3oool0203oool002H0oooo0P00001D0?oo
o`@000004@3oool5000007h0oooo0P00000:0?ooo`009P3oool00`000000oooo0?ooo`1A0?ooo`@0
00004@3oool600000800oooo00<000000?ooo`3oool0203oool002H0oooo00<000000?ooo`3oool0
D03oool400000140oooo100000230?ooo`030000003oool0oooo00P0oooo000V0?ooo`030000003o
ool0oooo04h0oooo1000000@0?ooo`050000003oool0oooo0?ooo`000000Q@3oool00`000000oooo
0?ooo`080?ooo`009P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo1000
000@0?ooo`<00000R03oool00`000000oooo0?ooo`080?ooo`007P3oool5000000<0oooo00<00000
0?ooo`3oool0>@3ooolG000000<0oooo1`0000020?ooo`L00000R@3oool00`000000oooo0?ooo`08
0?ooo`00803oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3ooolo000000<0oooo1`0000020?ooo`H000002@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo000P0?ooo`030000003oool0oooo00<0ooool000000:0?ooo`00
803oool00`000000oooo0?ooo`0F0?ooo`L000000P3oool00`000000oooo0?ooo`3K0?ooo`00803o
ool00`000000oooo0?ooo`3m0?ooo`007`3oool200000?l0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.92499, -0.282642, \
0.0501504, 0.00743829}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetDirectory["\<C:\Documents and Settings\doepke\My \
Documents\sync\mathematica\>"]\), "\[IndentingNewLine]", 
    \(\(Export["\<plot1.eps\>", 
        plot1, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<plot2.eps\>", 
        plot2, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<plot3.eps\>", plot3, "\<EPS\>"];\)\)}], "Input"],

Cell[BoxData[
    \("C:\\Documents and Settings\\doepke\\My \
Documents\\sync\\mathematica"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plot1 = 
        ListPlot[wsout/wuout, PlotRange \[Rule] {{0, 12}, {2, 7}}, 
          PlotStyle \[Rule] Thickness[0.01], AxesOrigin \[Rule] {0, 0}, 
          Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time\>", "\<Wage Ratio\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(plot2 = 
        ListPlot[popout, PlotRange \[Rule] {{0, 12}, {0, 30}}, 
          PlotStyle \[Rule] Thickness[0.01], AxesOrigin \[Rule] {0, 0}, 
          Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time\>", "\<Population Growth\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(plot3 = 
        ListPlot[clout, PlotRange \[Rule] {{0, 12}, {\(- .1\), 1}}, 
          PlotStyle \[Rule] Thickness[0.01], AxesOrigin \[Rule] {0, 0}, 
          Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<Time\>", "\<Working Children\>"}];\)\)}], \
"Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.247214 0.123607 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -18.5625 -32 ]
[-0.01875 .30902 -6 32 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(3)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(5)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(6)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(7)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -105.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
93 10.2813 translate
90 rotate
-93 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Wage) show
93.000 12.813 moveto
(Ratio) show
123.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .02472 m
1 .02472 L
s
.99625 .04944 m
1 .04944 L
s
.99625 .07416 m
1 .07416 L
s
.99625 .09889 m
1 .09889 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .17305 m
1 .17305 L
s
.99625 .19777 m
1 .19777 L
s
.99625 .22249 m
1 .22249 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .29666 m
1 .29666 L
s
.99625 .32138 m
1 .32138 L
s
.99625 .3461 m
1 .3461 L
s
.99625 .39554 m
1 .39554 L
s
.99625 .42026 m
1 .42026 L
s
.99625 .44498 m
1 .44498 L
s
.99625 .46971 m
1 .46971 L
s
.99625 .51915 m
1 .51915 L
s
.99625 .54387 m
1 .54387 L
s
.99625 .56859 m
1 .56859 L
s
.99625 .59331 m
1 .59331 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05719 m
.16667 .05656 L
.25 .12752 L
.33333 .20914 L
.41667 .30543 L
.5 .40726 L
.58333 .47167 L
.66667 .51319 L
.75 .4814 L
.83333 .4252 L
.91667 .40151 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{272.625, 168.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004@0000Z2000`400?l00000o`00003oo`3ooolA
0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00Q@3oool3
000000@0oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool3000007D0oooo
00260?ooo`030000003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000001h0?ooo`00QP3oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`@00000M@3oool008H0oooo00<000000?ooo`3oool0
0`3oool200000080oooo0`0000000`3oool000000?ooo`020?ooo`800000MP3oool008@0oooo00D0
00000?ooo`000000oooo000000270?ooo`00Q03oool5000000@0oooo00<000000?ooo`3oool0P03o
ool00?l0oooo4@3oool00?l0oooo4@3oool00?l0oooo4@3oool004<0oooo1000000S0?ooo`<00000
8@3oool3000002<0oooo0P00000O0?ooo`D000000P3oool2000001d0oooo1@0000000`3oool00000
00000002000000/0oooo00130?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0803o
ool010000000oooo0?ooo`00000Q0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo0000000>
0?ooo`00A03oool00`000000oooo0?ooo`0Q0?ooo`D000008@3oool010000000oooo0?ooo`00000Q
0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`00A@3o
ool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo00000280oooo0`00000S0?ooo`800000
8@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00130?ooo`040000003oool0oooo00000280
oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo0000
0200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00140?ooo`800000903oool2
000002<0oooo0`00000R0?ooo`800000803oool2000000@0oooo0P00000N0?ooo`800000103oool2
000000`0oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo000P
0?ooon4000003`3oool00200oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool03@3oool00200oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0=0?ooo`00803o
ool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00d0oooo000P0?ooo`030000003oool0
oooo0=d0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0g03oool20000
00l0oooo000P0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool03@3oool00200oooo
00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?oo
o`3M0?ooo`030000003oool0oooo00d0oooo000P0?ooo`030000003oool0oooo0=d0oooo00<00000
0?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0=0?oo
o`00803oool00`000000oooo0?ooo`3L0?ooo`8000003`3oool00200oooo00<000000?ooo`3oool0
3P3ooolF00000;T0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool03P3o
oolG00000;P0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool08`3oool4
00000;H0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0903oool40000
0;D0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool09P3oool300000;<0
oooo0P00000?0?ooo`00803oool00`000000oooo0?ooo`0W0?ooo`<00000/`3oool00`000000oooo
0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`0X0?ooo`<00000/P3oool00`000000oooo0?oo
o`0=0?ooo`00803oool00`000000oooo0?ooo`0Y0?ooo`<00000/@3oool00`000000oooo0?ooo`0=
0?ooo`00803oool00`000000oooo0?ooo`0Z0?ooo`@00000[`3oool00`000000oooo0?ooo`0=0?oo
o`00803oool00`000000oooo0?ooo`0[0?ooo`@00000[P3oool00`000000oooo0?ooo`0=0?ooo`00
803oool00`000000oooo0?ooo`0]0?ooo`<00000[03oool2000000l0oooo000P0?ooo`030000003o
ool0oooo02h0oooo0`00002/0?ooo`030000003oool0oooo00d0oooo000P0?ooo`030000003oool0
oooo02l0oooo0`00002[0?ooo`030000003oool0oooo00d0oooo000I0?ooo`8000001@3oool00`00
0000oooo0?ooo`0`0?ooo`@00000Z@3oool00`000000oooo0?ooo`0=0?ooo`00603oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0340oooo1000002X0?ooo`030000003oool0oooo
00d0oooo000J0?ooo`030000003oool0oooo00<0oooo0P00000d0?ooo`<00000Y@3oool3000000l0
oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03oool300000:H0oooo
00<000000?ooo`3oool03@3oool001P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0e0?ooo`<00000Y@3oool00`000000oooo0?ooo`0=0?ooo`006@3oool2000000D0oooo00<0
00000?ooo`3oool0=P3oool300000:@0oooo00<000000?ooo`3oool03@3oool00200oooo00<00000
0?ooo`3oool0=`3oool300000:<0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?oo
o`3oool0>03oool300000:80oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3o
ool0>@3oool300000:00oooo0P00000?0?ooo`00803oool00`000000oooo0?ooo`0j0?ooo`<00000
X03oool00`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`0k0?ooo`<00000W`3o
ool00`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`0l0?ooo`<00000WP3oool0
0`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`0m0?ooo`<00000W@3oool00`00
0000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`0n0?ooo`<00000V`3oool2000000l0
oooo000P0?ooo`030000003oool0oooo03l0oooo0`00002K0?ooo`030000003oool0oooo00d0oooo
000<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0@03oool3000009X0oooo00<0
00000?ooo`3oool03@3oool000`0oooo1@00000?0?ooo`030000003oool0oooo0440oooo0`00002I
0?ooo`030000003oool0oooo00d0oooo000<0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`120?ooo`<00000V03oool00`000000oooo0?ooo`0=0?oo
o`003P3oool3000000l0oooo00<000000?ooo`3oool0@`3oool3000009L0oooo00<000000?ooo`3o
ool03@3oool000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo04@0oooo0`00002E0?ooo`8000003`3oool000`0oooo1@00000?0?ooo`030000003o
ool0oooo04D0oooo0`00002E0?ooo`030000003oool0oooo00d0oooo000P0?ooo`030000003oool0
oooo04H0oooo0`00002D0?ooo`030000003oool0oooo00d0oooo000@0?ooo`8000003P3oool00`00
0000oooo0?ooo`170?ooo`<00000T`3oool00`000000oooo0?ooo`0=0?ooo`003P3oool010000000
oooo00000000000>0?ooo`030000003oool0oooo04P0oooo0`00002B0?ooo`030000003oool0oooo
00d0oooo000>0?ooo`040000003oool00000000000h0oooo00<000000?ooo`3oool0B@3oool20000
0940oooo0P00000?0?ooo`003P3oool4000000h0oooo00<000000?ooo`3oool0BP3oool200000940
oooo00<000000?ooo`3oool03@3oool00140oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1:0?ooo`<00000T03oool00`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?oo
o`1;0?ooo`<00000S`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool200000080oooo00<00000
0?ooo`3oool0103oool3000000<0oooo00<000000?ooo`3oool0C03oool3000008h0oooo00<00000
0?ooo`3oool03@3oool000h0oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0C@3oool3000008d0oooo00<000000?ooo`3oool03@3o
ool000h0oooo00H000000?ooo`3oool000000?ooo`0000040?ooo`D000000`3oool2000004l0oooo
0`00002:0?ooo`<000003`3oool000h0oooo1@0000050?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0C`3oool2000008`0oooo00<000000?ooo`3oool03@3oool000h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo000000040?ooo`030000003oool0oooo0500oooo0P00
002;0?ooo`030000003oool0oooo00d0oooo000J0?ooo`800000103oool00`000000oooo0?ooo`1@
0?ooo`<00000RP3oool00`000000oooo0?ooo`0=0?ooo`003`3oool2000000l0oooo00<000000?oo
o`3oool0D@3oool3000008T0oooo00<000000?ooo`3oool03@3oool000h0oooo0P0000000`3oool0
00000?ooo`0=0?ooo`030000003oool0oooo0580oooo0`0000270?ooo`8000003`3oool000h0oooo
0P0000000`3oool000000?ooo`0=0?ooo`030000003oool0oooo05<0oooo0`0000270?ooo`030000
003oool0oooo00d0oooo000?0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0E03o
ool3000008H0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0E@3oool3
000008D0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0EP3oool20000
08D0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0E`3oool2000008@0
oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0E`3oool300000880oooo
0P00000?0?ooo`00803oool00`000000oooo0?ooo`1H0?ooo`<00000PP3oool00`000000oooo0?oo
o`0=0?ooo`00803oool00`000000oooo0?ooo`1I0?ooo`<00000P@3oool00`000000oooo0?ooo`0=
0?ooo`00803oool00`000000oooo0?ooo`1J0?ooo`<00000P03oool00`000000oooo0?ooo`0=0?oo
o`00303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0F`3oool200000800oooo00<000000?ooo`3oool03@3oool000`0oooo1P00000>0?ooo`030000
003oool0oooo05`0oooo0P00001n0?ooo`8000003`3oool000`0oooo00H000000?ooo`3oool00000
0?ooo`00000>0?ooo`030000003oool0oooo05`0oooo0`00001n0?ooo`030000003oool0oooo00d0
oooo000<0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0G@3oool3000007d0
oooo00<000000?ooo`3oool03@3oool000d0oooo0P0000000`3oool000000?ooo`0>0?ooo`030000
003oool0oooo05h0oooo0`00001l0?ooo`030000003oool0oooo00d0oooo000A0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0G`3oool3000007/0oooo00<000000?ooo`3oool03@3o
ool00200oooo00<000000?ooo`3oool0H03oool2000007/0oooo00<000000?ooo`3oool03@3oool0
0100oooo0P00000>0?ooo`030000003oool0oooo0640oooo0P00001i0?ooo`8000003`3oool000h0
oooo00@000000?ooo`00000000003P3oool00`000000oooo0?ooo`1Q0?ooo`<00000N@3oool00`00
0000oooo0?ooo`0=0?ooo`003P3oool010000000oooo00000000000>0?ooo`030000003oool0oooo
0680oooo0`00001h0?ooo`030000003oool0oooo00d0oooo000>0?ooo`@000003P3oool00`000000
oooo0?ooo`1S0?ooo`<00000M`3oool00`000000oooo0?ooo`0=0?ooo`004@3oool00`000000oooo
0?ooo`050?ooo`8000001@3oool00`000000oooo0?ooo`1T0?ooo`<00000MP3oool00`000000oooo
0?ooo`0=0?ooo`003P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0I@3oool2000007H0oooo00<000000?ooo`3oool03@3oool000d0oooo1000
000:0?ooo`030000003oool0oooo0080oooo0P00001W0?ooo`800000L`3oool3000000l0oooo000>
0?ooo`040000003oool0oooo000000L0oooo0P0000050?ooo`030000003oool0oooo06H0oooo0`00
001d0?ooo`030000003oool0oooo00d0oooo000>0?ooo`040000003oool0oooo000000L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1W0?ooo`<00000L`3oool00`000000oooo0?oo
o`0=0?ooo`003P3oool00`000000oooo000000080?ooo`<00000103oool00`000000oooo0?ooo`1X
0?ooo`<00000LP3oool00`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`1Y0?oo
o`<00000L@3oool00`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`1Z0?ooo`80
0000GP3oool00`000000oooo0?ooo`0?0?ooo`8000003`3oool00200oooo00<000000?ooo`3oool0
J`3oool2000005X0oooo1000000B0?ooo`030000003oool0oooo00d0oooo000>0?ooo`040000003o
ool0oooo000000h0oooo00<000000?ooo`3oool0J`3oool3000005H0oooo1P00000C0?ooo`030000
003oool0oooo00d0oooo000<0?ooo`030000003oool0000000<000003P3oool00`000000oooo0?oo
o`1/0?ooo`<00000DP3oool6000001H0oooo00<000000?ooo`3oool03@3oool00140oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1]0?ooo`@00000C@3oool6000001T0oooo00<00000
0?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0KP3oool4000004T0oooo1P00000L0?oo
o`030000003oool0oooo00d0oooo000P0?ooo`030000003oool0oooo0700oooo0`0000140?ooo`L0
00007P3oool2000000l0oooo000?0?ooo`8000003`3oool00`000000oooo0?ooo`1a0?ooo`<00000
@@3oool600000280oooo00<000000?ooo`3oool03@3oool000h0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`1b0?ooo`@00000?P3oool4000002D0oooo00<000000?ooo`3oool0
3@3oool000h0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`1c0?ooo`@00000
>`3oool4000002L0oooo00<000000?ooo`3oool03@3oool000l0oooo0P00000?0?ooo`030000003o
ool0oooo07D0oooo0`00000i0?ooo`@00000:03oool00`000000oooo0?ooo`0=0?ooo`00803oool0
0`000000oooo0?ooo`1f0?ooo`@00000=@3oool4000002T0oooo0P00000?0?ooo`00803oool00`00
0000oooo0?ooo`1g0?ooo`@00000<`3oool4000002/0oooo00<000000?ooo`3oool03@3oool00200
oooo00<000000?ooo`3oool0N@3oool300000300oooo1000000]0?ooo`030000003oool0oooo00d0
oooo000P0?ooo`030000003oool0oooo07X0oooo0`00000^0?ooo`@00000;P3oool00`000000oooo
0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`1k0?ooo`@00000:P3oool400000300oooo00<0
00000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0O03oool4000002P0oooo1000000a
0?ooo`030000003oool0oooo00d0oooo000P0?ooo`030000003oool0oooo07h0oooo1000000T0?oo
o`@00000<P3oool2000000l0oooo000P0?ooo`030000003oool0oooo07l0oooo1@00000Q0?ooo`@0
0000=03oool00`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`210?ooo`D00000
703oool5000003H0oooo00<000000?ooo`3oool03@3oool001P0oooo0`0000050?ooo`030000003o
ool0oooo08<0oooo1@00000H0?ooo`H00000=`3oool00`000000oooo0?ooo`0=0?ooo`00603oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo08D0oooo1P00000B0?ooo`H00000>P3o
ool00`000000oooo0?ooo`0=0?ooo`00603oool010000000oooo0?ooo`0000040?ooo`800000R03o
ool6000000d0oooo1`00000j0?ooo`<000003`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo08X0oooo1@0000080?ooo`L00000?`3oool00`000000oooo0?ooo`0=0?ooo`006@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo08`0oooo1@0000040?ooo`H00000@P3oool00`00
0000oooo0?ooo`0=0?ooo`006@3oool3000000@0oooo00<000000?ooo`3oool0SP3oool:000004D0
oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0T03oool6000004L0oooo
00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo00d0oooo000P0?ooo`030000003oool0oooo0=`0oooo0P00000?
0?ooo`00803oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00d0oooo000P0?ooo`03
0000003oool0oooo0=d0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0
g@3oool00`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`3M0?ooo`030000003o
ool0oooo00d0oooo000P0?ooo`030000003oool0oooo0=`0oooo0P00000?0?ooo`00803oool00`00
0000oooo0?ooo`3M0?ooo`030000003oool0oooo00d0oooo000P0?ooo`030000003oool0oooo0=d0
oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0g@3oool00`000000oooo
0?ooo`0=0?ooo`00803oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00d0oooo000P
0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?oo
o`3oool0g03oool2000000l0oooo000P0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3o
ool03@3oool00200oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0=0?ooo`00803o
ool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00d0oooo000P0?ooo`030000003oool0
oooo0=d0oooo00<000000?ooo`3oool03@3oool00200oooo00<000000?ooo`3oool0g03oool20000
00l0oooo000P0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool03@3oool00200oooo
00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0=0?ooo`00803oool00`000000oooo0?oo
o`3M0?ooo`030000003oool0oooo00d0oooo000J0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0g@3oool00`000000oooo0?ooo`0=0?ooo`006P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo000J0?ooo`030000003oool0oooo00<0ooooh@00000?0?ooo`00
6`3oool00`000000oooo0?ooo`3b0?ooo`00603oool010000000oooo0?ooo`00003d0?ooo`00603o
ool400000?@0oooo003o0?oooa40oooo0000\
\>"],
  ImageRangeCache->{{{0, 271.625}, {167.438, 0}} -> {-1.7174, 1.12082, \
0.0535203, 0.0360823}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0 0.0206011 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .10301 -6 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -12 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5625 -53 ]
[-0.01875 .30902 -12 53 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(10)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(15)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(20)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(25)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(30)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -132.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
114 10.2813 translate
90 rotate
-114 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Population) show
129.000 12.813 moveto
(Growth) show
165.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .59486 m
.16667 .59486 L
.25 .59128 L
.33333 .58878 L
.41667 .58703 L
.5 .34671 L
.58333 .13504 L
.66667 .12588 L
.75 .20507 L
.83333 .32823 L
.91667 .3483 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{272.625, 168.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004@0000Z2000`400?l00000o`00003oo`3ooolA
0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00R03oool3
000000@0oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool300000780oooo
00290?ooo`030000003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000001e0?ooo`00R@3oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`@00000LP3oool008T0oooo00<000000?ooo`3oool0
0`3oool200000080oooo0`0000000`3oool000000?ooo`020?ooo`800000L`3oool008L0oooo00D0
00000?ooo`000000oooo000000240?ooo`00Q`3oool5000000@0oooo00<000000?ooo`3oool0O@3o
ool00?l0oooo4@3oool00?l0oooo4@3oool00?l0oooo4@3oool004H0oooo1000000S0?ooo`<00000
8@3oool3000002<0oooo0P00000O0?ooo`D000000P3oool2000001d0oooo1@0000000`3oool00000
00000002000000P0oooo00160?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0803o
ool010000000oooo0?ooo`00000Q0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`00A`3oool00`000000oooo0?ooo`0Q0?ooo`D000008@3oool010000000oooo0?ooo`00000Q
0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`00B03o
ool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo00000280oooo0`00000S0?ooo`800000
8@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00160?ooo`040000003oool0oooo00000280
oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo0000
0200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00170?ooo`800000903oool2
000002<0oooo0`00000R0?ooo`800000803oool2000000@0oooo0P00000N0?ooo`800000103oool2
000000T0oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo000S
0?ooon400000303oool002<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool02P3oool002<0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0:0?ooo`008`3o
ool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0
oooo0=`0oooo0P00000<0?ooo`008`3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo
00X0oooo000S0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool02P3oool002<0oooo
00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?oo
o`3M0?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0oooo0=`0oooo0P00000<
0?ooo`008`3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00X0oooo000S0?ooo`03
0000003oool0oooo0=d0oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3oool0
g@3oool00`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`3L0?ooo`800000303o
ool002<0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0:0?ooo`008`3oool00`00
0000oooo0?ooo`3M0?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0oooo0=d0
oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3oool0g@3oool00`000000oooo
0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`3L0?ooo`800000303oool000T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0=d0oooo00<00000
0?ooo`3oool02P3oool000T0oooo1P00000D0?ooo`030000003oool0oooo0=d0oooo00<000000?oo
o`3oool02P3oool000T0oooo00H000000?ooo`3oool000000?ooo`00000=0?ooo`8000001@3oool0
0`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00X0oooo00090?ooo`040000003oool0oooo
000000h0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3M0?ooo`030000003o
ool0oooo00X0oooo000:0?ooo`8000004P3oool00`000000oooo0?ooo`020?ooo`800000g03oool3
000000`0oooo000L0?ooo`8000001@3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo
00X0oooo000L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0g@3oool00`000000
oooo0?ooo`0:0?ooo`00303oool2000000h0oooo0`0000040?ooo`030000003oool0oooo0=d0oooo
00<000000?ooo`3oool02P3oool000/0oooo00@000000?ooo`3oool00000503oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo04L0oooo0P00000<0?ooo`002`3oool010000000oooo0?oo
o`00000D0?ooo`030000003oool0oooo08T0oooo2`0000190?ooo`030000003oool0oooo00X0oooo
000<0?ooo`8000005@3oool00`000000oooo0?ooo`1o0?oooaH00000B03oool00`000000oooo0?oo
o`0:0?ooo`008`3oool00`000000oooo0?ooo`1n0?ooo`/000002P3oool3000004L0oooo00<00000
0?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo07h0oooo0P00000D0?ooo`<00000AP3oool00`000000oooo0?ooo`0:0?oo
o`002`3oool600000180oooo00<000000?ooo`3oool0OP3oool2000001D0oooo100000130?ooo`80
0000303oool000/0oooo00H000000?ooo`3oool000000?ooo`00000B0?ooo`030000003oool0oooo
07d0oooo0`00000F0?ooo`@00000@`3oool00`000000oooo0?ooo`0:0?ooo`002`3oool010000000
oooo0?ooo`00000D0?ooo`030000003oool0oooo07d0oooo0P00000I0?ooo`<00000@P3oool00`00
0000oooo0?ooo`0:0?ooo`00303oool2000001D0oooo00<000000?ooo`3oool0O03oool3000001X0
oooo0`0000110?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0oooo07`0oooo
0P00000L0?ooo`<00000?`3oool2000000`0oooo000;0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0O03oool2000001d0oooo0`00000o0?ooo`030000003oool0oooo00X0oooo000;
0?ooo`<000005@3oool00`000000oooo0?ooo`1k0?ooo`<000007P3oool3000003h0oooo00<00000
0?ooo`3oool02P3oool000h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1k0?oo
o`800000803oool3000003d0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`00
00005@3oool00`000000oooo0?ooo`1j0?ooo`<000008@3oool4000003/0oooo00<000000?ooo`3o
ool02P3oool000/0oooo1000000D0?ooo`030000003oool0oooo07X0oooo0P00000S0?ooo`@00000
>@3oool2000000`0oooo000>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0NP3o
ool2000002D0oooo0`00000i0?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003oool0
oooo07T0oooo0`00000V0?ooo`<00000>03oool00`000000oooo0?ooo`0:0?ooo`002@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo1@0000020?ooo`8000001@3oool00`00
0000oooo0?ooo`1i0?ooo`800000:03oool3000003L0oooo00<000000?ooo`3oool02P3oool000T0
oooo1P0000080?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo07T0oooo0P00000Y0?ooo`800000=`3oool00`000000oooo0?ooo`0:0?oo
o`003P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`800000N@3oool3000002X0oooo0P00000d0?ooo`<00000303oool001L0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0N03oool2000002`0oooo0P00000e0?ooo`030000003oool0oooo00X0oooo000G0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
07L0oooo0`00000]0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02P3oool001H0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1g0?ooo`800000;P3oool2000003@0
oooo00<000000?ooo`3oool02P3oool000d0oooo0P00000D0?ooo`030000003oool0oooo07L0oooo
0P00000_0?ooo`800000<P3oool2000000`0oooo000;0?ooo`040000003oool00000000001@0oooo
00<000000?ooo`3oool0MP3oool300000300oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0:0?ooo`002`3oool010000000oooo00000000000D0?ooo`030000003oool0oooo07H0oooo
0P00000a0?ooo`800000<P3oool00`000000oooo0?ooo`0:0?ooo`002`3oool4000001@0oooo00<0
00000?ooo`3oool0M@3oool300000380oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`003P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07D0oooo0P00000c
0?ooo`800000<@3oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo07D0oooo0P00000d0?ooo`800000;`3oool2000000`0oooo000:0?ooo`@0
00005@3oool00`000000oooo0?ooo`1d0?ooo`<00000=@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00X0oooo000;0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3o
ool0M03oool2000003H0oooo0P00000_0?ooo`030000003oool0oooo00X0oooo000;0?ooo`040000
003oool0oooo000001@0oooo00<000000?ooo`3oool0M03oool2000003L0oooo0P00000^0?ooo`03
0000003oool0oooo00X0oooo000;0?ooo`030000003oool0000001D0oooo00<000000?ooo`3oool0
L`3oool3000003P0oooo00<000000?ooo`3oool0:`3oool2000000`0oooo000S0?ooo`030000003o
ool0oooo07<0oooo0P00000i0?ooo`800000;@3oool00`000000oooo0?ooo`0:0?ooo`008`3oool0
0`000000oooo0?ooo`1b0?ooo`<00000>P3oool2000002`0oooo00<000000?ooo`3oool02P3oool0
02<0oooo00<000000?ooo`3oool0LP3oool2000003`0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0:0?ooo`002`3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo
0780oooo0P00000l0?ooo`800000:`3oool00`000000oooo0?ooo`0:0?ooo`002@3oool00`000000
oooo00000003000001@0oooo00<000000?ooo`3oool0L@3oool3000003d0oooo0P00000Y0?ooo`80
0000303oool000h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1a0?ooo`800000
?`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo000S0?ooo`030000003o
ool0oooo0740oooo0P00000o0?ooo`800000:@3oool00`000000oooo0?ooo`0:0?ooo`005@3oool5
00000080oooo0P0000050?ooo`030000003oool0oooo0700oooo0`0000100?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool02P3oool000`0oooo0P0000090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0700oooo0P000011
0?ooo`800000:03oool00`000000oooo0?ooo`0:0?ooo`002`3oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool200000700oooo0`000012
0?ooo`8000009@3oool3000000`0oooo000;0?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0K`3oool2000004@0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`00303oool2000000T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06l0oooo0P0000140?oo
o`8000009P3oool00`000000oooo0?ooo`0:0?ooo`005P3oool2000000@0oooo0`0000040?ooo`03
0000003oool0oooo06h0oooo0`0000150?ooo`8000009@3oool00`000000oooo0?ooo`0:0?ooo`00
2`3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo06h0oooo0P0000170?ooo`@0
00008@3oool2000000`0oooo000;0?ooo`@00000503oool00`000000oooo0?ooo`1]0?ooo`<00000
A`3oool8000001h0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`1]0?ooo`800000C03oool8000001X0oooo00<000000?ooo`3oool02P3o
ool000/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1]0?ooo`800000D03oool8
000001H0oooo00<000000?ooo`3oool02P3oool000`0oooo0`00000D0?ooo`030000003oool0oooo
06`0oooo0`00001D0?ooo`L000004`3oool00`000000oooo0?ooo`0:0?ooo`003P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo06`0oooo0P00001I0?ooo`@000004@3oool2000000`0
oooo000S0?ooo`030000003oool0oooo06`0oooo0P00001L0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3oool0J`3oool3000006l0oooo00<0
00000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3oool0J`3oool200000700oooo00<00000
0?ooo`3oool02P3oool002<0oooo00<000000?ooo`3oool0J`3oool200000700oooo00<000000?oo
o`3oool02P3oool002<0oooo00<000000?ooo`3oool0JP3oool3000006l0oooo0P00000<0?ooo`00
8`3oool00`000000oooo0?ooo`1Z0?ooo`800000L@3oool00`000000oooo0?ooo`0:0?ooo`008`3o
ool00`000000oooo0?ooo`1Z0?ooo`800000L@3oool00`000000oooo0?ooo`0:0?ooo`002P3oool4
000001D0oooo00<000000?ooo`3oool0J@3oool300000740oooo00<000000?ooo`3oool02P3oool0
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
06T0oooo0P00001a0?ooo`800000303oool000T0oooo00H000000?ooo`3oool000000?ooo`00000D
0?ooo`030000003oool0oooo06P0oooo0`00001b0?ooo`030000003oool0oooo00X0oooo00090?oo
o`030000003oool0oooo008000005@3oool00`000000oooo0?ooo`1X0?ooo`800000L`3oool00`00
0000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`060?ooo`@000000`3oool2000000D0
oooo00<000000?ooo`3oool0J03oool2000007<0oooo00<000000?ooo`3oool02P3oool001D0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06L0
oooo0`00001c0?ooo`030000003oool0oooo00X0oooo000;0?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`800000J03oool20000
0780oooo0`00000<0?ooo`002`3oool4000000P0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0I`3oool2000007@0oooo00<000000?oo
o`3oool02P3oool000/0oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0IP3oool3000007@0oooo00<0
00000?ooo`3oool02P3oool000/0oooo00@000000?ooo`3oool000001`3oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo06H0oooo0P00001e0?ooo`030000003oool0oooo00X0oooo000S
0?ooo`030000003oool0oooo06H0oooo0P00001d0?ooo`800000303oool002<0oooo00<000000?oo
o`3oool0I@3oool3000007D0oooo00<000000?ooo`3oool02P3oool000`0oooo0P00000E0?ooo`03
0000003oool0oooo06D0oooo0P00001f0?ooo`030000003oool0oooo00X0oooo000;0?ooo`040000
003oool0oooo000001@0oooo00<000000?ooo`3oool0I@3oool2000007H0oooo00<000000?ooo`3o
ool02P3oool000/0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`1T0?ooo`<0
0000MP3oool00`000000oooo0?ooo`0:0?ooo`00303oool2000001D0oooo00<000000?ooo`3oool0
I03oool2000007H0oooo0P00000<0?ooo`008`3oool00`000000oooo0?ooo`1T0?ooo`800000M`3o
ool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo06<0oooo0`00001g0?ooo`030000003oool0oooo00X0oooo000;0?ooo`<000005@3oool00`00
0000oooo0?ooo`1S0?ooo`800000N03oool00`000000oooo0?ooo`0:0?ooo`002`3oool010000000
oooo0?ooo`00000D0?ooo`030000003oool0oooo0680oooo0`00001h0?ooo`030000003oool0oooo
00X0oooo000<0?ooo`8000005@3oool00`000000oooo0?ooo`1R0?ooo`800000N03oool2000000`0
oooo000;0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool0HP3oool2000007T0
oooo00<000000?ooo`3oool02P3oool000/0oooo0`00000E0?ooo`030000003oool0oooo0640oooo
0`00001i0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0H@3oool2000007X0oooo00<000000?ooo`3oool02P3oool000X0oooo1000000E
0?ooo`030000003oool0oooo0640oooo0P00001i0?ooo`800000303oool000/0oooo00@000000?oo
o`3oool00000503oool00`000000oooo0?ooo`1P0?ooo`<00000NP3oool00`000000oooo0?ooo`0:
0?ooo`002`3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo0600oooo0P00001k
0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0000000L0oooo100000030?oo
o`8000001@3oool00`000000oooo0?ooo`1P0?ooo`800000N`3oool00`000000oooo0?ooo`0:0?oo
o`005@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0G`3oool3000007/0oooo00<000000?ooo`3oool02P3oool000T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool200000600oooo0P00001j0?ooo`<00000303oool000T0oooo1P0000080?ooo`030000
003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo05l0oooo0P00001l0?ooo`030000
003oool0oooo00X0oooo000;0?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05h0oooo0`00001l0?ooo`03
0000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`<00000
103oool00`000000oooo0?ooo`1N0?ooo`800000O@3oool00`000000oooo0?ooo`0:0?ooo`00303o
ool3000001@0oooo00<000000?ooo`3oool0GP3oool2000007d0oooo00<000000?ooo`3oool02P3o
ool000h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1M0?ooo`<00000O03oool2
000000`0oooo000S0?ooo`030000003oool0oooo05d0oooo0P00001n0?ooo`030000003oool0oooo
00X0oooo000S0?ooo`030000003oool0oooo05`0oooo0`00001n0?ooo`030000003oool0oooo00X0
oooo000S0?ooo`030000003oool0oooo05`0oooo0P00001o0?ooo`030000003oool0oooo00X0oooo
000S0?ooo`030000003oool0oooo05`0oooo0P00001n0?ooo`800000303oool002<0oooo00<00000
0?ooo`3oool0F`3oool3000007l0oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?oo
o`3oool0F`3oool200000800oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3o
ool0F`3oool200000800oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3oool0
FP3oool300000800oooo00<000000?ooo`3oool02P3oool002<0oooo00<000000?ooo`3oool0FP3o
ool200000800oooo0P00000<0?ooo`008`3oool00`000000oooo0?ooo`1J0?ooo`800000P@3oool0
0`000000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`0e0?ooobL00000P@3oool00`00
0000oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`0R0?ooocT00000PP3oool00`000000
oooo0?ooo`0:0?ooo`008`3oool00`000000oooo0?ooo`0>0?ooobL00000Y`3oool2000000`0oooo
000S0?ooo`030000003oool0oooo00h0oooo5000002k0?ooo`030000003oool0oooo00X0oooo000S
0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool02P3oool001H0oooo0P0000040?oo
o`8000001@3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00X0oooo000E0?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:
0?ooo`005`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3ooooQ
000000`0oooo000H0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0k`3oool0
01D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003a0?ooo`005P3oool2
000000@0oooo0P00003b0?ooo`00o`3ooolA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 271.625}, {167.438, 0}} -> {-1.87797, -5.27508, \
0.0535203, 0.216495}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0.0561849 0.561849 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21.5625 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .05618 -6 -4.5 ]
[-0.0125 .05618 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .28092 -18 -4.5 ]
[-0.0125 .28092 0 4.5 ]
[-0.0125 .39329 -18 -4.5 ]
[-0.0125 .39329 0 4.5 ]
[-0.0125 .50566 -18 -4.5 ]
[-0.0125 .50566 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -50 ]
[-0.01875 .30902 -18 50 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Time) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05618 m
.00625 .05618 L
s
[(0)] -0.0125 .05618 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.2)] -0.0125 .16855 1 0 Mshowa
0 .28092 m
.00625 .28092 L
s
[(0.4)] -0.0125 .28092 1 0 Mshowa
0 .39329 m
.00625 .39329 L
s
[(0.6)] -0.0125 .39329 1 0 Mshowa
0 .50566 m
.00625 .50566 L
s
[(0.8)] -0.0125 .50566 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .30902 m
.00375 .30902 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .42139 m
.00375 .42139 L
s
0 .44948 m
.00375 .44948 L
s
0 .47757 m
.00375 .47757 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
0 .58994 m
.00375 .58994 L
s
0 .02809 m
.00375 .02809 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
111 10.2813 translate
90 rotate
-111 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Working) show
111.000 12.813 moveto
(Children) show
159.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05618 m
1 .05618 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .28092 m
1 .28092 L
s
.99375 .39329 m
1 .39329 L
s
.99375 .50566 m
1 .50566 L
s
.125 Mabswid
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .44948 m
1 .44948 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.99625 .58994 m
1 .58994 L
s
.99625 .02809 m
1 .02809 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61475 L
.25 .61245 L
.33333 .61083 L
.41667 .60968 L
.5 .56877 L
.58333 .49189 L
.66667 .43263 L
.75 .41828 L
.83333 .44777 L
.91667 .47041 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{272.625, 168.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004@0000Z2000`400?l00000o`00003oo`3ooolA
0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00o`3ooolA0?ooo`00R`3oool3
000000@0oooo0`0000001`3oool000000000003oool000000?ooo`0000000P3oool3000006l0oooo
002<0?ooo`030000003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000001b0?ooo`00S03oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`@00000K`3oool008`0oooo00<000000?ooo`3oool0
0`3oool200000080oooo0`0000000`3oool000000?ooo`020?ooo`800000L03oool008X0oooo00D0
00000?ooo`000000oooo000000210?ooo`00RP3oool5000000@0oooo00<000000?ooo`3oool0NP3o
ool00?l0oooo4@3oool00?l0oooo4@3oool00?l0oooo4@3oool004T0oooo1000000S0?ooo`<00000
8@3oool3000002<0oooo0P00000O0?ooo`D000000P3oool2000001d0oooo1@0000000`3oool00000
00000002000000D0oooo00190?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0803o
ool010000000oooo0?ooo`00000Q0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`00BP3oool00`000000oooo0?ooo`0Q0?ooo`D000008@3oool010000000oooo0?ooo`00000Q
0?ooo`040000003oool0oooo00000200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`00B`3o
ool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo00000280oooo0`00000S0?ooo`800000
8@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00190?ooo`040000003oool0oooo00000280
oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0oooo0000
0200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo001:0?ooo`800000903oool2
000002<0oooo0`00000R0?ooo`800000803oool2000000@0oooo0P00000N0?ooo`800000103oool2
000000H0oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo003o0?oooa40oooo000V
0?ooon4000002@3oool002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`009P3o
ool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0
oooo0=d0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`00
0000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`3L0?ooo`8000002@3oool002H0oooo
00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?oo
o`3M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<00000
0?ooo`3oool01`3oool001l0oooo0P0000050?ooo`030000003oool0oooo0=d0oooo00<000000?oo
o`3oool01`3oool001h0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3M0?oo
o`030000003oool0oooo00L0oooo000N0?ooo`040000003oool0oooo000000@0oooo0P00003L0?oo
o`<000002@3oool001h0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3M0?oo
o`030000003oool0oooo00L0oooo000N0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0g@3oool00`000000oooo0?ooo`070?ooo`007`3oool2000000D0oooo00<000000?ooo`3o
ool0g@3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`3M0?ooo`030000
003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3o
ool002H0oooo00<000000?ooo`3oool0g03oool2000000T0oooo000V0?ooo`030000003oool0oooo
0=d0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`000000
oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo
00060?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?oo
o`070?ooo`001P3oool5000001/0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`07
0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0g@3oool00`000000oooo0?ooo`070?ooo`00203oool3000001/0oooo00<000000?ooo`3o
ool0g03oool2000000T0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo00060?ooo`D000006`3o
ool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0
oooo0=d0oooo00<000000?ooo`3oool01`3oool000T0oooo0P00000K0?ooo`030000003oool0oooo
0=d0oooo00<000000?ooo`3oool01`3oool000P0oooo00@000000?ooo`3oool000006P3oool00`00
0000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo00080?ooo`040000003oool0oooo0000
01X0oooo00<000000?ooo`3oool0g03oool2000000T0oooo00090?ooo`8000006`3oool00`000000
oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=d0oooo
00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?oo
o`070?ooo`00203oool010000000oooo0?ooo`0000070?ooo`800000103oool2000000<0oooo1000
00040?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3oool000P0oooo10000006
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3M0?ooo`030000003oool0oooo00L0oooo00080?ooo`040000003oool0oooo000000H0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`800000g03oool3000000T0oooo
00080?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3oool00180oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0=d0oooo00<000000?ooo`3oool01`3oool000H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool0g@3oool00`000000
oooo0?ooo`070?ooo`001P3oool6000001X0oooo00<000000?ooo`3oool0g@3oool00`000000oooo
0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0=d0oooo00<0
00000?ooo`3oool01`3oool000P0oooo1000000J0?ooo`030000003oool0oooo0=d0oooo00<00000
0?ooo`3oool01`3oool000P0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`3L
0?ooo`8000002@3oool002H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?oo
o`009P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000
003oool0oooo0=d0oooo00<000000?ooo`3oool01`3oool000P0oooo00@000000?ooo`3oool00000
6P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo00060?ooo`030000003o
ool0000000<000006P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000;
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0g03oool2000000T0oooo000V0?oo
o`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3oool000P0oooo00@000000?ooo`3o
ool000006P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo00080?ooo`@0
00006P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`00203o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3o
ool000T0oooo0`00000J0?ooo`030000003oool0oooo0=`0oooo0P0000090?ooo`002`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3oool002H0
oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`002@3oool200000080oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo
00080?ooo`060000003oool0oooo0000003oool000001@3oool2000000@0oooo0P0000050?ooo`<0
00000`3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo00080?ooo`060000
003oool0oooo0000003oool00000103oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`00203oool50000
00D0oooo00@000000?ooo`3oool00000203oool5000000<0oooo0P00003L0?ooo`<000002@3oool0
00P0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`004P3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0g@3o
ool00`000000oooo0?ooo`070?ooo`004`3oool2000000/0oooo0P0000040?ooo`030000003oool0
oooo0=d0oooo00<000000?ooo`3oool01`3oool002H0oooo00<000000?ooo`3oool0g@3oool00`00
0000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0
oooo000V0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3oool002H0oooo00<0
00000?ooo`3oool0g03oool2000000T0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<00000
0?ooo`3oool01`3oool000L0oooo1000000K0?ooo`030000003oool0oooo0=d0oooo00<000000?oo
o`3oool01`3oool000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3oool000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool0
1`3oool000H0oooo0P0000030?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0g@3o
ool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`3L0?ooo`8000002@3oool0
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0=d0oooo00<000000?ooo`3oool01`3oool000H0oooo1P00000J0?ooo`030000003oool0oooo0=d0
oooo00<000000?ooo`3oool01`3oool000P0oooo00@000000?ooo`3oool000006P3oool00`000000
oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo00080?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`002@3oool3000001X0oooo00<0
00000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`002`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0=`0oooo0P0000090?ooo`009P3oool00`000000oooo0?ooo`3M0?oo
o`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`3M0?ooo`03
0000003oool0oooo00L0oooo00060?ooo`030000003oool0000000<000006P3oool00`000000oooo
0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000;0?ooo`030000003oool0oooo00D0oooo0P00
00040?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?oo
o`070?ooo`004P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`070?ooo`004P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000@0oooo0P00003L0?ooo`<000002@3oool000H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000P0
oooo0`0000050?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool01`3oool000H0oooo
1P0000060?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo000;0?ooo`030000003oool0oooo00D0oooo
0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo00L0oooo
000V0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`070?ooo`009P3oool00`000000oooo0?ooo`2O0?ooo`X00000=03oool00`000000oooo0?ooo`07
0?ooo`009P3oool00`000000oooo0?ooo`2I0?oooa800000<@3oool2000000T0oooo00090?ooo`80
00006`3oool00`000000oooo0?ooo`2B0?ooo`d000002@3oool6000002l0oooo00<000000?ooo`3o
ool01`3oool000P0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`2A0?ooo`P0
00004@3oool6000002d0oooo00<000000?ooo`3oool01`3oool000H0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo08l0oooo1000000J0?ooo`H00000
:P3oool00`000000oooo0?ooo`070?ooo`001P3oool6000001X0oooo00<000000?ooo`3oool0SP3o
ool4000001d0oooo1P00000X0?ooo`030000003oool0oooo00L0oooo000;0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0S@3oool300000280oooo1P00000U0?ooo`030000003oool0
oooo00L0oooo000V0?ooo`030000003oool0oooo08/0oooo1000000U0?ooo`L000008@3oool20000
00T0oooo00080?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0RP3oool40000
02T0oooo2000000N0?ooo`030000003oool0oooo00L0oooo00080?ooo`@000006P3oool00`000000
oooo0?ooo`280?ooo`@00000;`3oool8000001X0oooo00<000000?ooo`3oool01`3oool000P0oooo
00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`270?ooo`@00000=03oool8000001H0
oooo00<000000?ooo`3oool01`3oool000P0oooo00@000000?ooo`3oool000006P3oool00`000000
oooo0?ooo`260?ooo`<00000>P3oool7000001<0oooo00<000000?ooo`3oool01`3oool002H0oooo
00<000000?ooo`3oool0Q03oool4000003l0oooo1000000B0?ooo`030000003oool0oooo00L0oooo
000V0?ooo`030000003oool0oooo08<0oooo100000130?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01`3oool000T0oooo0P00000K0?ooo`030000003oool0oooo0880oooo0`00001G
0?ooo`8000002@3oool000P0oooo0P0000000`3oool000000?ooo`0I0?ooo`030000003oool0oooo
0800oooo1000001I0?ooo`030000003oool0oooo00L0oooo00080?ooo`80000000<0oooo0000003o
ool06@3oool00`000000oooo0?ooo`1o0?ooo`@00000FP3oool00`000000oooo0?ooo`070?ooo`00
2@3oool00`000000oooo0000000J0?ooo`030000003oool0oooo07h0oooo0`00001L0?ooo`030000
003oool0oooo00L0oooo000C0?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003o
ool0oooo07d0oooo0`00001M0?ooo`030000003oool0oooo00L0oooo00080?ooo`040000003oool0
oooo000000H0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo07`0oooo0`00001N0?ooo`030000003oool0oooo00L0oooo00080?ooo`@00000
1P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo0P00001l0?oo
o`<00000G@3oool3000000T0oooo00080?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool000002@3oool2000000D0oooo00<000000?ooo`3oool0NP3oool300000600oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0N@3oool300000640oooo00<00000
0?ooo`3oool01`3oool000T0oooo0`0000070?ooo`8000002P3oool2000000D0oooo00<000000?oo
o`3oool0N03oool300000680oooo00<000000?ooo`3oool01`3oool000/0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`1g0?ooo`<00000H`3oool00`000000oooo0?ooo`070?ooo`00
9P3oool00`000000oooo0?ooo`1e0?ooo`@00000I03oool00`000000oooo0?ooo`070?ooo`009P3o
ool00`000000oooo0?ooo`1d0?ooo`@00000I03oool2000000T0oooo000V0?ooo`030000003oool0
oooo07<0oooo0`00001W0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo
0780oooo0`00001X0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0740
oooo0`00001Y0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0700oooo
0`00001Z0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo06l0oooo0`00
001[0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo06h0oooo0`00001[
0?ooo`8000002@3oool002H0oooo00<000000?ooo`3oool0K@3oool3000006d0oooo00<000000?oo
o`3oool01`3oool002H0oooo00<000000?ooo`3oool0J`3oool4000006h0oooo00<000000?ooo`3o
ool01`3oool002H0oooo00<000000?ooo`3oool0J@3oool5000006l0oooo00<000000?ooo`3oool0
1`3oool002H0oooo00<000000?ooo`3oool0I`3oool500000740oooo00<000000?ooo`3oool01`3o
ool002H0oooo00<000000?ooo`3oool0I@3oool5000007<0oooo00<000000?ooo`3oool01`3oool0
02H0oooo00<000000?ooo`3oool0HP3oool6000007D0oooo00<000000?ooo`3oool01`3oool002H0
oooo00<000000?ooo`3oool0H03oool6000007H0oooo0P0000090?ooo`009P3oool00`000000oooo
0?ooo`1N0?ooo`D00000NP3oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?oo
o`1L0?ooo`D00000O03oool00`000000oooo0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`1J
0?ooo`D00000OP3oool00`000000oooo0?ooo`070?ooo`007P3oool5000000<0oooo00<000000?oo
o`3oool0=@3ooolX00000800oooo00<000000?ooo`3oool01`3oool00200oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0ooooC00000080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00200oooo00<000000?ooo`3oool0
0`3ooooQ000000T0oooo000P0?ooo`030000003oool0oooo01@0oooo0P00003G0?ooo`00803oool0
0`000000oooo0?ooo`3]0?ooo`007`3oool200000>l0oooo003o0?oooa40oooo0000\
\>"],
  ImageRangeCache->{{{0, 271.625}, {167.438, 0}} -> {-2.03853, -0.293419, \
0.0535203, 0.00793812}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear[AxesLabel]\)], "Input"],

Cell[BoxData[
    \(Clear::"wrsym" \(\(:\)\(\ \)\) 
      "Symbol \!\(AxesLabel\) is Protected."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetDirectory["\<C:\Documents and Settings\doepke\My \
Documents\sync\mathematica\>"]\), "\[IndentingNewLine]", 
    \(\(Export["\<plot5dyn2.eps\>", 
        plot1, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<plot6dyn2.eps\>", plot3, "\<EPS\>"];\)\)}], "Input"],

Cell[BoxData[
    \("C:\\Documents and Settings\\doepke\\My \
Documents\\sync\\mathematica"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot5 = 
        ListPlot[etaout, PlotRange \[Rule] {{0, 12}, {0, 1}}, 
          PlotStyle \[Rule] Thickness[0.01], AxesOrigin \[Rule] {0, 0}, 
          AxesLabel \[Rule] "\<Time\>", Frame \[Rule] True];\)\)], "Input"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(plot5\)\" is similar to \
existing symbols \!\({plot5a, plot5b}\)."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 0 m
.16667 0 L
.25 0 L
.33333 0 L
.41667 .37082 L
.5 .61803 L
.58333 .61803 L
.66667 .43262 L
.75 .18541 L
.83333 .18541 L
.91667 .12361 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{366.75, 226.688},
  ImageMargins->{{213, 0}, {0, 30}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005^0000hR000`400?l00000o`00003oo`3ooom_
0?ooo`00C03oool4000003H0oooo0`00000c0?ooo`<00000=`3oool200000380oooo1@0000020?oo
o`800000;`3oool5000000030?ooo`0000000000008000000P3oool004`0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0b0?ooo`040000003oool0oooo000003D0oooo00@000000?oo
o`3oool00000<`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0;P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo001=0?ooo`030000003oool0oooo03@0oooo1@00
000c0?ooo`040000003oool0oooo000003D0oooo00@000000?ooo`3oool00000<`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo03<0oooo00@000000?ooo`3o
ool00000=03oool3000003L0oooo0P00000d0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool0
04`0oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0000000e0?ooo`030000003oool0
oooo03D0oooo00@000000?ooo`3oool00000<`3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0;P3oool01@000000oooo0?ooo`3oool000000080oooo0@0000010?ooo`40
oooo001=0?ooo`800000=`3oool2000003D0oooo0`00000f0?ooo`800000<`3oool2000000@0oooo
0P00000`0?ooo`800000103oool2000000<0oooo003o0?ooofl0oooo003o0?ooofl0oooo003o0?oo
ofl0oooo003o0?ooofl0oooo003o0?ooofl0oooo000a0?oooeL00000iP3oool001H0ooooo`00001C
000000H0oooo000F0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3ooomG0000
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0d0?ooo`@00000=@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo
0?ooo`1]0?ooo`<00000gP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?oo
o`1]0?ooo`<00000gP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1]
0?ooo`<00000gP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1]0?oo
o`<00000gP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1]0?ooo`@0
0000g@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1^0?ooo`<00000
g@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1^0?ooo`<00000g@3o
ool00`000000oooo0?ooo`040?ooo`005P3oool2000006l0oooo0`00003K0?ooo`<000001P3oool0
01H0oooo00<000000?ooo`3oool0KP3oool400000=`0oooo00<000000?ooo`3oool0103oool001H0
oooo00<000000?ooo`3oool0K`3oool300000=`0oooo00<000000?ooo`3oool0103oool001H0oooo
00<000000?ooo`3oool0K`3oool300000=`0oooo00<000000?ooo`3oool0103oool001H0oooo00<0
00000?ooo`3oool0K`3oool300000=`0oooo00<000000?ooo`3oool0103oool001H0oooo00<00000
0?ooo`3oool0K`3oool300000=`0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?oo
o`3oool0K`3oool400000=/0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3o
ool0L03oool300000=/0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0
L03oool300000=/0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0L03o
ool300000=/0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0L03oool4
00000=X0oooo00<000000?ooo`3oool0103oool001H0oooo0P00001b0?ooo`<00000f03oool30000
00H0oooo000F0?ooo`030000003oool0oooo0740oooo0`00003J0?ooo`030000003oool0oooo00@0
oooo000F0?ooo`030000003oool0oooo0740oooo0`00003J0?ooo`030000003oool0oooo00@0oooo
000F0?ooo`030000003oool0oooo0740oooo0`00003J0?ooo`030000003oool0oooo00@0oooo000F
0?ooo`030000003oool0oooo0740oooo1000003I0?ooo`030000003oool0oooo00@0oooo000F0?oo
o`030000003oool0oooo0780oooo0`00003I0?ooo`030000003oool0oooo00@0oooo000F0?ooo`03
0000003oool0oooo0780oooo0`00003I0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000
003oool0oooo0780oooo0`00003I0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003o
ool0oooo0780oooo1000003H0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0
oooo07<0oooo0`00003H0?ooo`030000003oool0oooo00@0oooo000F0?ooo`800000M03oool30000
0=H0oooo0`0000060?ooo`005P3oool00`000000oooo0?ooo`1c0?ooo`<00000f03oool00`000000
oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1c0?ooo`@00000e`3oool00`000000oooo
0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1d0?ooo`<00000e`3oool00`000000oooo0?oo
o`040?ooo`005P3oool00`000000oooo0?ooo`1d0?ooo`<00000e`3oool00`000000oooo0?ooo`04
0?ooo`005P3oool00`000000oooo0?ooo`1d0?ooo`<00000e`3oool00`000000oooo0?ooo`040?oo
o`005P3oool00`000000oooo0?ooo`1d0?ooo`<00000e`3oool00`000000oooo0?ooo`040?ooo`00
5P3oool00`000000oooo0?ooo`1d0?ooo`@00000eP3oool00`000000oooo0?ooo`040?ooo`005P3o
ool00`000000oooo0?ooo`1e0?ooo`<00000eP3oool00`000000oooo0?ooo`040?ooo`000P3oool2
000000@0oooo0P0000030?ooo`@000001@3oool00`000000oooo0?ooo`1e0?ooo`<00000eP3oool0
0`000000oooo0?ooo`040?ooo`0000D0oooo0000003oool0oooo000000080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0M@3oool300000;T0oooo0`00000J0?ooo`030000003oool0
oooo00@0oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool3
000007D0oooo1000002g0?ooo`@00000603oool3000000H0oooo00001@3oool000000?ooo`3oool0
000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1f0?ooo`<00000]P3oool5
000001X0oooo00<000000?ooo`3oool0103oool000050?ooo`000000oooo0?ooo`000000203oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo07H0oooo0`00002d0?ooo`D00000703o
ool00`000000oooo0?ooo`040?ooo`000P3oool2000000X0oooo0P0000060?ooo`030000003oool0
oooo07H0oooo0`00002c0?ooo`D000007@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`00
0000oooo0?ooo`1f0?ooo`<00000/@3oool6000001h0oooo00<000000?ooo`3oool0103oool001H0
oooo00<000000?ooo`3oool0MP3oool400000:l0oooo1@00000P0?ooo`030000003oool0oooo00@0
oooo000F0?ooo`030000003oool0oooo07L0oooo0`00002^0?ooo`D000008@3oool00`000000oooo
0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1g0?ooo`<00000[03oool5000002<0oooo00<0
00000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0M`3oool300000:/0oooo1@00000T
0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo07L0oooo1000002X0?oo
o`H000009@3oool00`000000oooo0?ooo`040?ooo`005P3oool2000007T0oooo0`00002W0?ooo`D0
00009@3oool3000000H0oooo000F0?ooo`030000003oool0oooo07P0oooo0`00002V0?ooo`D00000
:03oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1h0?ooo`<00000Y03o
ool5000002X0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0N03oool3
00000:<0oooo1@00000[0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo
07P0oooo1000002P0?ooo`H00000;03oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000
oooo0?ooo`1i0?ooo`<00000W`3oool5000002h0oooo00<000000?ooo`3oool0103oool001H0oooo
00<000000?ooo`3oool0N@3oool3000009h0oooo1@00000_0?ooo`030000003oool0oooo00@0oooo
000F0?ooo`030000003oool0oooo07T0oooo0`00002L0?ooo`D00000<@3oool00`000000oooo0?oo
o`040?ooo`005P3oool00`000000oooo0?ooo`1i0?ooo`@00000VP3oool500000380oooo00<00000
0?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0NP3oool3000007`0oooo8P00000c0?oo
o`030000003oool0oooo00@0oooo000F0?ooo`800000N`3oool3000007`0oooo8000000c0?ooo`<0
00001P3oool001H0oooo00<000000?ooo`3oool0NP3oool3000007/0oooo8000000f0?ooo`030000
003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo07X0oooo0`00001k0?ooo`<00000D`3o
ool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1j0?ooo`@00000NP3oool3
000005<0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0N`3oool30000
07T0oooo1000001C0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo07/0
oooo0`00001i0?ooo`<00000E03oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo
0?ooo`1k0?ooo`<00000N@3oool3000005@0oooo00<000000?ooo`3oool0103oool001H0oooo00<0
00000?ooo`3oool0N`3oool4000007L0oooo1000001D0?ooo`030000003oool0oooo00@0oooo000F
0?ooo`030000003oool0oooo07`0oooo0`00001g0?ooo`<00000E@3oool00`000000oooo0?ooo`04
0?ooo`005P3oool00`000000oooo0?ooo`1l0?ooo`<00000M`3oool3000005D0oooo00<000000?oo
o`3oool0103oool001H0oooo00<000000?ooo`3oool0O03oool3000007H0oooo1000001E0?ooo`03
0000003oool0oooo00@0oooo000F0?ooo`800000O@3oool3000007H0oooo0`00001D0?ooo`<00000
1P3oool001H0oooo00<000000?ooo`3oool0O03oool4000007D0oooo0`00001F0?ooo`030000003o
ool0oooo00@0oooo000F0?ooo`030000003oool0oooo07d0oooo0`00001d0?ooo`@00000EP3oool0
0`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`1m0?ooo`<00000M03oool30000
05L0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0O@3oool3000007@0
oooo0`00001G0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo07d0oooo
1000001b0?ooo`@00000E`3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?oo
o`1n0?ooo`<00000LP3oool3000005P0oooo00<000000?ooo`3oool0103oool001H0oooo00<00000
0?ooo`3oool0OP3oool300000780oooo0`00001H0?ooo`030000003oool0oooo00@0oooo00020?oo
o`800000103oool2000000D0oooo0`0000040?ooo`030000003oool0oooo07h0oooo0`00001a0?oo
o`@00000F03oool00`000000oooo0?ooo`040?ooo`0000D0oooo0000003oool0oooo0000000;0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0OP3oool300000740oooo0`00001I0?oo
o`030000003oool0oooo00@0oooo00001@3oool000000?ooo`3oool0000000P0oooo1@0000040?oo
o`<00000OP3oool400000700oooo0`00001G0?ooo`<000001P3oool000050?ooo`000000oooo0?oo
o`000000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo07l0oooo0`00001_
0?ooo`@00000F@3oool00`000000oooo0?ooo`040?ooo`0000D0oooo0000003oool0oooo00000009
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0O`3oool3000006l0oooo0`00001J
0?ooo`030000003oool0oooo00@0oooo00020?ooo`8000002`3oool2000000D0oooo00<000000?oo
o`3oool0O`3oool3000006l0oooo0`00001J0?ooo`030000003oool0oooo00@0oooo000F0?ooo`03
0000003oool0oooo07l0oooo1000001]0?ooo`@00000FP3oool00`000000oooo0?ooo`040?ooo`00
5P3oool00`000000oooo0?ooo`200?ooo`<00000K@3oool3000005/0oooo00<000000?ooo`3oool0
103oool001H0oooo00<000000?ooo`3oool0P03oool3000006d0oooo0`00001K0?ooo`030000003o
ool0oooo00@0oooo000F0?ooo`030000003oool0oooo0800oooo0`00001/0?ooo`@00000F`3oool0
0`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`200?ooo`<00000K03oool30000
05`0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0P03oool4000006/0
oooo0`00001L0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0840oooo
0`00001Z0?ooo`@00000G03oool00`000000oooo0?ooo`040?ooo`005P3oool200000880oooo0`00
001Z0?ooo`<00000F`3oool3000000H0oooo000F0?ooo`030000003oool0oooo0840oooo0`00001Z
0?ooo`<00000G@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`210?oo
o`@00000J03oool4000005d0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3o
ool0PP3oool3000006P0oooo0`00001N0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000
003oool0oooo0880oooo0`00001X0?ooo`<00000GP3oool00`000000oooo0?ooo`040?ooo`005P3o
ool00`000000oooo0?ooo`220?ooo`<00000I`3oool4000005h0oooo00<000000?ooo`3oool0103o
ool001H0oooo00<000000?ooo`3oool0PP3oool4000006H0oooo0`00001O0?ooo`030000003oool0
oooo00@0oooo000F0?ooo`030000003oool0oooo08<0oooo0`00001V0?ooo`<00000G`3oool00`00
0000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`230?ooo`<00000I@3oool4000005l0
oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0P`3oool3000006D0oooo
0`00001P0?ooo`030000003oool0oooo00@0oooo000F0?ooo`800000Q03oool3000006D0oooo0`00
001N0?ooo`<000001P3oool001H0oooo00<000000?ooo`3oool0P`3oool4000006<0oooo1000001P
0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo08@0oooo0`00001S0?oo
o`<00000H@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`240?ooo`<0
0000H`3oool300000640oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0
Q03oool300000680oooo1000001Q0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003o
ool0oooo08@0oooo1000001Q0?ooo`<00000HP3oool00`000000oooo0?ooo`040?ooo`005P3oool0
0`000000oooo0?ooo`250?ooo`<00000H@3oool300000680oooo00<000000?ooo`3oool0103oool0
01H0oooo00<000000?ooo`3oool0Q@3oool300000600oooo1000001R0?ooo`030000003oool0oooo
00@0oooo000F0?ooo`030000003oool0oooo08D0oooo0`00001P0?ooo`<00000H`3oool00`000000
oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`250?ooo`<00000H03oool3000006<0oooo
00<000000?ooo`3oool0103oool001H0oooo0P0000260?ooo`@00000GP3oool400000640oooo0`00
00060?ooo`005P3oool00`000000oooo0?ooo`260?ooo`<00000GP3oool3000006@0oooo00<00000
0?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0QP3oool3000005h0oooo0`00001T0?oo
o`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo08H0oooo0`00001M0?ooo`@0
0000I03oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`260?ooo`@00000
G03oool3000006D0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0Q`3o
ool3000005`0oooo0`00001U0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0
oooo08L0oooo0`00001K0?ooo`@00000I@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`00
0000oooo0?ooo`270?ooo`<00000F`3oool3000006H0oooo00<000000?ooo`3oool0103oool001H0
oooo00<000000?ooo`3oool0Q`3oool3000005/0oooo0`00001V0?ooo`030000003oool0oooo00@0
oooo00020?ooo`800000103oool2000000<0oooo0`0000060?ooo`030000003oool0oooo08L0oooo
1000001I0?ooo`@00000IP3oool00`000000oooo0?ooo`040?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0R03oool3000005T0
oooo0`00001W0?ooo`030000003oool0oooo00@0oooo00001@3oool000000?ooo`3oool0000000P0
oooo00@000000?ooo`3oool000001@3oool3000008P0oooo0`00001I0?ooo`<00000I@3oool30000
00H0oooo00001@3oool000000?ooo`3oool0000000P0oooo0`0000060?ooo`030000003oool0oooo
08P0oooo1000001G0?ooo`@00000I`3oool00`000000oooo0?ooo`040?ooo`0000D0oooo0000003o
ool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0R@3oool30000
05L0oooo0`00001X0?ooo`030000003oool0oooo00@0oooo00020?ooo`8000002P3oool3000000D0
oooo00<000000?ooo`3oool0R@3oool3000005L0oooo0`00001X0?ooo`030000003oool0oooo00@0
oooo000F0?ooo`030000003oool0oooo08T0oooo1000001E0?ooo`@00000J03oool00`000000oooo
0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`2:0?ooo`<00000E@3oool3000006T0oooo00<0
00000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0RP3oool3000005D0oooo0`00001Y
0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo08X0oooo1000001C0?oo
o`@00000J@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`2;0?ooo`<0
0000D`3oool3000006X0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0
R`3oool3000005<0oooo0`00001Z0?ooo`030000003oool0oooo00@0oooo000F0?ooo`800000S03o
ool400000540oooo1000001X0?ooo`<000001P3oool001H0oooo00<000000?ooo`3oool0S03oool3
00000540oooo0`00001[0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo
08`0oooo0`00001A0?ooo`<00000J`3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000
oooo0?ooo`2<0?ooo`@00000C`3oool4000006/0oooo00<000000?ooo`3oool0103oool001H0oooo
00<000000?ooo`3oool0S@3oool3000004l0oooo0`00001/0?ooo`030000003oool0oooo00@0oooo
000F0?ooo`030000003oool0oooo08d0oooo0`00001?0?ooo`<00000K03oool00`000000oooo0?oo
o`040?ooo`005P3oool00`000000oooo0?ooo`2=0?ooo`@00000C@3oool4000006`0oooo00<00000
0?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0SP3oool3000004d0oooo0`00001]0?oo
o`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo08h0oooo0`00001=0?ooo`<0
0000K@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`2>0?ooo`@00000
B`3oool4000006d0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0S`3o
ool3000004/0oooo0`00001^0?ooo`030000003oool0oooo00@0oooo000F0?ooo`800000T03oool3
000004/0oooo0`00001/0?ooo`<000001P3oool001H0oooo00<000000?ooo`3oool0S`3oool40000
04T0oooo1000001^0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0900
oooo0`0000190?ooo`<00000K`3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo
0?ooo`2@0?ooo`<00000B03oool4000006l0oooo00<000000?ooo`3oool0103oool001H0oooo00<0
00000?ooo`3oool0T03oool4000004L0oooo0`00001`0?ooo`030000003oool0oooo00@0oooo000F
0?ooo`030000003oool0oooo0940oooo0`0000170?ooo`<00000L03oool00`000000oooo0?ooo`04
0?ooo`005P3oool00`000000oooo0?ooo`2A0?ooo`<00000AP3oool400000700oooo00<000000?oo
o`3oool0103oool001H0oooo00<000000?ooo`3oool0T@3oool4000004D0oooo0`00001a0?ooo`03
0000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0980oooo0`0000140?ooo`@00000
L@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`2B0?ooo`<00000A03o
ool300000780oooo00<000000?ooo`3oool0103oool001H0oooo0P00002C0?ooo`@00000@P3oool4
00000700oooo0`0000060?ooo`005P3oool00`000000oooo0?ooo`2C0?ooo`<00000@P3oool30000
07<0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0T`3oool300000440
oooo1000001c0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo09<0oooo
100000100?ooo`<00000M03oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?oo
o`2D0?ooo`<00000?`3oool4000007@0oooo00<000000?ooo`3oool0103oool001H0oooo00<00000
0?ooo`3oool0U03oool3000003l0oooo0`00001e0?ooo`030000003oool0oooo00@0oooo000F0?oo
o`030000003oool0oooo09@0oooo1000000n0?ooo`<00000M@3oool00`000000oooo0?ooo`040?oo
o`005P3oool00`000000oooo0?ooo`2E0?ooo`<00000?@3oool4000007D0oooo00<000000?ooo`3o
ool0103oool00080oooo0P0000040?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool0
U@3oool3000003d0oooo0`00001f0?ooo`030000003oool0oooo00@0oooo00001@3oool000000?oo
o`3oool0000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2E0?ooo`@0
0000>`3oool4000007H0oooo00<000000?ooo`3oool0103oool000050?ooo`000000oooo0?ooo`00
0000203oool010000000oooo0?ooo`0000050?ooo`<00000UP3oool3000003/0oooo0`00001e0?oo
o`<000001P3oool000050?ooo`000000oooo0?ooo`0000002@3oool2000000H0oooo00<000000?oo
o`3oool0UP3oool3000003X0oooo1000001g0?ooo`030000003oool0oooo00@0oooo00001@3oool0
00000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2F
0?ooo`@00000>@3oool3000007P0oooo00<000000?ooo`3oool0103oool00080oooo0P00000:0?oo
o`8000001P3oool00`000000oooo0?ooo`2G0?ooo`<00000>03oool4000007P0oooo00<000000?oo
o`3oool0103oool001H0oooo00<000000?ooo`3oool0U`3oool3000003P0oooo0`00001i0?ooo`03
0000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo09L0oooo1000000f0?ooo`@00000
N@3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`2H0?ooo`<00000=P3o
ool3000007X0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0V03oool3
000003H0oooo0`00001j0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo
09P0oooo1000000d0?ooo`@00000NP3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000
oooo0?ooo`2I0?ooo`<00000=03oool3000007/0oooo00<000000?ooo`3oool0103oool001H0oooo
00<000000?ooo`3oool0V@3oool3000003<0oooo1000001k0?ooo`030000003oool0oooo00@0oooo
000F0?ooo`800000VP3oool400000380oooo0`00001j0?ooo`<000001P3oool001H0oooo00<00000
0?ooo`3oool0VP3oool300000340oooo1000001l0?ooo`030000003oool0oooo00@0oooo000F0?oo
o`030000003oool0oooo09X0oooo0`00000a0?ooo`<00000O@3oool00`000000oooo0?ooo`040?oo
o`005P3oool00`000000oooo0?ooo`2J0?ooo`@00000;`3oool4000007d0oooo00<000000?ooo`3o
ool0103oool001H0oooo00<000000?ooo`3oool0V`3oool3000002l0oooo0`00001n0?ooo`030000
003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo09/0oooo0`00000_0?ooo`<00000OP3o
ool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`2K0?ooo`@00000;@3oool4
000007h0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0W03oool30000
02d0oooo0`00001o0?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo09`0
oooo0`00000/0?ooo`@00000O`3oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo
0?ooo`2L0?ooo`@00000:`3oool300000800oooo00<000000?ooo`3oool0103oool001H0oooo0P00
002N0?ooo`<00000:P3oool4000007h0oooo0`0000060?ooo`005P3oool00`000000oooo0?ooo`2M
0?ooo`<00000:P3oool300000840oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?oo
o`3oool0W@3oool4000002P0oooo100000210?ooo`030000003oool0oooo00@0oooo000F0?ooo`03
0000003oool0oooo09h0oooo0`00000X0?ooo`<00000PP3oool00`000000oooo0?ooo`040?ooo`00
5P3oool00`000000oooo0?ooo`2N0?ooo`<000009`3oool400000880oooo00<000000?ooo`3oool0
103oool001H0oooo00<000000?ooo`3oool0WP3oool4000002H0oooo0`0000230?ooo`030000003o
ool0oooo00@0oooo000F0?ooo`030000003oool0oooo09l0oooo0`00000V0?ooo`<00000P`3oool0
0`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`2O0?ooo`<000009@3oool40000
08<0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool0W`3oool4000002@0
oooo0`0000240?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000003oool0oooo0:00oooo
0`00000S0?ooo`@00000Q03oool00`000000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?oo
o`2P0?ooo`<000008`3oool3000008D0oooo00<000000?ooo`3oool0103oool001H0oooo0P00002Q
0?ooo`@000008@3oool4000008<0oooo0`0000060?ooo`005P3oool00`000000oooo0?ooo`2Q0?oo
o`<000008@3oool3000008H0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3o
ool0X@3oool300000200oooo100000260?ooo`030000003oool0oooo00@0oooo000F0?ooo`030000
003oool0oooo0:40oooo1000000O0?ooo`<00000Q`3oool00`000000oooo0?ooo`040?ooo`005P3o
ool00`000000oooo0?ooo`2R0?ooo`<000007P3oool4000008L0oooo00<000000?ooo`3oool0103o
ool001H0oooo00<000000?ooo`3oool0XP3oool3000001h0oooo0`0000280?ooo`030000003oool0
oooo00@0oooo000F0?ooo`030000003oool0oooo0:80oooo1000000M0?ooo`<00000R03oool00`00
0000oooo0?ooo`040?ooo`005P3oool00`000000oooo0?ooo`2S0?ooo`<00000703oool4000008P0
oooo00<000000?ooo`3oool0103oool000d0oooo1@0000040?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0c0?ooo`<00000703oool3000001T0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00@0oooo
000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00T0oooo8P00000;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo000?
0?ooo`030000003oool0oooo00@0ooooo`00001C000000H0oooo000?0?ooo`030000003oool0oooo
0:/0oooo8000002A0?ooo`003`3oool00`000000oooo0?ooo`3o0?oooed0oooo000>0?ooo`800000
o`3ooomO0?ooo`00o`3ooom_0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 365.75}, {225.688, 0}} -> {-0.810131, -0.0635039, \
0.0356592, 0.00480815}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowSize->{897, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 38, 0, 95, "Title"],
Cell[1817, 55, 112, 3, 80, "Subtitle"],
Cell[1932, 60, 119, 2, 50, "Input"],

Cell[CellGroupData[{
Cell[2076, 66, 65, 0, 73, "Section"],
Cell[2144, 68, 43, 0, 33, "Text"],
Cell[2190, 70, 607, 12, 250, "Input"],
Cell[2800, 84, 127, 3, 33, "Text"],
Cell[2930, 89, 208, 4, 90, "Input"],
Cell[3141, 95, 133, 3, 30, "Input"],
Cell[3277, 100, 382, 6, 71, "Text"],
Cell[3662, 108, 203, 4, 90, "Input"],
Cell[3868, 114, 241, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4146, 123, 43, 0, 73, "Section"],
Cell[4192, 125, 36, 0, 33, "Text"],
Cell[4231, 127, 86, 1, 30, "Input"],
Cell[4320, 130, 89, 2, 33, "Text"],
Cell[4412, 134, 437, 10, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4886, 149, 67, 0, 73, "Section"],
Cell[4956, 151, 116, 3, 33, "Text"],
Cell[5075, 156, 8763, 152, 1914, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13875, 313, 64, 0, 73, "Section"],
Cell[13942, 315, 216, 4, 52, "Text"],
Cell[14161, 321, 5445, 86, 1670, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19643, 412, 73, 0, 73, "Section"],
Cell[19719, 414, 613, 10, 142, "Text"],
Cell[20335, 426, 2401, 43, 710, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22773, 474, 48, 0, 73, "Section"],
Cell[22824, 476, 6458, 110, 1912, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29319, 591, 73, 0, 73, "Section"],
Cell[29395, 593, 548, 11, 190, "Input"],

Cell[CellGroupData[{
Cell[29968, 608, 47, 1, 30, "Input"],
Cell[30018, 611, 89, 1, 29, "Output"]
}, Open  ]],
Cell[30122, 615, 50, 1, 30, "Input"],
Cell[30175, 618, 62, 0, 33, "Text"],
Cell[30240, 620, 214, 4, 90, "Input"],

Cell[CellGroupData[{
Cell[30479, 628, 859, 18, 130, "Input"],

Cell[CellGroupData[{
Cell[31363, 650, 23908, 746, 177, 7130, 534, "GraphicsData", "PostScript", \
"Graphics"],
Cell[55274, 1398, 24131, 720, 177, 6759, 501, "GraphicsData", "PostScript", \
"Graphics"],
Cell[79408, 2120, 23274, 664, 177, 6296, 450, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[102731, 2790, 302, 6, 50, "Input"],
Cell[103036, 2798, 22999, 730, 186, 7241, 531, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126072, 3533, 49, 1, 30, "Input"],
Cell[126124, 3536, 111, 2, 22, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126272, 3543, 482, 9, 110, "Input"],
Cell[126757, 3554, 105, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126899, 3561, 243, 4, 50, "Input"],
Cell[127145, 3567, 20787, 579, 186, 4455, 373, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147969, 4151, 244, 4, 50, "Input"],
Cell[148216, 4157, 185, 3, 22, "Message"],
Cell[148404, 4162, 22444, 599, 265, 4470, 373, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[170897, 4767, 97, 2, 73, "Section"],
Cell[170997, 4771, 51, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[171073, 4776, 1224, 24, 190, "Input"],

Cell[CellGroupData[{
Cell[172322, 4804, 28009, 948, 186, 10487, 727, "GraphicsData", "PostScript", \
"Graphics"],
Cell[200334, 5754, 31303, 1017, 186, 10885, 760, "GraphicsData", \
"PostScript", "Graphics"],
Cell[231640, 6773, 29218, 945, 186, 10434, 709, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[260907, 7724, 377, 7, 90, "Input"],
Cell[261287, 7733, 105, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261429, 7740, 857, 18, 130, "Input"],

Cell[CellGroupData[{
Cell[262311, 7762, 22057, 666, 177, 6383, 468, "GraphicsData", "PostScript", \
"Graphics"],
Cell[284371, 8430, 24547, 725, 177, 6758, 501, "GraphicsData", "PostScript", \
"Graphics"],
Cell[308921, 9157, 22330, 652, 177, 6296, 450, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[331300, 9815, 49, 1, 30, "Input"],
Cell[331352, 9818, 111, 2, 22, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[331500, 9825, 296, 5, 70, "Input"],
Cell[331799, 9832, 105, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[331941, 9839, 242, 4, 50, "Input"],
Cell[332186, 9845, 190, 3, 22, "Message"],
Cell[332379, 9850, 26363, 648, 265, 4450, 373, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

